/* Xtensa configuration-specific ISA information.

   Copyright (c) 2003-2019 Tensilica Inc.

   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
   "Software"), to deal in the Software without restriction, including
   without limitation the rights to use, copy, modify, merge, publish,
   distribute, sublicense, and/or sell copies of the Software, and to
   permit persons to whom the Software is furnished to do so, subject to
   the following conditions:

   The above copyright notice and this permission notice shall be included
   in all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
   IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
   CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
   TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  */

#include "ansidecl.h"
#include <xtensa-isa.h>
#include "xtensa-isa-internal.h"


/* Sysregs.  */

static xtensa_sysreg_internal sysregs[] = {
  { "LBEG", 0, 0 },
  { "LEND", 1, 0 },
  { "LCOUNT", 2, 0 },
  { "BR", 4, 0 },
  { "MMID", 89, 0 },
  { "DDR", 104, 0 },
  { "CONFIGID0", 176, 0 },
  { "CONFIGID1", 208, 0 },
  { "INTERRUPT", 226, 0 },
  { "INTCLEAR", 227, 0 },
  { "CCOUNT", 234, 0 },
  { "PRID", 235, 0 },
  { "ICOUNT", 236, 0 },
  { "CCOMPARE0", 240, 0 },
  { "CCOMPARE1", 241, 0 },
  { "CCOMPARE2", 242, 0 },
  { "VECBASE", 231, 0 },
  { "EPC1", 177, 0 },
  { "EPC2", 178, 0 },
  { "EPC3", 179, 0 },
  { "EPC4", 180, 0 },
  { "EPC5", 181, 0 },
  { "EPC6", 182, 0 },
  { "EPC7", 183, 0 },
  { "EXCSAVE1", 209, 0 },
  { "EXCSAVE2", 210, 0 },
  { "EXCSAVE3", 211, 0 },
  { "EXCSAVE4", 212, 0 },
  { "EXCSAVE5", 213, 0 },
  { "EXCSAVE6", 214, 0 },
  { "EXCSAVE7", 215, 0 },
  { "EPS2", 194, 0 },
  { "EPS3", 195, 0 },
  { "EPS4", 196, 0 },
  { "EPS5", 197, 0 },
  { "EPS6", 198, 0 },
  { "EPS7", 199, 0 },
  { "EXCCAUSE", 232, 0 },
  { "DEPC", 192, 0 },
  { "EXCVADDR", 238, 0 },
  { "WINDOWBASE", 72, 0 },
  { "WINDOWSTART", 73, 0 },
  { "MECR", 110, 0 },
  { "MEPC", 106, 0 },
  { "MEPS", 107, 0 },
  { "MESAVE", 108, 0 },
  { "MEVADDR", 111, 0 },
  { "MESR", 109, 0 },
  { "MEMCTL", 97, 0 },
  { "SAR", 3, 0 },
  { "PS", 230, 0 },
  { "INTENABLE", 228, 0 },
  { "DBREAKA0", 144, 0 },
  { "DBREAKC0", 160, 0 },
  { "DBREAKA1", 145, 0 },
  { "DBREAKC1", 161, 0 },
  { "IBREAKA0", 128, 0 },
  { "IBREAKA1", 129, 0 },
  { "IBREAKENABLE", 96, 0 },
  { "ICOUNTLEVEL", 237, 0 },
  { "DEBUGCAUSE", 233, 0 },
  { "PREFCTL", 40, 0 },
  { "CPENABLE", 224, 0 },
  { "SCOMPARE1", 12, 0 },
  { "ATOMCTL", 99, 0 },
  { "THREADPTR", 231, 1 },
  { "AE_OVF_SAR", 240, 1 },
  { "AE_BITHEAD", 241, 1 },
  { "AE_TS_FTS_BU_BP", 242, 1 },
  { "AE_CW_SD_NO", 243, 1 },
  { "AE_CBEGIN0", 246, 1 },
  { "AE_CEND0", 247, 1 },
  { "FCR", 232, 1 },
  { "FSR", 233, 1 }
};

#define NUM_SYSREGS 74
#define MAX_SPECIAL_REG 242
#define MAX_USER_REG 247


/* Processor states.  */

static xtensa_state_internal states[] = {
  { "LCOUNT", 32, 0 },
  { "PC", 32, 0 },
  { "ICOUNT", 32, 0 },
  { "DDR", 32, 0 },
  { "INTERRUPT", 21, 0 },
  { "CCOUNT", 32, 0 },
  { "XTSYNC", 1, 0 },
  { "VECBASE", 22, 0 },
  { "EPC1", 32, 0 },
  { "EPC2", 32, 0 },
  { "EPC3", 32, 0 },
  { "EPC4", 32, 0 },
  { "EPC5", 32, 0 },
  { "EPC6", 32, 0 },
  { "EPC7", 32, 0 },
  { "EXCSAVE1", 32, 0 },
  { "EXCSAVE2", 32, 0 },
  { "EXCSAVE3", 32, 0 },
  { "EXCSAVE4", 32, 0 },
  { "EXCSAVE5", 32, 0 },
  { "EXCSAVE6", 32, 0 },
  { "EXCSAVE7", 32, 0 },
  { "EPS2", 13, 0 },
  { "EPS3", 13, 0 },
  { "EPS4", 13, 0 },
  { "EPS5", 13, 0 },
  { "EPS6", 13, 0 },
  { "EPS7", 13, 0 },
  { "EXCCAUSE", 6, 0 },
  { "PSINTLEVEL", 4, 0 },
  { "PSUM", 1, 0 },
  { "PSWOE", 1, 0 },
  { "PSEXCM", 1, 0 },
  { "DEPC", 32, 0 },
  { "EXCVADDR", 32, 0 },
  { "WindowBase", 4, 0 },
  { "WindowStart", 16, 0 },
  { "PSCALLINC", 2, 0 },
  { "PSOWB", 4, 0 },
  { "MECR", 7, XTENSA_STATE_IS_SHARED_OR },
  { "MEPC", 32, 0 },
  { "MEPS", 13, 0 },
  { "MESAVE", 32, 0 },
  { "MEVADDR", 32, 0 },
  { "MESRErrEnab", 1, 0 },
  { "MESRErrTest", 1, 0 },
  { "MESRMemE", 1, 0 },
  { "MESRDME", 1, 0 },
  { "MESRMemType", 4, 0 },
  { "MESRAccType", 2, 0 },
  { "MESRErrType", 2, 0 },
  { "MESRWay", 2, 0 },
  { "MESRDataExc", 1, 0 },
  { "MESRInstExc", 1, 0 },
  { "MESRRCE", 1, 0 },
  { "MESRDLCE", 1, 0 },
  { "MESRILCE", 1, 0 },
  { "LBEG", 32, 0 },
  { "LEND", 32, 0 },
  { "MEMCTL", 24, 0 },
  { "SAR", 6, 0 },
  { "THREADPTR", 32, 0 },
  { "InOCDMode", 1, 0 },
  { "INTENABLE", 21, 0 },
  { "DBREAKA0", 32, 0 },
  { "DBREAKC0", 8, 0 },
  { "DBREAKA1", 32, 0 },
  { "DBREAKC1", 8, 0 },
  { "IBREAKA0", 32, 0 },
  { "IBREAKA1", 32, 0 },
  { "IBREAKENABLE", 2, 0 },
  { "ICOUNTLEVEL", 4, 0 },
  { "DEBUGCAUSE", 6, 0 },
  { "DBNUM", 4, 0 },
  { "CCOMPARE0", 32, 0 },
  { "CCOMPARE1", 32, 0 },
  { "CCOMPARE2", 32, 0 },
  { "PREFCTL", 9, 0 },
  { "CPENABLE", 2, 0 },
  { "SCOMPARE1", 32, 0 },
  { "ATOMCTL", 6, 0 },
  { "AE_OVERFLOW", 1, XTENSA_STATE_IS_SHARED_OR },
  { "AE_CBEGIN0", 32, 0 },
  { "AE_CEND0", 32, 0 },
  { "AE_SAR", 7, 0 },
  { "AE_CWRAP", 1, 0 },
  { "AE_BITHEAD", 32, 0 },
  { "AE_BITPTR", 4, 0 },
  { "AE_BITSUSED", 4, 0 },
  { "AE_TABLESIZE", 4, 0 },
  { "AE_FIRST_TS", 4, 0 },
  { "AE_NEXTOFFSET", 27, 0 },
  { "AE_SEARCHDONE", 1, 0 },
  { "RoundMode", 2, 0 },
  { "InvalidEnable", 1, 0 },
  { "DivZeroEnable", 1, 0 },
  { "OverflowEnable", 1, 0 },
  { "UnderflowEnable", 1, 0 },
  { "InexactEnable", 1, 0 },
  { "InvalidFlag", 1, XTENSA_STATE_IS_SHARED_OR },
  { "DivZeroFlag", 1, XTENSA_STATE_IS_SHARED_OR },
  { "OverflowFlag", 1, XTENSA_STATE_IS_SHARED_OR },
  { "UnderflowFlag", 1, XTENSA_STATE_IS_SHARED_OR },
  { "InexactFlag", 1, XTENSA_STATE_IS_SHARED_OR },
  { "FPreserved20", 20, 0 },
  { "FPreserved20a", 20, 0 },
  { "FPreserved5", 5, 0 },
  { "FPreserved7", 7, 0 }
};

#define NUM_STATES 108

enum xtensa_state_id {
  STATE_LCOUNT,
  STATE_PC,
  STATE_ICOUNT,
  STATE_DDR,
  STATE_INTERRUPT,
  STATE_CCOUNT,
  STATE_XTSYNC,
  STATE_VECBASE,
  STATE_EPC1,
  STATE_EPC2,
  STATE_EPC3,
  STATE_EPC4,
  STATE_EPC5,
  STATE_EPC6,
  STATE_EPC7,
  STATE_EXCSAVE1,
  STATE_EXCSAVE2,
  STATE_EXCSAVE3,
  STATE_EXCSAVE4,
  STATE_EXCSAVE5,
  STATE_EXCSAVE6,
  STATE_EXCSAVE7,
  STATE_EPS2,
  STATE_EPS3,
  STATE_EPS4,
  STATE_EPS5,
  STATE_EPS6,
  STATE_EPS7,
  STATE_EXCCAUSE,
  STATE_PSINTLEVEL,
  STATE_PSUM,
  STATE_PSWOE,
  STATE_PSEXCM,
  STATE_DEPC,
  STATE_EXCVADDR,
  STATE_WindowBase,
  STATE_WindowStart,
  STATE_PSCALLINC,
  STATE_PSOWB,
  STATE_MECR,
  STATE_MEPC,
  STATE_MEPS,
  STATE_MESAVE,
  STATE_MEVADDR,
  STATE_MESRErrEnab,
  STATE_MESRErrTest,
  STATE_MESRMemE,
  STATE_MESRDME,
  STATE_MESRMemType,
  STATE_MESRAccType,
  STATE_MESRErrType,
  STATE_MESRWay,
  STATE_MESRDataExc,
  STATE_MESRInstExc,
  STATE_MESRRCE,
  STATE_MESRDLCE,
  STATE_MESRILCE,
  STATE_LBEG,
  STATE_LEND,
  STATE_MEMCTL,
  STATE_SAR,
  STATE_THREADPTR,
  STATE_InOCDMode,
  STATE_INTENABLE,
  STATE_DBREAKA0,
  STATE_DBREAKC0,
  STATE_DBREAKA1,
  STATE_DBREAKC1,
  STATE_IBREAKA0,
  STATE_IBREAKA1,
  STATE_IBREAKENABLE,
  STATE_ICOUNTLEVEL,
  STATE_DEBUGCAUSE,
  STATE_DBNUM,
  STATE_CCOMPARE0,
  STATE_CCOMPARE1,
  STATE_CCOMPARE2,
  STATE_PREFCTL,
  STATE_CPENABLE,
  STATE_SCOMPARE1,
  STATE_ATOMCTL,
  STATE_AE_OVERFLOW,
  STATE_AE_CBEGIN0,
  STATE_AE_CEND0,
  STATE_AE_SAR,
  STATE_AE_CWRAP,
  STATE_AE_BITHEAD,
  STATE_AE_BITPTR,
  STATE_AE_BITSUSED,
  STATE_AE_TABLESIZE,
  STATE_AE_FIRST_TS,
  STATE_AE_NEXTOFFSET,
  STATE_AE_SEARCHDONE,
  STATE_RoundMode,
  STATE_InvalidEnable,
  STATE_DivZeroEnable,
  STATE_OverflowEnable,
  STATE_UnderflowEnable,
  STATE_InexactEnable,
  STATE_InvalidFlag,
  STATE_DivZeroFlag,
  STATE_OverflowFlag,
  STATE_UnderflowFlag,
  STATE_InexactFlag,
  STATE_FPreserved20,
  STATE_FPreserved20a,
  STATE_FPreserved5,
  STATE_FPreserved7
};


/* Field definitions.  */

static unsigned
Field_t_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_t_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_s_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_s_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_r_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_r_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_op2_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 8) >> 28);
  return tie_t;
}

static void
Field_op2_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00000) | (tie_t << 20);
}

static unsigned
Field_op1_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 12) >> 28);
  return tie_t;
}

static void
Field_op1_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0000) | (tie_t << 16);
}

static unsigned
Field_op0_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_op0_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_n_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 26) >> 30);
  return tie_t;
}

static void
Field_n_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x30) | (tie_t << 4);
}

static unsigned
Field_m_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 24) >> 30);
  return tie_t;
}

static void
Field_m_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0xc0) | (tie_t << 6);
}

static unsigned
Field_sr_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_sr_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
  tie_t = (val << 24) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_st_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_st_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
  tie_t = (val << 24) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_thi3_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 24) >> 29);
  return tie_t;
}

static void
Field_thi3_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0xe0) | (tie_t << 5);
}

static unsigned
Field_inst_15_12_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_inst_15_12_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_inst_11_8_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_inst_11_8_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_inst_7_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 24) >> 31);
  return tie_t;
}

static void
Field_inst_7_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x80) | (tie_t << 7);
}

static unsigned
Field_inst_7_4_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_inst_7_4_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_inst_5_4_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 26) >> 30);
  return tie_t;
}

static void
Field_inst_5_4_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x30) | (tie_t << 4);
}

static unsigned
Field_inst_7_6_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 24) >> 30);
  return tie_t;
}

static void
Field_inst_7_6_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0xc0) | (tie_t << 6);
}

static unsigned
Field_inst_4_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 27) >> 31);
  return tie_t;
}

static void
Field_inst_4_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x10) | (tie_t << 4);
}

static unsigned
Field_inst_9_8_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 22) >> 30);
  return tie_t;
}

static void
Field_inst_9_8_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x300) | (tie_t << 8);
}

static unsigned
Field_inst_12_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 19) >> 31);
  return tie_t;
}

static void
Field_inst_12_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x1000) | (tie_t << 12);
}

static unsigned
Field_inst_19_17_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 12) >> 29);
  return tie_t;
}

static void
Field_inst_19_17_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0xe0000) | (tie_t << 17);
}

static unsigned
Field_inst_19_18_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 12) >> 30);
  return tie_t;
}

static void
Field_inst_19_18_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0xc0000) | (tie_t << 18);
}

static unsigned
Field_op0_Slot_inst16a_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_op0_Slot_inst16a_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_t_Slot_inst16b_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_t_Slot_inst16b_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_r_Slot_inst16b_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_r_Slot_inst16b_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_op0_Slot_inst16b_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_op0_Slot_inst16b_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_z_Slot_inst16b_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 25) >> 31);
  return tie_t;
}

static void
Field_z_Slot_inst16b_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x40) | (tie_t << 6);
}

static unsigned
Field_i_Slot_inst16b_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 24) >> 31);
  return tie_t;
}

static void
Field_i_Slot_inst16b_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x80) | (tie_t << 7);
}

static unsigned
Field_s_Slot_inst16b_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_s_Slot_inst16b_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_fld_ae_slot2_0_19_0_Slot_ae_slot2_0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 20) | ((insn[0] << 12) >> 12);
  return tie_t;
}

static void
Field_fld_ae_slot2_0_19_0_Slot_ae_slot2_0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 12) >> 12;
  insn[0] = (insn[0] & ~0xfffff) | (tie_t << 0);
}

static unsigned
Field_fld_ae_slot2_0_19_13_Slot_ae_slot2_0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 7) | ((insn[0] << 12) >> 25);
  return tie_t;
}

static void
Field_fld_ae_slot2_0_19_13_Slot_ae_slot2_0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 25) >> 25;
  insn[0] = (insn[0] & ~0xfe000) | (tie_t << 13);
}

static unsigned
Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 12) >> 24);
  return tie_t;
}

static void
Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0xff000) | (tie_t << 12);
}

static unsigned
Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_fld_ae_slot2_0_19_14_Slot_ae_slot2_0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 6) | ((insn[0] << 12) >> 26);
  return tie_t;
}

static void
Field_fld_ae_slot2_0_19_14_Slot_ae_slot2_0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 26) >> 26;
  insn[0] = (insn[0] & ~0xfc000) | (tie_t << 14);
}

static unsigned
Field_fld_ae_slot1_19_0_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 20) | ((insn[0] << 12) >> 12);
  return tie_t;
}

static void
Field_fld_ae_slot1_19_0_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 12) >> 12;
  insn[0] = (insn[0] & ~0xfffff) | (tie_t << 0);
}

static unsigned
Field_fld_ae_slot1_19_14_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 6) | ((insn[0] << 12) >> 26);
  return tie_t;
}

static void
Field_fld_ae_slot1_19_14_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 26) >> 26;
  insn[0] = (insn[0] & ~0xfc000) | (tie_t << 14);
}

static unsigned
Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 12) >> 24);
  return tie_t;
}

static void
Field_fld_ae_slot1_19_12_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0xff000) | (tie_t << 12);
}

static unsigned
Field_fld_ae_slot1_9_8_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 22) >> 30);
  return tie_t;
}

static void
Field_fld_ae_slot1_9_8_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x300) | (tie_t << 8);
}

static unsigned
Field_fld_ae_slot1_7_4_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_fld_ae_slot1_7_4_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_fld_ae_slot1_3_3_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 28) >> 31);
  return tie_t;
}

static void
Field_fld_ae_slot1_3_3_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x8) | (tie_t << 3);
}

static unsigned
Field_fld_ae_slot1_0_0_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 31) >> 31);
  return tie_t;
}

static void
Field_fld_ae_slot1_0_0_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x1) | (tie_t << 0);
}

static unsigned
Field_fld_ae_slot0_19_16_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 12) >> 28);
  return tie_t;
}

static void
Field_fld_ae_slot0_19_16_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0000) | (tie_t << 16);
}

static unsigned
Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 12) >> 24);
  return tie_t;
}

static void
Field_fld_ae_slot0_19_12_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0xff000) | (tie_t << 12);
}

static unsigned
Field_fld_ae_slot0_19_17_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 12) >> 29);
  return tie_t;
}

static void
Field_fld_ae_slot0_19_17_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0xe0000) | (tie_t << 17);
}

static unsigned
Field_fld_ae_slot0_19_0_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 20) | ((insn[0] << 12) >> 12);
  return tie_t;
}

static void
Field_fld_ae_slot0_19_0_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 12) >> 12;
  insn[0] = (insn[0] & ~0xfffff) | (tie_t << 0);
}

static unsigned
Field_fld_ae_slot0_19_14_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 6) | ((insn[0] << 12) >> 26);
  return tie_t;
}

static void
Field_fld_ae_slot0_19_14_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 26) >> 26;
  insn[0] = (insn[0] & ~0xfc000) | (tie_t << 14);
}

static unsigned
Field_fld_ae_slot0_6_5_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 25) >> 30);
  return tie_t;
}

static void
Field_fld_ae_slot0_6_5_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x60) | (tie_t << 5);
}

static unsigned
Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 24) >> 31);
  return tie_t;
}

static void
Field_fld_ae_slot0_7_7_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x80) | (tie_t << 7);
}

static unsigned
Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_fld_ae_slot0_7_4_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_fld_ae_slot0_19_7_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 13) | ((insn[0] << 12) >> 19);
  return tie_t;
}

static void
Field_fld_ae_slot0_19_7_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 19) >> 19;
  insn[0] = (insn[0] & ~0xfff80) | (tie_t << 7);
}

static unsigned
Field_fld_ae_slot0_4_0_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 5) | ((insn[0] << 27) >> 27);
  return tie_t;
}

static void
Field_fld_ae_slot0_4_0_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 27) >> 27;
  insn[0] = (insn[0] & ~0x1f) | (tie_t << 0);
}

static unsigned
Field_fld_ae_slot0_11_8_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_fld_ae_slot0_11_8_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_fld_ae_slot0_4_2_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 27) >> 29);
  return tie_t;
}

static void
Field_fld_ae_slot0_4_2_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x1c) | (tie_t << 2);
}

static unsigned
Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 27) >> 31);
  return tie_t;
}

static void
Field_fld_ae_slot0_4_4_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x10) | (tie_t << 4);
}

static unsigned
Field_fld_ae_slot0_5_4_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 26) >> 30);
  return tie_t;
}

static void
Field_fld_ae_slot0_5_4_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x30) | (tie_t << 4);
}

static unsigned
Field_fld_ae_slot2_1_18_0_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 19) | ((insn[0] << 13) >> 13);
  return tie_t;
}

static void
Field_fld_ae_slot2_1_18_0_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 13) >> 13;
  insn[0] = (insn[0] & ~0x7ffff) | (tie_t << 0);
}

static unsigned
Field_fld_ae_slot2_1_18_16_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 13) >> 29);
  return tie_t;
}

static void
Field_fld_ae_slot2_1_18_16_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x70000) | (tie_t << 16);
}

static unsigned
Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 7) | ((insn[0] << 13) >> 25);
  return tie_t;
}

static void
Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 25) >> 25;
  insn[0] = (insn[0] & ~0x7f000) | (tie_t << 12);
}

static unsigned
Field_fld_ae_slot2_1_7_4_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_fld_ae_slot2_1_7_4_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_fld_ae_slot2_1_9_8_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 22) >> 30);
  return tie_t;
}

static void
Field_fld_ae_slot2_1_9_8_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x300) | (tie_t << 8);
}

static unsigned
Field_fld_ae_slot2_1_8_8_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 23) >> 31);
  return tie_t;
}

static void
Field_fld_ae_slot2_1_8_8_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x100) | (tie_t << 8);
}

static unsigned
Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 11) | ((insn[0] << 13) >> 21);
  return tie_t;
}

static void
Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 21) >> 21;
  insn[0] = (insn[0] & ~0x7ff00) | (tie_t << 8);
}

static unsigned
Field_fld_ae_slot2_1_1_0_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 30) >> 30);
  return tie_t;
}

static void
Field_fld_ae_slot2_1_1_0_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x3) | (tie_t << 0);
}

static unsigned
Field_fld_ae_slot2_1_0_0_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 31) >> 31);
  return tie_t;
}

static void
Field_fld_ae_slot2_1_0_0_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x1) | (tie_t << 0);
}

static unsigned
Field_fld_ae2_slot1_23_0_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 24) | ((insn[0] << 8) >> 8);
  return tie_t;
}

static void
Field_fld_ae2_slot1_23_0_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 8) >> 8;
  insn[0] = (insn[0] & ~0xffffff) | (tie_t << 0);
}

static unsigned
Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 8) >> 28);
  return tie_t;
}

static void
Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00000) | (tie_t << 20);
}

static unsigned
Field_fld_ae2_slot1_18_16_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 13) >> 29);
  return tie_t;
}

static void
Field_fld_ae2_slot1_18_16_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x70000) | (tie_t << 16);
}

static unsigned
Field_fld_ae2_slot1_7_7_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 24) >> 31);
  return tie_t;
}

static void
Field_fld_ae2_slot1_7_7_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x80) | (tie_t << 7);
}

static unsigned
Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 8) >> 24);
  return tie_t;
}

static void
Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0xff0000) | (tie_t << 16);
}

static unsigned
Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 20) >> 24);
  return tie_t;
}

static void
Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0xff0) | (tie_t << 4);
}

static unsigned
Field_fld_ae2_slot1_13_11_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 18) >> 29);
  return tie_t;
}

static void
Field_fld_ae2_slot1_13_11_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x3800) | (tie_t << 11);
}

static unsigned
Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_fld_ae2_slot1_7_3_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 5) | ((insn[0] << 24) >> 27);
  return tie_t;
}

static void
Field_fld_ae2_slot1_7_3_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 27) >> 27;
  insn[0] = (insn[0] & ~0xf8) | (tie_t << 3);
}

static unsigned
Field_fld_ae2_slot1_1_0_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 30) >> 30);
  return tie_t;
}

static void
Field_fld_ae2_slot1_1_0_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x3) | (tie_t << 0);
}

static unsigned
Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 16) | ((insn[0] << 0) >> 16);
  return tie_t;
}

static void
Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 16) >> 16;
  insn[0] = (insn[0] & ~0xffff0000) | (tie_t << 16);
}

static unsigned
Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 20) | ((insn[0] << 0) >> 12);
  return tie_t;
}

static void
Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 12) >> 12;
  insn[0] = (insn[0] & ~0xfffff000) | (tie_t << 12);
}

static unsigned
Field_fld_ae2_slot0_31_17_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 15) | ((insn[0] << 0) >> 17);
  return tie_t;
}

static void
Field_fld_ae2_slot0_31_17_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 17) >> 17;
  insn[0] = (insn[0] & ~0xfffe0000) | (tie_t << 17);
}

static unsigned
Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 25) | ((insn[0] << 0) >> 7);
  return tie_t;
}

static void
Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 7) >> 7;
  insn[0] = (insn[0] & ~0xffffff80) | (tie_t << 7);
}

static unsigned
Field_fld_ae2_slot0_6_0_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 7) | ((insn[0] << 25) >> 25);
  return tie_t;
}

static void
Field_fld_ae2_slot0_6_0_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 25) >> 25;
  insn[0] = (insn[0] & ~0x7f) | (tie_t << 0);
}

static unsigned
Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 0) >> 30);
  return tie_t;
}

static void
Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0xc0000000) | (tie_t << 30);
}

static unsigned
Field_fld_ae2_slot0_11_4_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 20) >> 24);
  return tie_t;
}

static void
Field_fld_ae2_slot0_11_4_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0xff0) | (tie_t << 4);
}

static unsigned
Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 20) >> 31);
  return tie_t;
}

static void
Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x800) | (tie_t << 11);
}

static unsigned
Field_fld_ae2_slot0_9_8_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 22) >> 30);
  return tie_t;
}

static void
Field_fld_ae2_slot0_9_8_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x300) | (tie_t << 8);
}

static unsigned
Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 17) | ((insn[0] << 0) >> 15);
  return tie_t;
}

static void
Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 15) >> 15;
  insn[0] = (insn[0] & ~0xffff8000) | (tie_t << 15);
}

static unsigned
Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 25) >> 29);
  return tie_t;
}

static void
Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x70) | (tie_t << 4);
}

static unsigned
Field_fld_ae2_slot0_4_0_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 5) | ((insn[0] << 27) >> 27);
  return tie_t;
}

static void
Field_fld_ae2_slot0_4_0_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 27) >> 27;
  insn[0] = (insn[0] & ~0x1f) | (tie_t << 0);
}

static unsigned
Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 27) >> 31);
  return tie_t;
}

static void
Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x10) | (tie_t << 4);
}

static unsigned
Field_fld_ae2_slot0_4_2_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 27) >> 29);
  return tie_t;
}

static void
Field_fld_ae2_slot0_4_2_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x1c) | (tie_t << 2);
}

static unsigned
Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 24) >> 31);
  return tie_t;
}

static void
Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x80) | (tie_t << 7);
}

static unsigned
Field_fld_ae2_slot0_14_12_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 17) >> 29);
  return tie_t;
}

static void
Field_fld_ae2_slot0_14_12_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x7000) | (tie_t << 12);
}

static unsigned
Field_fld_ae2_slot0_5_4_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 26) >> 30);
  return tie_t;
}

static void
Field_fld_ae2_slot0_5_4_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x30) | (tie_t << 4);
}

static unsigned
Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_fld_ae2_slot0_8_8_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 23) >> 31);
  return tie_t;
}

static void
Field_fld_ae2_slot0_8_8_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x100) | (tie_t << 8);
}

static unsigned
Field_fld_ae2_slot0_1_0_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 30) >> 30);
  return tie_t;
}

static void
Field_fld_ae2_slot0_1_0_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x3) | (tie_t << 0);
}

static unsigned
Field_fld_ae2_slot0_0_0_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 31) >> 31);
  return tie_t;
}

static void
Field_fld_ae2_slot0_0_0_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x1) | (tie_t << 0);
}

static unsigned
Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 13) >> 29);
  return tie_t;
}

static void
Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x70000) | (tie_t << 16);
}

static unsigned
Field_fld_ae_minislot2_18_0_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 19) | ((insn[0] << 13) >> 13);
  return tie_t;
}

static void
Field_fld_ae_minislot2_18_0_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 13) >> 13;
  insn[0] = (insn[0] & ~0x7ffff) | (tie_t << 0);
}

static unsigned
Field_fld_ae_minislot2_11_4_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 20) >> 24);
  return tie_t;
}

static void
Field_fld_ae_minislot2_11_4_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0xff0) | (tie_t << 4);
}

static unsigned
Field_fld_ae_minislot2_9_8_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 22) >> 30);
  return tie_t;
}

static void
Field_fld_ae_minislot2_9_8_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x300) | (tie_t << 8);
}

static unsigned
Field_fld_ae_minislot2_3_0_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_fld_ae_minislot2_3_0_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_fld_ae_minislot2_18_8_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 11) | ((insn[0] << 13) >> 21);
  return tie_t;
}

static void
Field_fld_ae_minislot2_18_8_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 21) >> 21;
  insn[0] = (insn[0] & ~0x7ff00) | (tie_t << 8);
}

static unsigned
Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_fld_ae_minislot1_0_0_Slot_ae_minislot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 31) >> 31);
  return tie_t;
}

static void
Field_fld_ae_minislot1_0_0_Slot_ae_minislot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x1) | (tie_t << 0);
}

static unsigned
Field_fld_ae_minislot0_16_0_Slot_ae_minislot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 17) | ((insn[0] << 15) >> 15);
  return tie_t;
}

static void
Field_fld_ae_minislot0_16_0_Slot_ae_minislot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 15) >> 15;
  insn[0] = (insn[0] & ~0x1ffff) | (tie_t << 0);
}

static unsigned
Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 5) | ((insn[0] << 15) >> 27);
  return tie_t;
}

static void
Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 27) >> 27;
  insn[0] = (insn[0] & ~0x1f000) | (tie_t << 12);
}

static unsigned
Field_fld_ae_minislot0_16_8_Slot_ae_minislot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 9) | ((insn[0] << 15) >> 23);
  return tie_t;
}

static void
Field_fld_ae_minislot0_16_8_Slot_ae_minislot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 23) >> 23;
  insn[0] = (insn[0] & ~0x1ff00) | (tie_t << 8);
}

static unsigned
Field_fld_ae_minislot0_16_10_Slot_ae_minislot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 7) | ((insn[0] << 15) >> 25);
  return tie_t;
}

static void
Field_fld_ae_minislot0_16_10_Slot_ae_minislot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 25) >> 25;
  insn[0] = (insn[0] & ~0x1fc00) | (tie_t << 10);
}

static unsigned
Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_fld_xt_flix64_slot2_15_8_Slot_xt_flix64_slot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 16) >> 24);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot2_15_8_Slot_xt_flix64_slot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0xff00) | (tie_t << 8);
}

static unsigned
Field_fld_xt_flix64_slot2_3_3_Slot_xt_flix64_slot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 28) >> 31);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot2_3_3_Slot_xt_flix64_slot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x8) | (tie_t << 3);
}

static unsigned
Field_fld_xt_flix64_slot2_7_4_Slot_xt_flix64_slot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot2_7_4_Slot_xt_flix64_slot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_fld_xt_flix64_slot2_15_0_Slot_xt_flix64_slot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 16) | ((insn[0] << 16) >> 16);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot2_15_0_Slot_xt_flix64_slot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 16) >> 16;
  insn[0] = (insn[0] & ~0xffff) | (tie_t << 0);
}

static unsigned
Field_fld_xt_flix64_slot2_15_13_Slot_xt_flix64_slot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 16) >> 29);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot2_15_13_Slot_xt_flix64_slot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0xe000) | (tie_t << 13);
}

static unsigned
Field_fld_xt_dummy_0_0_Slot_xt_dummy_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 31) >> 31);
  return tie_t;
}

static void
Field_fld_xt_dummy_0_0_Slot_xt_dummy_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x1) | (tie_t << 0);
}

static unsigned
Field_fld_xt_flix64_slot1_19_8_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 12) | ((insn[0] << 12) >> 20);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot1_19_8_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 20) >> 20;
  insn[0] = (insn[0] & ~0xfff00) | (tie_t << 8);
}

static unsigned
Field_fld_xt_flix64_slot1_19_16_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 12) >> 28);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot1_19_16_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0000) | (tie_t << 16);
}

static unsigned
Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 12) >> 24);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0xff000) | (tie_t << 12);
}

static unsigned
Field_fld_xt_flix64_slot1_19_17_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 12) >> 29);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot1_19_17_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0xe0000) | (tie_t << 17);
}

static unsigned
Field_fld_xt_flix64_slot1_19_18_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 12) >> 30);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot1_19_18_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0xc0000) | (tie_t << 18);
}

static unsigned
Field_fld_xt_flix64_slot1_3_0_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot1_3_0_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_fld_xt_flix64_slot1_7_4_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot1_7_4_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_fld_xt_flix64_slot1_19_0_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 20) | ((insn[0] << 12) >> 12);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot1_19_0_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 12) >> 12;
  insn[0] = (insn[0] & ~0xfffff) | (tie_t << 0);
}

static unsigned
Field_fld_xt_flix64_slot1_19_13_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 7) | ((insn[0] << 12) >> 25);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot1_19_13_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 25) >> 25;
  insn[0] = (insn[0] & ~0xfe000) | (tie_t << 13);
}

static unsigned
Field_fld_xt_flix64_slot0_20_8_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 13) | ((insn[0] << 11) >> 19);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot0_20_8_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 19) >> 19;
  insn[0] = (insn[0] & ~0x1fff00) | (tie_t << 8);
}

static unsigned
Field_fld_xt_flix64_slot0_20_16_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 5) | ((insn[0] << 11) >> 27);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot0_20_16_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 27) >> 27;
  insn[0] = (insn[0] & ~0x1f0000) | (tie_t << 16);
}

static unsigned
Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 9) | ((insn[0] << 11) >> 23);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 23) >> 23;
  insn[0] = (insn[0] & ~0x1ff000) | (tie_t << 12);
}

static unsigned
Field_fld_xt_flix64_slot0_20_17_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 11) >> 28);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot0_20_17_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0x1e0000) | (tie_t << 17);
}

static unsigned
Field_fld_xt_flix64_slot0_20_20_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 11) >> 31);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot0_20_20_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x100000) | (tie_t << 20);
}

static unsigned
Field_fld_xt_flix64_slot0_7_4_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot0_7_4_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_fld_xt_flix64_slot0_20_0_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 21) | ((insn[0] << 11) >> 11);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot0_20_0_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 11) >> 11;
  insn[0] = (insn[0] & ~0x1fffff) | (tie_t << 0);
}

static unsigned
Field_fld_xt_flix64_slot0_3_0_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot0_3_0_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_fld_xt_flix64_slot0_20_5_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 16) | ((insn[0] << 11) >> 16);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot0_20_5_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 16) >> 16;
  insn[0] = (insn[0] & ~0x1fffe0) | (tie_t << 5);
}

static unsigned
Field_fld_xt_flix64_slot0_20_13_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 11) >> 24);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot0_20_13_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0x1fe000) | (tie_t << 13);
}

static unsigned
Field_fld_xt_flix64_slot3_30_6_Slot_xt_flix64_slot3_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 25) | ((insn[0] << 1) >> 7);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot3_30_6_Slot_xt_flix64_slot3_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 7) >> 7;
  insn[0] = (insn[0] & ~0x7fffffc0) | (tie_t << 6);
}

static unsigned
Field_fld_xt_flix64_slot3_5_0_Slot_xt_flix64_slot3_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 6) | ((insn[0] << 26) >> 26);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot3_5_0_Slot_xt_flix64_slot3_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 26) >> 26;
  insn[0] = (insn[0] & ~0x3f) | (tie_t << 0);
}

static unsigned
Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 5) | ((insn[0] << 1) >> 27);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 27) >> 27;
  insn[0] = (insn[0] & ~0x7c000000) | (tie_t << 26);
}

static unsigned
Field_fld_xt_flix64_slot3_7_4_Slot_xt_flix64_slot3_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot3_7_4_Slot_xt_flix64_slot3_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_fld_xt_flix64_slot3_30_27_Slot_xt_flix64_slot3_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 1) >> 28);
  return tie_t;
}

static void
Field_fld_xt_flix64_slot3_30_27_Slot_xt_flix64_slot3_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0x78000000) | (tie_t << 27);
}

static unsigned
Field_t_Slot_inst16a_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_t_Slot_inst16a_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_t_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_t_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_t_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_t_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_t_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_t_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_t_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_t_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_t_Slot_xt_flix64_slot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_t_Slot_xt_flix64_slot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_t_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_t_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_t_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_t_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_t_Slot_xt_flix64_slot3_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_t_Slot_xt_flix64_slot3_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_bbi4_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 19) >> 31);
  return tie_t;
}

static void
Field_bbi4_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x1000) | (tie_t << 12);
}

static unsigned
Field_bbi_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 19) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_bbi_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x1000) | (tie_t << 12);
}

static unsigned
Field_bbi_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 21) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_bbi_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x400) | (tie_t << 10);
}

static unsigned
Field_bbi_Slot_xt_flix64_slot3_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 5) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_bbi_Slot_xt_flix64_slot3_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x4000000) | (tie_t << 26);
}

static unsigned
Field_imm12_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 12) | ((insn[0] << 8) >> 20);
  return tie_t;
}

static void
Field_imm12_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 20) >> 20;
  insn[0] = (insn[0] & ~0xfff000) | (tie_t << 12);
}

static unsigned
Field_imm8_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 8) >> 24);
  return tie_t;
}

static void
Field_imm8_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0xff0000) | (tie_t << 16);
}

static unsigned
Field_imm8_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 16) >> 24);
  return tie_t;
}

static void
Field_imm8_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0xff00) | (tie_t << 8);
}

static unsigned
Field_imm8_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 16) >> 24);
  return tie_t;
}

static void
Field_imm8_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0xff00) | (tie_t << 8);
}

static unsigned
Field_imm8_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 16) >> 24);
  return tie_t;
}

static void
Field_imm8_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0xff00) | (tie_t << 8);
}

static unsigned
Field_imm8_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 16) >> 24);
  return tie_t;
}

static void
Field_imm8_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0xff00) | (tie_t << 8);
}

static unsigned
Field_imm8_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 16) >> 24);
  return tie_t;
}

static void
Field_imm8_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0xff00) | (tie_t << 8);
}

static unsigned
Field_s_Slot_inst16a_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_s_Slot_inst16a_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_s_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_s_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_s_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_s_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_s_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_s_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_s_Slot_ae_minislot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_s_Slot_ae_minislot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_s_Slot_xt_flix64_slot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_s_Slot_xt_flix64_slot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_s_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_s_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_s_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_s_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_s_Slot_xt_flix64_slot3_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_s_Slot_xt_flix64_slot3_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_imm12b_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  tie_t = (tie_t << 8) | ((insn[0] << 8) >> 24);
  return tie_t;
}

static void
Field_imm12b_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 24) >> 24;
  insn[0] = (insn[0] & ~0xff0000) | (tie_t << 16);
  tie_t = (val << 20) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_imm12b_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 16) >> 24);
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_imm12b_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
  tie_t = (val << 20) >> 24;
  insn[0] = (insn[0] & ~0xff00) | (tie_t << 8);
}

static unsigned
Field_imm12b_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 16) >> 24);
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_imm12b_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
  tie_t = (val << 20) >> 24;
  insn[0] = (insn[0] & ~0xff00) | (tie_t << 8);
}

static unsigned
Field_imm12b_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 8) | ((insn[0] << 16) >> 24);
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_imm12b_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
  tie_t = (val << 20) >> 24;
  insn[0] = (insn[0] & ~0xff00) | (tie_t << 8);
}

static unsigned
Field_imm12b_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 12) | ((insn[0] << 16) >> 20);
  return tie_t;
}

static void
Field_imm12b_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 20) >> 20;
  insn[0] = (insn[0] & ~0xfff0) | (tie_t << 4);
}

static unsigned
Field_imm12b_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 12) | ((insn[0] << 16) >> 20);
  return tie_t;
}

static void
Field_imm12b_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 20) >> 20;
  insn[0] = (insn[0] & ~0xfff0) | (tie_t << 4);
}

static unsigned
Field_imm16_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 16) | ((insn[0] << 8) >> 16);
  return tie_t;
}

static void
Field_imm16_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 16) >> 16;
  insn[0] = (insn[0] & ~0xffff00) | (tie_t << 8);
}

static unsigned
Field_imm16_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 16) | ((insn[0] << 12) >> 16);
  return tie_t;
}

static void
Field_imm16_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 16) >> 16;
  insn[0] = (insn[0] & ~0xffff0) | (tie_t << 4);
}

static unsigned
Field_offset_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 18) | ((insn[0] << 8) >> 14);
  return tie_t;
}

static void
Field_offset_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 14) >> 14;
  insn[0] = (insn[0] & ~0xffffc0) | (tie_t << 6);
}

static unsigned
Field_offset_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 18) | ((insn[0] << 14) >> 14);
  return tie_t;
}

static void
Field_offset_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 14) >> 14;
  insn[0] = (insn[0] & ~0x3ffff) | (tie_t << 0);
}

static unsigned
Field_op2_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 15) >> 28);
  return tie_t;
}

static void
Field_op2_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0x1e000) | (tie_t << 13);
}

static unsigned
Field_op2_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 15) >> 31);
  tie_t = (tie_t << 3) | ((insn[0] << 17) >> 29);
  return tie_t;
}

static void
Field_op2_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x7000) | (tie_t << 12);
  tie_t = (val << 28) >> 31;
  insn[0] = (insn[0] & ~0x10000) | (tie_t << 16);
}

static unsigned
Field_op2_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 15) >> 28);
  return tie_t;
}

static void
Field_op2_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0x1e000) | (tie_t << 13);
}

static unsigned
Field_op2_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 15) >> 28);
  return tie_t;
}

static void
Field_op2_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0x1e000) | (tie_t << 13);
}

static unsigned
Field_r_Slot_inst16a_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_r_Slot_inst16a_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_r_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_r_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_r_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_r_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_r_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_r_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_r_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_r_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_r_Slot_xt_flix64_slot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_r_Slot_xt_flix64_slot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_r_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_r_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_r_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_r_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_r_Slot_xt_flix64_slot3_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_r_Slot_xt_flix64_slot3_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_r_disp_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 17) >> 29);
  return tie_t;
}

static void
Field_r_disp_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x7000) | (tie_t << 12);
}

static unsigned
Field_r_3_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 16) >> 31);
  return tie_t;
}

static void
Field_r_3_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x8000) | (tie_t << 15);
}

static unsigned
Field_sa4_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 11) >> 31);
  return tie_t;
}

static void
Field_sa4_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x100000) | (tie_t << 20);
}

static unsigned
Field_sae4_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 15) >> 31);
  return tie_t;
}

static void
Field_sae4_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x10000) | (tie_t << 16);
}

static unsigned
Field_sae_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 15) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_sae_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x10000) | (tie_t << 16);
}

static unsigned
Field_sae_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 19) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_sae_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x1000) | (tie_t << 12);
}

static unsigned
Field_sae_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 16) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_sae_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x8000) | (tie_t << 15);
}

static unsigned
Field_sae_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 19) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_sae_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x1000) | (tie_t << 12);
}

static unsigned
Field_sae_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 19) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_sae_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x1000) | (tie_t << 12);
}

static unsigned
Field_sal_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 11) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_sal_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x100000) | (tie_t << 20);
}

static unsigned
Field_sal_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 19) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_sal_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x1000) | (tie_t << 12);
}

static unsigned
Field_sal_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 19) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_sal_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x1000) | (tie_t << 12);
}

static unsigned
Field_sargt_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 11) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_sargt_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x100000) | (tie_t << 20);
}

static unsigned
Field_sargt_Slot_xt_flix64_slot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 19) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_sargt_Slot_xt_flix64_slot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x1000) | (tie_t << 12);
}

static unsigned
Field_sargt_Slot_xt_flix64_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 19) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_sargt_Slot_xt_flix64_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x1000) | (tie_t << 12);
}

static unsigned
Field_sargt_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 19) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_sargt_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x1000) | (tie_t << 12);
}

static unsigned
Field_sas4_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 27) >> 31);
  return tie_t;
}

static void
Field_sas4_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x10) | (tie_t << 4);
}

static unsigned
Field_sas_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 27) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_sas_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x10) | (tie_t << 4);
}

static unsigned
Field_sas_Slot_xt_flix64_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 5) | ((insn[0] << 27) >> 27);
  return tie_t;
}

static void
Field_sas_Slot_xt_flix64_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 27) >> 27;
  insn[0] = (insn[0] & ~0x1f) | (tie_t << 0);
}

static unsigned
Field_imm4_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_imm4_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_mn_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 24) >> 30);
  tie_t = (tie_t << 2) | ((insn[0] << 26) >> 30);
  return tie_t;
}

static void
Field_mn_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x30) | (tie_t << 4);
  tie_t = (val << 28) >> 30;
  insn[0] = (insn[0] & ~0xc0) | (tie_t << 6);
}

static unsigned
Field_i_Slot_inst16a_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 24) >> 31);
  return tie_t;
}

static void
Field_i_Slot_inst16a_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x80) | (tie_t << 7);
}

static unsigned
Field_imm6lo_Slot_inst16a_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_imm6lo_Slot_inst16a_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_imm6lo_Slot_inst16b_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_imm6lo_Slot_inst16b_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_imm6hi_Slot_inst16a_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 26) >> 30);
  return tie_t;
}

static void
Field_imm6hi_Slot_inst16a_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x30) | (tie_t << 4);
}

static unsigned
Field_imm6hi_Slot_inst16b_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 26) >> 30);
  return tie_t;
}

static void
Field_imm6hi_Slot_inst16b_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x30) | (tie_t << 4);
}

static unsigned
Field_imm7lo_Slot_inst16a_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_imm7lo_Slot_inst16a_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_imm7lo_Slot_inst16b_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_imm7lo_Slot_inst16b_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_imm7hi_Slot_inst16a_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 25) >> 29);
  return tie_t;
}

static void
Field_imm7hi_Slot_inst16a_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x70) | (tie_t << 4);
}

static unsigned
Field_imm7hi_Slot_inst16b_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 25) >> 29);
  return tie_t;
}

static void
Field_imm7hi_Slot_inst16b_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x70) | (tie_t << 4);
}

static unsigned
Field_z_Slot_inst16a_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 25) >> 31);
  return tie_t;
}

static void
Field_z_Slot_inst16a_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x40) | (tie_t << 6);
}

static unsigned
Field_imm6_Slot_inst16b_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 26) >> 30);
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_imm6_Slot_inst16b_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
  tie_t = (val << 26) >> 30;
  insn[0] = (insn[0] & ~0x30) | (tie_t << 4);
}

static unsigned
Field_imm7_Slot_inst16b_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 25) >> 29);
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_imm7_Slot_inst16b_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
  tie_t = (val << 25) >> 29;
  insn[0] = (insn[0] & ~0x70) | (tie_t << 4);
}

static unsigned
Field_imm7_Slot_xt_flix64_slot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  tie_t = (tie_t << 3) | ((insn[0] << 29) >> 29);
  return tie_t;
}

static void
Field_imm7_Slot_xt_flix64_slot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x7) | (tie_t << 0);
  tie_t = (val << 25) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_t2_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 24) >> 29);
  return tie_t;
}

static void
Field_t2_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0xe0) | (tie_t << 5);
}

static unsigned
Field_t2_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 20) >> 29);
  return tie_t;
}

static void
Field_t2_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0xe00) | (tie_t << 9);
}

static unsigned
Field_t2_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 16) >> 31);
  tie_t = (tie_t << 2) | ((insn[0] << 24) >> 30);
  return tie_t;
}

static void
Field_t2_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0xc0) | (tie_t << 6);
  tie_t = (val << 29) >> 31;
  insn[0] = (insn[0] & ~0x8000) | (tie_t << 15);
}

static unsigned
Field_s2_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 20) >> 29);
  return tie_t;
}

static void
Field_s2_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0xe00) | (tie_t << 9);
}

static unsigned
Field_r2_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 16) >> 29);
  return tie_t;
}

static void
Field_r2_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0xe000) | (tie_t << 13);
}

static unsigned
Field_r2_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 28) >> 29);
  return tie_t;
}

static void
Field_r2_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0xe) | (tie_t << 1);
}

static unsigned
Field_r2_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 20) >> 29);
  return tie_t;
}

static void
Field_r2_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0xe00) | (tie_t << 9);
}

static unsigned
Field_t4_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 24) >> 30);
  return tie_t;
}

static void
Field_t4_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0xc0) | (tie_t << 6);
}

static unsigned
Field_t4_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 20) >> 30);
  return tie_t;
}

static void
Field_t4_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0xc00) | (tie_t << 10);
}

static unsigned
Field_t4_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 16) >> 31);
  tie_t = (tie_t << 1) | ((insn[0] << 24) >> 31);
  return tie_t;
}

static void
Field_t4_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x80) | (tie_t << 7);
  tie_t = (val << 30) >> 31;
  insn[0] = (insn[0] & ~0x8000) | (tie_t << 15);
}

static unsigned
Field_s4_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 20) >> 30);
  return tie_t;
}

static void
Field_s4_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0xc00) | (tie_t << 10);
}

static unsigned
Field_r4_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 16) >> 30);
  return tie_t;
}

static void
Field_r4_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0xc000) | (tie_t << 14);
}

static unsigned
Field_r4_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 28) >> 30);
  return tie_t;
}

static void
Field_r4_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0xc) | (tie_t << 2);
}

static unsigned
Field_r4_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 20) >> 30);
  return tie_t;
}

static void
Field_r4_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0xc00) | (tie_t << 10);
}

static unsigned
Field_t8_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 24) >> 31);
  return tie_t;
}

static void
Field_t8_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x80) | (tie_t << 7);
}

static unsigned
Field_s8_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 20) >> 31);
  return tie_t;
}

static void
Field_s8_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x800) | (tie_t << 11);
}

static unsigned
Field_r8_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 16) >> 31);
  return tie_t;
}

static void
Field_r8_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x8000) | (tie_t << 15);
}

static unsigned
Field_xt_wbr15_imm_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 15) | ((insn[0] << 8) >> 17);
  return tie_t;
}

static void
Field_xt_wbr15_imm_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 17) >> 17;
  insn[0] = (insn[0] & ~0xfffe00) | (tie_t << 9);
}

static unsigned
Field_xt_wbr18_imm_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 18) | ((insn[0] << 8) >> 14);
  return tie_t;
}

static void
Field_xt_wbr18_imm_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 14) >> 14;
  insn[0] = (insn[0] & ~0xffffc0) | (tie_t << 6);
}

static unsigned
Field_xt_wbr18_imm_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 18) | ((insn[0] << 2) >> 14);
  return tie_t;
}

static void
Field_xt_wbr18_imm_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 14) >> 14;
  insn[0] = (insn[0] & ~0x3ffff000) | (tie_t << 12);
}

static unsigned
Field_xt_wbr18_imm_Slot_xt_flix64_slot3_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 18) | ((insn[0] << 6) >> 14);
  return tie_t;
}

static void
Field_xt_wbr18_imm_Slot_xt_flix64_slot3_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 14) >> 14;
  insn[0] = (insn[0] & ~0x3ffff00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_fhba4_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_fhba4_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_fhba4_2_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_fhba4_2_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_tp7_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_tp7_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_tp7_Slot_ae_slot2_0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_tp7_Slot_ae_slot2_0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_tp7_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_tp7_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_osa32_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 15) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_osa32_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x10000) | (tie_t << 16);
}

static unsigned
Field_ae_fld_osa32_Slot_ae_slot2_0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 19) >> 31);
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_osa32_Slot_ae_slot2_0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
  tie_t = (val << 27) >> 31;
  insn[0] = (insn[0] & ~0x1000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_osa32_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 21) >> 29);
  tie_t = (tie_t << 2) | ((insn[0] << 28) >> 30);
  return tie_t;
}

static void
Field_ae_fld_osa32_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0xc) | (tie_t << 2);
  tie_t = (val << 27) >> 29;
  insn[0] = (insn[0] & ~0x700) | (tie_t << 8);
}

static unsigned
Field_ae_fld_osa64_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 14) >> 30);
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_osa64_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
  tie_t = (val << 26) >> 30;
  insn[0] = (insn[0] & ~0x30000) | (tie_t << 16);
}

static unsigned
Field_ae_fld_osa64_Slot_ae_slot2_0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 18) >> 30);
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_osa64_Slot_ae_slot2_0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
  tie_t = (val << 26) >> 30;
  insn[0] = (insn[0] & ~0x3000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_osa64_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 21) >> 29);
  tie_t = (tie_t << 3) | ((insn[0] << 28) >> 29);
  return tie_t;
}

static void
Field_ae_fld_osa64_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0xe) | (tie_t << 1);
  tie_t = (val << 26) >> 29;
  insn[0] = (insn[0] & ~0x700) | (tie_t << 8);
}

static unsigned
Field_ae_fld_imm2_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 20) >> 30);
  return tie_t;
}

static void
Field_ae_fld_imm2_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0xc00) | (tie_t << 10);
}

static unsigned
Field_ae_fld_imm2_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 29) >> 30);
  return tie_t;
}

static void
Field_ae_fld_imm2_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x6) | (tie_t << 1);
}

static unsigned
Field_ae_fld_imm2_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 12) >> 31);
  tie_t = (tie_t << 1) | ((insn[0] << 29) >> 31);
  return tie_t;
}

static void
Field_ae_fld_imm2_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x4) | (tie_t << 2);
  tie_t = (val << 30) >> 31;
  insn[0] = (insn[0] & ~0x80000) | (tie_t << 19);
}

static unsigned
Field_ae_fld_immls64_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_immls64_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_immls64_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 18) >> 30);
  tie_t = (tie_t << 1) | ((insn[0] << 24) >> 31);
  tie_t = (tie_t << 1) | ((insn[0] << 27) >> 31);
  return tie_t;
}

static void
Field_ae_fld_immls64_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x10) | (tie_t << 4);
  tie_t = (val << 30) >> 31;
  insn[0] = (insn[0] & ~0x80) | (tie_t << 7);
  tie_t = (val << 28) >> 30;
  insn[0] = (insn[0] & ~0x3000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_immls64_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 17) >> 29);
  tie_t = (tie_t << 1) | ((insn[0] << 24) >> 31);
  return tie_t;
}

static void
Field_ae_fld_immls64_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x80) | (tie_t << 7);
  tie_t = (val << 28) >> 29;
  insn[0] = (insn[0] & ~0x7000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_immls64_Slot_ae_minislot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_immls64_Slot_ae_minislot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_immls64pos_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 25) >> 29);
  return tie_t;
}

static void
Field_ae_fld_immls64pos_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x70) | (tie_t << 4);
}

static unsigned
Field_ae_fld_immls64pos_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 25) >> 29);
  return tie_t;
}

static void
Field_ae_fld_immls64pos_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x70) | (tie_t << 4);
}

static unsigned
Field_ae_fld_immls64pos_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 17) >> 29);
  return tie_t;
}

static void
Field_ae_fld_immls64pos_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x7000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_immls32_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_immls32_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_immls32_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_immls32_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_immls32_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 17) >> 29);
  tie_t = (tie_t << 1) | ((insn[0] << 24) >> 31);
  return tie_t;
}

static void
Field_ae_fld_immls32_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x80) | (tie_t << 7);
  tie_t = (val << 28) >> 29;
  insn[0] = (insn[0] & ~0x7000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_immls32_Slot_ae_minislot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_immls32_Slot_ae_minislot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_immls16_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_immls16_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_immls16_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_immls16_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_immls16_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 3) | ((insn[0] << 17) >> 29);
  tie_t = (tie_t << 1) | ((insn[0] << 24) >> 31);
  return tie_t;
}

static void
Field_ae_fld_immls16_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 31) >> 31;
  insn[0] = (insn[0] & ~0x80) | (tie_t << 7);
  tie_t = (val << 28) >> 29;
  insn[0] = (insn[0] & ~0x7000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_immls16_Slot_ae_minislot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_immls16_Slot_ae_minislot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_osa16_Slot_ae_slot2_0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_osa16_Slot_ae_slot2_0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_osa16_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_osa16_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_mul_d0_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_mul_d0_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_mul_d0_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_mul_d0_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_mul_d1_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_mul_d1_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_mul_d1_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_mul_d1_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_mul_q0_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_mul_q0_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_mul_q0_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_mul_q0_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_mul_x2_s2_d1_Slot_ae_slot2_0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_mul_x2_s2_d1_Slot_ae_slot2_0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_mul_x2_s2_d0_Slot_ae_slot2_0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_mul_x2_s2_d0_Slot_ae_slot2_0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_mul_x2_s2_q0_Slot_ae_slot2_0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_mul_x2_s2_q0_Slot_ae_slot2_0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_mul_x4_d2_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 12) >> 28);
  return tie_t;
}

static void
Field_ae_fld_mul_x4_d2_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0000) | (tie_t << 16);
}

static unsigned
Field_ae_fld_mul_x4_q1_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_mul_x4_q1_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_ls_v_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ls_v_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_ls_v_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ls_v_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_ls_v_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ls_v_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_ls_v_Slot_ae_minislot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ls_v_Slot_ae_minislot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_ls_uu_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 26) >> 30);
  return tie_t;
}

static void
Field_ae_fld_ls_uu_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x30) | (tie_t << 4);
}

static unsigned
Field_ae_fld_ls_uu_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 25) >> 30);
  return tie_t;
}

static void
Field_ae_fld_ls_uu_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x60) | (tie_t << 5);
}

static unsigned
Field_ae_fld_ls_uu_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 25) >> 30);
  return tie_t;
}

static void
Field_ae_fld_ls_uu_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x60) | (tie_t << 5);
}

static unsigned
Field_ae_fld_ls_su_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 26) >> 30);
  return tie_t;
}

static void
Field_ae_fld_ls_su_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x30) | (tie_t << 4);
}

static unsigned
Field_ae_fld_ls_su_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 25) >> 30);
  return tie_t;
}

static void
Field_ae_fld_ls_su_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x60) | (tie_t << 5);
}

static unsigned
Field_ae_fld_ls_su_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 25) >> 30);
  return tie_t;
}

static void
Field_ae_fld_ls_su_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x60) | (tie_t << 5);
}

static unsigned
Field_ae_fld_ls_av_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ls_av_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_ls_av_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ls_av_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_ls_av_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ls_av_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_ls_v1_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ls_v1_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_ls_v1_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ls_v1_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_ls_v1_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ls_v1_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_ls_v1_Slot_ae_minislot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ls_v1_Slot_ae_minislot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_ls_v2_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ls_v2_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_ls_v2_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ls_v2_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_cmpp_v0_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_cmpp_v0_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_cmpp_v0_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_cmpp_v0_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_cmpp_v0_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_cmpp_v0_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_cmpp_v1_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_cmpp_v1_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_cmpp_v1_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_cmpp_v1_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_cmpp_v1_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_cmpp_v1_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_cmpp_v_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_cmpp_v_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_cmpp_v_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_cmpp_v_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_cmpp_v_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_cmpp_v_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_uu_v_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 26) >> 30);
  return tie_t;
}

static void
Field_ae_fld_uu_v_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x30) | (tie_t << 4);
}

static unsigned
Field_ae_fld_uu_v_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 30) >> 30);
  return tie_t;
}

static void
Field_ae_fld_uu_v_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x3) | (tie_t << 0);
}

static unsigned
Field_ae_fld_uu_v_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 30) >> 30);
  return tie_t;
}

static void
Field_ae_fld_uu_v_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x3) | (tie_t << 0);
}

static unsigned
Field_ae_fld_uu_uu_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 24) >> 30);
  return tie_t;
}

static void
Field_ae_fld_uu_uu_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0xc0) | (tie_t << 6);
}

static unsigned
Field_ae_fld_uu_uu_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 25) >> 30);
  return tie_t;
}

static void
Field_ae_fld_uu_uu_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x60) | (tie_t << 5);
}

static unsigned
Field_ae_fld_uu_uu_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 25) >> 30);
  return tie_t;
}

static void
Field_ae_fld_uu_uu_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x60) | (tie_t << 5);
}

static unsigned
Field_ae_fld_dr_to_ar_v0_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_ar_v0_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_dr_to_ar_v0_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_ar_v0_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_dr_to_ar_v0_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_ar_v0_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_dr_to_ar_v0_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_ar_v0_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_cmov_v_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_cmov_v_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_cmov_v_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_cmov_v_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_cmov_v_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_cmov_v_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_cmov_v0_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_cmov_v0_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_cmov_v0_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_cmov_v0_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_cmov_v0_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_cmov_v0_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_pks_d_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_pks_d_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_pks_d_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_pks_d_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_pks_d_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_pks_d_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_pks_s_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_pks_s_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_pks_s_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_pks_s_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_pks_s_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_pks_s_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_shift_d_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_shift_d_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_shift_d_Slot_ae_slot2_0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_shift_d_Slot_ae_slot2_0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_shift_d_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_shift_d_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_shift_d_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_shift_d_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_shift_d0_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_shift_d0_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_shift_d0_Slot_ae_slot2_0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_shift_d0_Slot_ae_slot2_0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_shift_d0_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_shift_d0_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_shift_d0_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_shift_d0_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_shift_sd_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 12) >> 28);
  return tie_t;
}

static void
Field_ae_fld_shift_sd_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0000) | (tie_t << 16);
}

static unsigned
Field_ae_fld_shift_sd_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_shift_sd_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_shift_sd_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_shift_sd_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_dr_to_dr_v_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_dr_to_dr_v_Slot_ae_slot2_0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v_Slot_ae_slot2_0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_dr_to_dr_v_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_dr_to_dr_v_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_dr_to_dr_v_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_dr_to_dr_v_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_dr_to_dr_v0_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v0_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_dr_to_dr_v0_Slot_ae_slot2_0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v0_Slot_ae_slot2_0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_dr_to_dr_v0_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v0_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_dr_to_dr_v0_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v0_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_dr_to_dr_v0_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v0_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_dr_to_dr_v0_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v0_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_dr_to_dr_v1_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v1_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_dr_to_dr_v1_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v1_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_dr_to_dr_v1_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v1_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_dr_to_dr_v1_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v1_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_dr_to_dr_v1_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_dr_to_dr_v1_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_to_dr_v_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_to_dr_v_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_to_dr_v_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_to_dr_v_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_to_dr_v_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_to_dr_v_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_to_dr_v_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_to_dr_v_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_to_dr_v_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_to_dr_v_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_to_dr_v_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_to_dr_v_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_to_dr_v0_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_to_dr_v0_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_to_dr_v0_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_to_dr_v0_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_to_dr_v0_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_to_dr_v0_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_to_dr_v0_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_to_dr_v0_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_to_dr_v0_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_to_dr_v0_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_to_dr_v0_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_to_dr_v0_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_selimm_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 12) >> 28);
  return tie_t;
}

static void
Field_ae_fld_selimm_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0000) | (tie_t << 16);
}

static unsigned
Field_ae_fld_selimm_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_selimm_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_selimm_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 12) >> 31);
  tie_t = (tie_t << 3) | ((insn[0] << 25) >> 29);
  return tie_t;
}

static void
Field_ae_fld_selimm_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x70) | (tie_t << 4);
  tie_t = (val << 28) >> 31;
  insn[0] = (insn[0] & ~0x80000) | (tie_t << 19);
}

static unsigned
Field_ae_fld_selimm_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_selimm_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_selimm_n_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 18) >> 30);
  return tie_t;
}

static void
Field_ae_fld_selimm_n_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x3000) | (tie_t << 12);
}

static unsigned
Field_fld_ar_to_dr_imm_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  tie_t = (tie_t << 2) | ((insn[0] << 26) >> 30);
  return tie_t;
}

static void
Field_fld_ar_to_dr_imm_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0x30) | (tie_t << 4);
  tie_t = (val << 26) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_fld_ar_to_dr_imm_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 20) >> 30);
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_fld_ar_to_dr_imm_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
  tie_t = (val << 26) >> 30;
  insn[0] = (insn[0] & ~0xc00) | (tie_t << 10);
}

static unsigned
Field_fld_ar_to_dr_imm_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 24) >> 30);
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_fld_ar_to_dr_imm_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
  tie_t = (val << 26) >> 30;
  insn[0] = (insn[0] & ~0xc0) | (tie_t << 6);
}

static unsigned
Field_fld_ar_to_dr_imm_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 20) >> 30);
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_fld_ar_to_dr_imm_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
  tie_t = (val << 26) >> 30;
  insn[0] = (insn[0] & ~0xc00) | (tie_t << 10);
}

static unsigned
Field_fld_ar_to_dr_imm_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 1) | ((insn[0] << 12) >> 31);
  tie_t = (tie_t << 2) | ((insn[0] << 16) >> 30);
  tie_t = (tie_t << 3) | ((insn[0] << 21) >> 29);
  return tie_t;
}

static void
Field_fld_ar_to_dr_imm_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 29) >> 29;
  insn[0] = (insn[0] & ~0x700) | (tie_t << 8);
  tie_t = (val << 27) >> 30;
  insn[0] = (insn[0] & ~0xc000) | (tie_t << 14);
  tie_t = (val << 26) >> 31;
  insn[0] = (insn[0] & ~0x80000) | (tie_t << 19);
}

static unsigned
Field_fld_ar_to_dr_imm_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 24) >> 30);
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_fld_ar_to_dr_imm_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
  tie_t = (val << 26) >> 30;
  insn[0] = (insn[0] & ~0xc0) | (tie_t << 6);
}

static unsigned
Field_fld_ar_to_dr_imm_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 20) >> 30);
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_fld_ar_to_dr_imm_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
  tie_t = (val << 26) >> 30;
  insn[0] = (insn[0] & ~0xc00) | (tie_t << 10);
}

static unsigned
Field_fld_ar_to_dr_imm_Slot_ae_minislot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 22) >> 30);
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_fld_ar_to_dr_imm_Slot_ae_minislot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
  tie_t = (val << 26) >> 30;
  insn[0] = (insn[0] & ~0x300) | (tie_t << 8);
}

static unsigned
Field_ae_fld_arth_v_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_arth_v_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_arth_v_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_arth_v_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_arth_v_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_arth_v_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_arth_v_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_arth_v_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_arth_v_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_arth_v_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_arth_v0_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_arth_v0_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_arth_v0_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_arth_v0_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_arth_v0_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_arth_v0_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_arth_v0_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_arth_v0_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_arth_v0_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_arth_v0_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_arth_v1_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_arth_v1_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_arth_v1_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_arth_v1_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_arth_v1_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_arth_v1_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_arth_v1_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_arth_v1_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_arth_v1_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_arth_v1_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_ae_fld_ar_to_dr_v_Slot_inst_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ar_to_dr_v_Slot_inst_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_ar_to_dr_v_Slot_ae_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ar_to_dr_v_Slot_ae_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_ar_to_dr_v_Slot_ae_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ar_to_dr_v_Slot_ae_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_ar_to_dr_v_Slot_ae_slot2_1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ar_to_dr_v_Slot_ae_slot2_1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_ar_to_dr_v_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 28) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ar_to_dr_v_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf) | (tie_t << 0);
}

static unsigned
Field_ae_fld_ar_to_dr_v_Slot_ae2_slot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 20) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ar_to_dr_v_Slot_ae2_slot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf00) | (tie_t << 8);
}

static unsigned
Field_ae_fld_ar_to_dr_v_Slot_ae_minislot2_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 16) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ar_to_dr_v_Slot_ae_minislot2_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf000) | (tie_t << 12);
}

static unsigned
Field_ae_fld_ar_to_dr_v_Slot_ae_minislot0_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 4) | ((insn[0] << 24) >> 28);
  return tie_t;
}

static void
Field_ae_fld_ar_to_dr_v_Slot_ae_minislot0_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 28) >> 28;
  insn[0] = (insn[0] & ~0xf0) | (tie_t << 4);
}

static unsigned
Field_fld_ae2_slot1_7_6_Slot_ae2_slot1_get (const xtensa_insnbuf insn)
{
  unsigned tie_t = 0;
  tie_t = (tie_t << 2) | ((insn[0] << 24) >> 30);
  return tie_t;
}

static void
Field_fld_ae2_slot1_7_6_Slot_ae2_slot1_set (xtensa_insnbuf insn, uint32 val)
{
  uint32 tie_t;
  tie_t = (val << 30) >> 30;
  insn[0] = (insn[0] & ~0xc0) | (tie_t << 6);
}

static void
Implicit_Field_set (xtensa_insnbuf insn ATTRIBUTE_UNUSED,
		    uint32 val ATTRIBUTE_UNUSED)
{
  /* Do nothing.  */
}

static unsigned
Implicit_Field_ar0_get (const xtensa_insnbuf insn ATTRIBUTE_UNUSED)
{
  return 0;
}

static unsigned
Implicit_Field_ar4_get (const xtensa_insnbuf insn ATTRIBUTE_UNUSED)
{
  return 4;
}

static unsigned
Implicit_Field_ar8_get (const xtensa_insnbuf insn ATTRIBUTE_UNUSED)
{
  return 8;
}

static unsigned
Implicit_Field_ar12_get (const xtensa_insnbuf insn ATTRIBUTE_UNUSED)
{
  return 12;
}

static unsigned
Implicit_Field_bt16_get (const xtensa_insnbuf insn ATTRIBUTE_UNUSED)
{
  return 0;
}

static unsigned
Implicit_Field_bs16_get (const xtensa_insnbuf insn ATTRIBUTE_UNUSED)
{
  return 0;
}

static unsigned
Implicit_Field_br16_get (const xtensa_insnbuf insn ATTRIBUTE_UNUSED)
{
  return 0;
}

static unsigned
Implicit_Field_brall_get (const xtensa_insnbuf insn ATTRIBUTE_UNUSED)
{
  return 0;
}

enum xtensa_field_id {
  FIELD_t,
  FIELD_bbi4,
  FIELD_bbi,
  FIELD_imm12,
  FIELD_imm8,
  FIELD_s,
  FIELD_imm12b,
  FIELD_imm16,
  FIELD_m,
  FIELD_n,
  FIELD_offset,
  FIELD_op0,
  FIELD_op1,
  FIELD_op2,
  FIELD_r,
  FIELD_r_disp,
  FIELD_r_3,
  FIELD_sa4,
  FIELD_sae4,
  FIELD_sae,
  FIELD_sal,
  FIELD_sargt,
  FIELD_sas4,
  FIELD_sas,
  FIELD_sr,
  FIELD_st,
  FIELD_thi3,
  FIELD_imm4,
  FIELD_mn,
  FIELD_i,
  FIELD_imm6lo,
  FIELD_imm6hi,
  FIELD_imm7lo,
  FIELD_imm7hi,
  FIELD_z,
  FIELD_imm6,
  FIELD_imm7,
  FIELD_t2,
  FIELD_s2,
  FIELD_r2,
  FIELD_t4,
  FIELD_s4,
  FIELD_r4,
  FIELD_t8,
  FIELD_s8,
  FIELD_r8,
  FIELD_xt_wbr15_imm,
  FIELD_xt_wbr18_imm,
  FIELD_ae_fld_fhba4,
  FIELD_ae_fld_fhba4_2,
  FIELD_ae_fld_tp7,
  FIELD_ae_fld_osa32,
  FIELD_ae_fld_osa64,
  FIELD_ae_fld_imm2,
  FIELD_ae_fld_immls64,
  FIELD_ae_fld_immls64pos,
  FIELD_ae_fld_immls32,
  FIELD_ae_fld_immls16,
  FIELD_ae_fld_osa16,
  FIELD_Inst_15_12,
  FIELD_Inst_11_8,
  FIELD_Inst_7_4,
  FIELD_Inst_12,
  FIELD_Inst_7,
  FIELD_Inst_5_4,
  FIELD_Inst_7_6,
  FIELD_Inst_19_17,
  FIELD_Inst_19_18,
  FIELD_Inst_9_8,
  FIELD_Inst_4,
  FIELD_ae_fld_mul_d0,
  FIELD_ae_fld_mul_d1,
  FIELD_ae_fld_mul_q0,
  FIELD_ae_fld_mul_x2_S2_d1,
  FIELD_ae_fld_mul_x2_S2_d0,
  FIELD_ae_fld_mul_x2_S2_q0,
  FIELD_ae_fld_mul_x4_d2,
  FIELD_ae_fld_mul_x4_q1,
  FIELD_ae_fld_ls_v,
  FIELD_ae_fld_ls_uu,
  FIELD_ae_fld_ls_su,
  FIELD_ae_fld_ls_av,
  FIELD_ae_fld_ls_v1,
  FIELD_ae_fld_ls_v2,
  FIELD_ae_fld_cmpp_v0,
  FIELD_ae_fld_cmpp_v1,
  FIELD_ae_fld_cmpp_v,
  FIELD_ae_fld_uu_v,
  FIELD_ae_fld_uu_uu,
  FIELD_ae_fld_dr_to_ar_v0,
  FIELD_ae_fld_cmov_v,
  FIELD_ae_fld_cmov_v0,
  FIELD_ae_fld_pks_d,
  FIELD_ae_fld_pks_s,
  FIELD_ae_fld_shift_d,
  FIELD_ae_fld_shift_d0,
  FIELD_ae_fld_shift_sd,
  FIELD_ae_fld_dr_to_dr_v,
  FIELD_ae_fld_dr_to_dr_v0,
  FIELD_ae_fld_dr_to_dr_v1,
  FIELD_ae_fld_to_dr_v,
  FIELD_ae_fld_to_dr_v0,
  FIELD_ae_fld_selimm,
  FIELD_ae_fld_selimm_N,
  FIELD_fld_ar_to_dr_imm,
  FIELD_ae_fld_arth_v,
  FIELD_ae_fld_arth_v0,
  FIELD_ae_fld_arth_v1,
  FIELD_ae_fld_ar_to_dr_v,
  FIELD_fld_ae2_slot0_11_4,
  FIELD_fld_ae2_slot0_7_4,
  FIELD_fld_ae2_slot0_9_8,
  FIELD_fld_ae2_slot0_11_11,
  FIELD_fld_ae2_slot0_31_30,
  FIELD_fld_ae2_slot0_11_8,
  FIELD_fld_ae2_slot0_31_12,
  FIELD_fld_ae_slot0_19_12,
  FIELD_fld_ae_minislot2_18_16,
  FIELD_fld_ae_slot0_19_16,
  FIELD_fld_ae2_slot0_31_17,
  FIELD_fld_ae_slot0_19_17,
  FIELD_fld_ae_minislot0_16_0,
  FIELD_fld_ae_minislot1_0_0,
  FIELD_fld_ae_minislot2_18_0,
  FIELD_fld_ae2_slot0_6_0,
  FIELD_fld_ae2_slot1_23_0,
  FIELD_fld_ae_slot2_1_18_0,
  FIELD_fld_ae_slot0_19_0,
  FIELD_fld_ae_slot1_19_0,
  FIELD_fld_ae_slot2_0_19_0,
  FIELD_fld_ae_slot0_7_4,
  FIELD_fld_ae_slot0_11_8,
  FIELD_fld_ae2_slot0_31_7,
  FIELD_fld_ae_slot0_19_7,
  FIELD_fld_ae_slot1_19_14,
  FIELD_fld_ae_slot2_1_9_8,
  FIELD_fld_ae2_slot0_31_16,
  FIELD_fld_ae_slot2_1_7_4,
  FIELD_fld_ae_slot2_1_18_12,
  FIELD_fld_ae_slot2_1_1_0,
  FIELD_fld_ae2_slot1_7_4,
  FIELD_fld_ae_slot1_19_12,
  FIELD_fld_ae_slot2_0_19_12,
  FIELD_fld_ae2_slot1_23_16,
  FIELD_fld_ae2_slot1_23_20,
  FIELD_fld_ae2_slot0_3_0,
  FIELD_fld_ae2_slot1_11_4,
  FIELD_fld_ae_slot2_1_18_8,
  FIELD_fld_ae_slot1_7_4,
  FIELD_fld_ae_minislot2_11_4,
  FIELD_fld_ae_minislot0_16_10,
  FIELD_fld_ae_minislot2_3_0,
  FIELD_fld_ae_minislot2_9_8,
  FIELD_fld_ae2_slot1_13_11,
  FIELD_fld_ae_slot0_5_4,
  FIELD_fld_ae_slot1_9_8,
  FIELD_fld_ae_minislot0_16_8,
  FIELD_fld_ae2_slot1_7_7,
  FIELD_fld_ae2_slot1_18_16,
  FIELD_fld_ae_slot2_1_18_16,
  FIELD_fld_ae2_slot0_8_8,
  FIELD_fld_ae_slot2_1_0_0,
  FIELD_fld_ae_minislot0_16_12,
  FIELD_fld_ae2_slot0_6_4,
  FIELD_fld_ae2_slot0_31_15,
  FIELD_fld_ae_slot0_6_5,
  FIELD_fld_ae_slot0_19_14,
  FIELD_fld_ae_slot0_7_7,
  FIELD_fld_ae2_slot0_4_4,
  FIELD_fld_ae2_slot0_7_7,
  FIELD_fld_ae_slot0_4_4,
  FIELD_fld_ae2_slot0_4_2,
  FIELD_fld_ae_slot0_4_2,
  FIELD_fld_ae2_slot0_4_0,
  FIELD_fld_ae_slot0_4_0,
  FIELD_fld_ae_minislot2_18_8,
  FIELD_fld_ae2_slot0_5_4,
  FIELD_fld_ae2_slot0_14_12,
  FIELD_fld_ae_slot2_1_8_8,
  FIELD_fld_ae2_slot1_1_0,
  FIELD_fld_ae2_slot1_7_3,
  FIELD_fld_ae_slot1_0_0,
  FIELD_fld_ae_slot1_3_3,
  FIELD_fld_ae_minislot2_11_8,
  FIELD_fld_ae_slot2_0_7_4,
  FIELD_fld_ae2_slot0_1_0,
  FIELD_fld_ae_slot2_0_19_13,
  FIELD_fld_ae2_slot0_0_0,
  FIELD_fld_ae_slot2_0_19_14,
  FIELD_fld_ae2_slot1_7_6,
  FIELD_fld_xt_flix64_slot3_7_4,
  FIELD_fld_xt_flix64_slot3_30_27,
  FIELD_fld_xt_flix64_slot3_30_26,
  FIELD_fld_xt_flix64_slot0_20_8,
  FIELD_fld_xt_flix64_slot1_19_8,
  FIELD_fld_xt_flix64_slot2_15_8,
  FIELD_fld_xt_flix64_slot2_3_3,
  FIELD_fld_xt_flix64_slot0_7_4,
  FIELD_fld_xt_flix64_slot2_7_4,
  FIELD_fld_xt_flix64_slot0_20_12,
  FIELD_fld_xt_flix64_slot1_19_12,
  FIELD_fld_xt_flix64_slot2_15_12,
  FIELD_fld_xt_flix64_slot0_20_16,
  FIELD_fld_xt_flix64_slot1_19_16,
  FIELD_fld_xt_flix64_slot0_20_17,
  FIELD_fld_xt_flix64_slot1_19_17,
  FIELD_fld_xt_flix64_slot1_19_18,
  FIELD_fld_xt_flix64_slot0_20_20,
  FIELD_fld_xt_flix64_slot1_7_4,
  FIELD_fld_xt_flix64_slot3_5_0,
  FIELD_fld_xt_flix64_slot3_30_6,
  FIELD_fld_xt_flix64_slot0_20_0,
  FIELD_fld_xt_flix64_slot1_19_0,
  FIELD_fld_xt_dummy_0_0,
  FIELD_fld_xt_flix64_slot2_15_0,
  FIELD_fld_xt_flix64_slot0_3_0,
  FIELD_fld_xt_flix64_slot1_3_0,
  FIELD_fld_xt_flix64_slot0_20_13,
  FIELD_fld_xt_flix64_slot1_19_13,
  FIELD_fld_xt_flix64_slot2_15_13,
  FIELD_fld_xt_flix64_slot0_20_5,
  FIELD__ar0,
  FIELD__ar4,
  FIELD__ar8,
  FIELD__ar12,
  FIELD__bt16,
  FIELD__bs16,
  FIELD__br16,
  FIELD__brall
};


/* Functional units.  */

static xtensa_funcUnit_internal funcUnits[] = {
  {"XT_LOADSTORE_UNIT", 1},
  { "mul_function", 1 },
  { "mul_S2_function", 1 },
  { "ae_add32x27", 1 },
  { "ae_shift32x4", 1 },
  { "ae_shift32x5", 1 },
  { "ae_leftshift32x5", 1 },
  { "ae_mulpp33x24_1", 1 },
  { "ae_mulpp33x24_2", 1 }
};

enum xtensa_funcUnit_id {
  FUNCUNIT_XT_LOADSTORE_UNIT,
  FUNCUNIT_mul_function,
  FUNCUNIT_mul_S2_function,
  FUNCUNIT_ae_add32x27,
  FUNCUNIT_ae_shift32x4,
  FUNCUNIT_ae_shift32x5,
  FUNCUNIT_ae_leftshift32x5,
  FUNCUNIT_ae_mulpp33x24_1,
  FUNCUNIT_ae_mulpp33x24_2
};


/* Register files.  */

enum xtensa_regfile_id {
  REGFILE_AR,
  REGFILE_BR,
  REGFILE_AE_DR,
  REGFILE_AE_VALIGN,
  REGFILE_FR,
  REGFILE_BR2,
  REGFILE_BR4,
  REGFILE_BR8,
  REGFILE_BR16
};

static xtensa_regfile_internal regfiles[] = {
  { "AR", "a", REGFILE_AR, 32, 64 },
  { "BR", "b", REGFILE_BR, 1, 16 },
  { "AE_DR", "aed", REGFILE_AE_DR, 64, 16 },
  { "AE_VALIGN", "u", REGFILE_AE_VALIGN, 64, 4 },
  { "FR", "f", REGFILE_FR, 32, 16 },
  { "BR2", "b", REGFILE_BR, 2, 8 },
  { "BR4", "b", REGFILE_BR, 4, 4 },
  { "BR8", "b", REGFILE_BR, 8, 2 },
  { "BR16", "b", REGFILE_BR, 16, 1 }
};


/* Interfaces.  */

#define interfaces 0


/* Constant tables.  */

/* constant table ai4c */
static const unsigned CONST_TBL_ai4c_0[] = {
  0xffffffff,
  0x1,
  0x2,
  0x3,
  0x4,
  0x5,
  0x6,
  0x7,
  0x8,
  0x9,
  0xa,
  0xb,
  0xc,
  0xd,
  0xe,
  0xf,
  0
};

/* constant table b4c */
static const unsigned CONST_TBL_b4c_0[] = {
  0xffffffff,
  0x1,
  0x2,
  0x3,
  0x4,
  0x5,
  0x6,
  0x7,
  0x8,
  0xa,
  0xc,
  0x10,
  0x20,
  0x40,
  0x80,
  0x100,
  0
};

/* constant table b4cu */
static const unsigned CONST_TBL_b4cu_0[] = {
  0x8000,
  0x10000,
  0x2,
  0x3,
  0x4,
  0x5,
  0x6,
  0x7,
  0x8,
  0xa,
  0xc,
  0x10,
  0x20,
  0x40,
  0x80,
  0x100,
  0
};

/* constant table bitmask8 */
static const unsigned CONST_TBL_bitmask8_0[] = {
  0 & 0xff,
  0x1 & 0xff,
  0x3 & 0xff,
  0x7 & 0xff,
  0xf & 0xff,
  0x1f & 0xff,
  0x3f & 0xff,
  0x7f & 0xff,
  0
};

/* constant table ae_seliencode */
static const unsigned CONST_TBL_ae_seliencode_0[] = {
  0x4e5 & 0xfff,
  0x65 & 0xfff,
  0x77 & 0xfff,
  0x4f7 & 0xfff,
  0x72e & 0xfff,
  0x29c & 0xfff,
  0xaf & 0xfff,
  0xa6 & 0xfff,
  0x2ef & 0xfff,
  0x10d & 0xfff,
  0x599 & 0xfff,
  0,
  0,
  0,
  0,
  0,
  0
};

/* constant table RECIP_Data8 */
static const unsigned CONST_TBL_RECIP_Data8_0[] = {
  0xff & 0xff,
  0xfd & 0xff,
  0xfb & 0xff,
  0xf9 & 0xff,
  0xf7 & 0xff,
  0xf5 & 0xff,
  0xf4 & 0xff,
  0xf2 & 0xff,
  0xf0 & 0xff,
  0xee & 0xff,
  0xed & 0xff,
  0xeb & 0xff,
  0xe9 & 0xff,
  0xe8 & 0xff,
  0xe6 & 0xff,
  0xe4 & 0xff,
  0xe3 & 0xff,
  0xe1 & 0xff,
  0xe0 & 0xff,
  0xde & 0xff,
  0xdd & 0xff,
  0xdb & 0xff,
  0xda & 0xff,
  0xd8 & 0xff,
  0xd7 & 0xff,
  0xd5 & 0xff,
  0xd4 & 0xff,
  0xd3 & 0xff,
  0xd1 & 0xff,
  0xd0 & 0xff,
  0xcf & 0xff,
  0xcd & 0xff,
  0xcc & 0xff,
  0xcb & 0xff,
  0xca & 0xff,
  0xc8 & 0xff,
  0xc7 & 0xff,
  0xc6 & 0xff,
  0xc5 & 0xff,
  0xc4 & 0xff,
  0xc2 & 0xff,
  0xc1 & 0xff,
  0xc0 & 0xff,
  0xbf & 0xff,
  0xbe & 0xff,
  0xbd & 0xff,
  0xbc & 0xff,
  0xbb & 0xff,
  0xba & 0xff,
  0xb9 & 0xff,
  0xb8 & 0xff,
  0xb7 & 0xff,
  0xb6 & 0xff,
  0xb5 & 0xff,
  0xb4 & 0xff,
  0xb3 & 0xff,
  0xb2 & 0xff,
  0xb1 & 0xff,
  0xb0 & 0xff,
  0xaf & 0xff,
  0xae & 0xff,
  0xad & 0xff,
  0xac & 0xff,
  0xab & 0xff,
  0xaa & 0xff,
  0xa9 & 0xff,
  0xa8 & 0xff,
  0xa8 & 0xff,
  0xa7 & 0xff,
  0xa6 & 0xff,
  0xa5 & 0xff,
  0xa4 & 0xff,
  0xa3 & 0xff,
  0xa3 & 0xff,
  0xa2 & 0xff,
  0xa1 & 0xff,
  0xa0 & 0xff,
  0x9f & 0xff,
  0x9f & 0xff,
  0x9e & 0xff,
  0x9d & 0xff,
  0x9c & 0xff,
  0x9c & 0xff,
  0x9b & 0xff,
  0x9a & 0xff,
  0x99 & 0xff,
  0x99 & 0xff,
  0x98 & 0xff,
  0x97 & 0xff,
  0x97 & 0xff,
  0x96 & 0xff,
  0x95 & 0xff,
  0x95 & 0xff,
  0x94 & 0xff,
  0x93 & 0xff,
  0x93 & 0xff,
  0x92 & 0xff,
  0x91 & 0xff,
  0x91 & 0xff,
  0x90 & 0xff,
  0x8f & 0xff,
  0x8f & 0xff,
  0x8e & 0xff,
  0x8e & 0xff,
  0x8d & 0xff,
  0x8c & 0xff,
  0x8c & 0xff,
  0x8b & 0xff,
  0x8b & 0xff,
  0x8a & 0xff,
  0x89 & 0xff,
  0x89 & 0xff,
  0x88 & 0xff,
  0x88 & 0xff,
  0x87 & 0xff,
  0x87 & 0xff,
  0x86 & 0xff,
  0x85 & 0xff,
  0x85 & 0xff,
  0x84 & 0xff,
  0x84 & 0xff,
  0x83 & 0xff,
  0x83 & 0xff,
  0x82 & 0xff,
  0x82 & 0xff,
  0x81 & 0xff,
  0x81 & 0xff,
  0x81 & 0xff,
  0
};

/* constant table RSQRT_Data8 */
static const unsigned CONST_TBL_RSQRT_Data8_0[] = {
  0xb4 & 0xff,
  0xb3 & 0xff,
  0xb2 & 0xff,
  0xb0 & 0xff,
  0xaf & 0xff,
  0xae & 0xff,
  0xac & 0xff,
  0xab & 0xff,
  0xaa & 0xff,
  0xa9 & 0xff,
  0xa8 & 0xff,
  0xa7 & 0xff,
  0xa6 & 0xff,
  0xa5 & 0xff,
  0xa3 & 0xff,
  0xa2 & 0xff,
  0xa1 & 0xff,
  0xa0 & 0xff,
  0x9f & 0xff,
  0x9e & 0xff,
  0x9e & 0xff,
  0x9d & 0xff,
  0x9c & 0xff,
  0x9b & 0xff,
  0x9a & 0xff,
  0x99 & 0xff,
  0x98 & 0xff,
  0x97 & 0xff,
  0x97 & 0xff,
  0x96 & 0xff,
  0x95 & 0xff,
  0x94 & 0xff,
  0x93 & 0xff,
  0x93 & 0xff,
  0x92 & 0xff,
  0x91 & 0xff,
  0x90 & 0xff,
  0x90 & 0xff,
  0x8f & 0xff,
  0x8e & 0xff,
  0x8e & 0xff,
  0x8d & 0xff,
  0x8c & 0xff,
  0x8c & 0xff,
  0x8b & 0xff,
  0x8a & 0xff,
  0x8a & 0xff,
  0x89 & 0xff,
  0x89 & 0xff,
  0x88 & 0xff,
  0x87 & 0xff,
  0x87 & 0xff,
  0x86 & 0xff,
  0x86 & 0xff,
  0x85 & 0xff,
  0x84 & 0xff,
  0x84 & 0xff,
  0x83 & 0xff,
  0x83 & 0xff,
  0x82 & 0xff,
  0x82 & 0xff,
  0x81 & 0xff,
  0x81 & 0xff,
  0x80 & 0xff,
  0xff & 0xff,
  0xfd & 0xff,
  0xfb & 0xff,
  0xf9 & 0xff,
  0xf7 & 0xff,
  0xf6 & 0xff,
  0xf4 & 0xff,
  0xf2 & 0xff,
  0xf1 & 0xff,
  0xef & 0xff,
  0xed & 0xff,
  0xec & 0xff,
  0xea & 0xff,
  0xe9 & 0xff,
  0xe7 & 0xff,
  0xe6 & 0xff,
  0xe4 & 0xff,
  0xe3 & 0xff,
  0xe1 & 0xff,
  0xe0 & 0xff,
  0xdf & 0xff,
  0xdd & 0xff,
  0xdc & 0xff,
  0xdb & 0xff,
  0xda & 0xff,
  0xd8 & 0xff,
  0xd7 & 0xff,
  0xd6 & 0xff,
  0xd5 & 0xff,
  0xd4 & 0xff,
  0xd3 & 0xff,
  0xd2 & 0xff,
  0xd0 & 0xff,
  0xcf & 0xff,
  0xce & 0xff,
  0xcd & 0xff,
  0xcc & 0xff,
  0xcb & 0xff,
  0xca & 0xff,
  0xc9 & 0xff,
  0xc8 & 0xff,
  0xc7 & 0xff,
  0xc6 & 0xff,
  0xc6 & 0xff,
  0xc5 & 0xff,
  0xc4 & 0xff,
  0xc3 & 0xff,
  0xc2 & 0xff,
  0xc1 & 0xff,
  0xc0 & 0xff,
  0xbf & 0xff,
  0xbf & 0xff,
  0xbe & 0xff,
  0xbd & 0xff,
  0xbc & 0xff,
  0xbb & 0xff,
  0xbb & 0xff,
  0xba & 0xff,
  0xb9 & 0xff,
  0xb8 & 0xff,
  0xb8 & 0xff,
  0xb7 & 0xff,
  0xb6 & 0xff,
  0xb5 & 0xff,
  0
};

/* constant table RECIP_Data10_2 */
static const unsigned CONST_TBL_RECIP_Data10_2_0[] = {
  0x3fc & 0x3ff,
  0x3f4 & 0x3ff,
  0x3ec & 0x3ff,
  0x3e5 & 0x3ff,
  0x3dd & 0x3ff,
  0x3d6 & 0x3ff,
  0x3cf & 0x3ff,
  0x3c7 & 0x3ff,
  0x3c0 & 0x3ff,
  0x3b9 & 0x3ff,
  0x3b2 & 0x3ff,
  0x3ac & 0x3ff,
  0x3a5 & 0x3ff,
  0x39e & 0x3ff,
  0x398 & 0x3ff,
  0x391 & 0x3ff,
  0x38b & 0x3ff,
  0x385 & 0x3ff,
  0x37f & 0x3ff,
  0x378 & 0x3ff,
  0x373 & 0x3ff,
  0x36c & 0x3ff,
  0x367 & 0x3ff,
  0x361 & 0x3ff,
  0x35c & 0x3ff,
  0x356 & 0x3ff,
  0x350 & 0x3ff,
  0x34b & 0x3ff,
  0x345 & 0x3ff,
  0x340 & 0x3ff,
  0x33b & 0x3ff,
  0x335 & 0x3ff,
  0x330 & 0x3ff,
  0x32c & 0x3ff,
  0x327 & 0x3ff,
  0x322 & 0x3ff,
  0x31c & 0x3ff,
  0x318 & 0x3ff,
  0x314 & 0x3ff,
  0x30e & 0x3ff,
  0x30a & 0x3ff,
  0x306 & 0x3ff,
  0x300 & 0x3ff,
  0x2fc & 0x3ff,
  0x2f8 & 0x3ff,
  0x2f4 & 0x3ff,
  0x2f0 & 0x3ff,
  0x2ea & 0x3ff,
  0x2e6 & 0x3ff,
  0x2e2 & 0x3ff,
  0x2de & 0x3ff,
  0x2da & 0x3ff,
  0x2d6 & 0x3ff,
  0x2d2 & 0x3ff,
  0x2ce & 0x3ff,
  0x2ca & 0x3ff,
  0x2c6 & 0x3ff,
  0x2c2 & 0x3ff,
  0x2be & 0x3ff,
  0x2ba & 0x3ff,
  0x2b8 & 0x3ff,
  0x2b4 & 0x3ff,
  0x2b0 & 0x3ff,
  0x2ac & 0x3ff,
  0x2a8 & 0x3ff,
  0x2a6 & 0x3ff,
  0x2a2 & 0x3ff,
  0x29e & 0x3ff,
  0x29c & 0x3ff,
  0x298 & 0x3ff,
  0x294 & 0x3ff,
  0x290 & 0x3ff,
  0x28e & 0x3ff,
  0x28a & 0x3ff,
  0x288 & 0x3ff,
  0x284 & 0x3ff,
  0x280 & 0x3ff,
  0x27e & 0x3ff,
  0x27a & 0x3ff,
  0x278 & 0x3ff,
  0x274 & 0x3ff,
  0x272 & 0x3ff,
  0x26e & 0x3ff,
  0x26c & 0x3ff,
  0x268 & 0x3ff,
  0x266 & 0x3ff,
  0x264 & 0x3ff,
  0x260 & 0x3ff,
  0x25e & 0x3ff,
  0x25a & 0x3ff,
  0x258 & 0x3ff,
  0x254 & 0x3ff,
  0x252 & 0x3ff,
  0x250 & 0x3ff,
  0x24c & 0x3ff,
  0x24a & 0x3ff,
  0x248 & 0x3ff,
  0x246 & 0x3ff,
  0x242 & 0x3ff,
  0x240 & 0x3ff,
  0x23e & 0x3ff,
  0x23c & 0x3ff,
  0x238 & 0x3ff,
  0x236 & 0x3ff,
  0x234 & 0x3ff,
  0x232 & 0x3ff,
  0x230 & 0x3ff,
  0x22c & 0x3ff,
  0x22a & 0x3ff,
  0x228 & 0x3ff,
  0x226 & 0x3ff,
  0x224 & 0x3ff,
  0x220 & 0x3ff,
  0x21e & 0x3ff,
  0x21c & 0x3ff,
  0x21a & 0x3ff,
  0x218 & 0x3ff,
  0x216 & 0x3ff,
  0x214 & 0x3ff,
  0x212 & 0x3ff,
  0x210 & 0x3ff,
  0x20e & 0x3ff,
  0x20c & 0x3ff,
  0x208 & 0x3ff,
  0x208 & 0x3ff,
  0x204 & 0x3ff,
  0x204 & 0x3ff,
  0x201 & 0x3ff,
  0
};

/* constant table RSQRT_10b_256 */
static const unsigned CONST_TBL_RSQRT_10b_256_0[] = {
  0x1a5 & 0x3ff,
  0x1a0 & 0x3ff,
  0x19a & 0x3ff,
  0x195 & 0x3ff,
  0x18f & 0x3ff,
  0x18a & 0x3ff,
  0x185 & 0x3ff,
  0x180 & 0x3ff,
  0x17a & 0x3ff,
  0x175 & 0x3ff,
  0x170 & 0x3ff,
  0x16b & 0x3ff,
  0x166 & 0x3ff,
  0x161 & 0x3ff,
  0x15d & 0x3ff,
  0x158 & 0x3ff,
  0x153 & 0x3ff,
  0x14e & 0x3ff,
  0x14a & 0x3ff,
  0x145 & 0x3ff,
  0x140 & 0x3ff,
  0x13c & 0x3ff,
  0x138 & 0x3ff,
  0x133 & 0x3ff,
  0x12f & 0x3ff,
  0x12a & 0x3ff,
  0x126 & 0x3ff,
  0x122 & 0x3ff,
  0x11e & 0x3ff,
  0x11a & 0x3ff,
  0x115 & 0x3ff,
  0x111 & 0x3ff,
  0x10d & 0x3ff,
  0x109 & 0x3ff,
  0x105 & 0x3ff,
  0x101 & 0x3ff,
  0xfd & 0x3ff,
  0xfa & 0x3ff,
  0xf6 & 0x3ff,
  0xf2 & 0x3ff,
  0xee & 0x3ff,
  0xea & 0x3ff,
  0xe7 & 0x3ff,
  0xe3 & 0x3ff,
  0xdf & 0x3ff,
  0xdc & 0x3ff,
  0xd8 & 0x3ff,
  0xd5 & 0x3ff,
  0xd1 & 0x3ff,
  0xce & 0x3ff,
  0xca & 0x3ff,
  0xc7 & 0x3ff,
  0xc3 & 0x3ff,
  0xc0 & 0x3ff,
  0xbd & 0x3ff,
  0xb9 & 0x3ff,
  0xb6 & 0x3ff,
  0xb3 & 0x3ff,
  0xb0 & 0x3ff,
  0xad & 0x3ff,
  0xa9 & 0x3ff,
  0xa6 & 0x3ff,
  0xa3 & 0x3ff,
  0xa0 & 0x3ff,
  0x9d & 0x3ff,
  0x9a & 0x3ff,
  0x97 & 0x3ff,
  0x94 & 0x3ff,
  0x91 & 0x3ff,
  0x8e & 0x3ff,
  0x8b & 0x3ff,
  0x88 & 0x3ff,
  0x85 & 0x3ff,
  0x82 & 0x3ff,
  0x7f & 0x3ff,
  0x7d & 0x3ff,
  0x7a & 0x3ff,
  0x77 & 0x3ff,
  0x74 & 0x3ff,
  0x71 & 0x3ff,
  0x6f & 0x3ff,
  0x6c & 0x3ff,
  0x69 & 0x3ff,
  0x67 & 0x3ff,
  0x64 & 0x3ff,
  0x61 & 0x3ff,
  0x5f & 0x3ff,
  0x5c & 0x3ff,
  0x5a & 0x3ff,
  0x57 & 0x3ff,
  0x54 & 0x3ff,
  0x52 & 0x3ff,
  0x4f & 0x3ff,
  0x4d & 0x3ff,
  0x4a & 0x3ff,
  0x48 & 0x3ff,
  0x45 & 0x3ff,
  0x43 & 0x3ff,
  0x41 & 0x3ff,
  0x3e & 0x3ff,
  0x3c & 0x3ff,
  0x3a & 0x3ff,
  0x37 & 0x3ff,
  0x35 & 0x3ff,
  0x33 & 0x3ff,
  0x30 & 0x3ff,
  0x2e & 0x3ff,
  0x2c & 0x3ff,
  0x29 & 0x3ff,
  0x27 & 0x3ff,
  0x25 & 0x3ff,
  0x23 & 0x3ff,
  0x20 & 0x3ff,
  0x1e & 0x3ff,
  0x1c & 0x3ff,
  0x1a & 0x3ff,
  0x18 & 0x3ff,
  0x16 & 0x3ff,
  0x14 & 0x3ff,
  0x11 & 0x3ff,
  0xf & 0x3ff,
  0xd & 0x3ff,
  0xb & 0x3ff,
  0x9 & 0x3ff,
  0x7 & 0x3ff,
  0x5 & 0x3ff,
  0x3 & 0x3ff,
  0x1 & 0x3ff,
  0x3fc & 0x3ff,
  0x3f4 & 0x3ff,
  0x3ec & 0x3ff,
  0x3e5 & 0x3ff,
  0x3dd & 0x3ff,
  0x3d5 & 0x3ff,
  0x3ce & 0x3ff,
  0x3c7 & 0x3ff,
  0x3bf & 0x3ff,
  0x3b8 & 0x3ff,
  0x3b1 & 0x3ff,
  0x3aa & 0x3ff,
  0x3a3 & 0x3ff,
  0x39c & 0x3ff,
  0x395 & 0x3ff,
  0x38e & 0x3ff,
  0x388 & 0x3ff,
  0x381 & 0x3ff,
  0x37a & 0x3ff,
  0x374 & 0x3ff,
  0x36d & 0x3ff,
  0x367 & 0x3ff,
  0x361 & 0x3ff,
  0x35a & 0x3ff,
  0x354 & 0x3ff,
  0x34e & 0x3ff,
  0x348 & 0x3ff,
  0x342 & 0x3ff,
  0x33c & 0x3ff,
  0x336 & 0x3ff,
  0x330 & 0x3ff,
  0x32b & 0x3ff,
  0x325 & 0x3ff,
  0x31f & 0x3ff,
  0x31a & 0x3ff,
  0x314 & 0x3ff,
  0x30f & 0x3ff,
  0x309 & 0x3ff,
  0x304 & 0x3ff,
  0x2fe & 0x3ff,
  0x2f9 & 0x3ff,
  0x2f4 & 0x3ff,
  0x2ee & 0x3ff,
  0x2e9 & 0x3ff,
  0x2e4 & 0x3ff,
  0x2df & 0x3ff,
  0x2da & 0x3ff,
  0x2d5 & 0x3ff,
  0x2d0 & 0x3ff,
  0x2cb & 0x3ff,
  0x2c6 & 0x3ff,
  0x2c1 & 0x3ff,
  0x2bd & 0x3ff,
  0x2b8 & 0x3ff,
  0x2b3 & 0x3ff,
  0x2ae & 0x3ff,
  0x2aa & 0x3ff,
  0x2a5 & 0x3ff,
  0x2a1 & 0x3ff,
  0x29c & 0x3ff,
  0x298 & 0x3ff,
  0x293 & 0x3ff,
  0x28f & 0x3ff,
  0x28a & 0x3ff,
  0x286 & 0x3ff,
  0x282 & 0x3ff,
  0x27d & 0x3ff,
  0x279 & 0x3ff,
  0x275 & 0x3ff,
  0x271 & 0x3ff,
  0x26d & 0x3ff,
  0x268 & 0x3ff,
  0x264 & 0x3ff,
  0x260 & 0x3ff,
  0x25c & 0x3ff,
  0x258 & 0x3ff,
  0x254 & 0x3ff,
  0x250 & 0x3ff,
  0x24c & 0x3ff,
  0x249 & 0x3ff,
  0x245 & 0x3ff,
  0x241 & 0x3ff,
  0x23d & 0x3ff,
  0x239 & 0x3ff,
  0x235 & 0x3ff,
  0x232 & 0x3ff,
  0x22e & 0x3ff,
  0x22a & 0x3ff,
  0x227 & 0x3ff,
  0x223 & 0x3ff,
  0x220 & 0x3ff,
  0x21c & 0x3ff,
  0x218 & 0x3ff,
  0x215 & 0x3ff,
  0x211 & 0x3ff,
  0x20e & 0x3ff,
  0x20a & 0x3ff,
  0x207 & 0x3ff,
  0x204 & 0x3ff,
  0x200 & 0x3ff,
  0x1fd & 0x3ff,
  0x1f9 & 0x3ff,
  0x1f6 & 0x3ff,
  0x1f3 & 0x3ff,
  0x1f0 & 0x3ff,
  0x1ec & 0x3ff,
  0x1e9 & 0x3ff,
  0x1e6 & 0x3ff,
  0x1e3 & 0x3ff,
  0x1df & 0x3ff,
  0x1dc & 0x3ff,
  0x1d9 & 0x3ff,
  0x1d6 & 0x3ff,
  0x1d3 & 0x3ff,
  0x1d0 & 0x3ff,
  0x1cd & 0x3ff,
  0x1ca & 0x3ff,
  0x1c7 & 0x3ff,
  0x1c4 & 0x3ff,
  0x1c1 & 0x3ff,
  0x1be & 0x3ff,
  0x1bb & 0x3ff,
  0x1b8 & 0x3ff,
  0x1b5 & 0x3ff,
  0x1b2 & 0x3ff,
  0x1af & 0x3ff,
  0x1ac & 0x3ff,
  0x1aa & 0x3ff,
  0
};

/* constant table RECIP_10b_256 */
static const unsigned CONST_TBL_RECIP_10b_256_0[] = {
  0x3fc & 0x3ff,
  0x3f4 & 0x3ff,
  0x3ec & 0x3ff,
  0x3e4 & 0x3ff,
  0x3dd & 0x3ff,
  0x3d5 & 0x3ff,
  0x3cd & 0x3ff,
  0x3c6 & 0x3ff,
  0x3be & 0x3ff,
  0x3b7 & 0x3ff,
  0x3af & 0x3ff,
  0x3a8 & 0x3ff,
  0x3a1 & 0x3ff,
  0x399 & 0x3ff,
  0x392 & 0x3ff,
  0x38b & 0x3ff,
  0x384 & 0x3ff,
  0x37d & 0x3ff,
  0x376 & 0x3ff,
  0x36f & 0x3ff,
  0x368 & 0x3ff,
  0x361 & 0x3ff,
  0x35b & 0x3ff,
  0x354 & 0x3ff,
  0x34d & 0x3ff,
  0x346 & 0x3ff,
  0x340 & 0x3ff,
  0x339 & 0x3ff,
  0x333 & 0x3ff,
  0x32c & 0x3ff,
  0x326 & 0x3ff,
  0x320 & 0x3ff,
  0x319 & 0x3ff,
  0x313 & 0x3ff,
  0x30d & 0x3ff,
  0x307 & 0x3ff,
  0x300 & 0x3ff,
  0x2fa & 0x3ff,
  0x2f4 & 0x3ff,
  0x2ee & 0x3ff,
  0x2e8 & 0x3ff,
  0x2e2 & 0x3ff,
  0x2dc & 0x3ff,
  0x2d7 & 0x3ff,
  0x2d1 & 0x3ff,
  0x2cb & 0x3ff,
  0x2c5 & 0x3ff,
  0x2bf & 0x3ff,
  0x2ba & 0x3ff,
  0x2b4 & 0x3ff,
  0x2af & 0x3ff,
  0x2a9 & 0x3ff,
  0x2a3 & 0x3ff,
  0x29e & 0x3ff,
  0x299 & 0x3ff,
  0x293 & 0x3ff,
  0x28e & 0x3ff,
  0x288 & 0x3ff,
  0x283 & 0x3ff,
  0x27e & 0x3ff,
  0x279 & 0x3ff,
  0x273 & 0x3ff,
  0x26e & 0x3ff,
  0x269 & 0x3ff,
  0x264 & 0x3ff,
  0x25f & 0x3ff,
  0x25a & 0x3ff,
  0x255 & 0x3ff,
  0x250 & 0x3ff,
  0x24b & 0x3ff,
  0x246 & 0x3ff,
  0x241 & 0x3ff,
  0x23c & 0x3ff,
  0x237 & 0x3ff,
  0x232 & 0x3ff,
  0x22e & 0x3ff,
  0x229 & 0x3ff,
  0x224 & 0x3ff,
  0x21f & 0x3ff,
  0x21b & 0x3ff,
  0x216 & 0x3ff,
  0x211 & 0x3ff,
  0x20d & 0x3ff,
  0x208 & 0x3ff,
  0x204 & 0x3ff,
  0x1ff & 0x3ff,
  0x1fb & 0x3ff,
  0x1f6 & 0x3ff,
  0x1f2 & 0x3ff,
  0x1ed & 0x3ff,
  0x1e9 & 0x3ff,
  0x1e5 & 0x3ff,
  0x1e0 & 0x3ff,
  0x1dc & 0x3ff,
  0x1d8 & 0x3ff,
  0x1d4 & 0x3ff,
  0x1cf & 0x3ff,
  0x1cb & 0x3ff,
  0x1c7 & 0x3ff,
  0x1c3 & 0x3ff,
  0x1bf & 0x3ff,
  0x1bb & 0x3ff,
  0x1b6 & 0x3ff,
  0x1b2 & 0x3ff,
  0x1ae & 0x3ff,
  0x1aa & 0x3ff,
  0x1a6 & 0x3ff,
  0x1a2 & 0x3ff,
  0x19e & 0x3ff,
  0x19a & 0x3ff,
  0x197 & 0x3ff,
  0x193 & 0x3ff,
  0x18f & 0x3ff,
  0x18b & 0x3ff,
  0x187 & 0x3ff,
  0x183 & 0x3ff,
  0x17f & 0x3ff,
  0x17c & 0x3ff,
  0x178 & 0x3ff,
  0x174 & 0x3ff,
  0x171 & 0x3ff,
  0x16d & 0x3ff,
  0x169 & 0x3ff,
  0x166 & 0x3ff,
  0x162 & 0x3ff,
  0x15e & 0x3ff,
  0x15b & 0x3ff,
  0x157 & 0x3ff,
  0x154 & 0x3ff,
  0x150 & 0x3ff,
  0x14d & 0x3ff,
  0x149 & 0x3ff,
  0x146 & 0x3ff,
  0x142 & 0x3ff,
  0x13f & 0x3ff,
  0x13b & 0x3ff,
  0x138 & 0x3ff,
  0x134 & 0x3ff,
  0x131 & 0x3ff,
  0x12e & 0x3ff,
  0x12a & 0x3ff,
  0x127 & 0x3ff,
  0x124 & 0x3ff,
  0x120 & 0x3ff,
  0x11d & 0x3ff,
  0x11a & 0x3ff,
  0x117 & 0x3ff,
  0x113 & 0x3ff,
  0x110 & 0x3ff,
  0x10d & 0x3ff,
  0x10a & 0x3ff,
  0x107 & 0x3ff,
  0x103 & 0x3ff,
  0x100 & 0x3ff,
  0xfd & 0x3ff,
  0xfa & 0x3ff,
  0xf7 & 0x3ff,
  0xf4 & 0x3ff,
  0xf1 & 0x3ff,
  0xee & 0x3ff,
  0xeb & 0x3ff,
  0xe8 & 0x3ff,
  0xe5 & 0x3ff,
  0xe2 & 0x3ff,
  0xdf & 0x3ff,
  0xdc & 0x3ff,
  0xd9 & 0x3ff,
  0xd6 & 0x3ff,
  0xd3 & 0x3ff,
  0xd0 & 0x3ff,
  0xcd & 0x3ff,
  0xca & 0x3ff,
  0xc8 & 0x3ff,
  0xc5 & 0x3ff,
  0xc2 & 0x3ff,
  0xbf & 0x3ff,
  0xbc & 0x3ff,
  0xb9 & 0x3ff,
  0xb7 & 0x3ff,
  0xb4 & 0x3ff,
  0xb1 & 0x3ff,
  0xae & 0x3ff,
  0xac & 0x3ff,
  0xa9 & 0x3ff,
  0xa6 & 0x3ff,
  0xa4 & 0x3ff,
  0xa1 & 0x3ff,
  0x9e & 0x3ff,
  0x9c & 0x3ff,
  0x99 & 0x3ff,
  0x96 & 0x3ff,
  0x94 & 0x3ff,
  0x91 & 0x3ff,
  0x8e & 0x3ff,
  0x8c & 0x3ff,
  0x89 & 0x3ff,
  0x87 & 0x3ff,
  0x84 & 0x3ff,
  0x82 & 0x3ff,
  0x7f & 0x3ff,
  0x7c & 0x3ff,
  0x7a & 0x3ff,
  0x77 & 0x3ff,
  0x75 & 0x3ff,
  0x73 & 0x3ff,
  0x70 & 0x3ff,
  0x6e & 0x3ff,
  0x6b & 0x3ff,
  0x69 & 0x3ff,
  0x66 & 0x3ff,
  0x64 & 0x3ff,
  0x61 & 0x3ff,
  0x5f & 0x3ff,
  0x5d & 0x3ff,
  0x5a & 0x3ff,
  0x58 & 0x3ff,
  0x56 & 0x3ff,
  0x53 & 0x3ff,
  0x51 & 0x3ff,
  0x4f & 0x3ff,
  0x4c & 0x3ff,
  0x4a & 0x3ff,
  0x48 & 0x3ff,
  0x45 & 0x3ff,
  0x43 & 0x3ff,
  0x41 & 0x3ff,
  0x3f & 0x3ff,
  0x3c & 0x3ff,
  0x3a & 0x3ff,
  0x38 & 0x3ff,
  0x36 & 0x3ff,
  0x33 & 0x3ff,
  0x31 & 0x3ff,
  0x2f & 0x3ff,
  0x2d & 0x3ff,
  0x2b & 0x3ff,
  0x29 & 0x3ff,
  0x26 & 0x3ff,
  0x24 & 0x3ff,
  0x22 & 0x3ff,
  0x20 & 0x3ff,
  0x1e & 0x3ff,
  0x1c & 0x3ff,
  0x1a & 0x3ff,
  0x18 & 0x3ff,
  0x15 & 0x3ff,
  0x13 & 0x3ff,
  0x11 & 0x3ff,
  0xf & 0x3ff,
  0xd & 0x3ff,
  0xb & 0x3ff,
  0x9 & 0x3ff,
  0x7 & 0x3ff,
  0x5 & 0x3ff,
  0x3 & 0x3ff,
  0x1 & 0x3ff,
  0
};


/* Instruction operands.  */

static int
OperandSem_opnd_sem_soffsetx4_decode (uint32 *valp)
{
  unsigned soffsetx4_out_0;
  unsigned soffsetx4_in_0;
  soffsetx4_in_0 = *valp & 0x3ffff;
  soffsetx4_out_0 = 0x4 + ((((int) soffsetx4_in_0 << 14) >> 14) << 2);
  *valp = soffsetx4_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_soffsetx4_encode (uint32 *valp)
{
  unsigned soffsetx4_in_0;
  unsigned soffsetx4_out_0;
  soffsetx4_out_0 = *valp;
  soffsetx4_in_0 = ((soffsetx4_out_0 - 0x4) >> 2) & 0x3ffff;
  *valp = soffsetx4_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_immr_decode (uint32 *valp)
{
  unsigned immr_out_0;
  unsigned immr_in_0;
  immr_in_0 = *valp & 0xf;
  immr_out_0 = immr_in_0;
  *valp = immr_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_immr_encode (uint32 *valp)
{
  unsigned immr_in_0;
  unsigned immr_out_0;
  immr_out_0 = *valp;
  immr_in_0 = (immr_out_0 & 0xf);
  *valp = immr_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_uimm12x8_decode (uint32 *valp)
{
  unsigned uimm12x8_out_0;
  unsigned uimm12x8_in_0;
  uimm12x8_in_0 = *valp & 0xfff;
  uimm12x8_out_0 = uimm12x8_in_0 << 3;
  *valp = uimm12x8_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_uimm12x8_encode (uint32 *valp)
{
  unsigned uimm12x8_in_0;
  unsigned uimm12x8_out_0;
  uimm12x8_out_0 = *valp;
  uimm12x8_in_0 = ((uimm12x8_out_0 >> 3) & 0xfff);
  *valp = uimm12x8_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_simm4_decode (uint32 *valp)
{
  unsigned simm4_out_0;
  unsigned simm4_in_0;
  simm4_in_0 = *valp & 0xf;
  simm4_out_0 = ((int) simm4_in_0 << 28) >> 28;
  *valp = simm4_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_simm4_encode (uint32 *valp)
{
  unsigned simm4_in_0;
  unsigned simm4_out_0;
  simm4_out_0 = *valp;
  simm4_in_0 = (simm4_out_0 & 0xf);
  *valp = simm4_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_AR_decode (uint32 *valp ATTRIBUTE_UNUSED)
{
  return 0;
}

static int
OperandSem_opnd_sem_AR_encode (uint32 *valp)
{
  int error;
  error = (*valp >= 64);
  return error;
}

static int
OperandSem_opnd_sem_AR_0_decode (uint32 *valp ATTRIBUTE_UNUSED)
{
  return 0;
}

static int
OperandSem_opnd_sem_AR_0_encode (uint32 *valp)
{
  int error;
  error = (*valp >= 64);
  return error;
}

static int
OperandSem_opnd_sem_AR_4_decode (uint32 *valp ATTRIBUTE_UNUSED)
{
  return 0;
}

static int
OperandSem_opnd_sem_AR_4_encode (uint32 *valp)
{
  int error;
  error = (*valp >= 64);
  return error;
}

static int
OperandSem_opnd_sem_AR_8_decode (uint32 *valp ATTRIBUTE_UNUSED)
{
  return 0;
}

static int
OperandSem_opnd_sem_AR_8_encode (uint32 *valp)
{
  int error;
  error = (*valp >= 64);
  return error;
}

static int
OperandSem_opnd_sem_AR_12_decode (uint32 *valp ATTRIBUTE_UNUSED)
{
  return 0;
}

static int
OperandSem_opnd_sem_AR_12_encode (uint32 *valp)
{
  int error;
  error = (*valp >= 64);
  return error;
}

static int
OperandSem_opnd_sem_AR_entry_decode (uint32 *valp ATTRIBUTE_UNUSED)
{
  return 0;
}

static int
OperandSem_opnd_sem_AR_entry_encode (uint32 *valp)
{
  int error;
  error = (*valp >= 64);
  return error;
}

static int
OperandSem_opnd_sem_immrx4_decode (uint32 *valp)
{
  unsigned immrx4_out_0;
  unsigned immrx4_in_0;
  immrx4_in_0 = *valp & 0xf;
  immrx4_out_0 = (((0xfffffff) << 4) | immrx4_in_0) << 2;
  *valp = immrx4_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_immrx4_encode (uint32 *valp)
{
  unsigned immrx4_in_0;
  unsigned immrx4_out_0;
  immrx4_out_0 = *valp;
  immrx4_in_0 = ((immrx4_out_0 >> 2) & 0xf);
  *valp = immrx4_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_lsi4x4_decode (uint32 *valp)
{
  unsigned lsi4x4_out_0;
  unsigned lsi4x4_in_0;
  lsi4x4_in_0 = *valp & 0xf;
  lsi4x4_out_0 = lsi4x4_in_0 << 2;
  *valp = lsi4x4_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_lsi4x4_encode (uint32 *valp)
{
  unsigned lsi4x4_in_0;
  unsigned lsi4x4_out_0;
  lsi4x4_out_0 = *valp;
  lsi4x4_in_0 = ((lsi4x4_out_0 >> 2) & 0xf);
  *valp = lsi4x4_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_simm7_decode (uint32 *valp)
{
  unsigned simm7_out_0;
  unsigned simm7_in_0;
  simm7_in_0 = *valp & 0x7f;
  simm7_out_0 = ((((-((((simm7_in_0 >> 6) & 1)) & (((simm7_in_0 >> 5) & 1)))) & 0x1ffffff)) << 7) | simm7_in_0;
  *valp = simm7_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_simm7_encode (uint32 *valp)
{
  unsigned simm7_in_0;
  unsigned simm7_out_0;
  simm7_out_0 = *valp;
  simm7_in_0 = (simm7_out_0 & 0x7f);
  *valp = simm7_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_uimm6_decode (uint32 *valp)
{
  unsigned uimm6_out_0;
  unsigned uimm6_in_0;
  uimm6_in_0 = *valp & 0x3f;
  uimm6_out_0 = 0x4 + (((0) << 6) | uimm6_in_0);
  *valp = uimm6_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_uimm6_encode (uint32 *valp)
{
  unsigned uimm6_in_0;
  unsigned uimm6_out_0;
  uimm6_out_0 = *valp;
  uimm6_in_0 = (uimm6_out_0 - 0x4) & 0x3f;
  *valp = uimm6_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_ai4const_decode (uint32 *valp)
{
  unsigned ai4const_out_0;
  unsigned ai4const_in_0;
  ai4const_in_0 = *valp & 0xf;
  ai4const_out_0 = CONST_TBL_ai4c_0[ai4const_in_0 & 0xf];
  *valp = ai4const_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_ai4const_encode (uint32 *valp)
{
  unsigned ai4const_in_0;
  unsigned ai4const_out_0;
  ai4const_out_0 = *valp;
  switch (ai4const_out_0)
    {
    case 0xffffffff: ai4const_in_0 = 0; break;
    case 0x1: ai4const_in_0 = 0x1; break;
    case 0x2: ai4const_in_0 = 0x2; break;
    case 0x3: ai4const_in_0 = 0x3; break;
    case 0x4: ai4const_in_0 = 0x4; break;
    case 0x5: ai4const_in_0 = 0x5; break;
    case 0x6: ai4const_in_0 = 0x6; break;
    case 0x7: ai4const_in_0 = 0x7; break;
    case 0x8: ai4const_in_0 = 0x8; break;
    case 0x9: ai4const_in_0 = 0x9; break;
    case 0xa: ai4const_in_0 = 0xa; break;
    case 0xb: ai4const_in_0 = 0xb; break;
    case 0xc: ai4const_in_0 = 0xc; break;
    case 0xd: ai4const_in_0 = 0xd; break;
    case 0xe: ai4const_in_0 = 0xe; break;
    default: ai4const_in_0 = 0xf; break;
    }
  *valp = ai4const_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_b4const_decode (uint32 *valp)
{
  unsigned b4const_out_0;
  unsigned b4const_in_0;
  b4const_in_0 = *valp & 0xf;
  b4const_out_0 = CONST_TBL_b4c_0[b4const_in_0 & 0xf];
  *valp = b4const_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_b4const_encode (uint32 *valp)
{
  unsigned b4const_in_0;
  unsigned b4const_out_0;
  b4const_out_0 = *valp;
  switch (b4const_out_0)
    {
    case 0xffffffff: b4const_in_0 = 0; break;
    case 0x1: b4const_in_0 = 0x1; break;
    case 0x2: b4const_in_0 = 0x2; break;
    case 0x3: b4const_in_0 = 0x3; break;
    case 0x4: b4const_in_0 = 0x4; break;
    case 0x5: b4const_in_0 = 0x5; break;
    case 0x6: b4const_in_0 = 0x6; break;
    case 0x7: b4const_in_0 = 0x7; break;
    case 0x8: b4const_in_0 = 0x8; break;
    case 0xa: b4const_in_0 = 0x9; break;
    case 0xc: b4const_in_0 = 0xa; break;
    case 0x10: b4const_in_0 = 0xb; break;
    case 0x20: b4const_in_0 = 0xc; break;
    case 0x40: b4const_in_0 = 0xd; break;
    case 0x80: b4const_in_0 = 0xe; break;
    default: b4const_in_0 = 0xf; break;
    }
  *valp = b4const_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_b4constu_decode (uint32 *valp)
{
  unsigned b4constu_out_0;
  unsigned b4constu_in_0;
  b4constu_in_0 = *valp & 0xf;
  b4constu_out_0 = CONST_TBL_b4cu_0[b4constu_in_0 & 0xf];
  *valp = b4constu_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_b4constu_encode (uint32 *valp)
{
  unsigned b4constu_in_0;
  unsigned b4constu_out_0;
  b4constu_out_0 = *valp;
  switch (b4constu_out_0)
    {
    case 0x8000: b4constu_in_0 = 0; break;
    case 0x10000: b4constu_in_0 = 0x1; break;
    case 0x2: b4constu_in_0 = 0x2; break;
    case 0x3: b4constu_in_0 = 0x3; break;
    case 0x4: b4constu_in_0 = 0x4; break;
    case 0x5: b4constu_in_0 = 0x5; break;
    case 0x6: b4constu_in_0 = 0x6; break;
    case 0x7: b4constu_in_0 = 0x7; break;
    case 0x8: b4constu_in_0 = 0x8; break;
    case 0xa: b4constu_in_0 = 0x9; break;
    case 0xc: b4constu_in_0 = 0xa; break;
    case 0x10: b4constu_in_0 = 0xb; break;
    case 0x20: b4constu_in_0 = 0xc; break;
    case 0x40: b4constu_in_0 = 0xd; break;
    case 0x80: b4constu_in_0 = 0xe; break;
    default: b4constu_in_0 = 0xf; break;
    }
  *valp = b4constu_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_immt_decode (uint32 *valp)
{
  unsigned immt_out_0;
  unsigned immt_in_0;
  immt_in_0 = *valp & 0xf;
  immt_out_0 = immt_in_0;
  *valp = immt_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_immt_encode (uint32 *valp)
{
  unsigned immt_in_0;
  unsigned immt_out_0;
  immt_out_0 = *valp;
  immt_in_0 = immt_out_0 & 0xf;
  *valp = immt_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_uimm8_decode (uint32 *valp)
{
  unsigned uimm8_out_0;
  unsigned uimm8_in_0;
  uimm8_in_0 = *valp & 0xff;
  uimm8_out_0 = uimm8_in_0;
  *valp = uimm8_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_uimm8_encode (uint32 *valp)
{
  unsigned uimm8_in_0;
  unsigned uimm8_out_0;
  uimm8_out_0 = *valp;
  uimm8_in_0 = (uimm8_out_0 & 0xff);
  *valp = uimm8_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_uimm8x2_decode (uint32 *valp)
{
  unsigned uimm8x2_out_0;
  unsigned uimm8x2_in_0;
  uimm8x2_in_0 = *valp & 0xff;
  uimm8x2_out_0 = uimm8x2_in_0 << 1;
  *valp = uimm8x2_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_uimm8x2_encode (uint32 *valp)
{
  unsigned uimm8x2_in_0;
  unsigned uimm8x2_out_0;
  uimm8x2_out_0 = *valp;
  uimm8x2_in_0 = ((uimm8x2_out_0 >> 1) & 0xff);
  *valp = uimm8x2_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_uimm8x4_decode (uint32 *valp)
{
  unsigned uimm8x4_out_0;
  unsigned uimm8x4_in_0;
  uimm8x4_in_0 = *valp & 0xff;
  uimm8x4_out_0 = uimm8x4_in_0 << 2;
  *valp = uimm8x4_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_uimm8x4_encode (uint32 *valp)
{
  unsigned uimm8x4_in_0;
  unsigned uimm8x4_out_0;
  uimm8x4_out_0 = *valp;
  uimm8x4_in_0 = ((uimm8x4_out_0 >> 2) & 0xff);
  *valp = uimm8x4_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_uimm4x16_decode (uint32 *valp)
{
  unsigned uimm4x16_out_0;
  unsigned uimm4x16_in_0;
  uimm4x16_in_0 = *valp & 0xf;
  uimm4x16_out_0 = uimm4x16_in_0 << 4;
  *valp = uimm4x16_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_uimm4x16_encode (uint32 *valp)
{
  unsigned uimm4x16_in_0;
  unsigned uimm4x16_out_0;
  uimm4x16_out_0 = *valp;
  uimm4x16_in_0 = ((uimm4x16_out_0 >> 4) & 0xf);
  *valp = uimm4x16_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_uimmrx4_decode (uint32 *valp)
{
  unsigned uimmrx4_out_0;
  unsigned uimmrx4_in_0;
  uimmrx4_in_0 = *valp & 0xf;
  uimmrx4_out_0 = uimmrx4_in_0 << 2;
  *valp = uimmrx4_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_uimmrx4_encode (uint32 *valp)
{
  unsigned uimmrx4_in_0;
  unsigned uimmrx4_out_0;
  uimmrx4_out_0 = *valp;
  uimmrx4_in_0 = ((uimmrx4_out_0 >> 2) & 0xf);
  *valp = uimmrx4_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_simm8_decode (uint32 *valp)
{
  unsigned simm8_out_0;
  unsigned simm8_in_0;
  simm8_in_0 = *valp & 0xff;
  simm8_out_0 = ((int) simm8_in_0 << 24) >> 24;
  *valp = simm8_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_simm8_encode (uint32 *valp)
{
  unsigned simm8_in_0;
  unsigned simm8_out_0;
  simm8_out_0 = *valp;
  simm8_in_0 = (simm8_out_0 & 0xff);
  *valp = simm8_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_simm8x256_decode (uint32 *valp)
{
  unsigned simm8x256_out_0;
  unsigned simm8x256_in_0;
  simm8x256_in_0 = *valp & 0xff;
  simm8x256_out_0 = (((int) simm8x256_in_0 << 24) >> 24) << 8;
  *valp = simm8x256_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_simm8x256_encode (uint32 *valp)
{
  unsigned simm8x256_in_0;
  unsigned simm8x256_out_0;
  simm8x256_out_0 = *valp;
  simm8x256_in_0 = ((simm8x256_out_0 >> 8) & 0xff);
  *valp = simm8x256_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_simm12b_decode (uint32 *valp)
{
  unsigned simm12b_out_0;
  unsigned simm12b_in_0;
  simm12b_in_0 = *valp & 0xfff;
  simm12b_out_0 = ((int) simm12b_in_0 << 20) >> 20;
  *valp = simm12b_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_simm12b_encode (uint32 *valp)
{
  unsigned simm12b_in_0;
  unsigned simm12b_out_0;
  simm12b_out_0 = *valp;
  simm12b_in_0 = (simm12b_out_0 & 0xfff);
  *valp = simm12b_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_msalp32_decode (uint32 *valp)
{
  unsigned msalp32_out_0;
  unsigned msalp32_in_0;
  msalp32_in_0 = *valp & 0x1f;
  msalp32_out_0 = 0x20 - msalp32_in_0;
  *valp = msalp32_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_msalp32_encode (uint32 *valp)
{
  unsigned msalp32_in_0;
  unsigned msalp32_out_0;
  msalp32_out_0 = *valp;
  msalp32_in_0 = (0x20 - msalp32_out_0) & 0x1f;
  *valp = msalp32_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_op2p1_decode (uint32 *valp)
{
  unsigned op2p1_out_0;
  unsigned op2p1_in_0;
  op2p1_in_0 = *valp & 0xf;
  op2p1_out_0 = op2p1_in_0 + 0x1;
  *valp = op2p1_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_op2p1_encode (uint32 *valp)
{
  unsigned op2p1_in_0;
  unsigned op2p1_out_0;
  op2p1_out_0 = *valp;
  op2p1_in_0 = (op2p1_out_0 - 0x1) & 0xf;
  *valp = op2p1_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_label8_decode (uint32 *valp)
{
  unsigned label8_out_0;
  unsigned label8_in_0;
  label8_in_0 = *valp & 0xff;
  label8_out_0 = 0x4 + (((int) label8_in_0 << 24) >> 24);
  *valp = label8_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_label8_encode (uint32 *valp)
{
  unsigned label8_in_0;
  unsigned label8_out_0;
  label8_out_0 = *valp;
  label8_in_0 = (label8_out_0 - 0x4) & 0xff;
  *valp = label8_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_ulabel8_decode (uint32 *valp)
{
  unsigned ulabel8_out_0;
  unsigned ulabel8_in_0;
  ulabel8_in_0 = *valp & 0xff;
  ulabel8_out_0 = 0x4 + (((0) << 8) | ulabel8_in_0);
  *valp = ulabel8_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_ulabel8_encode (uint32 *valp)
{
  unsigned ulabel8_in_0;
  unsigned ulabel8_out_0;
  ulabel8_out_0 = *valp;
  ulabel8_in_0 = (ulabel8_out_0 - 0x4) & 0xff;
  *valp = ulabel8_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_label12_decode (uint32 *valp)
{
  unsigned label12_out_0;
  unsigned label12_in_0;
  label12_in_0 = *valp & 0xfff;
  label12_out_0 = 0x4 + (((int) label12_in_0 << 20) >> 20);
  *valp = label12_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_label12_encode (uint32 *valp)
{
  unsigned label12_in_0;
  unsigned label12_out_0;
  label12_out_0 = *valp;
  label12_in_0 = (label12_out_0 - 0x4) & 0xfff;
  *valp = label12_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_soffset_decode (uint32 *valp)
{
  unsigned soffset_out_0;
  unsigned soffset_in_0;
  soffset_in_0 = *valp & 0x3ffff;
  soffset_out_0 = 0x4 + (((int) soffset_in_0 << 14) >> 14);
  *valp = soffset_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_soffset_encode (uint32 *valp)
{
  unsigned soffset_in_0;
  unsigned soffset_out_0;
  soffset_out_0 = *valp;
  soffset_in_0 = (soffset_out_0 - 0x4) & 0x3ffff;
  *valp = soffset_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_uimm16x4_decode (uint32 *valp)
{
  unsigned uimm16x4_out_0;
  unsigned uimm16x4_in_0;
  uimm16x4_in_0 = *valp & 0xffff;
  uimm16x4_out_0 = (((0xffff) << 16) | uimm16x4_in_0) << 2;
  *valp = uimm16x4_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_uimm16x4_encode (uint32 *valp)
{
  unsigned uimm16x4_in_0;
  unsigned uimm16x4_out_0;
  uimm16x4_out_0 = *valp;
  uimm16x4_in_0 = (uimm16x4_out_0 >> 2) & 0xffff;
  *valp = uimm16x4_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_bbi_decode (uint32 *valp)
{
  unsigned bbi_out_0;
  unsigned bbi_in_0;
  bbi_in_0 = *valp & 0x1f;
  bbi_out_0 = (0 << 5) | bbi_in_0;
  *valp = bbi_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_bbi_encode (uint32 *valp)
{
  unsigned bbi_in_0;
  unsigned bbi_out_0;
  bbi_out_0 = *valp;
  bbi_in_0 = (bbi_out_0 & 0x1f);
  *valp = bbi_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_s_decode (uint32 *valp)
{
  unsigned s_out_0;
  unsigned s_in_0;
  s_in_0 = *valp & 0xf;
  s_out_0 = (0 << 4) | s_in_0;
  *valp = s_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_s_encode (uint32 *valp)
{
  unsigned s_in_0;
  unsigned s_out_0;
  s_out_0 = *valp;
  s_in_0 = (s_out_0 & 0xf);
  *valp = s_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_imms_decode (uint32 *valp)
{
  unsigned imms_out_0;
  unsigned imms_in_0;
  imms_in_0 = *valp & 0xf;
  imms_out_0 = imms_in_0;
  *valp = imms_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_imms_encode (uint32 *valp)
{
  unsigned imms_in_0;
  unsigned imms_out_0;
  imms_out_0 = *valp;
  imms_in_0 = imms_out_0 & 0xf;
  *valp = imms_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_BR_decode (uint32 *valp ATTRIBUTE_UNUSED)
{
  return 0;
}

static int
OperandSem_opnd_sem_BR_encode (uint32 *valp)
{
  int error;
  error = (*valp >= 16);
  return error;
}

static int
OperandSem_opnd_sem_BR2_decode (uint32 *valp)
{
  *valp = *valp << 1;
  return 0;
}

static int
OperandSem_opnd_sem_BR2_encode (uint32 *valp)
{
  int error;
  error = (*valp >= 16) || ((*valp & 1) != 0);
  *valp = *valp >> 1;
  return error;
}

static int
OperandSem_opnd_sem_BR4_decode (uint32 *valp)
{
  *valp = *valp << 2;
  return 0;
}

static int
OperandSem_opnd_sem_BR4_encode (uint32 *valp)
{
  int error;
  error = (*valp >= 16) || ((*valp & 3) != 0);
  *valp = *valp >> 2;
  return error;
}

static int
OperandSem_opnd_sem_BR8_decode (uint32 *valp)
{
  *valp = *valp << 3;
  return 0;
}

static int
OperandSem_opnd_sem_BR8_encode (uint32 *valp)
{
  int error;
  error = (*valp >= 16) || ((*valp & 7) != 0);
  *valp = *valp >> 3;
  return error;
}

static int
OperandSem_opnd_sem_BR16_decode (uint32 *valp)
{
  *valp = *valp << 4;
  return 0;
}

static int
OperandSem_opnd_sem_BR16_encode (uint32 *valp)
{
  int error;
  error = (*valp >= 16) || ((*valp & 15) != 0);
  *valp = *valp >> 4;
  return error;
}

static int
OperandSem_opnd_sem_tp7_decode (uint32 *valp)
{
  unsigned tp7_out_0;
  unsigned tp7_in_0;
  tp7_in_0 = *valp & 0xf;
  tp7_out_0 = tp7_in_0 + 0x7;
  *valp = tp7_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_tp7_encode (uint32 *valp)
{
  unsigned tp7_in_0;
  unsigned tp7_out_0;
  tp7_out_0 = *valp;
  tp7_in_0 = (tp7_out_0 - 0x7) & 0xf;
  *valp = tp7_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_xt_wbr15_label_decode (uint32 *valp)
{
  unsigned xt_wbr15_label_out_0;
  unsigned xt_wbr15_label_in_0;
  xt_wbr15_label_in_0 = *valp & 0x7fff;
  xt_wbr15_label_out_0 = 0x4 + (((int) xt_wbr15_label_in_0 << 17) >> 17);
  *valp = xt_wbr15_label_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_xt_wbr15_label_encode (uint32 *valp)
{
  unsigned xt_wbr15_label_in_0;
  unsigned xt_wbr15_label_out_0;
  xt_wbr15_label_out_0 = *valp;
  xt_wbr15_label_in_0 = (xt_wbr15_label_out_0 - 0x4) & 0x7fff;
  *valp = xt_wbr15_label_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_xt_wbr18_label_decode (uint32 *valp)
{
  unsigned xt_wbr18_label_out_0;
  unsigned xt_wbr18_label_in_0;
  xt_wbr18_label_in_0 = *valp & 0x3ffff;
  xt_wbr18_label_out_0 = 0x4 + (((int) xt_wbr18_label_in_0 << 14) >> 14);
  *valp = xt_wbr18_label_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_xt_wbr18_label_encode (uint32 *valp)
{
  unsigned xt_wbr18_label_in_0;
  unsigned xt_wbr18_label_out_0;
  xt_wbr18_label_out_0 = *valp;
  xt_wbr18_label_in_0 = (xt_wbr18_label_out_0 - 0x4) & 0x3ffff;
  *valp = xt_wbr18_label_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_ohba_decode (uint32 *valp)
{
  unsigned ae_ohba_out_0;
  unsigned ae_ohba_in_0;
  ae_ohba_in_0 = *valp & 0xf;
  ae_ohba_out_0 = (0 << 5) | (((((ae_ohba_in_0 & 0xf))) == 0) << 4) | ((ae_ohba_in_0 & 0xf));
  *valp = ae_ohba_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_ohba_encode (uint32 *valp)
{
  unsigned ae_ohba_in_0;
  unsigned ae_ohba_out_0;
  ae_ohba_out_0 = *valp;
  ae_ohba_in_0 = (ae_ohba_out_0 & 0xf);
  *valp = ae_ohba_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_opnd_tp7_decode (uint32 *valp)
{
  unsigned ae_opnd_tp7_out_0;
  unsigned ae_opnd_tp7_in_0;
  ae_opnd_tp7_in_0 = *valp & 0xf;
  ae_opnd_tp7_out_0 = ae_opnd_tp7_in_0 + 0x7;
  *valp = ae_opnd_tp7_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_opnd_tp7_encode (uint32 *valp)
{
  unsigned ae_opnd_tp7_in_0;
  unsigned ae_opnd_tp7_out_0;
  ae_opnd_tp7_out_0 = *valp;
  ae_opnd_tp7_in_0 = (ae_opnd_tp7_out_0 - 0x7) & 0xf;
  *valp = ae_opnd_tp7_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_imm2_decode (uint32 *valp)
{
  unsigned ae_imm2_out_0;
  unsigned ae_imm2_in_0;
  ae_imm2_in_0 = *valp & 0x3;
  ae_imm2_out_0 = (0 << 2) | ae_imm2_in_0;
  *valp = ae_imm2_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_imm2_encode (uint32 *valp)
{
  unsigned ae_imm2_in_0;
  unsigned ae_imm2_out_0;
  ae_imm2_out_0 = *valp;
  ae_imm2_in_0 = (ae_imm2_out_0 & 0x3);
  *valp = ae_imm2_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_osa32_decode (uint32 *valp)
{
  unsigned ae_osa32_out_0;
  unsigned ae_osa32_in_0;
  ae_osa32_in_0 = *valp & 0x1f;
  ae_osa32_out_0 = (0 << 5) | ae_osa32_in_0;
  *valp = ae_osa32_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_osa32_encode (uint32 *valp)
{
  unsigned ae_osa32_in_0;
  unsigned ae_osa32_out_0;
  ae_osa32_out_0 = *valp;
  ae_osa32_in_0 = (ae_osa32_out_0 & 0x1f);
  *valp = ae_osa32_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_osa64_decode (uint32 *valp)
{
  unsigned ae_osa64_out_0;
  unsigned ae_osa64_in_0;
  ae_osa64_in_0 = *valp & 0x3f;
  ae_osa64_out_0 = (0 << 6) | ae_osa64_in_0;
  *valp = ae_osa64_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_osa64_encode (uint32 *valp)
{
  unsigned ae_osa64_in_0;
  unsigned ae_osa64_out_0;
  ae_osa64_out_0 = *valp;
  ae_osa64_in_0 = (ae_osa64_out_0 & 0x3f);
  *valp = ae_osa64_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_immls64_decode (uint32 *valp)
{
  unsigned ae_immls64_out_0;
  unsigned ae_immls64_in_0;
  ae_immls64_in_0 = *valp & 0xf;
  ae_immls64_out_0 = (((int) ae_immls64_in_0 << 28) >> 28) << 3;
  *valp = ae_immls64_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_immls64_encode (uint32 *valp)
{
  unsigned ae_immls64_in_0;
  unsigned ae_immls64_out_0;
  ae_immls64_out_0 = *valp;
  ae_immls64_in_0 = ((ae_immls64_out_0 >> 3) & 0xf);
  *valp = ae_immls64_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_immls64pos_decode (uint32 *valp)
{
  unsigned ae_immls64pos_out_0;
  unsigned ae_immls64pos_in_0;
  ae_immls64pos_in_0 = *valp & 0x7;
  ae_immls64pos_out_0 = ((0 << 3) | ae_immls64pos_in_0) << 3;
  *valp = ae_immls64pos_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_immls64pos_encode (uint32 *valp)
{
  unsigned ae_immls64pos_in_0;
  unsigned ae_immls64pos_out_0;
  ae_immls64pos_out_0 = *valp;
  ae_immls64pos_in_0 = ((ae_immls64pos_out_0 >> 3) & 0x7);
  *valp = ae_immls64pos_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_immls32_decode (uint32 *valp)
{
  unsigned ae_immls32_out_0;
  unsigned ae_immls32_in_0;
  ae_immls32_in_0 = *valp & 0xf;
  ae_immls32_out_0 = (((int) ae_immls32_in_0 << 28) >> 28) << 2;
  *valp = ae_immls32_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_immls32_encode (uint32 *valp)
{
  unsigned ae_immls32_in_0;
  unsigned ae_immls32_out_0;
  ae_immls32_out_0 = *valp;
  ae_immls32_in_0 = ((ae_immls32_out_0 >> 2) & 0xf);
  *valp = ae_immls32_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_immls16_decode (uint32 *valp)
{
  unsigned ae_immls16_out_0;
  unsigned ae_immls16_in_0;
  ae_immls16_in_0 = *valp & 0xf;
  ae_immls16_out_0 = (((int) ae_immls16_in_0 << 28) >> 28) << 1;
  *valp = ae_immls16_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_immls16_encode (uint32 *valp)
{
  unsigned ae_immls16_in_0;
  unsigned ae_immls16_out_0;
  ae_immls16_out_0 = *valp;
  ae_immls16_in_0 = ((ae_immls16_out_0 >> 1) & 0xf);
  *valp = ae_immls16_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_osa16_decode (uint32 *valp)
{
  unsigned ae_osa16_out_0;
  unsigned ae_osa16_in_0;
  ae_osa16_in_0 = *valp & 0xf;
  ae_osa16_out_0 = (0 << 4) | ae_osa16_in_0;
  *valp = ae_osa16_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_osa16_encode (uint32 *valp)
{
  unsigned ae_osa16_in_0;
  unsigned ae_osa16_out_0;
  ae_osa16_out_0 = *valp;
  ae_osa16_in_0 = (ae_osa16_out_0 & 0xf);
  *valp = ae_osa16_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_selimm_N_decode (uint32 *valp)
{
  unsigned ae_selimm_N_out_0;
  unsigned ae_selimm_N_in_0;
  ae_selimm_N_in_0 = *valp & 0x3;
  ae_selimm_N_out_0 = (0 << 2) | ae_selimm_N_in_0;
  *valp = ae_selimm_N_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_ae_selimm_N_encode (uint32 *valp)
{
  unsigned ae_selimm_N_in_0;
  unsigned ae_selimm_N_out_0;
  ae_selimm_N_out_0 = *valp;
  ae_selimm_N_in_0 = (ae_selimm_N_out_0 & 0x3);
  *valp = ae_selimm_N_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_movi_imm_decode (uint32 *valp)
{
  unsigned movi_imm_out_0;
  unsigned movi_imm_in_0;
  movi_imm_in_0 = *valp & 0x3f;
  movi_imm_out_0 = ((((-(( ( ((((movi_imm_in_0 >> 4) & 0x3)) | 0xfffffffc)) == 0xffffffff))) & 0x3ffffff)) << 6) | movi_imm_in_0;
  *valp = movi_imm_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_movi_imm_encode (uint32 *valp)
{
  unsigned movi_imm_in_0;
  unsigned movi_imm_out_0;
  movi_imm_out_0 = *valp;
  movi_imm_in_0 = (movi_imm_out_0 & 0x3f);
  *valp = movi_imm_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_AE_DR_decode (uint32 *valp ATTRIBUTE_UNUSED)
{
  return 0;
}

static int
OperandSem_opnd_sem_AE_DR_encode (uint32 *valp)
{
  int error;
  error = (*valp >= 16);
  return error;
}

static int
OperandSem_opnd_sem_AE_VALIGN_decode (uint32 *valp ATTRIBUTE_UNUSED)
{
  return 0;
}

static int
OperandSem_opnd_sem_AE_VALIGN_encode (uint32 *valp)
{
  int error;
  error = (*valp >= 4);
  return error;
}

static int
OperandSem_opnd_sem_FR_decode (uint32 *valp ATTRIBUTE_UNUSED)
{
  return 0;
}

static int
OperandSem_opnd_sem_FR_encode (uint32 *valp)
{
  int error;
  error = (*valp >= 16);
  return error;
}

static int
OperandSem_opnd_sem_imm_t_decode (uint32 *valp)
{
  unsigned imm_t_out_0;
  unsigned imm_t_in_0;
  imm_t_in_0 = *valp & 0xf;
  imm_t_out_0 = (0 << 4) | imm_t_in_0;
  *valp = imm_t_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_imm_t_encode (uint32 *valp)
{
  unsigned imm_t_in_0;
  unsigned imm_t_out_0;
  imm_t_out_0 = *valp;
  imm_t_in_0 = (imm_t_out_0 & 0xf);
  *valp = imm_t_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_imm8x4_decode (uint32 *valp)
{
  unsigned imm8x4_out_0;
  unsigned imm8x4_in_0;
  imm8x4_in_0 = *valp & 0xff;
  imm8x4_out_0 = (0 << 10) | (imm8x4_in_0 << 2) | 0;
  *valp = imm8x4_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_imm8x4_encode (uint32 *valp)
{
  unsigned imm8x4_in_0;
  unsigned imm8x4_out_0;
  imm8x4_out_0 = *valp;
  imm8x4_in_0 = ((imm8x4_out_0 >> 2) & 0xff);
  *valp = imm8x4_in_0;
  return 0;
}

static int
OperandSem_opnd_sem_imm8x8_decode (uint32 *valp)
{
  unsigned imm8x8_out_0;
  unsigned imm8x8_in_0;
  imm8x8_in_0 = *valp & 0xff;
  imm8x8_out_0 = (0 << 11) | (imm8x8_in_0 << 3) | 0;
  *valp = imm8x8_out_0;
  return 0;
}

static int
OperandSem_opnd_sem_imm8x8_encode (uint32 *valp)
{
  unsigned imm8x8_in_0;
  unsigned imm8x8_out_0;
  imm8x8_out_0 = *valp;
  imm8x8_in_0 = ((imm8x8_out_0 >> 3) & 0xff);
  *valp = imm8x8_in_0;
  return 0;
}

static int
Operand_soffsetx4_ator (uint32 *valp, uint32 pc)
{
  *valp -= (pc & ~0x3);
  return 0;
}

static int
Operand_soffsetx4_rtoa (uint32 *valp, uint32 pc)
{
  *valp += (pc & ~0x3);
  return 0;
}

static int
Operand_uimm6_ator (uint32 *valp, uint32 pc)
{
  *valp -= pc;
  return 0;
}

static int
Operand_uimm6_rtoa (uint32 *valp, uint32 pc)
{
  *valp += pc;
  return 0;
}

static int
Operand_label8_ator (uint32 *valp, uint32 pc)
{
  *valp -= pc;
  return 0;
}

static int
Operand_label8_rtoa (uint32 *valp, uint32 pc)
{
  *valp += pc;
  return 0;
}

static int
Operand_ulabel8_ator (uint32 *valp, uint32 pc)
{
  *valp -= pc;
  return 0;
}

static int
Operand_ulabel8_rtoa (uint32 *valp, uint32 pc)
{
  *valp += pc;
  return 0;
}

static int
Operand_label12_ator (uint32 *valp, uint32 pc)
{
  *valp -= pc;
  return 0;
}

static int
Operand_label12_rtoa (uint32 *valp, uint32 pc)
{
  *valp += pc;
  return 0;
}

static int
Operand_soffset_ator (uint32 *valp, uint32 pc)
{
  *valp -= pc;
  return 0;
}

static int
Operand_soffset_rtoa (uint32 *valp, uint32 pc)
{
  *valp += pc;
  return 0;
}

static int
Operand_uimm16x4_ator (uint32 *valp, uint32 pc)
{
  *valp -= ((pc + 3) & ~0x3);
  return 0;
}

static int
Operand_uimm16x4_rtoa (uint32 *valp, uint32 pc)
{
  *valp += ((pc + 3) & ~0x3);
  return 0;
}

static int
Operand_xt_wbr15_label_ator (uint32 *valp, uint32 pc)
{
  *valp -= pc;
  return 0;
}

static int
Operand_xt_wbr15_label_rtoa (uint32 *valp, uint32 pc)
{
  *valp += pc;
  return 0;
}

static int
Operand_xt_wbr18_label_ator (uint32 *valp, uint32 pc)
{
  *valp -= pc;
  return 0;
}

static int
Operand_xt_wbr18_label_rtoa (uint32 *valp, uint32 pc)
{
  *valp += pc;
  return 0;
}

static xtensa_operand_internal operands[] = {
  { "soffsetx4", FIELD_offset, -1, 0,
    XTENSA_OPERAND_IS_PCRELATIVE,
    OperandSem_opnd_sem_soffsetx4_encode, OperandSem_opnd_sem_soffsetx4_decode,
    Operand_soffsetx4_ator, Operand_soffsetx4_rtoa },
  { "immr", FIELD_r, -1, 0,
    0,
    OperandSem_opnd_sem_immr_encode, OperandSem_opnd_sem_immr_decode,
    0, 0 },
  { "uimm12x8", FIELD_imm12, -1, 0,
    0,
    OperandSem_opnd_sem_uimm12x8_encode, OperandSem_opnd_sem_uimm12x8_decode,
    0, 0 },
  { "simm4", FIELD_mn, -1, 0,
    0,
    OperandSem_opnd_sem_simm4_encode, OperandSem_opnd_sem_simm4_decode,
    0, 0 },
  { "arr", FIELD_r, REGFILE_AR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AR_encode, OperandSem_opnd_sem_AR_decode,
    0, 0 },
  { "ars", FIELD_s, REGFILE_AR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AR_encode, OperandSem_opnd_sem_AR_decode,
    0, 0 },
  { "*ars_invisible", FIELD_s, REGFILE_AR, 1,
    XTENSA_OPERAND_IS_REGISTER | XTENSA_OPERAND_IS_INVISIBLE,
    OperandSem_opnd_sem_AR_encode, OperandSem_opnd_sem_AR_decode,
    0, 0 },
  { "art", FIELD_t, REGFILE_AR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AR_encode, OperandSem_opnd_sem_AR_decode,
    0, 0 },
  { "ar0", FIELD__ar0, REGFILE_AR, 1,
    XTENSA_OPERAND_IS_REGISTER | XTENSA_OPERAND_IS_INVISIBLE,
    OperandSem_opnd_sem_AR_0_encode, OperandSem_opnd_sem_AR_0_decode,
    0, 0 },
  { "ar4", FIELD__ar4, REGFILE_AR, 1,
    XTENSA_OPERAND_IS_REGISTER | XTENSA_OPERAND_IS_INVISIBLE,
    OperandSem_opnd_sem_AR_4_encode, OperandSem_opnd_sem_AR_4_decode,
    0, 0 },
  { "ar8", FIELD__ar8, REGFILE_AR, 1,
    XTENSA_OPERAND_IS_REGISTER | XTENSA_OPERAND_IS_INVISIBLE,
    OperandSem_opnd_sem_AR_8_encode, OperandSem_opnd_sem_AR_8_decode,
    0, 0 },
  { "ar12", FIELD__ar12, REGFILE_AR, 1,
    XTENSA_OPERAND_IS_REGISTER | XTENSA_OPERAND_IS_INVISIBLE,
    OperandSem_opnd_sem_AR_12_encode, OperandSem_opnd_sem_AR_12_decode,
    0, 0 },
  { "ars_entry", FIELD_s, REGFILE_AR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AR_entry_encode, OperandSem_opnd_sem_AR_entry_decode,
    0, 0 },
  { "immrx4", FIELD_r, -1, 0,
    0,
    OperandSem_opnd_sem_immrx4_encode, OperandSem_opnd_sem_immrx4_decode,
    0, 0 },
  { "lsi4x4", FIELD_r, -1, 0,
    0,
    OperandSem_opnd_sem_lsi4x4_encode, OperandSem_opnd_sem_lsi4x4_decode,
    0, 0 },
  { "simm7", FIELD_imm7, -1, 0,
    0,
    OperandSem_opnd_sem_simm7_encode, OperandSem_opnd_sem_simm7_decode,
    0, 0 },
  { "uimm6", FIELD_imm6, -1, 0,
    XTENSA_OPERAND_IS_PCRELATIVE,
    OperandSem_opnd_sem_uimm6_encode, OperandSem_opnd_sem_uimm6_decode,
    Operand_uimm6_ator, Operand_uimm6_rtoa },
  { "ai4const", FIELD_t, -1, 0,
    0,
    OperandSem_opnd_sem_ai4const_encode, OperandSem_opnd_sem_ai4const_decode,
    0, 0 },
  { "b4const", FIELD_r, -1, 0,
    0,
    OperandSem_opnd_sem_b4const_encode, OperandSem_opnd_sem_b4const_decode,
    0, 0 },
  { "b4constu", FIELD_r, -1, 0,
    0,
    OperandSem_opnd_sem_b4constu_encode, OperandSem_opnd_sem_b4constu_decode,
    0, 0 },
  { "immt", FIELD_t, -1, 0,
    0,
    OperandSem_opnd_sem_immt_encode, OperandSem_opnd_sem_immt_decode,
    0, 0 },
  { "uimm8", FIELD_imm8, -1, 0,
    0,
    OperandSem_opnd_sem_uimm8_encode, OperandSem_opnd_sem_uimm8_decode,
    0, 0 },
  { "uimm8x2", FIELD_imm8, -1, 0,
    0,
    OperandSem_opnd_sem_uimm8x2_encode, OperandSem_opnd_sem_uimm8x2_decode,
    0, 0 },
  { "uimm8x4", FIELD_imm8, -1, 0,
    0,
    OperandSem_opnd_sem_uimm8x4_encode, OperandSem_opnd_sem_uimm8x4_decode,
    0, 0 },
  { "uimm4x16", FIELD_op2, -1, 0,
    0,
    OperandSem_opnd_sem_uimm4x16_encode, OperandSem_opnd_sem_uimm4x16_decode,
    0, 0 },
  { "uimmrx4", FIELD_r, -1, 0,
    0,
    OperandSem_opnd_sem_uimmrx4_encode, OperandSem_opnd_sem_uimmrx4_decode,
    0, 0 },
  { "simm8", FIELD_imm8, -1, 0,
    0,
    OperandSem_opnd_sem_simm8_encode, OperandSem_opnd_sem_simm8_decode,
    0, 0 },
  { "simm8x256", FIELD_imm8, -1, 0,
    0,
    OperandSem_opnd_sem_simm8x256_encode, OperandSem_opnd_sem_simm8x256_decode,
    0, 0 },
  { "simm12b", FIELD_imm12b, -1, 0,
    0,
    OperandSem_opnd_sem_simm12b_encode, OperandSem_opnd_sem_simm12b_decode,
    0, 0 },
  { "msalp32", FIELD_sal, -1, 0,
    0,
    OperandSem_opnd_sem_msalp32_encode, OperandSem_opnd_sem_msalp32_decode,
    0, 0 },
  { "op2p1", FIELD_op2, -1, 0,
    0,
    OperandSem_opnd_sem_op2p1_encode, OperandSem_opnd_sem_op2p1_decode,
    0, 0 },
  { "label8", FIELD_imm8, -1, 0,
    XTENSA_OPERAND_IS_PCRELATIVE,
    OperandSem_opnd_sem_label8_encode, OperandSem_opnd_sem_label8_decode,
    Operand_label8_ator, Operand_label8_rtoa },
  { "ulabel8", FIELD_imm8, -1, 0,
    XTENSA_OPERAND_IS_PCRELATIVE,
    OperandSem_opnd_sem_ulabel8_encode, OperandSem_opnd_sem_ulabel8_decode,
    Operand_ulabel8_ator, Operand_ulabel8_rtoa },
  { "label12", FIELD_imm12, -1, 0,
    XTENSA_OPERAND_IS_PCRELATIVE,
    OperandSem_opnd_sem_label12_encode, OperandSem_opnd_sem_label12_decode,
    Operand_label12_ator, Operand_label12_rtoa },
  { "soffset", FIELD_offset, -1, 0,
    XTENSA_OPERAND_IS_PCRELATIVE,
    OperandSem_opnd_sem_soffset_encode, OperandSem_opnd_sem_soffset_decode,
    Operand_soffset_ator, Operand_soffset_rtoa },
  { "uimm16x4", FIELD_imm16, -1, 0,
    XTENSA_OPERAND_IS_PCRELATIVE,
    OperandSem_opnd_sem_uimm16x4_encode, OperandSem_opnd_sem_uimm16x4_decode,
    Operand_uimm16x4_ator, Operand_uimm16x4_rtoa },
  { "bbi", FIELD_bbi, -1, 0,
    0,
    OperandSem_opnd_sem_bbi_encode, OperandSem_opnd_sem_bbi_decode,
    0, 0 },
  { "sae", FIELD_sae, -1, 0,
    0,
    OperandSem_opnd_sem_bbi_encode, OperandSem_opnd_sem_bbi_decode,
    0, 0 },
  { "sas", FIELD_sas, -1, 0,
    0,
    OperandSem_opnd_sem_bbi_encode, OperandSem_opnd_sem_bbi_decode,
    0, 0 },
  { "sargt", FIELD_sargt, -1, 0,
    0,
    OperandSem_opnd_sem_bbi_encode, OperandSem_opnd_sem_bbi_decode,
    0, 0 },
  { "s", FIELD_s, -1, 0,
    0,
    OperandSem_opnd_sem_s_encode, OperandSem_opnd_sem_s_decode,
    0, 0 },
  { "imms", FIELD_s, -1, 0,
    0,
    OperandSem_opnd_sem_imms_encode, OperandSem_opnd_sem_imms_decode,
    0, 0 },
  { "imms1", FIELD_s, -1, 0,
    0,
    OperandSem_opnd_sem_imms_encode, OperandSem_opnd_sem_imms_decode,
    0, 0 },
  { "bt", FIELD_t, REGFILE_BR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_BR_encode, OperandSem_opnd_sem_BR_decode,
    0, 0 },
  { "bs", FIELD_s, REGFILE_BR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_BR_encode, OperandSem_opnd_sem_BR_decode,
    0, 0 },
  { "br", FIELD_r, REGFILE_BR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_BR_encode, OperandSem_opnd_sem_BR_decode,
    0, 0 },
  { "bt2", FIELD_t2, REGFILE_BR, 2,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_BR2_encode, OperandSem_opnd_sem_BR2_decode,
    0, 0 },
  { "bs2", FIELD_s2, REGFILE_BR, 2,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_BR2_encode, OperandSem_opnd_sem_BR2_decode,
    0, 0 },
  { "br2", FIELD_r2, REGFILE_BR, 2,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_BR2_encode, OperandSem_opnd_sem_BR2_decode,
    0, 0 },
  { "bt4", FIELD_t4, REGFILE_BR, 4,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_BR4_encode, OperandSem_opnd_sem_BR4_decode,
    0, 0 },
  { "bs4", FIELD_s4, REGFILE_BR, 4,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_BR4_encode, OperandSem_opnd_sem_BR4_decode,
    0, 0 },
  { "br4", FIELD_r4, REGFILE_BR, 4,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_BR4_encode, OperandSem_opnd_sem_BR4_decode,
    0, 0 },
  { "bt8", FIELD_t8, REGFILE_BR, 8,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_BR8_encode, OperandSem_opnd_sem_BR8_decode,
    0, 0 },
  { "bs8", FIELD_s8, REGFILE_BR, 8,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_BR8_encode, OperandSem_opnd_sem_BR8_decode,
    0, 0 },
  { "br8", FIELD_r8, REGFILE_BR, 8,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_BR8_encode, OperandSem_opnd_sem_BR8_decode,
    0, 0 },
  { "bt16", FIELD__bt16, REGFILE_BR, 16,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_BR16_encode, OperandSem_opnd_sem_BR16_decode,
    0, 0 },
  { "bs16", FIELD__bs16, REGFILE_BR, 16,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_BR16_encode, OperandSem_opnd_sem_BR16_decode,
    0, 0 },
  { "br16", FIELD__br16, REGFILE_BR, 16,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_BR16_encode, OperandSem_opnd_sem_BR16_decode,
    0, 0 },
  { "brall", FIELD__brall, REGFILE_BR, 16,
    XTENSA_OPERAND_IS_REGISTER | XTENSA_OPERAND_IS_INVISIBLE,
    OperandSem_opnd_sem_BR16_encode, OperandSem_opnd_sem_BR16_decode,
    0, 0 },
  { "tp7", FIELD_t, -1, 0,
    0,
    OperandSem_opnd_sem_tp7_encode, OperandSem_opnd_sem_tp7_decode,
    0, 0 },
  { "xt_wbr15_label", FIELD_xt_wbr15_imm, -1, 0,
    XTENSA_OPERAND_IS_PCRELATIVE,
    OperandSem_opnd_sem_xt_wbr15_label_encode, OperandSem_opnd_sem_xt_wbr15_label_decode,
    Operand_xt_wbr15_label_ator, Operand_xt_wbr15_label_rtoa },
  { "xt_wbr18_label", FIELD_xt_wbr18_imm, -1, 0,
    XTENSA_OPERAND_IS_PCRELATIVE,
    OperandSem_opnd_sem_xt_wbr18_label_encode, OperandSem_opnd_sem_xt_wbr18_label_decode,
    Operand_xt_wbr18_label_ator, Operand_xt_wbr18_label_rtoa },
  { "ae_ohba", FIELD_ae_fld_fhba4, -1, 0,
    0,
    OperandSem_opnd_sem_ae_ohba_encode, OperandSem_opnd_sem_ae_ohba_decode,
    0, 0 },
  { "ae_ohba2", FIELD_ae_fld_fhba4_2, -1, 0,
    0,
    OperandSem_opnd_sem_ae_ohba_encode, OperandSem_opnd_sem_ae_ohba_decode,
    0, 0 },
  { "ae_opnd_tp7", FIELD_ae_fld_tp7, -1, 0,
    0,
    OperandSem_opnd_sem_ae_opnd_tp7_encode, OperandSem_opnd_sem_ae_opnd_tp7_decode,
    0, 0 },
  { "ae_imm2", FIELD_ae_fld_imm2, -1, 0,
    0,
    OperandSem_opnd_sem_ae_imm2_encode, OperandSem_opnd_sem_ae_imm2_decode,
    0, 0 },
  { "ae_osa32", FIELD_ae_fld_osa32, -1, 0,
    0,
    OperandSem_opnd_sem_ae_osa32_encode, OperandSem_opnd_sem_ae_osa32_decode,
    0, 0 },
  { "ae_osa64", FIELD_ae_fld_osa64, -1, 0,
    0,
    OperandSem_opnd_sem_ae_osa64_encode, OperandSem_opnd_sem_ae_osa64_decode,
    0, 0 },
  { "ae_immls64", FIELD_ae_fld_immls64, -1, 0,
    0,
    OperandSem_opnd_sem_ae_immls64_encode, OperandSem_opnd_sem_ae_immls64_decode,
    0, 0 },
  { "ae_immls64pos", FIELD_ae_fld_immls64pos, -1, 0,
    0,
    OperandSem_opnd_sem_ae_immls64pos_encode, OperandSem_opnd_sem_ae_immls64pos_decode,
    0, 0 },
  { "ae_immls32", FIELD_ae_fld_immls32, -1, 0,
    0,
    OperandSem_opnd_sem_ae_immls32_encode, OperandSem_opnd_sem_ae_immls32_decode,
    0, 0 },
  { "ae_immls16", FIELD_ae_fld_immls16, -1, 0,
    0,
    OperandSem_opnd_sem_ae_immls16_encode, OperandSem_opnd_sem_ae_immls16_decode,
    0, 0 },
  { "ae_osa16", FIELD_ae_fld_osa16, -1, 0,
    0,
    OperandSem_opnd_sem_ae_osa16_encode, OperandSem_opnd_sem_ae_osa16_decode,
    0, 0 },
  { "ae_selimm", FIELD_ae_fld_selimm, -1, 0,
    0,
    OperandSem_opnd_sem_ae_osa16_encode, OperandSem_opnd_sem_ae_osa16_decode,
    0, 0 },
  { "ae_selimm.N", FIELD_ae_fld_selimm_N, -1, 0,
    0,
    OperandSem_opnd_sem_ae_selimm_N_encode, OperandSem_opnd_sem_ae_selimm_N_decode,
    0, 0 },
  { "movi_imm", FIELD_fld_ar_to_dr_imm, -1, 0,
    0,
    OperandSem_opnd_sem_movi_imm_encode, OperandSem_opnd_sem_movi_imm_decode,
    0, 0 },
  { "ae_mul_d0", FIELD_ae_fld_mul_d0, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_mul_d1", FIELD_ae_fld_mul_d1, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_mul_q0", FIELD_ae_fld_mul_q0, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_mul_S2_q0", FIELD_ae_fld_mul_x2_S2_q0, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_mul_S2_d0", FIELD_ae_fld_mul_x2_S2_d0, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_mul_S2_d1", FIELD_ae_fld_mul_x2_S2_d1, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_mul_d2", FIELD_ae_fld_mul_x4_d2, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_mul_q1", FIELD_ae_fld_mul_x4_q1, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_arth_v", FIELD_ae_fld_arth_v, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_arth_v0", FIELD_ae_fld_arth_v0, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_arth_v1", FIELD_ae_fld_arth_v1, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_ar_to_dr_v", FIELD_ae_fld_ar_to_dr_v, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_to_dr_v", FIELD_ae_fld_to_dr_v, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_to_dr_v0", FIELD_ae_fld_to_dr_v0, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_dr_to_dr_v", FIELD_ae_fld_dr_to_dr_v, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_dr_to_dr_v0", FIELD_ae_fld_dr_to_dr_v0, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_dr_to_dr_v1", FIELD_ae_fld_dr_to_dr_v1, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_cmpp_v0", FIELD_ae_fld_cmpp_v0, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_cmpp_v1", FIELD_ae_fld_cmpp_v1, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_cmpp_v", FIELD_ae_fld_cmpp_v, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_ls_v", FIELD_ae_fld_ls_v, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_ls_av", FIELD_ae_fld_ls_av, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_ls_v1", FIELD_ae_fld_ls_v1, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_ls_v2", FIELD_ae_fld_ls_v2, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_ls_uu", FIELD_ae_fld_ls_uu, REGFILE_AE_VALIGN, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_VALIGN_encode, OperandSem_opnd_sem_AE_VALIGN_decode,
    0, 0 },
  { "ae_ls_su", FIELD_ae_fld_ls_su, REGFILE_AE_VALIGN, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_VALIGN_encode, OperandSem_opnd_sem_AE_VALIGN_decode,
    0, 0 },
  { "ae_uu_v", FIELD_ae_fld_uu_v, REGFILE_AE_VALIGN, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_VALIGN_encode, OperandSem_opnd_sem_AE_VALIGN_decode,
    0, 0 },
  { "ae_uu_uu", FIELD_ae_fld_uu_uu, REGFILE_AE_VALIGN, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_VALIGN_encode, OperandSem_opnd_sem_AE_VALIGN_decode,
    0, 0 },
  { "ae_dr_to_ar_v0", FIELD_ae_fld_dr_to_ar_v0, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_cmov_v", FIELD_ae_fld_cmov_v, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_cmov_v0", FIELD_ae_fld_cmov_v0, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_pks_d", FIELD_ae_fld_pks_d, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_pks_s", FIELD_ae_fld_pks_s, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_shift_d", FIELD_ae_fld_shift_d, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_shift_d0", FIELD_ae_fld_shift_d0, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "ae_shift_sd", FIELD_ae_fld_shift_sd, REGFILE_AE_DR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_AE_DR_encode, OperandSem_opnd_sem_AE_DR_decode,
    0, 0 },
  { "frr", FIELD_r, REGFILE_FR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_FR_encode, OperandSem_opnd_sem_FR_decode,
    0, 0 },
  { "frs", FIELD_s, REGFILE_FR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_FR_encode, OperandSem_opnd_sem_FR_decode,
    0, 0 },
  { "frt", FIELD_t, REGFILE_FR, 1,
    XTENSA_OPERAND_IS_REGISTER,
    OperandSem_opnd_sem_FR_encode, OperandSem_opnd_sem_FR_decode,
    0, 0 },
  { "imm_t", FIELD_t, -1, 0,
    0,
    OperandSem_opnd_sem_imm_t_encode, OperandSem_opnd_sem_imm_t_decode,
    0, 0 },
  { "imm_s", FIELD_s, -1, 0,
    0,
    OperandSem_opnd_sem_imm_t_encode, OperandSem_opnd_sem_imm_t_decode,
    0, 0 },
  { "imm8x4", FIELD_imm8, -1, 0,
    0,
    OperandSem_opnd_sem_imm8x4_encode, OperandSem_opnd_sem_imm8x4_decode,
    0, 0 },
  { "imm8x8", FIELD_imm8, -1, 0,
    0,
    OperandSem_opnd_sem_imm8x8_encode, OperandSem_opnd_sem_imm8x8_decode,
    0, 0 },
  { "t", FIELD_t, -1, 0, 0, 0, 0, 0, 0 },
  { "bbi4", FIELD_bbi4, -1, 0, 0, 0, 0, 0, 0 },
  { "imm12", FIELD_imm12, -1, 0, 0, 0, 0, 0, 0 },
  { "imm8", FIELD_imm8, -1, 0, 0, 0, 0, 0, 0 },
  { "imm12b", FIELD_imm12b, -1, 0, 0, 0, 0, 0, 0 },
  { "imm16", FIELD_imm16, -1, 0, 0, 0, 0, 0, 0 },
  { "m", FIELD_m, -1, 0, 0, 0, 0, 0, 0 },
  { "n", FIELD_n, -1, 0, 0, 0, 0, 0, 0 },
  { "offset", FIELD_offset, -1, 0, 0, 0, 0, 0, 0 },
  { "op0", FIELD_op0, -1, 0, 0, 0, 0, 0, 0 },
  { "op1", FIELD_op1, -1, 0, 0, 0, 0, 0, 0 },
  { "op2", FIELD_op2, -1, 0, 0, 0, 0, 0, 0 },
  { "r", FIELD_r, -1, 0, 0, 0, 0, 0, 0 },
  { "r_disp", FIELD_r_disp, -1, 0, 0, 0, 0, 0, 0 },
  { "r_3", FIELD_r_3, -1, 0, 0, 0, 0, 0, 0 },
  { "sa4", FIELD_sa4, -1, 0, 0, 0, 0, 0, 0 },
  { "sae4", FIELD_sae4, -1, 0, 0, 0, 0, 0, 0 },
  { "sal", FIELD_sal, -1, 0, 0, 0, 0, 0, 0 },
  { "sas4", FIELD_sas4, -1, 0, 0, 0, 0, 0, 0 },
  { "sr", FIELD_sr, -1, 0, 0, 0, 0, 0, 0 },
  { "st", FIELD_st, -1, 0, 0, 0, 0, 0, 0 },
  { "thi3", FIELD_thi3, -1, 0, 0, 0, 0, 0, 0 },
  { "imm4", FIELD_imm4, -1, 0, 0, 0, 0, 0, 0 },
  { "mn", FIELD_mn, -1, 0, 0, 0, 0, 0, 0 },
  { "i", FIELD_i, -1, 0, 0, 0, 0, 0, 0 },
  { "imm6lo", FIELD_imm6lo, -1, 0, 0, 0, 0, 0, 0 },
  { "imm6hi", FIELD_imm6hi, -1, 0, 0, 0, 0, 0, 0 },
  { "imm7lo", FIELD_imm7lo, -1, 0, 0, 0, 0, 0, 0 },
  { "imm7hi", FIELD_imm7hi, -1, 0, 0, 0, 0, 0, 0 },
  { "z", FIELD_z, -1, 0, 0, 0, 0, 0, 0 },
  { "imm6", FIELD_imm6, -1, 0, 0, 0, 0, 0, 0 },
  { "imm7", FIELD_imm7, -1, 0, 0, 0, 0, 0, 0 },
  { "t2", FIELD_t2, -1, 0, 0, 0, 0, 0, 0 },
  { "s2", FIELD_s2, -1, 0, 0, 0, 0, 0, 0 },
  { "r2", FIELD_r2, -1, 0, 0, 0, 0, 0, 0 },
  { "t4", FIELD_t4, -1, 0, 0, 0, 0, 0, 0 },
  { "s4", FIELD_s4, -1, 0, 0, 0, 0, 0, 0 },
  { "r4", FIELD_r4, -1, 0, 0, 0, 0, 0, 0 },
  { "t8", FIELD_t8, -1, 0, 0, 0, 0, 0, 0 },
  { "s8", FIELD_s8, -1, 0, 0, 0, 0, 0, 0 },
  { "r8", FIELD_r8, -1, 0, 0, 0, 0, 0, 0 },
  { "xt_wbr15_imm", FIELD_xt_wbr15_imm, -1, 0, 0, 0, 0, 0, 0 },
  { "xt_wbr18_imm", FIELD_xt_wbr18_imm, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_fhba4", FIELD_ae_fld_fhba4, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_fhba4_2", FIELD_ae_fld_fhba4_2, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_tp7", FIELD_ae_fld_tp7, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_osa32", FIELD_ae_fld_osa32, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_osa64", FIELD_ae_fld_osa64, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_imm2", FIELD_ae_fld_imm2, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_immls64", FIELD_ae_fld_immls64, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_immls64pos", FIELD_ae_fld_immls64pos, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_immls32", FIELD_ae_fld_immls32, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_immls16", FIELD_ae_fld_immls16, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_osa16", FIELD_ae_fld_osa16, -1, 0, 0, 0, 0, 0, 0 },
  { "Inst_15_12", FIELD_Inst_15_12, -1, 0, 0, 0, 0, 0, 0 },
  { "Inst_11_8", FIELD_Inst_11_8, -1, 0, 0, 0, 0, 0, 0 },
  { "Inst_7_4", FIELD_Inst_7_4, -1, 0, 0, 0, 0, 0, 0 },
  { "Inst_12", FIELD_Inst_12, -1, 0, 0, 0, 0, 0, 0 },
  { "Inst_7", FIELD_Inst_7, -1, 0, 0, 0, 0, 0, 0 },
  { "Inst_5_4", FIELD_Inst_5_4, -1, 0, 0, 0, 0, 0, 0 },
  { "Inst_7_6", FIELD_Inst_7_6, -1, 0, 0, 0, 0, 0, 0 },
  { "Inst_19_17", FIELD_Inst_19_17, -1, 0, 0, 0, 0, 0, 0 },
  { "Inst_19_18", FIELD_Inst_19_18, -1, 0, 0, 0, 0, 0, 0 },
  { "Inst_9_8", FIELD_Inst_9_8, -1, 0, 0, 0, 0, 0, 0 },
  { "Inst_4", FIELD_Inst_4, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_mul_d0", FIELD_ae_fld_mul_d0, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_mul_d1", FIELD_ae_fld_mul_d1, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_mul_q0", FIELD_ae_fld_mul_q0, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_mul_x2_S2_d1", FIELD_ae_fld_mul_x2_S2_d1, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_mul_x2_S2_d0", FIELD_ae_fld_mul_x2_S2_d0, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_mul_x2_S2_q0", FIELD_ae_fld_mul_x2_S2_q0, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_mul_x4_d2", FIELD_ae_fld_mul_x4_d2, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_mul_x4_q1", FIELD_ae_fld_mul_x4_q1, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_ls_v", FIELD_ae_fld_ls_v, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_ls_uu", FIELD_ae_fld_ls_uu, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_ls_su", FIELD_ae_fld_ls_su, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_ls_av", FIELD_ae_fld_ls_av, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_ls_v1", FIELD_ae_fld_ls_v1, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_ls_v2", FIELD_ae_fld_ls_v2, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_cmpp_v0", FIELD_ae_fld_cmpp_v0, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_cmpp_v1", FIELD_ae_fld_cmpp_v1, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_cmpp_v", FIELD_ae_fld_cmpp_v, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_uu_v", FIELD_ae_fld_uu_v, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_uu_uu", FIELD_ae_fld_uu_uu, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_dr_to_ar_v0", FIELD_ae_fld_dr_to_ar_v0, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_cmov_v", FIELD_ae_fld_cmov_v, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_cmov_v0", FIELD_ae_fld_cmov_v0, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_pks_d", FIELD_ae_fld_pks_d, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_pks_s", FIELD_ae_fld_pks_s, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_shift_d", FIELD_ae_fld_shift_d, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_shift_d0", FIELD_ae_fld_shift_d0, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_shift_sd", FIELD_ae_fld_shift_sd, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_dr_to_dr_v", FIELD_ae_fld_dr_to_dr_v, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_dr_to_dr_v0", FIELD_ae_fld_dr_to_dr_v0, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_dr_to_dr_v1", FIELD_ae_fld_dr_to_dr_v1, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_to_dr_v", FIELD_ae_fld_to_dr_v, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_to_dr_v0", FIELD_ae_fld_to_dr_v0, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_selimm", FIELD_ae_fld_selimm, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_selimm.N", FIELD_ae_fld_selimm_N, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ar_to_dr_imm", FIELD_fld_ar_to_dr_imm, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_arth_v", FIELD_ae_fld_arth_v, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_arth_v0", FIELD_ae_fld_arth_v0, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_arth_v1", FIELD_ae_fld_arth_v1, -1, 0, 0, 0, 0, 0, 0 },
  { "ae_fld_ar_to_dr_v", FIELD_ae_fld_ar_to_dr_v, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_11_4", FIELD_fld_ae2_slot0_11_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_7_4", FIELD_fld_ae2_slot0_7_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_9_8", FIELD_fld_ae2_slot0_9_8, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_11_11", FIELD_fld_ae2_slot0_11_11, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_31_30", FIELD_fld_ae2_slot0_31_30, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_11_8", FIELD_fld_ae2_slot0_11_8, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_31_12", FIELD_fld_ae2_slot0_31_12, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot0_19_12", FIELD_fld_ae_slot0_19_12, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_minislot2_18_16", FIELD_fld_ae_minislot2_18_16, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot0_19_16", FIELD_fld_ae_slot0_19_16, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_31_17", FIELD_fld_ae2_slot0_31_17, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot0_19_17", FIELD_fld_ae_slot0_19_17, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_minislot0_16_0", FIELD_fld_ae_minislot0_16_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_minislot1_0_0", FIELD_fld_ae_minislot1_0_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_minislot2_18_0", FIELD_fld_ae_minislot2_18_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_6_0", FIELD_fld_ae2_slot0_6_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot1_23_0", FIELD_fld_ae2_slot1_23_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot2_1_18_0", FIELD_fld_ae_slot2_1_18_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot0_19_0", FIELD_fld_ae_slot0_19_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot1_19_0", FIELD_fld_ae_slot1_19_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot2_0_19_0", FIELD_fld_ae_slot2_0_19_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot0_7_4", FIELD_fld_ae_slot0_7_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot0_11_8", FIELD_fld_ae_slot0_11_8, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_31_7", FIELD_fld_ae2_slot0_31_7, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot0_19_7", FIELD_fld_ae_slot0_19_7, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot1_19_14", FIELD_fld_ae_slot1_19_14, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot2_1_9_8", FIELD_fld_ae_slot2_1_9_8, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_31_16", FIELD_fld_ae2_slot0_31_16, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot2_1_7_4", FIELD_fld_ae_slot2_1_7_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot2_1_18_12", FIELD_fld_ae_slot2_1_18_12, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot2_1_1_0", FIELD_fld_ae_slot2_1_1_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot1_7_4", FIELD_fld_ae2_slot1_7_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot1_19_12", FIELD_fld_ae_slot1_19_12, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot2_0_19_12", FIELD_fld_ae_slot2_0_19_12, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot1_23_16", FIELD_fld_ae2_slot1_23_16, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot1_23_20", FIELD_fld_ae2_slot1_23_20, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_3_0", FIELD_fld_ae2_slot0_3_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot1_11_4", FIELD_fld_ae2_slot1_11_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot2_1_18_8", FIELD_fld_ae_slot2_1_18_8, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot1_7_4", FIELD_fld_ae_slot1_7_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_minislot2_11_4", FIELD_fld_ae_minislot2_11_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_minislot0_16_10", FIELD_fld_ae_minislot0_16_10, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_minislot2_3_0", FIELD_fld_ae_minislot2_3_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_minislot2_9_8", FIELD_fld_ae_minislot2_9_8, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot1_13_11", FIELD_fld_ae2_slot1_13_11, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot0_5_4", FIELD_fld_ae_slot0_5_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot1_9_8", FIELD_fld_ae_slot1_9_8, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_minislot0_16_8", FIELD_fld_ae_minislot0_16_8, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot1_7_7", FIELD_fld_ae2_slot1_7_7, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot1_18_16", FIELD_fld_ae2_slot1_18_16, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot2_1_18_16", FIELD_fld_ae_slot2_1_18_16, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_8_8", FIELD_fld_ae2_slot0_8_8, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot2_1_0_0", FIELD_fld_ae_slot2_1_0_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_minislot0_16_12", FIELD_fld_ae_minislot0_16_12, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_6_4", FIELD_fld_ae2_slot0_6_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_31_15", FIELD_fld_ae2_slot0_31_15, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot0_6_5", FIELD_fld_ae_slot0_6_5, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot0_19_14", FIELD_fld_ae_slot0_19_14, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot0_7_7", FIELD_fld_ae_slot0_7_7, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_4_4", FIELD_fld_ae2_slot0_4_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_7_7", FIELD_fld_ae2_slot0_7_7, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot0_4_4", FIELD_fld_ae_slot0_4_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_4_2", FIELD_fld_ae2_slot0_4_2, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot0_4_2", FIELD_fld_ae_slot0_4_2, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_4_0", FIELD_fld_ae2_slot0_4_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot0_4_0", FIELD_fld_ae_slot0_4_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_minislot2_18_8", FIELD_fld_ae_minislot2_18_8, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_5_4", FIELD_fld_ae2_slot0_5_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_14_12", FIELD_fld_ae2_slot0_14_12, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot2_1_8_8", FIELD_fld_ae_slot2_1_8_8, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot1_1_0", FIELD_fld_ae2_slot1_1_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot1_7_3", FIELD_fld_ae2_slot1_7_3, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot1_0_0", FIELD_fld_ae_slot1_0_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot1_3_3", FIELD_fld_ae_slot1_3_3, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_minislot2_11_8", FIELD_fld_ae_minislot2_11_8, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot2_0_7_4", FIELD_fld_ae_slot2_0_7_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_1_0", FIELD_fld_ae2_slot0_1_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot2_0_19_13", FIELD_fld_ae_slot2_0_19_13, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot0_0_0", FIELD_fld_ae2_slot0_0_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae_slot2_0_19_14", FIELD_fld_ae_slot2_0_19_14, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_ae2_slot1_7_6", FIELD_fld_ae2_slot1_7_6, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot3_7_4", FIELD_fld_xt_flix64_slot3_7_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot3_30_27", FIELD_fld_xt_flix64_slot3_30_27, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot3_30_26", FIELD_fld_xt_flix64_slot3_30_26, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot0_20_8", FIELD_fld_xt_flix64_slot0_20_8, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot1_19_8", FIELD_fld_xt_flix64_slot1_19_8, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot2_15_8", FIELD_fld_xt_flix64_slot2_15_8, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot2_3_3", FIELD_fld_xt_flix64_slot2_3_3, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot0_7_4", FIELD_fld_xt_flix64_slot0_7_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot2_7_4", FIELD_fld_xt_flix64_slot2_7_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot0_20_12", FIELD_fld_xt_flix64_slot0_20_12, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot1_19_12", FIELD_fld_xt_flix64_slot1_19_12, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot2_15_12", FIELD_fld_xt_flix64_slot2_15_12, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot0_20_16", FIELD_fld_xt_flix64_slot0_20_16, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot1_19_16", FIELD_fld_xt_flix64_slot1_19_16, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot0_20_17", FIELD_fld_xt_flix64_slot0_20_17, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot1_19_17", FIELD_fld_xt_flix64_slot1_19_17, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot1_19_18", FIELD_fld_xt_flix64_slot1_19_18, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot0_20_20", FIELD_fld_xt_flix64_slot0_20_20, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot1_7_4", FIELD_fld_xt_flix64_slot1_7_4, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot3_5_0", FIELD_fld_xt_flix64_slot3_5_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot3_30_6", FIELD_fld_xt_flix64_slot3_30_6, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot0_20_0", FIELD_fld_xt_flix64_slot0_20_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot1_19_0", FIELD_fld_xt_flix64_slot1_19_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_dummy_0_0", FIELD_fld_xt_dummy_0_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot2_15_0", FIELD_fld_xt_flix64_slot2_15_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot0_3_0", FIELD_fld_xt_flix64_slot0_3_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot1_3_0", FIELD_fld_xt_flix64_slot1_3_0, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot0_20_13", FIELD_fld_xt_flix64_slot0_20_13, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot1_19_13", FIELD_fld_xt_flix64_slot1_19_13, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot2_15_13", FIELD_fld_xt_flix64_slot2_15_13, -1, 0, 0, 0, 0, 0, 0 },
  { "fld_xt_flix64_slot0_20_5", FIELD_fld_xt_flix64_slot0_20_5, -1, 0, 0, 0, 0, 0, 0 }
};

enum xtensa_operand_id {
  OPERAND_soffsetx4,
  OPERAND_immr,
  OPERAND_uimm12x8,
  OPERAND_simm4,
  OPERAND_arr,
  OPERAND_ars,
  OPERAND__ars_invisible,
  OPERAND_art,
  OPERAND_ar0,
  OPERAND_ar4,
  OPERAND_ar8,
  OPERAND_ar12,
  OPERAND_ars_entry,
  OPERAND_immrx4,
  OPERAND_lsi4x4,
  OPERAND_simm7,
  OPERAND_uimm6,
  OPERAND_ai4const,
  OPERAND_b4const,
  OPERAND_b4constu,
  OPERAND_immt,
  OPERAND_uimm8,
  OPERAND_uimm8x2,
  OPERAND_uimm8x4,
  OPERAND_uimm4x16,
  OPERAND_uimmrx4,
  OPERAND_simm8,
  OPERAND_simm8x256,
  OPERAND_simm12b,
  OPERAND_msalp32,
  OPERAND_op2p1,
  OPERAND_label8,
  OPERAND_ulabel8,
  OPERAND_label12,
  OPERAND_soffset,
  OPERAND_uimm16x4,
  OPERAND_bbi,
  OPERAND_sae,
  OPERAND_sas,
  OPERAND_sargt,
  OPERAND_s,
  OPERAND_imms,
  OPERAND_imms1,
  OPERAND_bt,
  OPERAND_bs,
  OPERAND_br,
  OPERAND_bt2,
  OPERAND_bs2,
  OPERAND_br2,
  OPERAND_bt4,
  OPERAND_bs4,
  OPERAND_br4,
  OPERAND_bt8,
  OPERAND_bs8,
  OPERAND_br8,
  OPERAND_bt16,
  OPERAND_bs16,
  OPERAND_br16,
  OPERAND_brall,
  OPERAND_tp7,
  OPERAND_xt_wbr15_label,
  OPERAND_xt_wbr18_label,
  OPERAND_ae_ohba,
  OPERAND_ae_ohba2,
  OPERAND_ae_opnd_tp7,
  OPERAND_ae_imm2,
  OPERAND_ae_osa32,
  OPERAND_ae_osa64,
  OPERAND_ae_immls64,
  OPERAND_ae_immls64pos,
  OPERAND_ae_immls32,
  OPERAND_ae_immls16,
  OPERAND_ae_osa16,
  OPERAND_ae_selimm,
  OPERAND_ae_selimm_N,
  OPERAND_movi_imm,
  OPERAND_ae_mul_d0,
  OPERAND_ae_mul_d1,
  OPERAND_ae_mul_q0,
  OPERAND_ae_mul_S2_q0,
  OPERAND_ae_mul_S2_d0,
  OPERAND_ae_mul_S2_d1,
  OPERAND_ae_mul_d2,
  OPERAND_ae_mul_q1,
  OPERAND_ae_arth_v,
  OPERAND_ae_arth_v0,
  OPERAND_ae_arth_v1,
  OPERAND_ae_ar_to_dr_v,
  OPERAND_ae_to_dr_v,
  OPERAND_ae_to_dr_v0,
  OPERAND_ae_dr_to_dr_v,
  OPERAND_ae_dr_to_dr_v0,
  OPERAND_ae_dr_to_dr_v1,
  OPERAND_ae_cmpp_v0,
  OPERAND_ae_cmpp_v1,
  OPERAND_ae_cmpp_v,
  OPERAND_ae_ls_v,
  OPERAND_ae_ls_av,
  OPERAND_ae_ls_v1,
  OPERAND_ae_ls_v2,
  OPERAND_ae_ls_uu,
  OPERAND_ae_ls_su,
  OPERAND_ae_uu_v,
  OPERAND_ae_uu_uu,
  OPERAND_ae_dr_to_ar_v0,
  OPERAND_ae_cmov_v,
  OPERAND_ae_cmov_v0,
  OPERAND_ae_pks_d,
  OPERAND_ae_pks_s,
  OPERAND_ae_shift_d,
  OPERAND_ae_shift_d0,
  OPERAND_ae_shift_sd,
  OPERAND_frr,
  OPERAND_frs,
  OPERAND_frt,
  OPERAND_imm_t,
  OPERAND_imm_s,
  OPERAND_imm8x4,
  OPERAND_imm8x8,
  OPERAND_t,
  OPERAND_bbi4,
  OPERAND_imm12,
  OPERAND_imm8,
  OPERAND_imm12b,
  OPERAND_imm16,
  OPERAND_m,
  OPERAND_n,
  OPERAND_offset,
  OPERAND_op0,
  OPERAND_op1,
  OPERAND_op2,
  OPERAND_r,
  OPERAND_r_disp,
  OPERAND_r_3,
  OPERAND_sa4,
  OPERAND_sae4,
  OPERAND_sal,
  OPERAND_sas4,
  OPERAND_sr,
  OPERAND_st,
  OPERAND_thi3,
  OPERAND_imm4,
  OPERAND_mn,
  OPERAND_i,
  OPERAND_imm6lo,
  OPERAND_imm6hi,
  OPERAND_imm7lo,
  OPERAND_imm7hi,
  OPERAND_z,
  OPERAND_imm6,
  OPERAND_imm7,
  OPERAND_t2,
  OPERAND_s2,
  OPERAND_r2,
  OPERAND_t4,
  OPERAND_s4,
  OPERAND_r4,
  OPERAND_t8,
  OPERAND_s8,
  OPERAND_r8,
  OPERAND_xt_wbr15_imm,
  OPERAND_xt_wbr18_imm,
  OPERAND_ae_fld_fhba4,
  OPERAND_ae_fld_fhba4_2,
  OPERAND_ae_fld_tp7,
  OPERAND_ae_fld_osa32,
  OPERAND_ae_fld_osa64,
  OPERAND_ae_fld_imm2,
  OPERAND_ae_fld_immls64,
  OPERAND_ae_fld_immls64pos,
  OPERAND_ae_fld_immls32,
  OPERAND_ae_fld_immls16,
  OPERAND_ae_fld_osa16,
  OPERAND_Inst_15_12,
  OPERAND_Inst_11_8,
  OPERAND_Inst_7_4,
  OPERAND_Inst_12,
  OPERAND_Inst_7,
  OPERAND_Inst_5_4,
  OPERAND_Inst_7_6,
  OPERAND_Inst_19_17,
  OPERAND_Inst_19_18,
  OPERAND_Inst_9_8,
  OPERAND_Inst_4,
  OPERAND_ae_fld_mul_d0,
  OPERAND_ae_fld_mul_d1,
  OPERAND_ae_fld_mul_q0,
  OPERAND_ae_fld_mul_x2_S2_d1,
  OPERAND_ae_fld_mul_x2_S2_d0,
  OPERAND_ae_fld_mul_x2_S2_q0,
  OPERAND_ae_fld_mul_x4_d2,
  OPERAND_ae_fld_mul_x4_q1,
  OPERAND_ae_fld_ls_v,
  OPERAND_ae_fld_ls_uu,
  OPERAND_ae_fld_ls_su,
  OPERAND_ae_fld_ls_av,
  OPERAND_ae_fld_ls_v1,
  OPERAND_ae_fld_ls_v2,
  OPERAND_ae_fld_cmpp_v0,
  OPERAND_ae_fld_cmpp_v1,
  OPERAND_ae_fld_cmpp_v,
  OPERAND_ae_fld_uu_v,
  OPERAND_ae_fld_uu_uu,
  OPERAND_ae_fld_dr_to_ar_v0,
  OPERAND_ae_fld_cmov_v,
  OPERAND_ae_fld_cmov_v0,
  OPERAND_ae_fld_pks_d,
  OPERAND_ae_fld_pks_s,
  OPERAND_ae_fld_shift_d,
  OPERAND_ae_fld_shift_d0,
  OPERAND_ae_fld_shift_sd,
  OPERAND_ae_fld_dr_to_dr_v,
  OPERAND_ae_fld_dr_to_dr_v0,
  OPERAND_ae_fld_dr_to_dr_v1,
  OPERAND_ae_fld_to_dr_v,
  OPERAND_ae_fld_to_dr_v0,
  OPERAND_ae_fld_selimm,
  OPERAND_ae_fld_selimm_N,
  OPERAND_fld_ar_to_dr_imm,
  OPERAND_ae_fld_arth_v,
  OPERAND_ae_fld_arth_v0,
  OPERAND_ae_fld_arth_v1,
  OPERAND_ae_fld_ar_to_dr_v,
  OPERAND_fld_ae2_slot0_11_4,
  OPERAND_fld_ae2_slot0_7_4,
  OPERAND_fld_ae2_slot0_9_8,
  OPERAND_fld_ae2_slot0_11_11,
  OPERAND_fld_ae2_slot0_31_30,
  OPERAND_fld_ae2_slot0_11_8,
  OPERAND_fld_ae2_slot0_31_12,
  OPERAND_fld_ae_slot0_19_12,
  OPERAND_fld_ae_minislot2_18_16,
  OPERAND_fld_ae_slot0_19_16,
  OPERAND_fld_ae2_slot0_31_17,
  OPERAND_fld_ae_slot0_19_17,
  OPERAND_fld_ae_minislot0_16_0,
  OPERAND_fld_ae_minislot1_0_0,
  OPERAND_fld_ae_minislot2_18_0,
  OPERAND_fld_ae2_slot0_6_0,
  OPERAND_fld_ae2_slot1_23_0,
  OPERAND_fld_ae_slot2_1_18_0,
  OPERAND_fld_ae_slot0_19_0,
  OPERAND_fld_ae_slot1_19_0,
  OPERAND_fld_ae_slot2_0_19_0,
  OPERAND_fld_ae_slot0_7_4,
  OPERAND_fld_ae_slot0_11_8,
  OPERAND_fld_ae2_slot0_31_7,
  OPERAND_fld_ae_slot0_19_7,
  OPERAND_fld_ae_slot1_19_14,
  OPERAND_fld_ae_slot2_1_9_8,
  OPERAND_fld_ae2_slot0_31_16,
  OPERAND_fld_ae_slot2_1_7_4,
  OPERAND_fld_ae_slot2_1_18_12,
  OPERAND_fld_ae_slot2_1_1_0,
  OPERAND_fld_ae2_slot1_7_4,
  OPERAND_fld_ae_slot1_19_12,
  OPERAND_fld_ae_slot2_0_19_12,
  OPERAND_fld_ae2_slot1_23_16,
  OPERAND_fld_ae2_slot1_23_20,
  OPERAND_fld_ae2_slot0_3_0,
  OPERAND_fld_ae2_slot1_11_4,
  OPERAND_fld_ae_slot2_1_18_8,
  OPERAND_fld_ae_slot1_7_4,
  OPERAND_fld_ae_minislot2_11_4,
  OPERAND_fld_ae_minislot0_16_10,
  OPERAND_fld_ae_minislot2_3_0,
  OPERAND_fld_ae_minislot2_9_8,
  OPERAND_fld_ae2_slot1_13_11,
  OPERAND_fld_ae_slot0_5_4,
  OPERAND_fld_ae_slot1_9_8,
  OPERAND_fld_ae_minislot0_16_8,
  OPERAND_fld_ae2_slot1_7_7,
  OPERAND_fld_ae2_slot1_18_16,
  OPERAND_fld_ae_slot2_1_18_16,
  OPERAND_fld_ae2_slot0_8_8,
  OPERAND_fld_ae_slot2_1_0_0,
  OPERAND_fld_ae_minislot0_16_12,
  OPERAND_fld_ae2_slot0_6_4,
  OPERAND_fld_ae2_slot0_31_15,
  OPERAND_fld_ae_slot0_6_5,
  OPERAND_fld_ae_slot0_19_14,
  OPERAND_fld_ae_slot0_7_7,
  OPERAND_fld_ae2_slot0_4_4,
  OPERAND_fld_ae2_slot0_7_7,
  OPERAND_fld_ae_slot0_4_4,
  OPERAND_fld_ae2_slot0_4_2,
  OPERAND_fld_ae_slot0_4_2,
  OPERAND_fld_ae2_slot0_4_0,
  OPERAND_fld_ae_slot0_4_0,
  OPERAND_fld_ae_minislot2_18_8,
  OPERAND_fld_ae2_slot0_5_4,
  OPERAND_fld_ae2_slot0_14_12,
  OPERAND_fld_ae_slot2_1_8_8,
  OPERAND_fld_ae2_slot1_1_0,
  OPERAND_fld_ae2_slot1_7_3,
  OPERAND_fld_ae_slot1_0_0,
  OPERAND_fld_ae_slot1_3_3,
  OPERAND_fld_ae_minislot2_11_8,
  OPERAND_fld_ae_slot2_0_7_4,
  OPERAND_fld_ae2_slot0_1_0,
  OPERAND_fld_ae_slot2_0_19_13,
  OPERAND_fld_ae2_slot0_0_0,
  OPERAND_fld_ae_slot2_0_19_14,
  OPERAND_fld_ae2_slot1_7_6,
  OPERAND_fld_xt_flix64_slot3_7_4,
  OPERAND_fld_xt_flix64_slot3_30_27,
  OPERAND_fld_xt_flix64_slot3_30_26,
  OPERAND_fld_xt_flix64_slot0_20_8,
  OPERAND_fld_xt_flix64_slot1_19_8,
  OPERAND_fld_xt_flix64_slot2_15_8,
  OPERAND_fld_xt_flix64_slot2_3_3,
  OPERAND_fld_xt_flix64_slot0_7_4,
  OPERAND_fld_xt_flix64_slot2_7_4,
  OPERAND_fld_xt_flix64_slot0_20_12,
  OPERAND_fld_xt_flix64_slot1_19_12,
  OPERAND_fld_xt_flix64_slot2_15_12,
  OPERAND_fld_xt_flix64_slot0_20_16,
  OPERAND_fld_xt_flix64_slot1_19_16,
  OPERAND_fld_xt_flix64_slot0_20_17,
  OPERAND_fld_xt_flix64_slot1_19_17,
  OPERAND_fld_xt_flix64_slot1_19_18,
  OPERAND_fld_xt_flix64_slot0_20_20,
  OPERAND_fld_xt_flix64_slot1_7_4,
  OPERAND_fld_xt_flix64_slot3_5_0,
  OPERAND_fld_xt_flix64_slot3_30_6,
  OPERAND_fld_xt_flix64_slot0_20_0,
  OPERAND_fld_xt_flix64_slot1_19_0,
  OPERAND_fld_xt_dummy_0_0,
  OPERAND_fld_xt_flix64_slot2_15_0,
  OPERAND_fld_xt_flix64_slot0_3_0,
  OPERAND_fld_xt_flix64_slot1_3_0,
  OPERAND_fld_xt_flix64_slot0_20_13,
  OPERAND_fld_xt_flix64_slot1_19_13,
  OPERAND_fld_xt_flix64_slot2_15_13,
  OPERAND_fld_xt_flix64_slot0_20_5
};


/* Iclass table.  */

static xtensa_arg_internal Iclass_xt_iclass_rfe_stateArgs[] = {
  { { STATE_PSEXCM }, 'o' },
  { { STATE_EPC1 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rfde_stateArgs[] = {
  { { STATE_DEPC }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_call12_args[] = {
  { { OPERAND_soffsetx4 }, 'i' },
  { { OPERAND_ar12 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_call12_stateArgs[] = {
  { { STATE_PSCALLINC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_call8_args[] = {
  { { OPERAND_soffsetx4 }, 'i' },
  { { OPERAND_ar8 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_call8_stateArgs[] = {
  { { STATE_PSCALLINC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_call4_args[] = {
  { { OPERAND_soffsetx4 }, 'i' },
  { { OPERAND_ar4 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_call4_stateArgs[] = {
  { { STATE_PSCALLINC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_callx12_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ar12 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_callx12_stateArgs[] = {
  { { STATE_PSCALLINC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_callx8_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ar8 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_callx8_stateArgs[] = {
  { { STATE_PSCALLINC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_callx4_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ar4 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_callx4_stateArgs[] = {
  { { STATE_PSCALLINC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_entry_args[] = {
  { { OPERAND_ars_entry }, 's' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm12x8 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_entry_stateArgs[] = {
  { { STATE_PSCALLINC }, 'i' },
  { { STATE_PSEXCM }, 'i' },
  { { STATE_PSWOE }, 'i' },
  { { STATE_WindowBase }, 'm' },
  { { STATE_WindowStart }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_movsp_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_movsp_stateArgs[] = {
  { { STATE_WindowBase }, 'i' },
  { { STATE_WindowStart }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rotw_args[] = {
  { { OPERAND_simm4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rotw_stateArgs[] = {
  { { STATE_WindowBase }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_retw_args[] = {
  { { OPERAND__ars_invisible }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_retw_stateArgs[] = {
  { { STATE_WindowBase }, 'm' },
  { { STATE_WindowStart }, 'm' },
  { { STATE_PSCALLINC }, 'o' },
  { { STATE_PSEXCM }, 'i' },
  { { STATE_PSWOE }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rfwou_stateArgs[] = {
  { { STATE_EPC1 }, 'i' },
  { { STATE_PSEXCM }, 'o' },
  { { STATE_WindowBase }, 'm' },
  { { STATE_WindowStart }, 'm' },
  { { STATE_PSOWB }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_l32e_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_immrx4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_s32e_args[] = {
  { { OPERAND_art }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_immrx4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_windowbase_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_windowbase_stateArgs[] = {
  { { STATE_WindowBase }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_windowbase_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_windowbase_stateArgs[] = {
  { { STATE_WindowBase }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_windowbase_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_windowbase_stateArgs[] = {
  { { STATE_WindowBase }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_windowstart_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_windowstart_stateArgs[] = {
  { { STATE_WindowStart }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_windowstart_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_windowstart_stateArgs[] = {
  { { STATE_WindowStart }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_windowstart_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_windowstart_stateArgs[] = {
  { { STATE_WindowStart }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rfme_stateArgs[] = {
  { { STATE_MESRMemE }, 'o' },
  { { STATE_MEPC }, 'i' },
  { { STATE_MEPS }, 'i' },
  { { STATE_PSWOE }, 'o' },
  { { STATE_PSCALLINC }, 'o' },
  { { STATE_PSOWB }, 'o' },
  { { STATE_PSUM }, 'o' },
  { { STATE_PSEXCM }, 'o' },
  { { STATE_PSINTLEVEL }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_mesr_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_mesr_stateArgs[] = {
  { { STATE_MESRErrEnab }, 'i' },
  { { STATE_MESRErrTest }, 'i' },
  { { STATE_MESRMemE }, 'i' },
  { { STATE_MESRDME }, 'i' },
  { { STATE_MESRMemType }, 'i' },
  { { STATE_MESRAccType }, 'i' },
  { { STATE_MESRErrType }, 'i' },
  { { STATE_MESRWay }, 'i' },
  { { STATE_MESRDataExc }, 'i' },
  { { STATE_MESRInstExc }, 'i' },
  { { STATE_MESRRCE }, 'i' },
  { { STATE_MESRDLCE }, 'i' },
  { { STATE_MESRILCE }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_mesr_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_mesr_stateArgs[] = {
  { { STATE_MESRErrEnab }, 'o' },
  { { STATE_MESRErrTest }, 'o' },
  { { STATE_MESRMemE }, 'o' },
  { { STATE_MESRDME }, 'o' },
  { { STATE_MESRMemType }, 'o' },
  { { STATE_MESRAccType }, 'o' },
  { { STATE_MESRErrType }, 'o' },
  { { STATE_MESRWay }, 'o' },
  { { STATE_MESRDataExc }, 'o' },
  { { STATE_MESRInstExc }, 'o' },
  { { STATE_MESRRCE }, 'o' },
  { { STATE_MESRDLCE }, 'o' },
  { { STATE_MESRILCE }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_mesr_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_mesr_stateArgs[] = {
  { { STATE_MESRErrEnab }, 'm' },
  { { STATE_MESRErrTest }, 'm' },
  { { STATE_MESRMemE }, 'm' },
  { { STATE_MESRDME }, 'm' },
  { { STATE_MESRMemType }, 'm' },
  { { STATE_MESRAccType }, 'm' },
  { { STATE_MESRErrType }, 'm' },
  { { STATE_MESRWay }, 'm' },
  { { STATE_MESRDataExc }, 'm' },
  { { STATE_MESRInstExc }, 'm' },
  { { STATE_MESRRCE }, 'm' },
  { { STATE_MESRDLCE }, 'm' },
  { { STATE_MESRILCE }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_mecr_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_mecr_stateArgs[] = {
  { { STATE_MECR }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_mecr_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_mecr_stateArgs[] = {
  { { STATE_MECR }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_mecr_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_mecr_stateArgs[] = {
  { { STATE_MECR }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_mepc_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_mepc_stateArgs[] = {
  { { STATE_MEPC }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_mepc_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_mepc_stateArgs[] = {
  { { STATE_MEPC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_mepc_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_mepc_stateArgs[] = {
  { { STATE_MEPC }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_meps_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_meps_stateArgs[] = {
  { { STATE_MEPS }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_meps_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_meps_stateArgs[] = {
  { { STATE_MEPS }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_meps_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_meps_stateArgs[] = {
  { { STATE_MEPS }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_mesave_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_mesave_stateArgs[] = {
  { { STATE_MESAVE }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_mesave_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_mesave_stateArgs[] = {
  { { STATE_MESAVE }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_mesave_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_mesave_stateArgs[] = {
  { { STATE_MESAVE }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_mevaddr_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_mevaddr_stateArgs[] = {
  { { STATE_MEVADDR }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_mevaddr_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_mevaddr_stateArgs[] = {
  { { STATE_MEVADDR }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_mevaddr_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_mevaddr_stateArgs[] = {
  { { STATE_MEVADDR }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_add_n_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_addi_n_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ai4const }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_bz6_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm6 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_loadi4_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_lsi4x4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_mov_n_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_movi_n_args[] = {
  { { OPERAND_ars }, 'o' },
  { { OPERAND_simm7 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_retn_args[] = {
  { { OPERAND__ars_invisible }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_storei4_args[] = {
  { { OPERAND_art }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_lsi4x4 }, 'i' }
};

static xtensa_arg_internal Iclass_rur_threadptr_args[] = {
  { { OPERAND_arr }, 'o' }
};

static xtensa_arg_internal Iclass_rur_threadptr_stateArgs[] = {
  { { STATE_THREADPTR }, 'i' }
};

static xtensa_arg_internal Iclass_wur_threadptr_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_wur_threadptr_stateArgs[] = {
  { { STATE_THREADPTR }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_addi_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_simm8 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_addmi_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_simm8x256 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_addsub_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_bit_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_bsi8_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_b4const }, 'i' },
  { { OPERAND_label8 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_bsi8b_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_bbi }, 'i' },
  { { OPERAND_label8 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_bsi8u_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_b4constu }, 'i' },
  { { OPERAND_label8 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_bst8_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' },
  { { OPERAND_label8 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_bsz12_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_label12 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_call0_args[] = {
  { { OPERAND_soffsetx4 }, 'i' },
  { { OPERAND_ar0 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_callx0_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ar0 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_exti_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_art }, 'i' },
  { { OPERAND_sae }, 'i' },
  { { OPERAND_op2p1 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_jump_args[] = {
  { { OPERAND_soffset }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_jumpx_args[] = {
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_l16ui_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm8x2 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_l16si_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm8x2 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_l32i_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm8x4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_l32r_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_uimm16x4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_l8i_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm8 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_loop_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ulabel8 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_loop_stateArgs[] = {
  { { STATE_LBEG }, 'o' },
  { { STATE_LEND }, 'o' },
  { { STATE_LCOUNT }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_loopz_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ulabel8 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_loopz_stateArgs[] = {
  { { STATE_LBEG }, 'o' },
  { { STATE_LEND }, 'o' },
  { { STATE_LCOUNT }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_movi_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_simm12b }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_movz_args[] = {
  { { OPERAND_arr }, 'm' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_neg_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_return_args[] = {
  { { OPERAND__ars_invisible }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_s16i_args[] = {
  { { OPERAND_art }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm8x2 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_s32i_args[] = {
  { { OPERAND_art }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm8x4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_s32nb_args[] = {
  { { OPERAND_art }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimmrx4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_s8i_args[] = {
  { { OPERAND_art }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm8 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_sar_args[] = {
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_sar_stateArgs[] = {
  { { STATE_SAR }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_sari_args[] = {
  { { OPERAND_sas }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_sari_stateArgs[] = {
  { { STATE_SAR }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_shifts_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_shifts_stateArgs[] = {
  { { STATE_SAR }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_shiftst_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_shiftst_stateArgs[] = {
  { { STATE_SAR }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_shiftt_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_shiftt_stateArgs[] = {
  { { STATE_SAR }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_slli_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_msalp32 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_srai_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_art }, 'i' },
  { { OPERAND_sargt }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_srli_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_art }, 'i' },
  { { OPERAND_s }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_sync_stateArgs[] = {
  { { STATE_XTSYNC }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsil_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_s }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsil_stateArgs[] = {
  { { STATE_PSWOE }, 'i' },
  { { STATE_PSCALLINC }, 'i' },
  { { STATE_PSOWB }, 'i' },
  { { STATE_PSUM }, 'i' },
  { { STATE_PSEXCM }, 'i' },
  { { STATE_PSINTLEVEL }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_lend_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_lend_stateArgs[] = {
  { { STATE_LEND }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_lend_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_lend_stateArgs[] = {
  { { STATE_LEND }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_lend_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_lend_stateArgs[] = {
  { { STATE_LEND }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_lcount_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_lcount_stateArgs[] = {
  { { STATE_LCOUNT }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_lcount_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_lcount_stateArgs[] = {
  { { STATE_XTSYNC }, 'o' },
  { { STATE_LCOUNT }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_lcount_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_lcount_stateArgs[] = {
  { { STATE_XTSYNC }, 'o' },
  { { STATE_LCOUNT }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_lbeg_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_lbeg_stateArgs[] = {
  { { STATE_LBEG }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_lbeg_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_lbeg_stateArgs[] = {
  { { STATE_LBEG }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_lbeg_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_lbeg_stateArgs[] = {
  { { STATE_LBEG }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_sar_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_sar_stateArgs[] = {
  { { STATE_SAR }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_sar_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_sar_stateArgs[] = {
  { { STATE_SAR }, 'o' },
  { { STATE_XTSYNC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_sar_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_sar_stateArgs[] = {
  { { STATE_SAR }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_memctl_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_memctl_stateArgs[] = {
  { { STATE_MEMCTL }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_memctl_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_memctl_stateArgs[] = {
  { { STATE_MEMCTL }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_memctl_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_memctl_stateArgs[] = {
  { { STATE_MEMCTL }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_litbase_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_litbase_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_litbase_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_configid0_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_configid0_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_configid1_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_243_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ps_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ps_stateArgs[] = {
  { { STATE_PSWOE }, 'i' },
  { { STATE_PSCALLINC }, 'i' },
  { { STATE_PSOWB }, 'i' },
  { { STATE_PSUM }, 'i' },
  { { STATE_PSEXCM }, 'i' },
  { { STATE_PSINTLEVEL }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ps_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ps_stateArgs[] = {
  { { STATE_PSWOE }, 'o' },
  { { STATE_PSCALLINC }, 'o' },
  { { STATE_PSOWB }, 'o' },
  { { STATE_PSUM }, 'o' },
  { { STATE_PSEXCM }, 'o' },
  { { STATE_PSINTLEVEL }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ps_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ps_stateArgs[] = {
  { { STATE_PSWOE }, 'm' },
  { { STATE_PSCALLINC }, 'm' },
  { { STATE_PSOWB }, 'm' },
  { { STATE_PSUM }, 'm' },
  { { STATE_PSEXCM }, 'm' },
  { { STATE_PSINTLEVEL }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_epc1_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_epc1_stateArgs[] = {
  { { STATE_EPC1 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_epc1_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_epc1_stateArgs[] = {
  { { STATE_EPC1 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_epc1_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_epc1_stateArgs[] = {
  { { STATE_EPC1 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_excsave1_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_excsave1_stateArgs[] = {
  { { STATE_EXCSAVE1 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_excsave1_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_excsave1_stateArgs[] = {
  { { STATE_EXCSAVE1 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_excsave1_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_excsave1_stateArgs[] = {
  { { STATE_EXCSAVE1 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_epc2_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_epc2_stateArgs[] = {
  { { STATE_EPC2 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_epc2_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_epc2_stateArgs[] = {
  { { STATE_EPC2 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_epc2_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_epc2_stateArgs[] = {
  { { STATE_EPC2 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_excsave2_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_excsave2_stateArgs[] = {
  { { STATE_EXCSAVE2 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_excsave2_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_excsave2_stateArgs[] = {
  { { STATE_EXCSAVE2 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_excsave2_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_excsave2_stateArgs[] = {
  { { STATE_EXCSAVE2 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_epc3_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_epc3_stateArgs[] = {
  { { STATE_EPC3 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_epc3_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_epc3_stateArgs[] = {
  { { STATE_EPC3 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_epc3_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_epc3_stateArgs[] = {
  { { STATE_EPC3 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_excsave3_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_excsave3_stateArgs[] = {
  { { STATE_EXCSAVE3 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_excsave3_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_excsave3_stateArgs[] = {
  { { STATE_EXCSAVE3 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_excsave3_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_excsave3_stateArgs[] = {
  { { STATE_EXCSAVE3 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_epc4_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_epc4_stateArgs[] = {
  { { STATE_EPC4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_epc4_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_epc4_stateArgs[] = {
  { { STATE_EPC4 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_epc4_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_epc4_stateArgs[] = {
  { { STATE_EPC4 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_excsave4_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_excsave4_stateArgs[] = {
  { { STATE_EXCSAVE4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_excsave4_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_excsave4_stateArgs[] = {
  { { STATE_EXCSAVE4 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_excsave4_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_excsave4_stateArgs[] = {
  { { STATE_EXCSAVE4 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_epc5_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_epc5_stateArgs[] = {
  { { STATE_EPC5 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_epc5_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_epc5_stateArgs[] = {
  { { STATE_EPC5 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_epc5_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_epc5_stateArgs[] = {
  { { STATE_EPC5 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_excsave5_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_excsave5_stateArgs[] = {
  { { STATE_EXCSAVE5 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_excsave5_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_excsave5_stateArgs[] = {
  { { STATE_EXCSAVE5 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_excsave5_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_excsave5_stateArgs[] = {
  { { STATE_EXCSAVE5 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_epc6_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_epc6_stateArgs[] = {
  { { STATE_EPC6 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_epc6_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_epc6_stateArgs[] = {
  { { STATE_EPC6 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_epc6_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_epc6_stateArgs[] = {
  { { STATE_EPC6 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_excsave6_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_excsave6_stateArgs[] = {
  { { STATE_EXCSAVE6 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_excsave6_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_excsave6_stateArgs[] = {
  { { STATE_EXCSAVE6 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_excsave6_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_excsave6_stateArgs[] = {
  { { STATE_EXCSAVE6 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_epc7_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_epc7_stateArgs[] = {
  { { STATE_EPC7 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_epc7_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_epc7_stateArgs[] = {
  { { STATE_EPC7 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_epc7_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_epc7_stateArgs[] = {
  { { STATE_EPC7 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_excsave7_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_excsave7_stateArgs[] = {
  { { STATE_EXCSAVE7 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_excsave7_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_excsave7_stateArgs[] = {
  { { STATE_EXCSAVE7 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_excsave7_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_excsave7_stateArgs[] = {
  { { STATE_EXCSAVE7 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_eps2_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_eps2_stateArgs[] = {
  { { STATE_EPS2 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_eps2_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_eps2_stateArgs[] = {
  { { STATE_EPS2 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_eps2_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_eps2_stateArgs[] = {
  { { STATE_EPS2 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_eps3_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_eps3_stateArgs[] = {
  { { STATE_EPS3 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_eps3_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_eps3_stateArgs[] = {
  { { STATE_EPS3 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_eps3_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_eps3_stateArgs[] = {
  { { STATE_EPS3 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_eps4_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_eps4_stateArgs[] = {
  { { STATE_EPS4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_eps4_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_eps4_stateArgs[] = {
  { { STATE_EPS4 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_eps4_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_eps4_stateArgs[] = {
  { { STATE_EPS4 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_eps5_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_eps5_stateArgs[] = {
  { { STATE_EPS5 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_eps5_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_eps5_stateArgs[] = {
  { { STATE_EPS5 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_eps5_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_eps5_stateArgs[] = {
  { { STATE_EPS5 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_eps6_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_eps6_stateArgs[] = {
  { { STATE_EPS6 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_eps6_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_eps6_stateArgs[] = {
  { { STATE_EPS6 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_eps6_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_eps6_stateArgs[] = {
  { { STATE_EPS6 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_eps7_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_eps7_stateArgs[] = {
  { { STATE_EPS7 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_eps7_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_eps7_stateArgs[] = {
  { { STATE_EPS7 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_eps7_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_eps7_stateArgs[] = {
  { { STATE_EPS7 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_excvaddr_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_excvaddr_stateArgs[] = {
  { { STATE_EXCVADDR }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_excvaddr_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_excvaddr_stateArgs[] = {
  { { STATE_EXCVADDR }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_excvaddr_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_excvaddr_stateArgs[] = {
  { { STATE_EXCVADDR }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_depc_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_depc_stateArgs[] = {
  { { STATE_DEPC }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_depc_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_depc_stateArgs[] = {
  { { STATE_DEPC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_depc_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_depc_stateArgs[] = {
  { { STATE_DEPC }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_exccause_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_exccause_stateArgs[] = {
  { { STATE_EXCCAUSE }, 'i' },
  { { STATE_XTSYNC }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_exccause_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_exccause_stateArgs[] = {
  { { STATE_EXCCAUSE }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_exccause_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_exccause_stateArgs[] = {
  { { STATE_EXCCAUSE }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_prid_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_vecbase_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_vecbase_stateArgs[] = {
  { { STATE_VECBASE }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_vecbase_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_vecbase_stateArgs[] = {
  { { STATE_VECBASE }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_vecbase_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_vecbase_stateArgs[] = {
  { { STATE_VECBASE }, 'm' }
};

static xtensa_arg_internal Iclass_xt_mul16_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_mul32_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_mul32h_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rfi_args[] = {
  { { OPERAND_s }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rfi_stateArgs[] = {
  { { STATE_PSWOE }, 'o' },
  { { STATE_PSCALLINC }, 'o' },
  { { STATE_PSOWB }, 'o' },
  { { STATE_PSUM }, 'o' },
  { { STATE_PSEXCM }, 'o' },
  { { STATE_PSINTLEVEL }, 'o' },
  { { STATE_EPC1 }, 'i' },
  { { STATE_EPC2 }, 'i' },
  { { STATE_EPC3 }, 'i' },
  { { STATE_EPC4 }, 'i' },
  { { STATE_EPC5 }, 'i' },
  { { STATE_EPC6 }, 'i' },
  { { STATE_EPC7 }, 'i' },
  { { STATE_EPS2 }, 'i' },
  { { STATE_EPS3 }, 'i' },
  { { STATE_EPS4 }, 'i' },
  { { STATE_EPS5 }, 'i' },
  { { STATE_EPS6 }, 'i' },
  { { STATE_EPS7 }, 'i' },
  { { STATE_InOCDMode }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_wait_args[] = {
  { { OPERAND_s }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wait_stateArgs[] = {
  { { STATE_PSINTLEVEL }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_interrupt_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_interrupt_stateArgs[] = {
  { { STATE_INTERRUPT }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_intset_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_intset_stateArgs[] = {
  { { STATE_XTSYNC }, 'o' },
  { { STATE_INTERRUPT }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_intclear_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_intclear_stateArgs[] = {
  { { STATE_XTSYNC }, 'o' },
  { { STATE_INTERRUPT }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_intenable_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_intenable_stateArgs[] = {
  { { STATE_INTENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_intenable_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_intenable_stateArgs[] = {
  { { STATE_INTENABLE }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_intenable_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_intenable_stateArgs[] = {
  { { STATE_INTENABLE }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_break_args[] = {
  { { OPERAND_imms }, 'i' },
  { { OPERAND_immt }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_break_stateArgs[] = {
  { { STATE_PSEXCM }, 'i' },
  { { STATE_PSINTLEVEL }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_break_n_args[] = {
  { { OPERAND_imms }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_break_n_stateArgs[] = {
  { { STATE_PSEXCM }, 'i' },
  { { STATE_PSINTLEVEL }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_dbreaka0_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_dbreaka0_stateArgs[] = {
  { { STATE_DBREAKA0 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_dbreaka0_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_dbreaka0_stateArgs[] = {
  { { STATE_DBREAKA0 }, 'o' },
  { { STATE_XTSYNC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_dbreaka0_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_dbreaka0_stateArgs[] = {
  { { STATE_DBREAKA0 }, 'm' },
  { { STATE_XTSYNC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_dbreakc0_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_dbreakc0_stateArgs[] = {
  { { STATE_DBREAKC0 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_dbreakc0_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_dbreakc0_stateArgs[] = {
  { { STATE_DBREAKC0 }, 'o' },
  { { STATE_XTSYNC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_dbreakc0_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_dbreakc0_stateArgs[] = {
  { { STATE_DBREAKC0 }, 'm' },
  { { STATE_XTSYNC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_dbreaka1_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_dbreaka1_stateArgs[] = {
  { { STATE_DBREAKA1 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_dbreaka1_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_dbreaka1_stateArgs[] = {
  { { STATE_DBREAKA1 }, 'o' },
  { { STATE_XTSYNC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_dbreaka1_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_dbreaka1_stateArgs[] = {
  { { STATE_DBREAKA1 }, 'm' },
  { { STATE_XTSYNC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_dbreakc1_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_dbreakc1_stateArgs[] = {
  { { STATE_DBREAKC1 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_dbreakc1_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_dbreakc1_stateArgs[] = {
  { { STATE_DBREAKC1 }, 'o' },
  { { STATE_XTSYNC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_dbreakc1_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_dbreakc1_stateArgs[] = {
  { { STATE_DBREAKC1 }, 'm' },
  { { STATE_XTSYNC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ibreaka0_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ibreaka0_stateArgs[] = {
  { { STATE_IBREAKA0 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ibreaka0_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ibreaka0_stateArgs[] = {
  { { STATE_IBREAKA0 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ibreaka0_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ibreaka0_stateArgs[] = {
  { { STATE_IBREAKA0 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ibreaka1_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ibreaka1_stateArgs[] = {
  { { STATE_IBREAKA1 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ibreaka1_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ibreaka1_stateArgs[] = {
  { { STATE_IBREAKA1 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ibreaka1_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ibreaka1_stateArgs[] = {
  { { STATE_IBREAKA1 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ibreakenable_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ibreakenable_stateArgs[] = {
  { { STATE_IBREAKENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ibreakenable_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ibreakenable_stateArgs[] = {
  { { STATE_IBREAKENABLE }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ibreakenable_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ibreakenable_stateArgs[] = {
  { { STATE_IBREAKENABLE }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_debugcause_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_debugcause_stateArgs[] = {
  { { STATE_DEBUGCAUSE }, 'i' },
  { { STATE_DBNUM }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_debugcause_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_debugcause_stateArgs[] = {
  { { STATE_DEBUGCAUSE }, 'o' },
  { { STATE_DBNUM }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_debugcause_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_debugcause_stateArgs[] = {
  { { STATE_DEBUGCAUSE }, 'm' },
  { { STATE_DBNUM }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_icount_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_icount_stateArgs[] = {
  { { STATE_ICOUNT }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_icount_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_icount_stateArgs[] = {
  { { STATE_XTSYNC }, 'o' },
  { { STATE_ICOUNT }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_icount_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_icount_stateArgs[] = {
  { { STATE_XTSYNC }, 'o' },
  { { STATE_ICOUNT }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_icountlevel_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_icountlevel_stateArgs[] = {
  { { STATE_ICOUNTLEVEL }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_icountlevel_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_icountlevel_stateArgs[] = {
  { { STATE_ICOUNTLEVEL }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_icountlevel_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_icountlevel_stateArgs[] = {
  { { STATE_ICOUNTLEVEL }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ddr_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ddr_stateArgs[] = {
  { { STATE_DDR }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ddr_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ddr_stateArgs[] = {
  { { STATE_XTSYNC }, 'o' },
  { { STATE_DDR }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ddr_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ddr_stateArgs[] = {
  { { STATE_XTSYNC }, 'o' },
  { { STATE_DDR }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_lddr32_p_args[] = {
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_lddr32_p_stateArgs[] = {
  { { STATE_XTSYNC }, 'o' },
  { { STATE_InOCDMode }, 'i' },
  { { STATE_DDR }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_sddr32_p_args[] = {
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_sddr32_p_stateArgs[] = {
  { { STATE_InOCDMode }, 'i' },
  { { STATE_DDR }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rfdo_args[] = {
  { { OPERAND_imms }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rfdo_stateArgs[] = {
  { { STATE_InOCDMode }, 'm' },
  { { STATE_EPC6 }, 'i' },
  { { STATE_PSWOE }, 'o' },
  { { STATE_PSCALLINC }, 'o' },
  { { STATE_PSOWB }, 'o' },
  { { STATE_PSUM }, 'o' },
  { { STATE_PSEXCM }, 'o' },
  { { STATE_PSINTLEVEL }, 'o' },
  { { STATE_EPS6 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rfdd_stateArgs[] = {
  { { STATE_InOCDMode }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_mmid_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_mmid_stateArgs[] = {
  { { STATE_XTSYNC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_bbool1_args[] = {
  { { OPERAND_br }, 'o' },
  { { OPERAND_bs }, 'i' },
  { { OPERAND_bt }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_bbool4_args[] = {
  { { OPERAND_bt }, 'o' },
  { { OPERAND_bs4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_bbool8_args[] = {
  { { OPERAND_bt }, 'o' },
  { { OPERAND_bs8 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_bbranch_args[] = {
  { { OPERAND_bs }, 'i' },
  { { OPERAND_label8 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_bmove_args[] = {
  { { OPERAND_arr }, 'm' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_bt }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_RSR_BR_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_brall }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_WSR_BR_args[] = {
  { { OPERAND_art }, 'i' },
  { { OPERAND_brall }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_XSR_BR_args[] = {
  { { OPERAND_art }, 'm' },
  { { OPERAND_brall }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ccount_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ccount_stateArgs[] = {
  { { STATE_CCOUNT }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ccount_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ccount_stateArgs[] = {
  { { STATE_XTSYNC }, 'o' },
  { { STATE_CCOUNT }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ccount_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ccount_stateArgs[] = {
  { { STATE_XTSYNC }, 'o' },
  { { STATE_CCOUNT }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ccompare0_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ccompare0_stateArgs[] = {
  { { STATE_CCOMPARE0 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ccompare0_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ccompare0_stateArgs[] = {
  { { STATE_CCOMPARE0 }, 'o' },
  { { STATE_INTERRUPT }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ccompare0_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ccompare0_stateArgs[] = {
  { { STATE_CCOMPARE0 }, 'm' },
  { { STATE_INTERRUPT }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ccompare1_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ccompare1_stateArgs[] = {
  { { STATE_CCOMPARE1 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ccompare1_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ccompare1_stateArgs[] = {
  { { STATE_CCOMPARE1 }, 'o' },
  { { STATE_INTERRUPT }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ccompare1_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ccompare1_stateArgs[] = {
  { { STATE_CCOMPARE1 }, 'm' },
  { { STATE_INTERRUPT }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ccompare2_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_ccompare2_stateArgs[] = {
  { { STATE_CCOMPARE2 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ccompare2_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_ccompare2_stateArgs[] = {
  { { STATE_CCOMPARE2 }, 'o' },
  { { STATE_INTERRUPT }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ccompare2_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_ccompare2_stateArgs[] = {
  { { STATE_CCOMPARE2 }, 'm' },
  { { STATE_INTERRUPT }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_icache_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm8x4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_icache_lock_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm4x16 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_icache_inv_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm8x4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_licx_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_licx_stateArgs[] = {
  { { STATE_MESRErrTest }, 'i' },
  { { STATE_MECR }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_sicx_args[] = {
  { { OPERAND_art }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_dcache_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm8x4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_dcache_dyn_args[] = {
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_dcache_ind_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm4x16 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_dcache_inv_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm8x4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_dpf_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm8x4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_dcache_lock_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm4x16 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_sdct_args[] = {
  { { OPERAND_art }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_ldct_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_ldct_stateArgs[] = {
  { { STATE_MESRErrTest }, 'i' },
  { { STATE_MECR }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_prefctl_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_prefctl_stateArgs[] = {
  { { STATE_PREFCTL }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_prefctl_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_prefctl_stateArgs[] = {
  { { STATE_PREFCTL }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_prefctl_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_prefctl_stateArgs[] = {
  { { STATE_PREFCTL }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_idtlb_args[] = {
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_idtlb_stateArgs[] = {
  { { STATE_XTSYNC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rdtlb_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wdtlb_args[] = {
  { { OPERAND_art }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wdtlb_stateArgs[] = {
  { { STATE_XTSYNC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_iitlb_args[] = {
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_ritlb_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_witlb_args[] = {
  { { OPERAND_art }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_cpenable_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_cpenable_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_cpenable_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_cpenable_stateArgs[] = {
  { { STATE_CPENABLE }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_cpenable_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_cpenable_stateArgs[] = {
  { { STATE_CPENABLE }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_clamp_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_tp7 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_minmax_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_nsa_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_sx_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_tp7 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_l32ai_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm8x4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_s32ri_args[] = {
  { { OPERAND_art }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm8x4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_s32c1i_args[] = {
  { { OPERAND_art }, 'm' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_uimm8x4 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_s32c1i_stateArgs[] = {
  { { STATE_SCOMPARE1 }, 'i' },
  { { STATE_XTSYNC }, 'i' },
  { { STATE_SCOMPARE1 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_scompare1_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_scompare1_stateArgs[] = {
  { { STATE_SCOMPARE1 }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_scompare1_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_scompare1_stateArgs[] = {
  { { STATE_SCOMPARE1 }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_scompare1_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_scompare1_stateArgs[] = {
  { { STATE_SCOMPARE1 }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_atomctl_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_rsr_atomctl_stateArgs[] = {
  { { STATE_ATOMCTL }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_atomctl_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wsr_atomctl_stateArgs[] = {
  { { STATE_ATOMCTL }, 'o' },
  { { STATE_XTSYNC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_atomctl_args[] = {
  { { OPERAND_art }, 'm' }
};

static xtensa_arg_internal Iclass_xt_iclass_xsr_atomctl_stateArgs[] = {
  { { STATE_ATOMCTL }, 'm' },
  { { STATE_XTSYNC }, 'o' }
};

static xtensa_arg_internal Iclass_xt_iclass_div_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_rer_args[] = {
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wer_args[] = {
  { { OPERAND_art }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wb18_0_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_xt_wbr18_label }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wb18_1_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_b4const }, 'i' },
  { { OPERAND_xt_wbr18_label }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wb18_2_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_b4constu }, 'i' },
  { { OPERAND_xt_wbr18_label }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wb18_3_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_bbi }, 'i' },
  { { OPERAND_xt_wbr18_label }, 'i' }
};

static xtensa_arg_internal Iclass_xt_iclass_wb18_4_args[] = {
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' },
  { { OPERAND_xt_wbr18_label }, 'i' }
};

static xtensa_arg_internal Iclass_rur_ae_ovf_sar_args[] = {
  { { OPERAND_arr }, 'o' }
};

static xtensa_arg_internal Iclass_rur_ae_ovf_sar_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'i' },
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_wur_ae_ovf_sar_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_wur_ae_ovf_sar_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'o' },
  { { STATE_AE_SAR }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_rur_ae_bithead_args[] = {
  { { OPERAND_arr }, 'o' }
};

static xtensa_arg_internal Iclass_rur_ae_bithead_stateArgs[] = {
  { { STATE_AE_BITHEAD }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_wur_ae_bithead_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_wur_ae_bithead_stateArgs[] = {
  { { STATE_AE_BITHEAD }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_rur_ae_ts_fts_bu_bp_args[] = {
  { { OPERAND_arr }, 'o' }
};

static xtensa_arg_internal Iclass_rur_ae_ts_fts_bu_bp_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'i' },
  { { STATE_AE_BITSUSED }, 'i' },
  { { STATE_AE_TABLESIZE }, 'i' },
  { { STATE_AE_FIRST_TS }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_wur_ae_ts_fts_bu_bp_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_wur_ae_ts_fts_bu_bp_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'o' },
  { { STATE_AE_BITSUSED }, 'o' },
  { { STATE_AE_TABLESIZE }, 'o' },
  { { STATE_AE_FIRST_TS }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_rur_ae_cw_sd_no_args[] = {
  { { OPERAND_arr }, 'o' }
};

static xtensa_arg_internal Iclass_rur_ae_cw_sd_no_stateArgs[] = {
  { { STATE_AE_CWRAP }, 'i' },
  { { STATE_AE_NEXTOFFSET }, 'i' },
  { { STATE_AE_SEARCHDONE }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_wur_ae_cw_sd_no_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_wur_ae_cw_sd_no_stateArgs[] = {
  { { STATE_AE_CWRAP }, 'o' },
  { { STATE_AE_NEXTOFFSET }, 'o' },
  { { STATE_AE_SEARCHDONE }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_rur_ae_cbegin0_args[] = {
  { { OPERAND_arr }, 'o' }
};

static xtensa_arg_internal Iclass_rur_ae_cbegin0_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_wur_ae_cbegin0_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_wur_ae_cbegin0_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_rur_ae_cend0_args[] = {
  { { OPERAND_arr }, 'o' }
};

static xtensa_arg_internal Iclass_rur_ae_cend0_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_wur_ae_cend0_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_wur_ae_cend0_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_rur_fcr_args[] = {
  { { OPERAND_arr }, 'o' }
};

static xtensa_arg_internal Iclass_rur_fcr_stateArgs[] = {
  { { STATE_RoundMode }, 'i' },
  { { STATE_InvalidEnable }, 'i' },
  { { STATE_DivZeroEnable }, 'i' },
  { { STATE_OverflowEnable }, 'i' },
  { { STATE_UnderflowEnable }, 'i' },
  { { STATE_InexactEnable }, 'i' },
  { { STATE_FPreserved20 }, 'i' },
  { { STATE_FPreserved5 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_wur_fcr_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_wur_fcr_stateArgs[] = {
  { { STATE_RoundMode }, 'o' },
  { { STATE_InvalidEnable }, 'o' },
  { { STATE_DivZeroEnable }, 'o' },
  { { STATE_OverflowEnable }, 'o' },
  { { STATE_UnderflowEnable }, 'o' },
  { { STATE_InexactEnable }, 'o' },
  { { STATE_FPreserved20 }, 'o' },
  { { STATE_FPreserved5 }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_rur_fsr_args[] = {
  { { OPERAND_arr }, 'o' }
};

static xtensa_arg_internal Iclass_rur_fsr_stateArgs[] = {
  { { STATE_InvalidFlag }, 'i' },
  { { STATE_DivZeroFlag }, 'i' },
  { { STATE_OverflowFlag }, 'i' },
  { { STATE_UnderflowFlag }, 'i' },
  { { STATE_InexactFlag }, 'i' },
  { { STATE_FPreserved20a }, 'i' },
  { { STATE_FPreserved7 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_wur_fsr_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_wur_fsr_stateArgs[] = {
  { { STATE_InvalidFlag }, 'o' },
  { { STATE_DivZeroFlag }, 'o' },
  { { STATE_OverflowFlag }, 'o' },
  { { STATE_UnderflowFlag }, 'o' },
  { { STATE_InexactFlag }, 'o' },
  { { STATE_FPreserved20a }, 'o' },
  { { STATE_FPreserved7 }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_RUR_AE_OVERFLOW_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_RUR_AE_OVERFLOW_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_OVERFLOW_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_OVERFLOW_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_RUR_AE_SAR_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_RUR_AE_SAR_stateArgs[] = {
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_SAR_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_SAR_stateArgs[] = {
  { { STATE_AE_SAR }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_RUR_AE_BITPTR_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_RUR_AE_BITPTR_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_BITPTR_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_BITPTR_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_RUR_AE_BITSUSED_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_RUR_AE_BITSUSED_stateArgs[] = {
  { { STATE_AE_BITSUSED }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_BITSUSED_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_BITSUSED_stateArgs[] = {
  { { STATE_AE_BITSUSED }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_RUR_AE_TABLESIZE_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_RUR_AE_TABLESIZE_stateArgs[] = {
  { { STATE_AE_TABLESIZE }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_TABLESIZE_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_TABLESIZE_stateArgs[] = {
  { { STATE_AE_TABLESIZE }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_RUR_AE_FIRST_TS_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_RUR_AE_FIRST_TS_stateArgs[] = {
  { { STATE_AE_FIRST_TS }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_FIRST_TS_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_FIRST_TS_stateArgs[] = {
  { { STATE_AE_FIRST_TS }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_RUR_AE_NEXTOFFSET_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_RUR_AE_NEXTOFFSET_stateArgs[] = {
  { { STATE_AE_NEXTOFFSET }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_NEXTOFFSET_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_NEXTOFFSET_stateArgs[] = {
  { { STATE_AE_NEXTOFFSET }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_RUR_AE_SEARCHDONE_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_RUR_AE_SEARCHDONE_stateArgs[] = {
  { { STATE_AE_SEARCHDONE }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_SEARCHDONE_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_SEARCHDONE_stateArgs[] = {
  { { STATE_AE_SEARCHDONE }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_RUR_AE_CWRAP_args[] = {
  { { OPERAND_art }, 'o' }
};

static xtensa_arg_internal Iclass_RUR_AE_CWRAP_stateArgs[] = {
  { { STATE_AE_CWRAP }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_CWRAP_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_WUR_AE_CWRAP_stateArgs[] = {
  { { STATE_AE_CWRAP }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16M_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16M_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16M_I_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls16 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16M_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16M_IU_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls16 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16M_IU_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16M_X_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16M_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16M_XU_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16M_XU_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16_I_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls16 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls16 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16_X_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16_XP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16_XP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32F24_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32F24_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32F24_I_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32F24_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32F24_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32F24_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32F24_X_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32F24_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32F24_XP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32F24_XP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32_I_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32_X_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32_XP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32_XP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32M_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32M_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32M_I_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32M_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32M_IU_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32M_IU_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32M_X_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32M_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32M_XU_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32M_XU_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X2M_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X2M_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X2M_I_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X2M_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X2M_IU_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X2M_IU_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X2M_X_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X2M_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X2M_XU_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X2M_XU_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2F24_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2F24_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2F24_I_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2F24_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2F24_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls64pos }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2F24_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2F24_RIP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_L32X2F24_RIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2F24_RIC_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_L32X2F24_RIC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2F24_X_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2F24_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2F24_XP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2F24_XP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2_I_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls64pos }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2_RIP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_L32X2_RIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2_RIC_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_L32X2_RIC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2_X_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2_XP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L32X2_XP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X4_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X4_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X4_I_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X4_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X4_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls64pos }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X4_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X4_RIP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_L16X4_RIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X4_RIC_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_L16X4_RIC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X4_X_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X4_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X4_XP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L16X4_XP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L64_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L64_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L64_I_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L64_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L64_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L64_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L64_X_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L64_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L64_XP_args[] = {
  { { OPERAND_ae_ls_v }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_L64_XP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X2M_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X2M_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X2M_I_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X2M_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X2M_IU_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X2M_IU_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X2M_X_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X2M_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X2M_XU_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X2M_XU_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2F24_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2F24_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2F24_I_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2F24_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2F24_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls64pos }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2F24_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2F24_RIP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_S32X2F24_RIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2F24_RIC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_S32X2F24_RIC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2F24_X_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2F24_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2F24_XP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2F24_XP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2_I_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls64pos }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2_RIP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_S32X2_RIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2_RIC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_S32X2_RIC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2_X_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2_XP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2_XP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X4_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X4_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X4_I_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X4_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X4_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls64pos }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X4_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X4_RIP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_S16X4_RIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X4_RIC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_S16X4_RIC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X4_X_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X4_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X4_XP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16X4_XP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16M_L_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16M_L_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16M_L_I_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls16 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16M_L_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16M_L_IU_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls16 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16M_L_IU_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16M_L_X_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16M_L_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16M_L_XU_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16M_L_XU_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32F24_L_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32F24_L_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32F24_L_I_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32F24_L_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32F24_L_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32F24_L_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32F24_L_X_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32F24_L_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32F24_L_XP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32F24_L_XP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32_L_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32_L_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32_L_I_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32_L_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32_L_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32_L_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32_L_X_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32_L_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32_L_XP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32_L_XP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16_0_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16_0_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16_0_I_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls16 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16_0_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16_0_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls16 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16_0_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16_0_X_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16_0_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16_0_XP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S16_0_XP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S64_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S64_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S64_I_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S64_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S64_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S64_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S64_X_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S64_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S64_XP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S64_XP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32M_XC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32M_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32M_I_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32M_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32M_IU_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32M_IU_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32M_X_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32M_X_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32M_XU_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32M_XU_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ZALIGN64_args[] = {
  { { OPERAND_ae_uu_uu }, 'o' }
};

static xtensa_arg_internal Iclass_AE_ZALIGN64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LALIGN64_I_args[] = {
  { { OPERAND_ae_ls_uu }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LALIGN64_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SALIGN64_I_args[] = {
  { { OPERAND_ae_ls_su }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SALIGN64_I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVALIGN_args[] = {
  { { OPERAND_ae_uu_uu }, 'o' },
  { { OPERAND_ae_uu_v }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVALIGN_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA64_PP_args[] = {
  { { OPERAND_ae_ls_uu }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA64_PP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA24POS_PC_args[] = {
  { { OPERAND_ae_ls_uu }, 'o' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA24POS_PC_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA24X2POS_PC_args[] = {
  { { OPERAND_ae_ls_uu }, 'o' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA24X2POS_PC_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA32X2POS_PC_args[] = {
  { { OPERAND_ae_ls_uu }, 'o' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA32X2POS_PC_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA16X4POS_PC_args[] = {
  { { OPERAND_ae_ls_uu }, 'o' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA16X4POS_PC_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA24NEG_PC_args[] = {
  { { OPERAND_ae_ls_uu }, 'o' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA24NEG_PC_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA24X2NEG_PC_args[] = {
  { { OPERAND_ae_ls_uu }, 'o' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA24X2NEG_PC_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA32X2NEG_PC_args[] = {
  { { OPERAND_ae_ls_uu }, 'o' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA32X2NEG_PC_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA16X4NEG_PC_args[] = {
  { { OPERAND_ae_ls_uu }, 'o' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA16X4NEG_PC_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA64POS_FP_args[] = {
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA64POS_FP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA64NEG_FP_args[] = {
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA64NEG_FP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA32X2_IC_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA32X2_IC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA32X2_IP_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA32X2_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA32X2_RIP_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA32X2_RIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA32X2_RIC_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA32X2_RIC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA16X4_IC_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA16X4_IC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA16X4_IP_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA16X4_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA16X4_RIP_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA16X4_RIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA16X4_RIC_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA16X4_RIC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA32X2F24_IC_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA32X2F24_IC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA32X2F24_IP_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA32X2F24_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA32X2F24_RIP_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA32X2F24_RIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA32X2F24_RIC_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA32X2F24_RIC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA24_IC_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA24_IC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA24_IP_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA24_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA24_RIP_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA24_RIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA24_RIC_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA24_RIC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA24X2_IC_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA24X2_IC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA24X2_IP_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA24X2_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA24X2_RIP_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA24X2_RIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LA24X2_RIC_args[] = {
  { { OPERAND_ae_ls_av }, 'o' },
  { { OPERAND_ae_ls_uu }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_LA24X2_RIC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA32X2_IC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA32X2_IC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA32X2_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA32X2_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA32X2_RIP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA32X2_RIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA32X2_RIC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA32X2_RIC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA16X4_IC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA16X4_IC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA16X4_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA16X4_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA16X4_RIP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA16X4_RIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA16X4_RIC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA16X4_RIC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA32X2F24_IC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA32X2F24_IC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA32X2F24_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA32X2F24_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA32X2F24_RIP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA32X2F24_RIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA32X2F24_RIC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA32X2F24_RIC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA24_L_IC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA24_L_IC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA24_L_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA24_L_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA24_L_RIP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA24_L_RIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA24_L_RIC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA24_L_RIC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA24X2_IC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA24X2_IC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA24X2_IP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA24X2_IP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA24X2_RIP_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA24X2_RIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SA24X2_RIC_args[] = {
  { { OPERAND_ae_ls_v }, 'i' },
  { { OPERAND_ae_ls_su }, 'm' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SA24X2_RIC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32RA64S_I_args[] = {
  { { OPERAND_ae_ls_v1 }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32RA64S_I_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32RA64S_IP_args[] = {
  { { OPERAND_ae_ls_v1 }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32RA64S_IP_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32RA64S_X_args[] = {
  { { OPERAND_ae_ls_v1 }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32RA64S_X_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32RA64S_XP_args[] = {
  { { OPERAND_ae_ls_v1 }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32RA64S_XP_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32RA64S_XC_args[] = {
  { { OPERAND_ae_ls_v1 }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32RA64S_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S24RA64S_I_args[] = {
  { { OPERAND_ae_ls_v1 }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S24RA64S_I_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S24RA64S_IP_args[] = {
  { { OPERAND_ae_ls_v1 }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_immls32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S24RA64S_IP_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S24RA64S_X_args[] = {
  { { OPERAND_ae_ls_v1 }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S24RA64S_X_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S24RA64S_XP_args[] = {
  { { OPERAND_ae_ls_v1 }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S24RA64S_XP_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S24RA64S_XC_args[] = {
  { { OPERAND_ae_ls_v1 }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S24RA64S_XC_stateArgs[] = {
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S32X2RA64S_IP_args[] = {
  { { OPERAND_ae_ls_v2 }, 'i' },
  { { OPERAND_ae_ls_v1 }, 'i' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_S32X2RA64S_IP_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_S24X2RA64S_IP_args[] = {
  { { OPERAND_ae_ls_v2 }, 'i' },
  { { OPERAND_ae_ls_v1 }, 'i' },
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_S24X2RA64S_IP_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADDBRBA32_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_art }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SEL16I_args[] = {
  { { OPERAND_ae_dr_to_dr_v }, 'o' },
  { { OPERAND_ae_dr_to_dr_v0 }, 'i' },
  { { OPERAND_ae_dr_to_dr_v1 }, 'i' },
  { { OPERAND_ae_selimm }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SEL16I_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SEL16I_N_args[] = {
  { { OPERAND_ae_dr_to_dr_v }, 'o' },
  { { OPERAND_ae_dr_to_dr_v0 }, 'i' },
  { { OPERAND_ae_dr_to_dr_v1 }, 'i' },
  { { OPERAND_ae_selimm_N }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SEL16I_N_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SHORTSWAP_args[] = {
  { { OPERAND_ae_to_dr_v }, 'o' },
  { { OPERAND_ae_to_dr_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SHORTSWAP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVT16X4_args[] = {
  { { OPERAND_ae_cmov_v }, 'm' },
  { { OPERAND_ae_cmov_v0 }, 'i' },
  { { OPERAND_bt4 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVT16X4_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVF16X4_args[] = {
  { { OPERAND_ae_cmov_v }, 'm' },
  { { OPERAND_ae_cmov_v0 }, 'i' },
  { { OPERAND_bt4 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVF16X4_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVT32X2_args[] = {
  { { OPERAND_ae_cmov_v }, 'm' },
  { { OPERAND_ae_cmov_v0 }, 'i' },
  { { OPERAND_bt2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVT32X2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVF32X2_args[] = {
  { { OPERAND_ae_cmov_v }, 'm' },
  { { OPERAND_ae_cmov_v0 }, 'i' },
  { { OPERAND_bt2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVF32X2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVDA32X2_args[] = {
  { { OPERAND_ae_ar_to_dr_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVDA32X2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVDA32_args[] = {
  { { OPERAND_ae_ar_to_dr_v }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVDA32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVDA16X2_args[] = {
  { { OPERAND_ae_ar_to_dr_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVDA16X2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVDA16_args[] = {
  { { OPERAND_ae_ar_to_dr_v }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVDA16_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVI_args[] = {
  { { OPERAND_ae_ar_to_dr_v }, 'o' },
  { { OPERAND_movi_imm }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVI_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCP24A32X2_args[] = {
  { { OPERAND_ae_ar_to_dr_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCP24A32X2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SAT16X4_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SAT16X4_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVT32X2F16_32_args[] = {
  { { OPERAND_ae_to_dr_v }, 'o' },
  { { OPERAND_ae_to_dr_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVT32X2F16_32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVT32X2F16_10_args[] = {
  { { OPERAND_ae_to_dr_v }, 'o' },
  { { OPERAND_ae_to_dr_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVT32X2F16_10_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SEXT32X2D16_32_args[] = {
  { { OPERAND_ae_to_dr_v }, 'o' },
  { { OPERAND_ae_to_dr_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SEXT32X2D16_32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SEXT32X2D16_10_args[] = {
  { { OPERAND_ae_to_dr_v }, 'o' },
  { { OPERAND_ae_to_dr_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SEXT32X2D16_10_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTA32F24S_L_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ae_dr_to_ar_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTA32F24S_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTA32F24S_H_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ae_dr_to_ar_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTA32F24S_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTP24A16X2_LL_args[] = {
  { { OPERAND_ae_ar_to_dr_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTP24A16X2_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTP24A16X2_LH_args[] = {
  { { OPERAND_ae_ar_to_dr_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTP24A16X2_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTP24A16X2_HL_args[] = {
  { { OPERAND_ae_ar_to_dr_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTP24A16X2_HL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTP24A16X2_HH_args[] = {
  { { OPERAND_ae_ar_to_dr_v }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTP24A16X2_HH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCP24Q48X2_args[] = {
  { { OPERAND_ae_dr_to_dr_v }, 'o' },
  { { OPERAND_ae_dr_to_dr_v0 }, 'i' },
  { { OPERAND_ae_dr_to_dr_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCP24Q48X2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCA32X2F64S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_shift_sd }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCA32X2F64S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCI32X2F64S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_shift_sd }, 'i' },
  { { OPERAND_ae_osa16 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCI32X2F64S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCA32F64S_L_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_shift_sd }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCA32F64S_L_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCI32F64S_L_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_shift_sd }, 'i' },
  { { OPERAND_ae_osa16 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCI32F64S_L_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCP16_args[] = {
  { { OPERAND_ae_dr_to_dr_v }, 'o' },
  { { OPERAND_ae_dr_to_dr_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCP16_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUND32X2F64SSYM_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUND32X2F64SSYM_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUND32X2F64SASYM_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUND32X2F64SASYM_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUND32X2F48SSYM_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUND32X2F48SSYM_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUND32X2F48SASYM_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUND32X2F48SASYM_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUND16X4F32SSYM_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' },
  { { OPERAND_ae_arth_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUND16X4F32SSYM_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUND16X4F32SASYM_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' },
  { { OPERAND_ae_arth_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUND16X4F32SASYM_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUND24X2F48SSYM_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUND24X2F48SSYM_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUND24X2F48SASYM_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUND24X2F48SASYM_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUNDSP16Q48X2SYM_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUNDSP16Q48X2SYM_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUNDSP16Q48X2ASYM_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUNDSP16Q48X2ASYM_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MINABS32S_args[] = {
  { { OPERAND_ae_cmpp_v }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MINABS32S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MAXABS32S_args[] = {
  { { OPERAND_ae_cmpp_v }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MAXABS32S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUNDSP16F24SYM_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUNDSP16F24SYM_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUNDSP16F24ASYM_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUNDSP16F24ASYM_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOV_args[] = {
  { { OPERAND_ae_to_dr_v }, 'o' },
  { { OPERAND_ae_to_dr_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOV_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVT64_args[] = {
  { { OPERAND_ae_cmov_v }, 'm' },
  { { OPERAND_ae_cmov_v0 }, 'i' },
  { { OPERAND_bt }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVT64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVF64_args[] = {
  { { OPERAND_ae_cmov_v }, 'm' },
  { { OPERAND_ae_cmov_v0 }, 'i' },
  { { OPERAND_bt }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVF64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTQ56A32S_args[] = {
  { { OPERAND_ae_ar_to_dr_v }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTQ56A32S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVT48A32_args[] = {
  { { OPERAND_ae_ar_to_dr_v }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVT48A32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVT64A32_args[] = {
  { { OPERAND_ae_ar_to_dr_v }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVT64A32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTQ56P32S_L_args[] = {
  { { OPERAND_ae_dr_to_dr_v }, 'o' },
  { { OPERAND_ae_dr_to_dr_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTQ56P32S_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTQ56P32S_H_args[] = {
  { { OPERAND_ae_dr_to_dr_v }, 'o' },
  { { OPERAND_ae_dr_to_dr_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVTQ56P32S_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVT64F32_H_args[] = {
  { { OPERAND_ae_dr_to_dr_v }, 'o' },
  { { OPERAND_ae_dr_to_dr_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_CVT64F32_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SAT48S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SAT48S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SATQ56S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SATQ56S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SAT24S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SAT24S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCQ32_args[] = {
  { { OPERAND_ae_dr_to_dr_v }, 'o' },
  { { OPERAND_ae_dr_to_dr_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCQ32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MINABS64S_args[] = {
  { { OPERAND_ae_cmpp_v }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MINABS64S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MAXABS64S_args[] = {
  { { OPERAND_ae_cmpp_v }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MAXABS64S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUNDSQ32F48SYM_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUNDSQ32F48SYM_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUNDSQ32F48ASYM_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ROUNDSQ32F48ASYM_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCA32Q48_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ae_dr_to_ar_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCA32Q48_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVAD32_L_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ae_dr_to_ar_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVAD32_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVAD32_H_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ae_dr_to_ar_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVAD32_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVAD16_3_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ae_dr_to_ar_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVAD16_3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVAD16_2_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ae_dr_to_ar_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVAD16_2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVAD16_1_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ae_dr_to_ar_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVAD16_1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVAD16_0_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ae_dr_to_ar_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MOVAD16_0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRA64_32_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRA64_32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_PKSR32_args[] = {
  { { OPERAND_ae_pks_d }, 'm' },
  { { OPERAND_ae_pks_s }, 'i' },
  { { OPERAND_ae_imm2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_PKSR32_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_PKSR24_args[] = {
  { { OPERAND_ae_pks_d }, 'm' },
  { { OPERAND_ae_pks_s }, 'i' },
  { { OPERAND_ae_imm2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_PKSR24_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCA16P24S_L_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ae_dr_to_ar_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCA16P24S_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCA16P24S_H_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ae_dr_to_ar_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_TRUNCA16P24S_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADD32_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADD32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUB32_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUB32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADDSUB32_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADDSUB32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUBADD32_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUBADD32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADD16_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADD16_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUB16_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUB16_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADD32_HL_LH_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADD32_HL_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NEG32_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NEG32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ABS32_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ABS32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADD24S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADD24S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUB24S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUB24S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADD32S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADD32S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUB32S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUB32S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADDSUB32S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADDSUB32S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUBADD32S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUBADD32S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADD16S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADD16S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUB16S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUB16S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NEG24S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NEG24S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ABS24S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ABS24S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NEG32S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NEG32S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ABS32S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ABS32S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NEG16S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NEG16S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ABS16S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ABS16S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LT16_args[] = {
  { { OPERAND_br4 }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LT16_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LE16_args[] = {
  { { OPERAND_br4 }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LE16_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_EQ16_args[] = {
  { { OPERAND_br4 }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_EQ16_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LT32_args[] = {
  { { OPERAND_br2 }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LT32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LE32_args[] = {
  { { OPERAND_br2 }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LE32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_EQ32_args[] = {
  { { OPERAND_br2 }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_EQ32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MIN32_args[] = {
  { { OPERAND_ae_cmpp_v }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MIN32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MAX32_args[] = {
  { { OPERAND_ae_cmpp_v }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MAX32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADD64_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADD64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUB64_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUB64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NEG64_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NEG64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ABS64_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ABS64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADDSQ56S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADDSQ56S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUBSQ56S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUBSQ56S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADD64S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ADD64S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUB64S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v0 }, 'i' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SUB64S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NEGSQ56S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NEGSQ56S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ABSSQ56S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ABSSQ56S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NEG64S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NEG64S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ABS64S_args[] = {
  { { OPERAND_ae_arth_v }, 'o' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_ABS64S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_AND_args[] = {
  { { OPERAND_ae_dr_to_dr_v }, 'o' },
  { { OPERAND_ae_dr_to_dr_v0 }, 'i' },
  { { OPERAND_ae_dr_to_dr_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_AND_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NAND_args[] = {
  { { OPERAND_ae_dr_to_dr_v }, 'o' },
  { { OPERAND_ae_dr_to_dr_v0 }, 'i' },
  { { OPERAND_ae_dr_to_dr_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NAND_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_OR_args[] = {
  { { OPERAND_ae_dr_to_dr_v }, 'o' },
  { { OPERAND_ae_dr_to_dr_v0 }, 'i' },
  { { OPERAND_ae_dr_to_dr_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_OR_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_XOR_args[] = {
  { { OPERAND_ae_dr_to_dr_v }, 'o' },
  { { OPERAND_ae_dr_to_dr_v0 }, 'i' },
  { { OPERAND_ae_dr_to_dr_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_XOR_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAI24_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAI24_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLI24_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLI24_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAI24_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAI24_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAS24_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAS24_stateArgs[] = {
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLS24_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLS24_stateArgs[] = {
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAS24_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAS24_stateArgs[] = {
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAI16_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa16 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAI16_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAI16R_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa16 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAI16R_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAI32_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAI32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLI32_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLI32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAI32_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAI32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAI32R_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAI32R_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAS32_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAS32_stateArgs[] = {
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLS32_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLS32_stateArgs[] = {
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAS32_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAS32_stateArgs[] = {
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAA32_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAA32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLA32_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLA32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAA32_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAA32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAI16S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa16 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAI16S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAA16S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAA16S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAA16S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAA16S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAA16RS_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAA16RS_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAI24S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAI24S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAS24S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAS24S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAI32S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa32 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAI32S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAS32S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAS32S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAA32S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAA32S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAA32S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAA32S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAA32RS_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAA32RS_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLASQ56_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLASQ56_stateArgs[] = {
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLSQ56_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLSQ56_stateArgs[] = {
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRASQ56_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRASQ56_stateArgs[] = {
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAAQ56_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAAQ56_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLAQ56_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLAQ56_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAAQ56_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAAQ56_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAI64_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAI64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLI64_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLI64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAI64_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAI64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAS64_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAS64_stateArgs[] = {
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLS64_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLS64_stateArgs[] = {
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAS64_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAS64_stateArgs[] = {
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAA64_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAA64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLA64_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRLA64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAA64_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SRAA64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAISQ56S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAISQ56S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLASSQ56S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLASSQ56S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAASQ56S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAASQ56S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAI64S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ae_osa64 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAI64S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAS64S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAS64S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_AE_SAR }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAA64S_args[] = {
  { { OPERAND_ae_shift_d }, 'o' },
  { { OPERAND_ae_shift_d0 }, 'i' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SLAA64S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LT64_args[] = {
  { { OPERAND_br }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LT64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LE64_args[] = {
  { { OPERAND_br }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LE64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_EQ64_args[] = {
  { { OPERAND_br }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_EQ64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MAX64_args[] = {
  { { OPERAND_ae_cmpp_v }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MAX64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MIN64_args[] = {
  { { OPERAND_ae_cmpp_v }, 'o' },
  { { OPERAND_ae_cmpp_v0 }, 'i' },
  { { OPERAND_ae_cmpp_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MIN64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NSA64_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ae_dr_to_ar_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NSA64_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NSAZ16_0_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ae_dr_to_ar_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NSAZ16_0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NSAZ32_L_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ae_dr_to_ar_v0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_NSAZ32_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32F48P16S_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32F48P16S_LL_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32S_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32S_LL_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32F48P16S_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32F48P16S_LL_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32R_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32R_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32F48P16S_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32F48P16S_LH_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32S_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32S_LH_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32F48P16S_LH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32F48P16S_LH_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32R_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32R_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32F48P16S_HH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32F48P16S_HH_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32S_HH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32S_HH_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32_HH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32_HH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32F48P16S_HH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32F48P16S_HH_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32R_HH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32R_HH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32R_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32R_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAS32F48P16S_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAS32F48P16S_LL_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32S_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32S_LL_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAS32F48P16S_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAS32F48P16S_LL_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32R_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32R_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAS32F48P16S_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAS32F48P16S_LH_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32S_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32S_LH_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAS32F48P16S_LH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAS32F48P16S_LH_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32R_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32R_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAS32F48P16S_HH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAS32F48P16S_HH_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32S_HH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32S_HH_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32_HH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32_HH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAS32F48P16S_HH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAS32F48P16S_HH_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32R_HH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32R_HH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32R_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32R_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSS32F48P16S_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSS32F48P16S_LL_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32S_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32S_LL_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSS32F48P16S_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSS32F48P16S_LL_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32R_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32R_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSS32F48P16S_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSS32F48P16S_LH_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32S_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32S_LH_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSS32F48P16S_LH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSS32F48P16S_LH_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32R_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32R_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSS32F48P16S_HH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSS32F48P16S_HH_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32S_HH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32S_HH_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32_HH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32_HH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSS32F48P16S_HH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSS32F48P16S_HH_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32R_HH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32R_HH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32R_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32R_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32S_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32S_LL_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32S_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32S_LL_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32U_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32U_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32U_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32U_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32U_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32U_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_33_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_33_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_22_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_22_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_32_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_32_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_21_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_21_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_31_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_31_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_30_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_30_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_10_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_10_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_20_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_20_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_11_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_11_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_00_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_00_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_00_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16SS_00_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_33_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_33_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_22_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_22_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_32_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_32_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_21_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_21_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_31_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_31_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_30_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_30_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_10_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_10_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_20_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_20_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_11_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_11_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_00_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_00_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_00_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16SS_00_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_33_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_33_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_22_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_22_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_32_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_32_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_21_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_21_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_31_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_31_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_30_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_30_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_10_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_10_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_20_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_20_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_11_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_11_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_00_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_00_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_00_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16SS_00_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD16SS_33_22_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD16SS_33_22_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD16SS_33_22_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD16SS_33_22_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD16SS_13_02_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD16SS_13_02_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD16SS_13_02_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD16SS_13_02_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD16SS_11_00_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD16SS_11_00_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD16SS_11_00_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD16SS_11_00_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD16SS_33_22_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD16SS_33_22_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD16SS_33_22_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD16SS_33_22_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD16SS_13_02_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD16SS_13_02_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD16SS_13_02_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD16SS_13_02_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD16SS_11_00_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD16SS_11_00_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD16SS_11_00_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD16SS_11_00_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD16SS_33_22_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD16SS_33_22_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD16SS_33_22_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD16SS_33_22_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD16SS_13_02_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD16SS_13_02_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD16SS_13_02_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD16SS_13_02_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD16SS_11_00_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD16SS_11_00_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD16SS_11_00_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD16SS_11_00_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD16SS_33_22_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD16SS_33_22_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD16SS_33_22_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD16SS_33_22_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD16SS_13_02_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD16SS_13_02_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD16SS_13_02_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD16SS_13_02_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD16SS_11_00_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD16SS_11_00_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD16SS_11_00_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD16SS_11_00_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF48Q32SP16S_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF48Q32SP16S_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF48Q32SP16S_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF48Q32SP16S_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF48Q32SP16U_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF48Q32SP16U_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF48Q32SP16U_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF48Q32SP16U_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULQ32SP16S_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULQ32SP16S_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULQ32SP16S_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULQ32SP16S_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULQ32SP16U_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULQ32SP16U_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULQ32SP16U_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULQ32SP16U_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF48Q32SP16S_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF48Q32SP16S_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF48Q32SP16S_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF48Q32SP16S_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF48Q32SP16U_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF48Q32SP16U_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF48Q32SP16U_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF48Q32SP16U_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAQ32SP16S_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAQ32SP16S_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAQ32SP16S_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAQ32SP16S_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAQ32SP16U_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAQ32SP16U_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAQ32SP16U_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAQ32SP16U_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF48Q32SP16S_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF48Q32SP16S_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF48Q32SP16S_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF48Q32SP16S_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF48Q32SP16U_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF48Q32SP16U_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF48Q32SP16U_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF48Q32SP16U_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSQ32SP16S_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSQ32SP16S_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSQ32SP16S_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSQ32SP16S_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSQ32SP16U_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSQ32SP16U_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSQ32SP16U_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSQ32SP16U_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP24X2RA_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP24X2RA_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP24X2R_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP24X2R_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULP24X2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULP24X2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP24X2RA_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP24X2RA_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP24X2R_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP24X2R_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULP24X2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULP24X2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP24X2RA_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP24X2RA_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP24X2R_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP24X2R_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAP24X2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAP24X2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP24X2RA_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP24X2RA_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP24X2R_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP24X2R_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAP24X2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAP24X2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP24X2RA_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP24X2RA_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP24X2R_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP24X2R_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSP24X2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSP24X2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP24X2RA_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP24X2RA_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP24X2R_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP24X2R_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSP24X2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSP24X2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD24_HH_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD24_HH_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD24_HH_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD24_HH_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD24_HH_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD24_HH_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD24_HH_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD24_HH_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD24_HL_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD24_HL_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD24_HL_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD24_HL_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD24_HL_LH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD24_HL_LH_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD24_HL_LH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD24_HL_LH_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASFD24_HH_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASFD24_HH_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASD24_HH_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASD24_HH_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASFD24_HH_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASFD24_HH_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASD24_HH_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASD24_HH_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASFD24_HL_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASFD24_HL_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASD24_HL_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASD24_HL_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASFD24_HL_LH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASFD24_HL_LH_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASD24_HL_LH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASD24_HL_LH_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAFD24_HH_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAFD24_HH_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAD24_HH_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAD24_HH_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAFD24_HH_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAFD24_HH_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAD24_HH_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAD24_HH_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD24_HH_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD24_HH_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSD24_HH_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSD24_HH_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD24_HH_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD24_HH_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSD24_HH_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSD24_HH_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD24_HL_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD24_HL_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSD24_HL_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSD24_HL_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD24_HL_LH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD24_HL_LH_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSD24_HL_LH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSD24_HL_LH_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD24_HH_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD24_HH_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD24_HH_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD24_HH_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD24_HH_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD24_HH_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD24_HH_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD24_HH_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD24_HL_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD24_HL_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD24_HL_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD24_HL_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD24_HL_LH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD24_HL_LH_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD24_HL_LH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD24_HL_LH_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASFD24_HH_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASFD24_HH_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASD24_HH_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASD24_HH_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASFD24_HH_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASFD24_HH_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASD24_HH_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASD24_HH_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASFD24_HL_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASFD24_HL_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASD24_HL_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASD24_HL_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASFD24_HL_LH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASFD24_HL_LH_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASD24_HL_LH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASD24_HL_LH_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAFD24_HH_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAFD24_HH_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAD24_HH_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAD24_HH_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAFD24_HH_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAFD24_HH_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAD24_HH_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAD24_HH_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD24_HH_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD24_HH_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSD24_HH_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSD24_HH_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD24_HH_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD24_HH_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSD24_HH_LL_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSD24_HH_LL_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD24_HL_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD24_HL_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSD24_HL_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSD24_HL_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD24_HL_LH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD24_HL_LH_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSD24_HL_LH_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSD24_HL_LH_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSRFQ32SP24S_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSRFQ32SP24S_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSRFQ32SP24S_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSRFQ32SP24S_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSRFQ32SP24S_H_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSRFQ32SP24S_H_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSRFQ32SP24S_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSRFQ32SP24S_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULARFQ32SP24S_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULARFQ32SP24S_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULARFQ32SP24S_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULARFQ32SP24S_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULARFQ32SP24S_H_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULARFQ32SP24S_H_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULARFQ32SP24S_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULARFQ32SP24S_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULRFQ32SP24S_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULRFQ32SP24S_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULRFQ32SP24S_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULRFQ32SP24S_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULRFQ32SP24S_H_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULRFQ32SP24S_H_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULRFQ32SP24S_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULRFQ32SP24S_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFQ32SP24S_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFQ32SP24S_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFQ32SP24S_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFQ32SP24S_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFQ32SP24S_H_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFQ32SP24S_H_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFQ32SP24S_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFQ32SP24S_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFQ32SP24S_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFQ32SP24S_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFQ32SP24S_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFQ32SP24S_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFQ32SP24S_H_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFQ32SP24S_H_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFQ32SP24S_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFQ32SP24S_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFQ32SP24S_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFQ32SP24S_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFQ32SP24S_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFQ32SP24S_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFQ32SP24S_H_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFQ32SP24S_H_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFQ32SP24S_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFQ32SP24S_L_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_L1_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_L1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_L1_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_L1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_L1_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_L1_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_L1_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_L1_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_L3_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_L3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_L3_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_L3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_L3_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_L3_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_L3_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_L3_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_H0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_H0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_H0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_H0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_H0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_H0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_H0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_H0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_H1_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_H1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_H1_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_H1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_H1_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_H1_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_H1_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_H1_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_H2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_H2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_H2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_H2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_H2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_H2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_H2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_H2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_H3_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_H3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_H3_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_H3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_H3_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF32X16_H3_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_H3_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL32X16_H3_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_L1_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_L1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_L1_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_L1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_L1_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_L1_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_L1_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_L1_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_L3_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_L3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_L3_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_L3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_L3_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_L3_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_L3_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_L3_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_H0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_H0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_H0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_H0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_H0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_H0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_H0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_H0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_H1_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_H1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_H1_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_H1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_H1_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_H1_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_H1_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_H1_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_H2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_H2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_H2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_H2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_H2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_H2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_H2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_H2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_H3_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_H3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_H3_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_H3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_H3_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF32X16_H3_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_H3_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA32X16_H3_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_L1_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_L1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_L1_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_L1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_L1_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_L1_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_L1_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_L1_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_L3_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_L3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_L3_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_L3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_L3_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_L3_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_L3_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_L3_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_H0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_H0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_H0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_H0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_H0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_H0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_H0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_H0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_H1_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_H1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_H1_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_H1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_H1_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_H1_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_H1_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_H1_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_H2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_H2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_H2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_H2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_H2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_H2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_H2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_H2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_H3_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_H3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_H3_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_H3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_H3_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF32X16_H3_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_H3_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS32X16_H3_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD32X16_H3_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD32X16_H3_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD32X16_H3_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD32X16_H3_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD32X16_H3_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD32X16_H3_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD32X16_H3_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD32X16_H3_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD32X16_H1_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD32X16_H1_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD32X16_H1_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD32X16_H1_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD32X16_H1_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD32X16_H1_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD32X16_H1_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD32X16_H1_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASFD32X16_H3_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASFD32X16_H3_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASD32X16_H3_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASD32X16_H3_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASFD32X16_H3_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASFD32X16_H3_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASD32X16_H3_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASD32X16_H3_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASFD32X16_H1_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASFD32X16_H1_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASD32X16_H1_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASD32X16_H1_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASFD32X16_H1_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASFD32X16_H1_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASD32X16_H1_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULASD32X16_H1_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAFD32X16_H3_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAFD32X16_H3_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAD32X16_H3_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAD32X16_H3_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAFD32X16_H3_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAFD32X16_H3_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAD32X16_H3_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAD32X16_H3_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAFD32X16_H1_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAFD32X16_H1_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAD32X16_H1_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAD32X16_H1_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAFD32X16_H1_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAFD32X16_H1_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAD32X16_H1_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSAD32X16_H1_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD32X16_H3_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD32X16_H3_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSD32X16_H3_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSD32X16_H3_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD32X16_H3_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD32X16_H3_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSD32X16_H3_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSD32X16_H3_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD32X16_H1_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD32X16_H1_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSD32X16_H1_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSD32X16_H1_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD32X16_H1_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSFD32X16_H1_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSD32X16_H1_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSSD32X16_H1_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD32X16_H3_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD32X16_H3_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD32X16_H3_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD32X16_H3_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD32X16_H3_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD32X16_H3_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD32X16_H3_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD32X16_H3_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD32X16_H1_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD32X16_H1_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD32X16_H1_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD32X16_H1_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD32X16_H1_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD32X16_H1_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD32X16_H1_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD32X16_H1_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASFD32X16_H3_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASFD32X16_H3_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASD32X16_H3_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASD32X16_H3_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASFD32X16_H3_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASFD32X16_H3_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASD32X16_H3_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASD32X16_H3_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASFD32X16_H1_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASFD32X16_H1_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASD32X16_H1_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASD32X16_H1_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASFD32X16_H1_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASFD32X16_H1_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASD32X16_H1_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZASD32X16_H1_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAFD32X16_H3_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAFD32X16_H3_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAD32X16_H3_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAD32X16_H3_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAFD32X16_H3_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAFD32X16_H3_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAD32X16_H3_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAD32X16_H3_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAFD32X16_H1_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAFD32X16_H1_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAD32X16_H1_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAD32X16_H1_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAFD32X16_H1_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAFD32X16_H1_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAD32X16_H1_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSAD32X16_H1_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD32X16_H3_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD32X16_H3_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSD32X16_H3_L2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSD32X16_H3_L2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD32X16_H3_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD32X16_H3_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSD32X16_H3_L2_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSD32X16_H3_L2_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD32X16_H1_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD32X16_H1_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSD32X16_H1_L0_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSD32X16_H1_L0_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD32X16_H1_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSFD32X16_H1_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSD32X16_H1_L0_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZSSD32X16_H1_L0_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD32X16_H2_L3_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD32X16_H2_L3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD32X16_H0_L1_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD32X16_H0_L1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD32X16_H2_L3_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD32X16_H2_L3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD32X16_H0_L1_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD32X16_H0_L1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD32X16_H2_L3_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD32X16_H2_L3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD32X16_H0_L1_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD32X16_H0_L1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD32X16_H2_L3_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD32X16_H2_L3_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD32X16_H0_L1_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD32X16_H0_L1_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD32X16_H2_L3_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD32X16_H2_L3_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD32X16_H0_L1_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAFD32X16_H0_L1_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD32X16_H2_L3_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD32X16_H2_L3_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD32X16_H0_L1_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAFD32X16_H0_L1_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD32X16_H2_L3_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD32X16_H2_L3_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD32X16_H0_L1_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULZAAD32X16_H0_L1_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD32X16_H2_L3_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD32X16_H2_L3_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD32X16_H0_L1_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAAD32X16_H0_L1_S2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULP32X16X2_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULP32X16X2_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X16X2RS_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X16X2RS_H_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X16X2RAS_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X16X2RAS_H_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X16X2RS_H_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X16X2RS_H_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X16X2RAS_H_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X16X2RAS_H_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULP32X16X2_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULP32X16X2_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X16X2RS_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X16X2RS_L_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X16X2RAS_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X16X2RAS_L_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X16X2RS_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X16X2RS_L_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X16X2RAS_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'o' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X16X2RAS_L_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAP32X16X2_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAP32X16X2_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X16X2RS_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X16X2RS_H_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X16X2RAS_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X16X2RAS_H_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X16X2RS_H_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X16X2RS_H_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X16X2RAS_H_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X16X2RAS_H_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAP32X16X2_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAP32X16X2_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X16X2RS_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X16X2RS_L_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X16X2RAS_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X16X2RAS_L_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X16X2RS_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X16X2RS_L_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X16X2RAS_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X16X2RAS_L_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSP32X16X2_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSP32X16X2_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X16X2RS_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X16X2RS_H_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X16X2RAS_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X16X2RAS_H_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X16X2RS_H_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X16X2RS_H_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X16X2RAS_H_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X16X2RAS_H_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSP32X16X2_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSP32X16X2_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X16X2RS_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X16X2RS_L_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X16X2RAS_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X16X2RAS_L_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X16X2RS_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X16X2RS_L_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X16X2RAS_L_S2_args[] = {
  { { OPERAND_ae_mul_S2_q0 }, 'm' },
  { { OPERAND_ae_mul_S2_d0 }, 'i' },
  { { OPERAND_ae_mul_S2_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X16X2RAS_L_S2_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULP32X2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULP32X2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X2RS_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X2RS_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X2RAS_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP32X2RAS_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAP32X2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAP32X2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X2RS_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X2RS_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X2RAS_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFP32X2RAS_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSP32X2_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSP32X2_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X2RS_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X2RS_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X2RAS_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSFP32X2RAS_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP16X4S_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP16X4S_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP16X4RAS_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFP16X4RAS_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULC24_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULC24_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFC24RA_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFC24RA_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULC32X16_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULC32X16_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFC32X16RAS_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFC32X16RAS_L_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULC32X16_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULC32X16_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFC32X16RAS_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFC32X16RAS_H_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAC24_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAC24_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFC24RA_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFC24RA_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAC32X16_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAC32X16_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFC32X16RAS_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFC32X16RAS_L_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAC32X16_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAC32X16_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFC32X16RAS_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFC32X16RAS_H_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16X4SS_args[] = {
  { { OPERAND_ae_mul_q1 }, 'o' },
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULF16X4SS_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16X4SS_args[] = {
  { { OPERAND_ae_mul_q1 }, 'm' },
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAF16X4SS_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16X4SS_args[] = {
  { { OPERAND_ae_mul_q1 }, 'm' },
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULSF16X4SS_stateArgs[] = {
  { { STATE_AE_OVERFLOW }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL16X4_args[] = {
  { { OPERAND_ae_mul_q1 }, 'o' },
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MUL16X4_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA16X4_args[] = {
  { { OPERAND_ae_mul_q1 }, 'm' },
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULA16X4_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS16X4_args[] = {
  { { OPERAND_ae_mul_q1 }, 'm' },
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d0 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULS16X4_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFD24X2_FIR_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_q1 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFD24X2_FIR_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFD24X2_FIR_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_q1 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFD24X2_FIR_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFD32X16X2_FIR_HH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_q1 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFD32X16X2_FIR_HH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFD32X16X2_FIR_HL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_q1 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFD32X16X2_FIR_HL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFD32X16X2_FIR_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_q1 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFD32X16X2_FIR_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFD32X16X2_FIR_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'o' },
  { { OPERAND_ae_mul_q1 }, 'o' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULFD32X16X2_FIR_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFD24X2_FIR_H_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_q1 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFD24X2_FIR_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFD24X2_FIR_L_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_q1 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFD24X2_FIR_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFD32X16X2_FIR_HH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_q1 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFD32X16X2_FIR_HH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFD32X16X2_FIR_HL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_q1 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFD32X16X2_FIR_HL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFD32X16X2_FIR_LH_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_q1 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFD32X16X2_FIR_LH_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFD32X16X2_FIR_LL_args[] = {
  { { OPERAND_ae_mul_q0 }, 'm' },
  { { OPERAND_ae_mul_q1 }, 'm' },
  { { OPERAND_ae_mul_d0 }, 'i' },
  { { OPERAND_ae_mul_d1 }, 'i' },
  { { OPERAND_ae_mul_d2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_MULAFD32X16X2_FIR_LL_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_DIV64D32_H_args[] = {
  { { OPERAND_ae_arth_v }, 'm' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_DIV64D32_H_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_DIV64D32_L_args[] = {
  { { OPERAND_ae_arth_v }, 'm' },
  { { OPERAND_ae_arth_v1 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_DIV64D32_L_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SHA32_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_VLDL32T_args[] = {
  { { OPERAND_br }, 'o' },
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_VLDL32T_stateArgs[] = {
  { { STATE_AE_TABLESIZE }, 'm' },
  { { STATE_AE_BITSUSED }, 'o' },
  { { STATE_AE_NEXTOFFSET }, 'm' },
  { { STATE_AE_SEARCHDONE }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_VLDL16T_args[] = {
  { { OPERAND_br }, 'o' },
  { { OPERAND_art }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_VLDL16T_stateArgs[] = {
  { { STATE_AE_TABLESIZE }, 'm' },
  { { STATE_AE_BITSUSED }, 'o' },
  { { STATE_AE_NEXTOFFSET }, 'm' },
  { { STATE_AE_SEARCHDONE }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_VLDL16C_args[] = {
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_VLDL16C_stateArgs[] = {
  { { STATE_AE_NEXTOFFSET }, 'm' },
  { { STATE_AE_TABLESIZE }, 'm' },
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_AE_FIRST_TS }, 'i' },
  { { STATE_AE_BITSUSED }, 'i' },
  { { STATE_AE_SEARCHDONE }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_VLDL16C_IP_args[] = {
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_VLDL16C_IP_stateArgs[] = {
  { { STATE_AE_NEXTOFFSET }, 'm' },
  { { STATE_AE_TABLESIZE }, 'm' },
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_AE_FIRST_TS }, 'i' },
  { { STATE_AE_BITSUSED }, 'i' },
  { { STATE_AE_SEARCHDONE }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_VLDL16C_IC_args[] = {
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_VLDL16C_IC_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CWRAP }, 'm' },
  { { STATE_AE_NEXTOFFSET }, 'm' },
  { { STATE_AE_TABLESIZE }, 'm' },
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_AE_FIRST_TS }, 'i' },
  { { STATE_AE_BITSUSED }, 'i' },
  { { STATE_AE_SEARCHDONE }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_VLDSHT_args[] = {
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_VLDSHT_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'i' },
  { { STATE_AE_BITHEAD }, 'i' },
  { { STATE_AE_FIRST_TS }, 'o' },
  { { STATE_AE_NEXTOFFSET }, 'o' },
  { { STATE_AE_TABLESIZE }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LB_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LB_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'i' },
  { { STATE_AE_BITHEAD }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LBI_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ae_ohba }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LBI_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'i' },
  { { STATE_AE_BITHEAD }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LBK_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LBK_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'i' },
  { { STATE_AE_BITHEAD }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LBKI_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_ae_ohba }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LBKI_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'i' },
  { { STATE_AE_BITHEAD }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LBS_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LBS_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'i' },
  { { STATE_AE_BITHEAD }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LBSI_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_ae_ohba }, 'i' }
};

static xtensa_arg_internal Iclass_AE_LBSI_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'i' },
  { { STATE_AE_BITHEAD }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_DB_args[] = {
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_DB_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_DBI_args[] = {
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_ohba }, 'i' }
};

static xtensa_arg_internal Iclass_AE_DBI_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_DB_IC_args[] = {
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_DB_IC_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CWRAP }, 'm' },
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_DBI_IC_args[] = {
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_ohba }, 'i' }
};

static xtensa_arg_internal Iclass_AE_DBI_IC_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CWRAP }, 'm' },
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_DB_IP_args[] = {
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_DB_IP_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_DBI_IP_args[] = {
  { { OPERAND_ars }, 'm' },
  { { OPERAND_ae_ohba }, 'i' }
};

static xtensa_arg_internal Iclass_AE_DBI_IP_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_VLEL32T_args[] = {
  { { OPERAND_br }, 'o' },
  { { OPERAND_art }, 'm' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_VLEL32T_stateArgs[] = {
  { { STATE_AE_BITSUSED }, 'o' },
  { { STATE_AE_NEXTOFFSET }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_VLEL16T_args[] = {
  { { OPERAND_br }, 'o' },
  { { OPERAND_art }, 'm' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_AE_VLEL16T_stateArgs[] = {
  { { STATE_AE_BITSUSED }, 'o' },
  { { STATE_AE_NEXTOFFSET }, 'o' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SB_args[] = {
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SB_stateArgs[] = {
  { { STATE_AE_BITSUSED }, 'i' },
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SBI_args[] = {
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' },
  { { OPERAND_ae_ohba2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SBI_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_VLES16C_args[] = {
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_VLES16C_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_AE_NEXTOFFSET }, 'i' },
  { { STATE_AE_BITSUSED }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SBF_args[] = {
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SBF_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'i' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SB_IC_args[] = {
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SB_IC_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CWRAP }, 'm' },
  { { STATE_AE_BITSUSED }, 'i' },
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SBI_IC_args[] = {
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' },
  { { OPERAND_ae_ohba2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SBI_IC_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CWRAP }, 'm' },
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_VLES16C_IC_args[] = {
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_VLES16C_IC_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CWRAP }, 'm' },
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_AE_NEXTOFFSET }, 'i' },
  { { STATE_AE_BITSUSED }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SBF_IC_args[] = {
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SBF_IC_stateArgs[] = {
  { { STATE_AE_CBEGIN0 }, 'i' },
  { { STATE_AE_CEND0 }, 'i' },
  { { STATE_AE_CWRAP }, 'm' },
  { { STATE_AE_BITPTR }, 'i' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SB_IP_args[] = {
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SB_IP_stateArgs[] = {
  { { STATE_AE_BITSUSED }, 'i' },
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SBI_IP_args[] = {
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' },
  { { OPERAND_ae_ohba2 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SBI_IP_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_VLES16C_IP_args[] = {
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_VLES16C_IP_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'm' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_AE_NEXTOFFSET }, 'i' },
  { { STATE_AE_BITSUSED }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SBF_IP_args[] = {
  { { OPERAND_ars }, 'm' }
};

static xtensa_arg_internal Iclass_AE_SBF_IP_stateArgs[] = {
  { { STATE_AE_BITPTR }, 'i' },
  { { STATE_AE_BITHEAD }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SEXT32_args[] = {
  { { OPERAND_ae_dr_to_dr_v }, 'o' },
  { { OPERAND_ae_dr_to_dr_v0 }, 'i' },
  { { OPERAND_ae_opnd_tp7 }, 'i' }
};

static xtensa_arg_internal Iclass_AE_SEXT32_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_LSI_args[] = {
  { { OPERAND_frt }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_imm8x4 }, 'i' }
};

static xtensa_arg_internal Iclass_LSI_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_LSIP_args[] = {
  { { OPERAND_frt }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_imm8x4 }, 'i' }
};

static xtensa_arg_internal Iclass_LSIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_LSX_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_LSX_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_LSXP_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_LSXP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_SSI_args[] = {
  { { OPERAND_frt }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_imm8x4 }, 'i' }
};

static xtensa_arg_internal Iclass_SSI_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_SSIP_args[] = {
  { { OPERAND_frt }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_imm8x4 }, 'i' }
};

static xtensa_arg_internal Iclass_SSIP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_SSX_args[] = {
  { { OPERAND_frr }, 'i' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_SSX_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_SSXP_args[] = {
  { { OPERAND_frr }, 'i' },
  { { OPERAND_ars }, 'm' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_SSXP_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_ABS_S_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_frs }, 'i' }
};

static xtensa_arg_internal Iclass_ABS_S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_NEG_S_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_frs }, 'i' }
};

static xtensa_arg_internal Iclass_NEG_S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_MOV_S_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_frs }, 'i' }
};

static xtensa_arg_internal Iclass_MOV_S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_MOVEQZ_S_args[] = {
  { { OPERAND_frr }, 'm' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_MOVEQZ_S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_MOVNEZ_S_args[] = {
  { { OPERAND_frr }, 'm' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_MOVNEZ_S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_MOVLTZ_S_args[] = {
  { { OPERAND_frr }, 'm' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_MOVLTZ_S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_MOVGEZ_S_args[] = {
  { { OPERAND_frr }, 'm' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_art }, 'i' }
};

static xtensa_arg_internal Iclass_MOVGEZ_S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_MOVF_S_args[] = {
  { { OPERAND_frr }, 'm' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_bt }, 'i' }
};

static xtensa_arg_internal Iclass_MOVF_S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_MOVT_S_args[] = {
  { { OPERAND_frr }, 'm' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_bt }, 'i' }
};

static xtensa_arg_internal Iclass_MOVT_S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_WFR_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_ars }, 'i' }
};

static xtensa_arg_internal Iclass_WFR_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_RFR_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_frs }, 'i' }
};

static xtensa_arg_internal Iclass_RFR_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_ROUND_S_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_imm_t }, 'i' }
};

static xtensa_arg_internal Iclass_ROUND_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_InexactFlag }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_CEIL_S_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_imm_t }, 'i' }
};

static xtensa_arg_internal Iclass_CEIL_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_InexactFlag }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_FLOOR_S_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_imm_t }, 'i' }
};

static xtensa_arg_internal Iclass_FLOOR_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_InexactFlag }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_TRUNC_S_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_imm_t }, 'i' }
};

static xtensa_arg_internal Iclass_TRUNC_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_InexactFlag }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_UTRUNC_S_args[] = {
  { { OPERAND_arr }, 'o' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_imm_t }, 'i' }
};

static xtensa_arg_internal Iclass_UTRUNC_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_InexactFlag }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_FLOAT_S_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_imm_t }, 'i' }
};

static xtensa_arg_internal Iclass_FLOAT_S_stateArgs[] = {
  { { STATE_InexactFlag }, 'm' },
  { { STATE_RoundMode }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_UFLOAT_S_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_ars }, 'i' },
  { { OPERAND_imm_t }, 'i' }
};

static xtensa_arg_internal Iclass_UFLOAT_S_stateArgs[] = {
  { { STATE_InexactFlag }, 'm' },
  { { STATE_RoundMode }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_UN_S_args[] = {
  { { OPERAND_br }, 'o' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_frt }, 'i' }
};

static xtensa_arg_internal Iclass_UN_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_ULT_S_args[] = {
  { { OPERAND_br }, 'o' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_frt }, 'i' }
};

static xtensa_arg_internal Iclass_ULT_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_ULE_S_args[] = {
  { { OPERAND_br }, 'o' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_frt }, 'i' }
};

static xtensa_arg_internal Iclass_ULE_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_UEQ_S_args[] = {
  { { OPERAND_br }, 'o' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_frt }, 'i' }
};

static xtensa_arg_internal Iclass_UEQ_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_OLT_S_args[] = {
  { { OPERAND_br }, 'o' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_frt }, 'i' }
};

static xtensa_arg_internal Iclass_OLT_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_OLE_S_args[] = {
  { { OPERAND_br }, 'o' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_frt }, 'i' }
};

static xtensa_arg_internal Iclass_OLE_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_OEQ_S_args[] = {
  { { OPERAND_br }, 'o' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_frt }, 'i' }
};

static xtensa_arg_internal Iclass_OEQ_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_ADD_S_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_frt }, 'i' }
};

static xtensa_arg_internal Iclass_ADD_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_OverflowFlag }, 'm' },
  { { STATE_UnderflowFlag }, 'm' },
  { { STATE_InexactFlag }, 'm' },
  { { STATE_RoundMode }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_SUB_S_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_frt }, 'i' }
};

static xtensa_arg_internal Iclass_SUB_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_OverflowFlag }, 'm' },
  { { STATE_UnderflowFlag }, 'm' },
  { { STATE_InexactFlag }, 'm' },
  { { STATE_RoundMode }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_MUL_S_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_frt }, 'i' }
};

static xtensa_arg_internal Iclass_MUL_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_OverflowFlag }, 'm' },
  { { STATE_UnderflowFlag }, 'm' },
  { { STATE_InexactFlag }, 'm' },
  { { STATE_RoundMode }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_MADD_S_args[] = {
  { { OPERAND_frr }, 'm' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_frt }, 'i' }
};

static xtensa_arg_internal Iclass_MADD_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_OverflowFlag }, 'm' },
  { { STATE_UnderflowFlag }, 'm' },
  { { STATE_InexactFlag }, 'm' },
  { { STATE_RoundMode }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_MSUB_S_args[] = {
  { { OPERAND_frr }, 'm' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_frt }, 'i' }
};

static xtensa_arg_internal Iclass_MSUB_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_OverflowFlag }, 'm' },
  { { STATE_UnderflowFlag }, 'm' },
  { { STATE_InexactFlag }, 'm' },
  { { STATE_RoundMode }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_SQRT0_S_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_frs }, 'i' }
};

static xtensa_arg_internal Iclass_SQRT0_S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_DIV0_S_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_frs }, 'i' }
};

static xtensa_arg_internal Iclass_DIV0_S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_RECIP0_S_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_frs }, 'i' }
};

static xtensa_arg_internal Iclass_RECIP0_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_DivZeroFlag }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_RSQRT0_S_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_frs }, 'i' }
};

static xtensa_arg_internal Iclass_RSQRT0_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_DivZeroFlag }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_MADDN_S_args[] = {
  { { OPERAND_frr }, 'm' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_frt }, 'i' }
};

static xtensa_arg_internal Iclass_MADDN_S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_DIVN_S_args[] = {
  { { OPERAND_frr }, 'm' },
  { { OPERAND_frs }, 'i' },
  { { OPERAND_frt }, 'i' }
};

static xtensa_arg_internal Iclass_DIVN_S_stateArgs[] = {
  { { STATE_OverflowFlag }, 'm' },
  { { STATE_UnderflowFlag }, 'm' },
  { { STATE_InexactFlag }, 'm' },
  { { STATE_RoundMode }, 'i' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_CONST_S_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_imm_s }, 'i' }
};

static xtensa_arg_internal Iclass_CONST_S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_NEXP01_S_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_frs }, 'i' }
};

static xtensa_arg_internal Iclass_NEXP01_S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_ADDEXP_S_args[] = {
  { { OPERAND_frr }, 'm' },
  { { OPERAND_frs }, 'i' }
};

static xtensa_arg_internal Iclass_ADDEXP_S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_ADDEXPM_S_args[] = {
  { { OPERAND_frr }, 'm' },
  { { OPERAND_frs }, 'i' }
};

static xtensa_arg_internal Iclass_ADDEXPM_S_stateArgs[] = {
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_MKDADJ_S_args[] = {
  { { OPERAND_frr }, 'm' },
  { { OPERAND_frs }, 'i' }
};

static xtensa_arg_internal Iclass_MKDADJ_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_DivZeroFlag }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_arg_internal Iclass_MKSADJ_S_args[] = {
  { { OPERAND_frr }, 'o' },
  { { OPERAND_frs }, 'i' }
};

static xtensa_arg_internal Iclass_MKSADJ_S_stateArgs[] = {
  { { STATE_InvalidFlag }, 'm' },
  { { STATE_CPENABLE }, 'i' }
};

static xtensa_iclass_internal iclasses[] = {
  { 0, 0 /* xt_iclass_excw */,
    0, 0, 0, 0 },
  { 0, 0 /* xt_iclass_rfe */,
    2, Iclass_xt_iclass_rfe_stateArgs, 0, 0 },
  { 0, 0 /* xt_iclass_rfde */,
    1, Iclass_xt_iclass_rfde_stateArgs, 0, 0 },
  { 0, 0 /* xt_iclass_syscall */,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_call12_args,
    1, Iclass_xt_iclass_call12_stateArgs, 0, 0 },
  { 2, Iclass_xt_iclass_call8_args,
    1, Iclass_xt_iclass_call8_stateArgs, 0, 0 },
  { 2, Iclass_xt_iclass_call4_args,
    1, Iclass_xt_iclass_call4_stateArgs, 0, 0 },
  { 2, Iclass_xt_iclass_callx12_args,
    1, Iclass_xt_iclass_callx12_stateArgs, 0, 0 },
  { 2, Iclass_xt_iclass_callx8_args,
    1, Iclass_xt_iclass_callx8_stateArgs, 0, 0 },
  { 2, Iclass_xt_iclass_callx4_args,
    1, Iclass_xt_iclass_callx4_stateArgs, 0, 0 },
  { 3, Iclass_xt_iclass_entry_args,
    5, Iclass_xt_iclass_entry_stateArgs, 0, 0 },
  { 2, Iclass_xt_iclass_movsp_args,
    2, Iclass_xt_iclass_movsp_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rotw_args,
    1, Iclass_xt_iclass_rotw_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_retw_args,
    5, Iclass_xt_iclass_retw_stateArgs, 0, 0 },
  { 0, 0 /* xt_iclass_rfwou */,
    5, Iclass_xt_iclass_rfwou_stateArgs, 0, 0 },
  { 3, Iclass_xt_iclass_l32e_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_s32e_args,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_windowbase_args,
    1, Iclass_xt_iclass_rsr_windowbase_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_windowbase_args,
    1, Iclass_xt_iclass_wsr_windowbase_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_windowbase_args,
    1, Iclass_xt_iclass_xsr_windowbase_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_windowstart_args,
    1, Iclass_xt_iclass_rsr_windowstart_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_windowstart_args,
    1, Iclass_xt_iclass_wsr_windowstart_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_windowstart_args,
    1, Iclass_xt_iclass_xsr_windowstart_stateArgs, 0, 0 },
  { 0, 0 /* xt_iclass_rfme */,
    9, Iclass_xt_iclass_rfme_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_mesr_args,
    13, Iclass_xt_iclass_rsr_mesr_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_mesr_args,
    13, Iclass_xt_iclass_wsr_mesr_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_mesr_args,
    13, Iclass_xt_iclass_xsr_mesr_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_mecr_args,
    1, Iclass_xt_iclass_rsr_mecr_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_mecr_args,
    1, Iclass_xt_iclass_wsr_mecr_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_mecr_args,
    1, Iclass_xt_iclass_xsr_mecr_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_mepc_args,
    1, Iclass_xt_iclass_rsr_mepc_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_mepc_args,
    1, Iclass_xt_iclass_wsr_mepc_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_mepc_args,
    1, Iclass_xt_iclass_xsr_mepc_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_meps_args,
    1, Iclass_xt_iclass_rsr_meps_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_meps_args,
    1, Iclass_xt_iclass_wsr_meps_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_meps_args,
    1, Iclass_xt_iclass_xsr_meps_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_mesave_args,
    1, Iclass_xt_iclass_rsr_mesave_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_mesave_args,
    1, Iclass_xt_iclass_wsr_mesave_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_mesave_args,
    1, Iclass_xt_iclass_xsr_mesave_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_mevaddr_args,
    1, Iclass_xt_iclass_rsr_mevaddr_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_mevaddr_args,
    1, Iclass_xt_iclass_wsr_mevaddr_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_mevaddr_args,
    1, Iclass_xt_iclass_xsr_mevaddr_stateArgs, 0, 0 },
  { 3, Iclass_xt_iclass_add_n_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_addi_n_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_bz6_args,
    0, 0, 0, 0 },
  { 0, 0 /* xt_iclass_ill_n */,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_loadi4_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_mov_n_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_movi_n_args,
    0, 0, 0, 0 },
  { 0, 0 /* xt_iclass_nopn */,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_retn_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_storei4_args,
    0, 0, 0, 0 },
  { 1, Iclass_rur_threadptr_args,
    1, Iclass_rur_threadptr_stateArgs, 0, 0 },
  { 1, Iclass_wur_threadptr_args,
    1, Iclass_wur_threadptr_stateArgs, 0, 0 },
  { 3, Iclass_xt_iclass_addi_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_addmi_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_addsub_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_bit_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_bsi8_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_bsi8b_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_bsi8u_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_bst8_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_bsz12_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_call0_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_callx0_args,
    0, 0, 0, 0 },
  { 4, Iclass_xt_iclass_exti_args,
    0, 0, 0, 0 },
  { 0, 0 /* xt_iclass_ill */,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_jump_args,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_jumpx_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_l16ui_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_l16si_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_l32i_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_l32r_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_l8i_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_loop_args,
    3, Iclass_xt_iclass_loop_stateArgs, 0, 0 },
  { 2, Iclass_xt_iclass_loopz_args,
    3, Iclass_xt_iclass_loopz_stateArgs, 0, 0 },
  { 2, Iclass_xt_iclass_movi_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_movz_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_neg_args,
    0, 0, 0, 0 },
  { 0, 0 /* xt_iclass_nop */,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_return_args,
    0, 0, 0, 0 },
  { 0, 0 /* xt_iclass_simcall */,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_s16i_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_s32i_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_s32nb_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_s8i_args,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_sar_args,
    1, Iclass_xt_iclass_sar_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_sari_args,
    1, Iclass_xt_iclass_sari_stateArgs, 0, 0 },
  { 2, Iclass_xt_iclass_shifts_args,
    1, Iclass_xt_iclass_shifts_stateArgs, 0, 0 },
  { 3, Iclass_xt_iclass_shiftst_args,
    1, Iclass_xt_iclass_shiftst_stateArgs, 0, 0 },
  { 2, Iclass_xt_iclass_shiftt_args,
    1, Iclass_xt_iclass_shiftt_stateArgs, 0, 0 },
  { 3, Iclass_xt_iclass_slli_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_srai_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_srli_args,
    0, 0, 0, 0 },
  { 0, 0 /* xt_iclass_memw */,
    0, 0, 0, 0 },
  { 0, 0 /* xt_iclass_extw */,
    0, 0, 0, 0 },
  { 0, 0 /* xt_iclass_isync */,
    0, 0, 0, 0 },
  { 0, 0 /* xt_iclass_sync */,
    1, Iclass_xt_iclass_sync_stateArgs, 0, 0 },
  { 2, Iclass_xt_iclass_rsil_args,
    6, Iclass_xt_iclass_rsil_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_lend_args,
    1, Iclass_xt_iclass_rsr_lend_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_lend_args,
    1, Iclass_xt_iclass_wsr_lend_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_lend_args,
    1, Iclass_xt_iclass_xsr_lend_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_lcount_args,
    1, Iclass_xt_iclass_rsr_lcount_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_lcount_args,
    2, Iclass_xt_iclass_wsr_lcount_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_lcount_args,
    2, Iclass_xt_iclass_xsr_lcount_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_lbeg_args,
    1, Iclass_xt_iclass_rsr_lbeg_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_lbeg_args,
    1, Iclass_xt_iclass_wsr_lbeg_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_lbeg_args,
    1, Iclass_xt_iclass_xsr_lbeg_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_sar_args,
    1, Iclass_xt_iclass_rsr_sar_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_sar_args,
    2, Iclass_xt_iclass_wsr_sar_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_sar_args,
    1, Iclass_xt_iclass_xsr_sar_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_memctl_args,
    1, Iclass_xt_iclass_rsr_memctl_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_memctl_args,
    1, Iclass_xt_iclass_wsr_memctl_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_memctl_args,
    1, Iclass_xt_iclass_xsr_memctl_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_litbase_args,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_litbase_args,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_litbase_args,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_configid0_args,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_configid0_args,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_configid1_args,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_243_args,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_ps_args,
    6, Iclass_xt_iclass_rsr_ps_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_ps_args,
    6, Iclass_xt_iclass_wsr_ps_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_ps_args,
    6, Iclass_xt_iclass_xsr_ps_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_epc1_args,
    1, Iclass_xt_iclass_rsr_epc1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_epc1_args,
    1, Iclass_xt_iclass_wsr_epc1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_epc1_args,
    1, Iclass_xt_iclass_xsr_epc1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_excsave1_args,
    1, Iclass_xt_iclass_rsr_excsave1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_excsave1_args,
    1, Iclass_xt_iclass_wsr_excsave1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_excsave1_args,
    1, Iclass_xt_iclass_xsr_excsave1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_epc2_args,
    1, Iclass_xt_iclass_rsr_epc2_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_epc2_args,
    1, Iclass_xt_iclass_wsr_epc2_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_epc2_args,
    1, Iclass_xt_iclass_xsr_epc2_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_excsave2_args,
    1, Iclass_xt_iclass_rsr_excsave2_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_excsave2_args,
    1, Iclass_xt_iclass_wsr_excsave2_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_excsave2_args,
    1, Iclass_xt_iclass_xsr_excsave2_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_epc3_args,
    1, Iclass_xt_iclass_rsr_epc3_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_epc3_args,
    1, Iclass_xt_iclass_wsr_epc3_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_epc3_args,
    1, Iclass_xt_iclass_xsr_epc3_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_excsave3_args,
    1, Iclass_xt_iclass_rsr_excsave3_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_excsave3_args,
    1, Iclass_xt_iclass_wsr_excsave3_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_excsave3_args,
    1, Iclass_xt_iclass_xsr_excsave3_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_epc4_args,
    1, Iclass_xt_iclass_rsr_epc4_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_epc4_args,
    1, Iclass_xt_iclass_wsr_epc4_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_epc4_args,
    1, Iclass_xt_iclass_xsr_epc4_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_excsave4_args,
    1, Iclass_xt_iclass_rsr_excsave4_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_excsave4_args,
    1, Iclass_xt_iclass_wsr_excsave4_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_excsave4_args,
    1, Iclass_xt_iclass_xsr_excsave4_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_epc5_args,
    1, Iclass_xt_iclass_rsr_epc5_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_epc5_args,
    1, Iclass_xt_iclass_wsr_epc5_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_epc5_args,
    1, Iclass_xt_iclass_xsr_epc5_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_excsave5_args,
    1, Iclass_xt_iclass_rsr_excsave5_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_excsave5_args,
    1, Iclass_xt_iclass_wsr_excsave5_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_excsave5_args,
    1, Iclass_xt_iclass_xsr_excsave5_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_epc6_args,
    1, Iclass_xt_iclass_rsr_epc6_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_epc6_args,
    1, Iclass_xt_iclass_wsr_epc6_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_epc6_args,
    1, Iclass_xt_iclass_xsr_epc6_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_excsave6_args,
    1, Iclass_xt_iclass_rsr_excsave6_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_excsave6_args,
    1, Iclass_xt_iclass_wsr_excsave6_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_excsave6_args,
    1, Iclass_xt_iclass_xsr_excsave6_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_epc7_args,
    1, Iclass_xt_iclass_rsr_epc7_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_epc7_args,
    1, Iclass_xt_iclass_wsr_epc7_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_epc7_args,
    1, Iclass_xt_iclass_xsr_epc7_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_excsave7_args,
    1, Iclass_xt_iclass_rsr_excsave7_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_excsave7_args,
    1, Iclass_xt_iclass_wsr_excsave7_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_excsave7_args,
    1, Iclass_xt_iclass_xsr_excsave7_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_eps2_args,
    1, Iclass_xt_iclass_rsr_eps2_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_eps2_args,
    1, Iclass_xt_iclass_wsr_eps2_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_eps2_args,
    1, Iclass_xt_iclass_xsr_eps2_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_eps3_args,
    1, Iclass_xt_iclass_rsr_eps3_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_eps3_args,
    1, Iclass_xt_iclass_wsr_eps3_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_eps3_args,
    1, Iclass_xt_iclass_xsr_eps3_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_eps4_args,
    1, Iclass_xt_iclass_rsr_eps4_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_eps4_args,
    1, Iclass_xt_iclass_wsr_eps4_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_eps4_args,
    1, Iclass_xt_iclass_xsr_eps4_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_eps5_args,
    1, Iclass_xt_iclass_rsr_eps5_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_eps5_args,
    1, Iclass_xt_iclass_wsr_eps5_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_eps5_args,
    1, Iclass_xt_iclass_xsr_eps5_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_eps6_args,
    1, Iclass_xt_iclass_rsr_eps6_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_eps6_args,
    1, Iclass_xt_iclass_wsr_eps6_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_eps6_args,
    1, Iclass_xt_iclass_xsr_eps6_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_eps7_args,
    1, Iclass_xt_iclass_rsr_eps7_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_eps7_args,
    1, Iclass_xt_iclass_wsr_eps7_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_eps7_args,
    1, Iclass_xt_iclass_xsr_eps7_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_excvaddr_args,
    1, Iclass_xt_iclass_rsr_excvaddr_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_excvaddr_args,
    1, Iclass_xt_iclass_wsr_excvaddr_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_excvaddr_args,
    1, Iclass_xt_iclass_xsr_excvaddr_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_depc_args,
    1, Iclass_xt_iclass_rsr_depc_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_depc_args,
    1, Iclass_xt_iclass_wsr_depc_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_depc_args,
    1, Iclass_xt_iclass_xsr_depc_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_exccause_args,
    2, Iclass_xt_iclass_rsr_exccause_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_exccause_args,
    1, Iclass_xt_iclass_wsr_exccause_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_exccause_args,
    1, Iclass_xt_iclass_xsr_exccause_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_prid_args,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_vecbase_args,
    1, Iclass_xt_iclass_rsr_vecbase_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_vecbase_args,
    1, Iclass_xt_iclass_wsr_vecbase_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_vecbase_args,
    1, Iclass_xt_iclass_xsr_vecbase_stateArgs, 0, 0 },
  { 3, Iclass_xt_mul16_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_mul32_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_mul32h_args,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_rfi_args,
    20, Iclass_xt_iclass_rfi_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wait_args,
    1, Iclass_xt_iclass_wait_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_interrupt_args,
    1, Iclass_xt_iclass_rsr_interrupt_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_intset_args,
    2, Iclass_xt_iclass_wsr_intset_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_intclear_args,
    2, Iclass_xt_iclass_wsr_intclear_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_intenable_args,
    1, Iclass_xt_iclass_rsr_intenable_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_intenable_args,
    1, Iclass_xt_iclass_wsr_intenable_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_intenable_args,
    1, Iclass_xt_iclass_xsr_intenable_stateArgs, 0, 0 },
  { 2, Iclass_xt_iclass_break_args,
    2, Iclass_xt_iclass_break_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_break_n_args,
    2, Iclass_xt_iclass_break_n_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_dbreaka0_args,
    1, Iclass_xt_iclass_rsr_dbreaka0_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_dbreaka0_args,
    2, Iclass_xt_iclass_wsr_dbreaka0_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_dbreaka0_args,
    2, Iclass_xt_iclass_xsr_dbreaka0_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_dbreakc0_args,
    1, Iclass_xt_iclass_rsr_dbreakc0_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_dbreakc0_args,
    2, Iclass_xt_iclass_wsr_dbreakc0_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_dbreakc0_args,
    2, Iclass_xt_iclass_xsr_dbreakc0_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_dbreaka1_args,
    1, Iclass_xt_iclass_rsr_dbreaka1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_dbreaka1_args,
    2, Iclass_xt_iclass_wsr_dbreaka1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_dbreaka1_args,
    2, Iclass_xt_iclass_xsr_dbreaka1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_dbreakc1_args,
    1, Iclass_xt_iclass_rsr_dbreakc1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_dbreakc1_args,
    2, Iclass_xt_iclass_wsr_dbreakc1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_dbreakc1_args,
    2, Iclass_xt_iclass_xsr_dbreakc1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_ibreaka0_args,
    1, Iclass_xt_iclass_rsr_ibreaka0_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_ibreaka0_args,
    1, Iclass_xt_iclass_wsr_ibreaka0_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_ibreaka0_args,
    1, Iclass_xt_iclass_xsr_ibreaka0_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_ibreaka1_args,
    1, Iclass_xt_iclass_rsr_ibreaka1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_ibreaka1_args,
    1, Iclass_xt_iclass_wsr_ibreaka1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_ibreaka1_args,
    1, Iclass_xt_iclass_xsr_ibreaka1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_ibreakenable_args,
    1, Iclass_xt_iclass_rsr_ibreakenable_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_ibreakenable_args,
    1, Iclass_xt_iclass_wsr_ibreakenable_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_ibreakenable_args,
    1, Iclass_xt_iclass_xsr_ibreakenable_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_debugcause_args,
    2, Iclass_xt_iclass_rsr_debugcause_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_debugcause_args,
    2, Iclass_xt_iclass_wsr_debugcause_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_debugcause_args,
    2, Iclass_xt_iclass_xsr_debugcause_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_icount_args,
    1, Iclass_xt_iclass_rsr_icount_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_icount_args,
    2, Iclass_xt_iclass_wsr_icount_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_icount_args,
    2, Iclass_xt_iclass_xsr_icount_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_icountlevel_args,
    1, Iclass_xt_iclass_rsr_icountlevel_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_icountlevel_args,
    1, Iclass_xt_iclass_wsr_icountlevel_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_icountlevel_args,
    1, Iclass_xt_iclass_xsr_icountlevel_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_ddr_args,
    1, Iclass_xt_iclass_rsr_ddr_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_ddr_args,
    2, Iclass_xt_iclass_wsr_ddr_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_ddr_args,
    2, Iclass_xt_iclass_xsr_ddr_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_lddr32_p_args,
    3, Iclass_xt_iclass_lddr32_p_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_sddr32_p_args,
    2, Iclass_xt_iclass_sddr32_p_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rfdo_args,
    9, Iclass_xt_iclass_rfdo_stateArgs, 0, 0 },
  { 0, 0 /* xt_iclass_rfdd */,
    1, Iclass_xt_iclass_rfdd_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_mmid_args,
    1, Iclass_xt_iclass_wsr_mmid_stateArgs, 0, 0 },
  { 3, Iclass_xt_iclass_bbool1_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_bbool4_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_bbool8_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_bbranch_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_bmove_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_RSR_BR_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_WSR_BR_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_XSR_BR_args,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_ccount_args,
    1, Iclass_xt_iclass_rsr_ccount_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_ccount_args,
    2, Iclass_xt_iclass_wsr_ccount_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_ccount_args,
    2, Iclass_xt_iclass_xsr_ccount_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_ccompare0_args,
    1, Iclass_xt_iclass_rsr_ccompare0_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_ccompare0_args,
    2, Iclass_xt_iclass_wsr_ccompare0_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_ccompare0_args,
    2, Iclass_xt_iclass_xsr_ccompare0_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_ccompare1_args,
    1, Iclass_xt_iclass_rsr_ccompare1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_ccompare1_args,
    2, Iclass_xt_iclass_wsr_ccompare1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_ccompare1_args,
    2, Iclass_xt_iclass_xsr_ccompare1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_ccompare2_args,
    1, Iclass_xt_iclass_rsr_ccompare2_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_ccompare2_args,
    2, Iclass_xt_iclass_wsr_ccompare2_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_ccompare2_args,
    2, Iclass_xt_iclass_xsr_ccompare2_stateArgs, 0, 0 },
  { 2, Iclass_xt_iclass_icache_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_icache_lock_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_icache_inv_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_licx_args,
    2, Iclass_xt_iclass_licx_stateArgs, 0, 0 },
  { 2, Iclass_xt_iclass_sicx_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_dcache_args,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_dcache_dyn_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_dcache_ind_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_dcache_inv_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_dpf_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_dcache_lock_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_sdct_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_ldct_args,
    2, Iclass_xt_iclass_ldct_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_prefctl_args,
    1, Iclass_xt_iclass_rsr_prefctl_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_prefctl_args,
    1, Iclass_xt_iclass_wsr_prefctl_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_prefctl_args,
    1, Iclass_xt_iclass_xsr_prefctl_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_idtlb_args,
    1, Iclass_xt_iclass_idtlb_stateArgs, 0, 0 },
  { 2, Iclass_xt_iclass_rdtlb_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_wdtlb_args,
    1, Iclass_xt_iclass_wdtlb_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_iitlb_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_ritlb_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_witlb_args,
    0, 0, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_cpenable_args,
    1, Iclass_xt_iclass_rsr_cpenable_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_cpenable_args,
    1, Iclass_xt_iclass_wsr_cpenable_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_cpenable_args,
    1, Iclass_xt_iclass_xsr_cpenable_stateArgs, 0, 0 },
  { 3, Iclass_xt_iclass_clamp_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_minmax_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_nsa_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_sx_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_l32ai_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_s32ri_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_s32c1i_args,
    3, Iclass_xt_iclass_s32c1i_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_scompare1_args,
    1, Iclass_xt_iclass_rsr_scompare1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_scompare1_args,
    1, Iclass_xt_iclass_wsr_scompare1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_scompare1_args,
    1, Iclass_xt_iclass_xsr_scompare1_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_rsr_atomctl_args,
    1, Iclass_xt_iclass_rsr_atomctl_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_wsr_atomctl_args,
    2, Iclass_xt_iclass_wsr_atomctl_stateArgs, 0, 0 },
  { 1, Iclass_xt_iclass_xsr_atomctl_args,
    2, Iclass_xt_iclass_xsr_atomctl_stateArgs, 0, 0 },
  { 3, Iclass_xt_iclass_div_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_rer_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_wer_args,
    0, 0, 0, 0 },
  { 2, Iclass_xt_iclass_wb18_0_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_wb18_1_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_wb18_2_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_wb18_3_args,
    0, 0, 0, 0 },
  { 3, Iclass_xt_iclass_wb18_4_args,
    0, 0, 0, 0 },
  { 1, Iclass_rur_ae_ovf_sar_args,
    3, Iclass_rur_ae_ovf_sar_stateArgs, 0, 0 },
  { 1, Iclass_wur_ae_ovf_sar_args,
    3, Iclass_wur_ae_ovf_sar_stateArgs, 0, 0 },
  { 1, Iclass_rur_ae_bithead_args,
    2, Iclass_rur_ae_bithead_stateArgs, 0, 0 },
  { 1, Iclass_wur_ae_bithead_args,
    2, Iclass_wur_ae_bithead_stateArgs, 0, 0 },
  { 1, Iclass_rur_ae_ts_fts_bu_bp_args,
    5, Iclass_rur_ae_ts_fts_bu_bp_stateArgs, 0, 0 },
  { 1, Iclass_wur_ae_ts_fts_bu_bp_args,
    5, Iclass_wur_ae_ts_fts_bu_bp_stateArgs, 0, 0 },
  { 1, Iclass_rur_ae_cw_sd_no_args,
    4, Iclass_rur_ae_cw_sd_no_stateArgs, 0, 0 },
  { 1, Iclass_wur_ae_cw_sd_no_args,
    4, Iclass_wur_ae_cw_sd_no_stateArgs, 0, 0 },
  { 1, Iclass_rur_ae_cbegin0_args,
    2, Iclass_rur_ae_cbegin0_stateArgs, 0, 0 },
  { 1, Iclass_wur_ae_cbegin0_args,
    2, Iclass_wur_ae_cbegin0_stateArgs, 0, 0 },
  { 1, Iclass_rur_ae_cend0_args,
    2, Iclass_rur_ae_cend0_stateArgs, 0, 0 },
  { 1, Iclass_wur_ae_cend0_args,
    2, Iclass_wur_ae_cend0_stateArgs, 0, 0 },
  { 1, Iclass_rur_fcr_args,
    9, Iclass_rur_fcr_stateArgs, 0, 0 },
  { 1, Iclass_wur_fcr_args,
    9, Iclass_wur_fcr_stateArgs, 0, 0 },
  { 1, Iclass_rur_fsr_args,
    8, Iclass_rur_fsr_stateArgs, 0, 0 },
  { 1, Iclass_wur_fsr_args,
    8, Iclass_wur_fsr_stateArgs, 0, 0 },
  { 1, Iclass_RUR_AE_OVERFLOW_args,
    2, Iclass_RUR_AE_OVERFLOW_stateArgs, 0, 0 },
  { 1, Iclass_WUR_AE_OVERFLOW_args,
    2, Iclass_WUR_AE_OVERFLOW_stateArgs, 0, 0 },
  { 1, Iclass_RUR_AE_SAR_args,
    2, Iclass_RUR_AE_SAR_stateArgs, 0, 0 },
  { 1, Iclass_WUR_AE_SAR_args,
    2, Iclass_WUR_AE_SAR_stateArgs, 0, 0 },
  { 1, Iclass_RUR_AE_BITPTR_args,
    2, Iclass_RUR_AE_BITPTR_stateArgs, 0, 0 },
  { 1, Iclass_WUR_AE_BITPTR_args,
    2, Iclass_WUR_AE_BITPTR_stateArgs, 0, 0 },
  { 1, Iclass_RUR_AE_BITSUSED_args,
    2, Iclass_RUR_AE_BITSUSED_stateArgs, 0, 0 },
  { 1, Iclass_WUR_AE_BITSUSED_args,
    2, Iclass_WUR_AE_BITSUSED_stateArgs, 0, 0 },
  { 1, Iclass_RUR_AE_TABLESIZE_args,
    2, Iclass_RUR_AE_TABLESIZE_stateArgs, 0, 0 },
  { 1, Iclass_WUR_AE_TABLESIZE_args,
    2, Iclass_WUR_AE_TABLESIZE_stateArgs, 0, 0 },
  { 1, Iclass_RUR_AE_FIRST_TS_args,
    2, Iclass_RUR_AE_FIRST_TS_stateArgs, 0, 0 },
  { 1, Iclass_WUR_AE_FIRST_TS_args,
    2, Iclass_WUR_AE_FIRST_TS_stateArgs, 0, 0 },
  { 1, Iclass_RUR_AE_NEXTOFFSET_args,
    2, Iclass_RUR_AE_NEXTOFFSET_stateArgs, 0, 0 },
  { 1, Iclass_WUR_AE_NEXTOFFSET_args,
    2, Iclass_WUR_AE_NEXTOFFSET_stateArgs, 0, 0 },
  { 1, Iclass_RUR_AE_SEARCHDONE_args,
    2, Iclass_RUR_AE_SEARCHDONE_stateArgs, 0, 0 },
  { 1, Iclass_WUR_AE_SEARCHDONE_args,
    2, Iclass_WUR_AE_SEARCHDONE_stateArgs, 0, 0 },
  { 1, Iclass_RUR_AE_CWRAP_args,
    2, Iclass_RUR_AE_CWRAP_stateArgs, 0, 0 },
  { 1, Iclass_WUR_AE_CWRAP_args,
    2, Iclass_WUR_AE_CWRAP_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16M_XC_args,
    3, Iclass_AE_L16M_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16M_I_args,
    1, Iclass_AE_L16M_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16M_IU_args,
    1, Iclass_AE_L16M_IU_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16M_X_args,
    1, Iclass_AE_L16M_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16M_XU_args,
    1, Iclass_AE_L16M_XU_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16_XC_args,
    3, Iclass_AE_L16_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16_I_args,
    1, Iclass_AE_L16_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16_IP_args,
    1, Iclass_AE_L16_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16_X_args,
    1, Iclass_AE_L16_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16_XP_args,
    1, Iclass_AE_L16_XP_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32F24_XC_args,
    3, Iclass_AE_L32F24_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32F24_I_args,
    1, Iclass_AE_L32F24_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32F24_IP_args,
    1, Iclass_AE_L32F24_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32F24_X_args,
    1, Iclass_AE_L32F24_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32F24_XP_args,
    1, Iclass_AE_L32F24_XP_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32_XC_args,
    3, Iclass_AE_L32_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32_I_args,
    1, Iclass_AE_L32_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32_IP_args,
    1, Iclass_AE_L32_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32_X_args,
    1, Iclass_AE_L32_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32_XP_args,
    1, Iclass_AE_L32_XP_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32M_XC_args,
    3, Iclass_AE_L32M_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32M_I_args,
    1, Iclass_AE_L32M_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32M_IU_args,
    1, Iclass_AE_L32M_IU_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32M_X_args,
    1, Iclass_AE_L32M_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32M_XU_args,
    1, Iclass_AE_L32M_XU_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16X2M_XC_args,
    3, Iclass_AE_L16X2M_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16X2M_I_args,
    1, Iclass_AE_L16X2M_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16X2M_IU_args,
    1, Iclass_AE_L16X2M_IU_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16X2M_X_args,
    1, Iclass_AE_L16X2M_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16X2M_XU_args,
    1, Iclass_AE_L16X2M_XU_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32X2F24_XC_args,
    3, Iclass_AE_L32X2F24_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32X2F24_I_args,
    1, Iclass_AE_L32X2F24_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32X2F24_IP_args,
    1, Iclass_AE_L32X2F24_IP_stateArgs, 0, 0 },
  { 2, Iclass_AE_L32X2F24_RIP_args,
    1, Iclass_AE_L32X2F24_RIP_stateArgs, 0, 0 },
  { 2, Iclass_AE_L32X2F24_RIC_args,
    3, Iclass_AE_L32X2F24_RIC_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32X2F24_X_args,
    1, Iclass_AE_L32X2F24_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32X2F24_XP_args,
    1, Iclass_AE_L32X2F24_XP_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32X2_XC_args,
    3, Iclass_AE_L32X2_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32X2_I_args,
    1, Iclass_AE_L32X2_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32X2_IP_args,
    1, Iclass_AE_L32X2_IP_stateArgs, 0, 0 },
  { 2, Iclass_AE_L32X2_RIP_args,
    1, Iclass_AE_L32X2_RIP_stateArgs, 0, 0 },
  { 2, Iclass_AE_L32X2_RIC_args,
    3, Iclass_AE_L32X2_RIC_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32X2_X_args,
    1, Iclass_AE_L32X2_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_L32X2_XP_args,
    1, Iclass_AE_L32X2_XP_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16X4_XC_args,
    3, Iclass_AE_L16X4_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16X4_I_args,
    1, Iclass_AE_L16X4_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16X4_IP_args,
    1, Iclass_AE_L16X4_IP_stateArgs, 0, 0 },
  { 2, Iclass_AE_L16X4_RIP_args,
    1, Iclass_AE_L16X4_RIP_stateArgs, 0, 0 },
  { 2, Iclass_AE_L16X4_RIC_args,
    3, Iclass_AE_L16X4_RIC_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16X4_X_args,
    1, Iclass_AE_L16X4_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_L16X4_XP_args,
    1, Iclass_AE_L16X4_XP_stateArgs, 0, 0 },
  { 3, Iclass_AE_L64_XC_args,
    3, Iclass_AE_L64_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_L64_I_args,
    1, Iclass_AE_L64_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_L64_IP_args,
    1, Iclass_AE_L64_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_L64_X_args,
    1, Iclass_AE_L64_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_L64_XP_args,
    1, Iclass_AE_L64_XP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16X2M_XC_args,
    3, Iclass_AE_S16X2M_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16X2M_I_args,
    1, Iclass_AE_S16X2M_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16X2M_IU_args,
    1, Iclass_AE_S16X2M_IU_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16X2M_X_args,
    1, Iclass_AE_S16X2M_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16X2M_XU_args,
    1, Iclass_AE_S16X2M_XU_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32X2F24_XC_args,
    3, Iclass_AE_S32X2F24_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32X2F24_I_args,
    1, Iclass_AE_S32X2F24_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32X2F24_IP_args,
    1, Iclass_AE_S32X2F24_IP_stateArgs, 0, 0 },
  { 2, Iclass_AE_S32X2F24_RIP_args,
    1, Iclass_AE_S32X2F24_RIP_stateArgs, 0, 0 },
  { 2, Iclass_AE_S32X2F24_RIC_args,
    3, Iclass_AE_S32X2F24_RIC_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32X2F24_X_args,
    1, Iclass_AE_S32X2F24_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32X2F24_XP_args,
    1, Iclass_AE_S32X2F24_XP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32X2_XC_args,
    3, Iclass_AE_S32X2_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32X2_I_args,
    1, Iclass_AE_S32X2_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32X2_IP_args,
    1, Iclass_AE_S32X2_IP_stateArgs, 0, 0 },
  { 2, Iclass_AE_S32X2_RIP_args,
    1, Iclass_AE_S32X2_RIP_stateArgs, 0, 0 },
  { 2, Iclass_AE_S32X2_RIC_args,
    3, Iclass_AE_S32X2_RIC_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32X2_X_args,
    1, Iclass_AE_S32X2_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32X2_XP_args,
    1, Iclass_AE_S32X2_XP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16X4_XC_args,
    3, Iclass_AE_S16X4_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16X4_I_args,
    1, Iclass_AE_S16X4_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16X4_IP_args,
    1, Iclass_AE_S16X4_IP_stateArgs, 0, 0 },
  { 2, Iclass_AE_S16X4_RIP_args,
    1, Iclass_AE_S16X4_RIP_stateArgs, 0, 0 },
  { 2, Iclass_AE_S16X4_RIC_args,
    3, Iclass_AE_S16X4_RIC_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16X4_X_args,
    1, Iclass_AE_S16X4_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16X4_XP_args,
    1, Iclass_AE_S16X4_XP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16M_L_XC_args,
    3, Iclass_AE_S16M_L_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16M_L_I_args,
    1, Iclass_AE_S16M_L_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16M_L_IU_args,
    1, Iclass_AE_S16M_L_IU_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16M_L_X_args,
    1, Iclass_AE_S16M_L_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16M_L_XU_args,
    1, Iclass_AE_S16M_L_XU_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32F24_L_XC_args,
    3, Iclass_AE_S32F24_L_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32F24_L_I_args,
    1, Iclass_AE_S32F24_L_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32F24_L_IP_args,
    1, Iclass_AE_S32F24_L_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32F24_L_X_args,
    1, Iclass_AE_S32F24_L_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32F24_L_XP_args,
    1, Iclass_AE_S32F24_L_XP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32_L_XC_args,
    3, Iclass_AE_S32_L_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32_L_I_args,
    1, Iclass_AE_S32_L_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32_L_IP_args,
    1, Iclass_AE_S32_L_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32_L_X_args,
    1, Iclass_AE_S32_L_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32_L_XP_args,
    1, Iclass_AE_S32_L_XP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16_0_XC_args,
    3, Iclass_AE_S16_0_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16_0_I_args,
    1, Iclass_AE_S16_0_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16_0_IP_args,
    1, Iclass_AE_S16_0_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16_0_X_args,
    1, Iclass_AE_S16_0_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_S16_0_XP_args,
    1, Iclass_AE_S16_0_XP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S64_XC_args,
    3, Iclass_AE_S64_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_S64_I_args,
    1, Iclass_AE_S64_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_S64_IP_args,
    1, Iclass_AE_S64_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S64_X_args,
    1, Iclass_AE_S64_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_S64_XP_args,
    1, Iclass_AE_S64_XP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32M_XC_args,
    3, Iclass_AE_S32M_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32M_I_args,
    1, Iclass_AE_S32M_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32M_IU_args,
    1, Iclass_AE_S32M_IU_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32M_X_args,
    1, Iclass_AE_S32M_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32M_XU_args,
    1, Iclass_AE_S32M_XU_stateArgs, 0, 0 },
  { 1, Iclass_AE_ZALIGN64_args,
    1, Iclass_AE_ZALIGN64_stateArgs, 0, 0 },
  { 3, Iclass_AE_LALIGN64_I_args,
    1, Iclass_AE_LALIGN64_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_SALIGN64_I_args,
    1, Iclass_AE_SALIGN64_I_stateArgs, 0, 0 },
  { 2, Iclass_AE_MOVALIGN_args,
    1, Iclass_AE_MOVALIGN_stateArgs, 0, 0 },
  { 2, Iclass_AE_LA64_PP_args,
    1, Iclass_AE_LA64_PP_stateArgs, 0, 0 },
  { 2, Iclass_AE_LA24POS_PC_args,
    3, Iclass_AE_LA24POS_PC_stateArgs, 0, 0 },
  { 2, Iclass_AE_LA24X2POS_PC_args,
    3, Iclass_AE_LA24X2POS_PC_stateArgs, 0, 0 },
  { 2, Iclass_AE_LA32X2POS_PC_args,
    3, Iclass_AE_LA32X2POS_PC_stateArgs, 0, 0 },
  { 2, Iclass_AE_LA16X4POS_PC_args,
    3, Iclass_AE_LA16X4POS_PC_stateArgs, 0, 0 },
  { 2, Iclass_AE_LA24NEG_PC_args,
    3, Iclass_AE_LA24NEG_PC_stateArgs, 0, 0 },
  { 2, Iclass_AE_LA24X2NEG_PC_args,
    3, Iclass_AE_LA24X2NEG_PC_stateArgs, 0, 0 },
  { 2, Iclass_AE_LA32X2NEG_PC_args,
    3, Iclass_AE_LA32X2NEG_PC_stateArgs, 0, 0 },
  { 2, Iclass_AE_LA16X4NEG_PC_args,
    3, Iclass_AE_LA16X4NEG_PC_stateArgs, 0, 0 },
  { 2, Iclass_AE_SA64POS_FP_args,
    1, Iclass_AE_SA64POS_FP_stateArgs, 0, 0 },
  { 2, Iclass_AE_SA64NEG_FP_args,
    1, Iclass_AE_SA64NEG_FP_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA32X2_IC_args,
    3, Iclass_AE_LA32X2_IC_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA32X2_IP_args,
    1, Iclass_AE_LA32X2_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA32X2_RIP_args,
    1, Iclass_AE_LA32X2_RIP_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA32X2_RIC_args,
    3, Iclass_AE_LA32X2_RIC_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA16X4_IC_args,
    3, Iclass_AE_LA16X4_IC_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA16X4_IP_args,
    1, Iclass_AE_LA16X4_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA16X4_RIP_args,
    1, Iclass_AE_LA16X4_RIP_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA16X4_RIC_args,
    3, Iclass_AE_LA16X4_RIC_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA32X2F24_IC_args,
    3, Iclass_AE_LA32X2F24_IC_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA32X2F24_IP_args,
    1, Iclass_AE_LA32X2F24_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA32X2F24_RIP_args,
    1, Iclass_AE_LA32X2F24_RIP_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA32X2F24_RIC_args,
    3, Iclass_AE_LA32X2F24_RIC_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA24_IC_args,
    3, Iclass_AE_LA24_IC_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA24_IP_args,
    1, Iclass_AE_LA24_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA24_RIP_args,
    1, Iclass_AE_LA24_RIP_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA24_RIC_args,
    3, Iclass_AE_LA24_RIC_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA24X2_IC_args,
    3, Iclass_AE_LA24X2_IC_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA24X2_IP_args,
    1, Iclass_AE_LA24X2_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA24X2_RIP_args,
    1, Iclass_AE_LA24X2_RIP_stateArgs, 0, 0 },
  { 3, Iclass_AE_LA24X2_RIC_args,
    3, Iclass_AE_LA24X2_RIC_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA32X2_IC_args,
    3, Iclass_AE_SA32X2_IC_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA32X2_IP_args,
    1, Iclass_AE_SA32X2_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA32X2_RIP_args,
    1, Iclass_AE_SA32X2_RIP_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA32X2_RIC_args,
    3, Iclass_AE_SA32X2_RIC_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA16X4_IC_args,
    3, Iclass_AE_SA16X4_IC_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA16X4_IP_args,
    1, Iclass_AE_SA16X4_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA16X4_RIP_args,
    1, Iclass_AE_SA16X4_RIP_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA16X4_RIC_args,
    3, Iclass_AE_SA16X4_RIC_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA32X2F24_IC_args,
    3, Iclass_AE_SA32X2F24_IC_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA32X2F24_IP_args,
    1, Iclass_AE_SA32X2F24_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA32X2F24_RIP_args,
    1, Iclass_AE_SA32X2F24_RIP_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA32X2F24_RIC_args,
    3, Iclass_AE_SA32X2F24_RIC_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA24_L_IC_args,
    3, Iclass_AE_SA24_L_IC_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA24_L_IP_args,
    1, Iclass_AE_SA24_L_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA24_L_RIP_args,
    1, Iclass_AE_SA24_L_RIP_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA24_L_RIC_args,
    3, Iclass_AE_SA24_L_RIC_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA24X2_IC_args,
    3, Iclass_AE_SA24X2_IC_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA24X2_IP_args,
    1, Iclass_AE_SA24X2_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA24X2_RIP_args,
    1, Iclass_AE_SA24X2_RIP_stateArgs, 0, 0 },
  { 3, Iclass_AE_SA24X2_RIC_args,
    3, Iclass_AE_SA24X2_RIC_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32RA64S_I_args,
    2, Iclass_AE_S32RA64S_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32RA64S_IP_args,
    2, Iclass_AE_S32RA64S_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32RA64S_X_args,
    2, Iclass_AE_S32RA64S_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32RA64S_XP_args,
    2, Iclass_AE_S32RA64S_XP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32RA64S_XC_args,
    4, Iclass_AE_S32RA64S_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_S24RA64S_I_args,
    2, Iclass_AE_S24RA64S_I_stateArgs, 0, 0 },
  { 3, Iclass_AE_S24RA64S_IP_args,
    2, Iclass_AE_S24RA64S_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S24RA64S_X_args,
    2, Iclass_AE_S24RA64S_X_stateArgs, 0, 0 },
  { 3, Iclass_AE_S24RA64S_XP_args,
    2, Iclass_AE_S24RA64S_XP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S24RA64S_XC_args,
    4, Iclass_AE_S24RA64S_XC_stateArgs, 0, 0 },
  { 3, Iclass_AE_S32X2RA64S_IP_args,
    2, Iclass_AE_S32X2RA64S_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_S24X2RA64S_IP_args,
    2, Iclass_AE_S24X2RA64S_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_ADDBRBA32_args,
    0, 0, 0, 0 },
  { 4, Iclass_AE_SEL16I_args,
    1, Iclass_AE_SEL16I_stateArgs, 0, 0 },
  { 4, Iclass_AE_SEL16I_N_args,
    1, Iclass_AE_SEL16I_N_stateArgs, 0, 0 },
  { 2, Iclass_AE_SHORTSWAP_args,
    1, Iclass_AE_SHORTSWAP_stateArgs, 0, 0 },
  { 3, Iclass_AE_MOVT16X4_args,
    1, Iclass_AE_MOVT16X4_stateArgs, 0, 0 },
  { 3, Iclass_AE_MOVF16X4_args,
    1, Iclass_AE_MOVF16X4_stateArgs, 0, 0 },
  { 3, Iclass_AE_MOVT32X2_args,
    1, Iclass_AE_MOVT32X2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MOVF32X2_args,
    1, Iclass_AE_MOVF32X2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MOVDA32X2_args,
    1, Iclass_AE_MOVDA32X2_stateArgs, 0, 0 },
  { 2, Iclass_AE_MOVDA32_args,
    1, Iclass_AE_MOVDA32_stateArgs, 0, 0 },
  { 3, Iclass_AE_MOVDA16X2_args,
    1, Iclass_AE_MOVDA16X2_stateArgs, 0, 0 },
  { 2, Iclass_AE_MOVDA16_args,
    1, Iclass_AE_MOVDA16_stateArgs, 0, 0 },
  { 2, Iclass_AE_MOVI_args,
    1, Iclass_AE_MOVI_stateArgs, 0, 0 },
  { 3, Iclass_AE_TRUNCP24A32X2_args,
    1, Iclass_AE_TRUNCP24A32X2_stateArgs, 0, 0 },
  { 3, Iclass_AE_SAT16X4_args,
    2, Iclass_AE_SAT16X4_stateArgs, 0, 0 },
  { 2, Iclass_AE_CVT32X2F16_32_args,
    1, Iclass_AE_CVT32X2F16_32_stateArgs, 0, 0 },
  { 2, Iclass_AE_CVT32X2F16_10_args,
    1, Iclass_AE_CVT32X2F16_10_stateArgs, 0, 0 },
  { 2, Iclass_AE_SEXT32X2D16_32_args,
    1, Iclass_AE_SEXT32X2D16_32_stateArgs, 0, 0 },
  { 2, Iclass_AE_SEXT32X2D16_10_args,
    1, Iclass_AE_SEXT32X2D16_10_stateArgs, 0, 0 },
  { 2, Iclass_AE_CVTA32F24S_L_args,
    1, Iclass_AE_CVTA32F24S_L_stateArgs, 0, 0 },
  { 2, Iclass_AE_CVTA32F24S_H_args,
    1, Iclass_AE_CVTA32F24S_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_CVTP24A16X2_LL_args,
    1, Iclass_AE_CVTP24A16X2_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_CVTP24A16X2_LH_args,
    1, Iclass_AE_CVTP24A16X2_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_CVTP24A16X2_HL_args,
    1, Iclass_AE_CVTP24A16X2_HL_stateArgs, 0, 0 },
  { 3, Iclass_AE_CVTP24A16X2_HH_args,
    1, Iclass_AE_CVTP24A16X2_HH_stateArgs, 0, 0 },
  { 3, Iclass_AE_TRUNCP24Q48X2_args,
    1, Iclass_AE_TRUNCP24Q48X2_stateArgs, 0, 0 },
  { 4, Iclass_AE_TRUNCA32X2F64S_args,
    2, Iclass_AE_TRUNCA32X2F64S_stateArgs, 0, 0 },
  { 4, Iclass_AE_TRUNCI32X2F64S_args,
    2, Iclass_AE_TRUNCI32X2F64S_stateArgs, 0, 0 },
  { 4, Iclass_AE_TRUNCA32F64S_L_args,
    2, Iclass_AE_TRUNCA32F64S_L_stateArgs, 0, 0 },
  { 4, Iclass_AE_TRUNCI32F64S_L_args,
    2, Iclass_AE_TRUNCI32F64S_L_stateArgs, 0, 0 },
  { 2, Iclass_AE_TRUNCP16_args,
    1, Iclass_AE_TRUNCP16_stateArgs, 0, 0 },
  { 3, Iclass_AE_ROUND32X2F64SSYM_args,
    2, Iclass_AE_ROUND32X2F64SSYM_stateArgs, 0, 0 },
  { 3, Iclass_AE_ROUND32X2F64SASYM_args,
    2, Iclass_AE_ROUND32X2F64SASYM_stateArgs, 0, 0 },
  { 3, Iclass_AE_ROUND32X2F48SSYM_args,
    2, Iclass_AE_ROUND32X2F48SSYM_stateArgs, 0, 0 },
  { 3, Iclass_AE_ROUND32X2F48SASYM_args,
    2, Iclass_AE_ROUND32X2F48SASYM_stateArgs, 0, 0 },
  { 3, Iclass_AE_ROUND16X4F32SSYM_args,
    2, Iclass_AE_ROUND16X4F32SSYM_stateArgs, 0, 0 },
  { 3, Iclass_AE_ROUND16X4F32SASYM_args,
    2, Iclass_AE_ROUND16X4F32SASYM_stateArgs, 0, 0 },
  { 3, Iclass_AE_ROUND24X2F48SSYM_args,
    2, Iclass_AE_ROUND24X2F48SSYM_stateArgs, 0, 0 },
  { 3, Iclass_AE_ROUND24X2F48SASYM_args,
    2, Iclass_AE_ROUND24X2F48SASYM_stateArgs, 0, 0 },
  { 3, Iclass_AE_ROUNDSP16Q48X2SYM_args,
    2, Iclass_AE_ROUNDSP16Q48X2SYM_stateArgs, 0, 0 },
  { 3, Iclass_AE_ROUNDSP16Q48X2ASYM_args,
    2, Iclass_AE_ROUNDSP16Q48X2ASYM_stateArgs, 0, 0 },
  { 3, Iclass_AE_MINABS32S_args,
    2, Iclass_AE_MINABS32S_stateArgs, 0, 0 },
  { 3, Iclass_AE_MAXABS32S_args,
    2, Iclass_AE_MAXABS32S_stateArgs, 0, 0 },
  { 2, Iclass_AE_ROUNDSP16F24SYM_args,
    2, Iclass_AE_ROUNDSP16F24SYM_stateArgs, 0, 0 },
  { 2, Iclass_AE_ROUNDSP16F24ASYM_args,
    2, Iclass_AE_ROUNDSP16F24ASYM_stateArgs, 0, 0 },
  { 2, Iclass_AE_MOV_args,
    1, Iclass_AE_MOV_stateArgs, 0, 0 },
  { 3, Iclass_AE_MOVT64_args,
    1, Iclass_AE_MOVT64_stateArgs, 0, 0 },
  { 3, Iclass_AE_MOVF64_args,
    1, Iclass_AE_MOVF64_stateArgs, 0, 0 },
  { 2, Iclass_AE_CVTQ56A32S_args,
    1, Iclass_AE_CVTQ56A32S_stateArgs, 0, 0 },
  { 2, Iclass_AE_CVT48A32_args,
    1, Iclass_AE_CVT48A32_stateArgs, 0, 0 },
  { 2, Iclass_AE_CVT64A32_args,
    1, Iclass_AE_CVT64A32_stateArgs, 0, 0 },
  { 2, Iclass_AE_CVTQ56P32S_L_args,
    1, Iclass_AE_CVTQ56P32S_L_stateArgs, 0, 0 },
  { 2, Iclass_AE_CVTQ56P32S_H_args,
    1, Iclass_AE_CVTQ56P32S_H_stateArgs, 0, 0 },
  { 2, Iclass_AE_CVT64F32_H_args,
    1, Iclass_AE_CVT64F32_H_stateArgs, 0, 0 },
  { 2, Iclass_AE_SAT48S_args,
    2, Iclass_AE_SAT48S_stateArgs, 0, 0 },
  { 2, Iclass_AE_SATQ56S_args,
    2, Iclass_AE_SATQ56S_stateArgs, 0, 0 },
  { 2, Iclass_AE_SAT24S_args,
    2, Iclass_AE_SAT24S_stateArgs, 0, 0 },
  { 2, Iclass_AE_TRUNCQ32_args,
    1, Iclass_AE_TRUNCQ32_stateArgs, 0, 0 },
  { 3, Iclass_AE_MINABS64S_args,
    2, Iclass_AE_MINABS64S_stateArgs, 0, 0 },
  { 3, Iclass_AE_MAXABS64S_args,
    2, Iclass_AE_MAXABS64S_stateArgs, 0, 0 },
  { 2, Iclass_AE_ROUNDSQ32F48SYM_args,
    2, Iclass_AE_ROUNDSQ32F48SYM_stateArgs, 0, 0 },
  { 2, Iclass_AE_ROUNDSQ32F48ASYM_args,
    2, Iclass_AE_ROUNDSQ32F48ASYM_stateArgs, 0, 0 },
  { 2, Iclass_AE_TRUNCA32Q48_args,
    1, Iclass_AE_TRUNCA32Q48_stateArgs, 0, 0 },
  { 2, Iclass_AE_MOVAD32_L_args,
    1, Iclass_AE_MOVAD32_L_stateArgs, 0, 0 },
  { 2, Iclass_AE_MOVAD32_H_args,
    1, Iclass_AE_MOVAD32_H_stateArgs, 0, 0 },
  { 2, Iclass_AE_MOVAD16_3_args,
    1, Iclass_AE_MOVAD16_3_stateArgs, 0, 0 },
  { 2, Iclass_AE_MOVAD16_2_args,
    1, Iclass_AE_MOVAD16_2_stateArgs, 0, 0 },
  { 2, Iclass_AE_MOVAD16_1_args,
    1, Iclass_AE_MOVAD16_1_stateArgs, 0, 0 },
  { 2, Iclass_AE_MOVAD16_0_args,
    1, Iclass_AE_MOVAD16_0_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRA64_32_args,
    1, Iclass_AE_SRA64_32_stateArgs, 0, 0 },
  { 3, Iclass_AE_PKSR32_args,
    2, Iclass_AE_PKSR32_stateArgs, 0, 0 },
  { 3, Iclass_AE_PKSR24_args,
    2, Iclass_AE_PKSR24_stateArgs, 0, 0 },
  { 2, Iclass_AE_TRUNCA16P24S_L_args,
    1, Iclass_AE_TRUNCA16P24S_L_stateArgs, 0, 0 },
  { 2, Iclass_AE_TRUNCA16P24S_H_args,
    1, Iclass_AE_TRUNCA16P24S_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_ADD32_args,
    1, Iclass_AE_ADD32_stateArgs, 0, 0 },
  { 3, Iclass_AE_SUB32_args,
    1, Iclass_AE_SUB32_stateArgs, 0, 0 },
  { 3, Iclass_AE_ADDSUB32_args,
    1, Iclass_AE_ADDSUB32_stateArgs, 0, 0 },
  { 3, Iclass_AE_SUBADD32_args,
    1, Iclass_AE_SUBADD32_stateArgs, 0, 0 },
  { 3, Iclass_AE_ADD16_args,
    1, Iclass_AE_ADD16_stateArgs, 0, 0 },
  { 3, Iclass_AE_SUB16_args,
    1, Iclass_AE_SUB16_stateArgs, 0, 0 },
  { 3, Iclass_AE_ADD32_HL_LH_args,
    1, Iclass_AE_ADD32_HL_LH_stateArgs, 0, 0 },
  { 2, Iclass_AE_NEG32_args,
    1, Iclass_AE_NEG32_stateArgs, 0, 0 },
  { 2, Iclass_AE_ABS32_args,
    1, Iclass_AE_ABS32_stateArgs, 0, 0 },
  { 3, Iclass_AE_ADD24S_args,
    2, Iclass_AE_ADD24S_stateArgs, 0, 0 },
  { 3, Iclass_AE_SUB24S_args,
    2, Iclass_AE_SUB24S_stateArgs, 0, 0 },
  { 3, Iclass_AE_ADD32S_args,
    2, Iclass_AE_ADD32S_stateArgs, 0, 0 },
  { 3, Iclass_AE_SUB32S_args,
    2, Iclass_AE_SUB32S_stateArgs, 0, 0 },
  { 3, Iclass_AE_ADDSUB32S_args,
    2, Iclass_AE_ADDSUB32S_stateArgs, 0, 0 },
  { 3, Iclass_AE_SUBADD32S_args,
    2, Iclass_AE_SUBADD32S_stateArgs, 0, 0 },
  { 3, Iclass_AE_ADD16S_args,
    2, Iclass_AE_ADD16S_stateArgs, 0, 0 },
  { 3, Iclass_AE_SUB16S_args,
    2, Iclass_AE_SUB16S_stateArgs, 0, 0 },
  { 2, Iclass_AE_NEG24S_args,
    2, Iclass_AE_NEG24S_stateArgs, 0, 0 },
  { 2, Iclass_AE_ABS24S_args,
    2, Iclass_AE_ABS24S_stateArgs, 0, 0 },
  { 2, Iclass_AE_NEG32S_args,
    1, Iclass_AE_NEG32S_stateArgs, 0, 0 },
  { 2, Iclass_AE_ABS32S_args,
    1, Iclass_AE_ABS32S_stateArgs, 0, 0 },
  { 2, Iclass_AE_NEG16S_args,
    1, Iclass_AE_NEG16S_stateArgs, 0, 0 },
  { 2, Iclass_AE_ABS16S_args,
    1, Iclass_AE_ABS16S_stateArgs, 0, 0 },
  { 3, Iclass_AE_LT16_args,
    1, Iclass_AE_LT16_stateArgs, 0, 0 },
  { 3, Iclass_AE_LE16_args,
    1, Iclass_AE_LE16_stateArgs, 0, 0 },
  { 3, Iclass_AE_EQ16_args,
    1, Iclass_AE_EQ16_stateArgs, 0, 0 },
  { 3, Iclass_AE_LT32_args,
    1, Iclass_AE_LT32_stateArgs, 0, 0 },
  { 3, Iclass_AE_LE32_args,
    1, Iclass_AE_LE32_stateArgs, 0, 0 },
  { 3, Iclass_AE_EQ32_args,
    1, Iclass_AE_EQ32_stateArgs, 0, 0 },
  { 3, Iclass_AE_MIN32_args,
    1, Iclass_AE_MIN32_stateArgs, 0, 0 },
  { 3, Iclass_AE_MAX32_args,
    1, Iclass_AE_MAX32_stateArgs, 0, 0 },
  { 3, Iclass_AE_ADD64_args,
    1, Iclass_AE_ADD64_stateArgs, 0, 0 },
  { 3, Iclass_AE_SUB64_args,
    1, Iclass_AE_SUB64_stateArgs, 0, 0 },
  { 2, Iclass_AE_NEG64_args,
    1, Iclass_AE_NEG64_stateArgs, 0, 0 },
  { 2, Iclass_AE_ABS64_args,
    1, Iclass_AE_ABS64_stateArgs, 0, 0 },
  { 3, Iclass_AE_ADDSQ56S_args,
    2, Iclass_AE_ADDSQ56S_stateArgs, 0, 0 },
  { 3, Iclass_AE_SUBSQ56S_args,
    2, Iclass_AE_SUBSQ56S_stateArgs, 0, 0 },
  { 3, Iclass_AE_ADD64S_args,
    2, Iclass_AE_ADD64S_stateArgs, 0, 0 },
  { 3, Iclass_AE_SUB64S_args,
    2, Iclass_AE_SUB64S_stateArgs, 0, 0 },
  { 2, Iclass_AE_NEGSQ56S_args,
    2, Iclass_AE_NEGSQ56S_stateArgs, 0, 0 },
  { 2, Iclass_AE_ABSSQ56S_args,
    2, Iclass_AE_ABSSQ56S_stateArgs, 0, 0 },
  { 2, Iclass_AE_NEG64S_args,
    2, Iclass_AE_NEG64S_stateArgs, 0, 0 },
  { 2, Iclass_AE_ABS64S_args,
    2, Iclass_AE_ABS64S_stateArgs, 0, 0 },
  { 3, Iclass_AE_AND_args,
    1, Iclass_AE_AND_stateArgs, 0, 0 },
  { 3, Iclass_AE_NAND_args,
    1, Iclass_AE_NAND_stateArgs, 0, 0 },
  { 3, Iclass_AE_OR_args,
    1, Iclass_AE_OR_stateArgs, 0, 0 },
  { 3, Iclass_AE_XOR_args,
    1, Iclass_AE_XOR_stateArgs, 0, 0 },
  { 3, Iclass_AE_SLAI24_args,
    1, Iclass_AE_SLAI24_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRLI24_args,
    1, Iclass_AE_SRLI24_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRAI24_args,
    1, Iclass_AE_SRAI24_stateArgs, 0, 0 },
  { 2, Iclass_AE_SLAS24_args,
    2, Iclass_AE_SLAS24_stateArgs, 0, 0 },
  { 2, Iclass_AE_SRLS24_args,
    2, Iclass_AE_SRLS24_stateArgs, 0, 0 },
  { 2, Iclass_AE_SRAS24_args,
    2, Iclass_AE_SRAS24_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRAI16_args,
    1, Iclass_AE_SRAI16_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRAI16R_args,
    1, Iclass_AE_SRAI16R_stateArgs, 0, 0 },
  { 3, Iclass_AE_SLAI32_args,
    1, Iclass_AE_SLAI32_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRLI32_args,
    1, Iclass_AE_SRLI32_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRAI32_args,
    1, Iclass_AE_SRAI32_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRAI32R_args,
    1, Iclass_AE_SRAI32R_stateArgs, 0, 0 },
  { 2, Iclass_AE_SLAS32_args,
    2, Iclass_AE_SLAS32_stateArgs, 0, 0 },
  { 2, Iclass_AE_SRLS32_args,
    2, Iclass_AE_SRLS32_stateArgs, 0, 0 },
  { 2, Iclass_AE_SRAS32_args,
    2, Iclass_AE_SRAS32_stateArgs, 0, 0 },
  { 3, Iclass_AE_SLAA32_args,
    1, Iclass_AE_SLAA32_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRLA32_args,
    1, Iclass_AE_SRLA32_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRAA32_args,
    1, Iclass_AE_SRAA32_stateArgs, 0, 0 },
  { 3, Iclass_AE_SLAI16S_args,
    2, Iclass_AE_SLAI16S_stateArgs, 0, 0 },
  { 3, Iclass_AE_SLAA16S_args,
    2, Iclass_AE_SLAA16S_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRAA16S_args,
    2, Iclass_AE_SRAA16S_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRAA16RS_args,
    2, Iclass_AE_SRAA16RS_stateArgs, 0, 0 },
  { 3, Iclass_AE_SLAI24S_args,
    2, Iclass_AE_SLAI24S_stateArgs, 0, 0 },
  { 2, Iclass_AE_SLAS24S_args,
    3, Iclass_AE_SLAS24S_stateArgs, 0, 0 },
  { 3, Iclass_AE_SLAI32S_args,
    2, Iclass_AE_SLAI32S_stateArgs, 0, 0 },
  { 2, Iclass_AE_SLAS32S_args,
    3, Iclass_AE_SLAS32S_stateArgs, 0, 0 },
  { 3, Iclass_AE_SLAA32S_args,
    2, Iclass_AE_SLAA32S_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRAA32S_args,
    2, Iclass_AE_SRAA32S_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRAA32RS_args,
    2, Iclass_AE_SRAA32RS_stateArgs, 0, 0 },
  { 2, Iclass_AE_SLASQ56_args,
    2, Iclass_AE_SLASQ56_stateArgs, 0, 0 },
  { 2, Iclass_AE_SRLSQ56_args,
    2, Iclass_AE_SRLSQ56_stateArgs, 0, 0 },
  { 2, Iclass_AE_SRASQ56_args,
    2, Iclass_AE_SRASQ56_stateArgs, 0, 0 },
  { 3, Iclass_AE_SLAAQ56_args,
    1, Iclass_AE_SLAAQ56_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRLAQ56_args,
    1, Iclass_AE_SRLAQ56_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRAAQ56_args,
    1, Iclass_AE_SRAAQ56_stateArgs, 0, 0 },
  { 3, Iclass_AE_SLAI64_args,
    1, Iclass_AE_SLAI64_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRLI64_args,
    1, Iclass_AE_SRLI64_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRAI64_args,
    1, Iclass_AE_SRAI64_stateArgs, 0, 0 },
  { 2, Iclass_AE_SLAS64_args,
    2, Iclass_AE_SLAS64_stateArgs, 0, 0 },
  { 2, Iclass_AE_SRLS64_args,
    2, Iclass_AE_SRLS64_stateArgs, 0, 0 },
  { 2, Iclass_AE_SRAS64_args,
    2, Iclass_AE_SRAS64_stateArgs, 0, 0 },
  { 3, Iclass_AE_SLAA64_args,
    1, Iclass_AE_SLAA64_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRLA64_args,
    1, Iclass_AE_SRLA64_stateArgs, 0, 0 },
  { 3, Iclass_AE_SRAA64_args,
    1, Iclass_AE_SRAA64_stateArgs, 0, 0 },
  { 3, Iclass_AE_SLAISQ56S_args,
    2, Iclass_AE_SLAISQ56S_stateArgs, 0, 0 },
  { 2, Iclass_AE_SLASSQ56S_args,
    3, Iclass_AE_SLASSQ56S_stateArgs, 0, 0 },
  { 3, Iclass_AE_SLAASQ56S_args,
    2, Iclass_AE_SLAASQ56S_stateArgs, 0, 0 },
  { 3, Iclass_AE_SLAI64S_args,
    2, Iclass_AE_SLAI64S_stateArgs, 0, 0 },
  { 2, Iclass_AE_SLAS64S_args,
    3, Iclass_AE_SLAS64S_stateArgs, 0, 0 },
  { 3, Iclass_AE_SLAA64S_args,
    2, Iclass_AE_SLAA64S_stateArgs, 0, 0 },
  { 3, Iclass_AE_LT64_args,
    1, Iclass_AE_LT64_stateArgs, 0, 0 },
  { 3, Iclass_AE_LE64_args,
    1, Iclass_AE_LE64_stateArgs, 0, 0 },
  { 3, Iclass_AE_EQ64_args,
    1, Iclass_AE_EQ64_stateArgs, 0, 0 },
  { 3, Iclass_AE_MAX64_args,
    1, Iclass_AE_MAX64_stateArgs, 0, 0 },
  { 3, Iclass_AE_MIN64_args,
    1, Iclass_AE_MIN64_stateArgs, 0, 0 },
  { 2, Iclass_AE_NSA64_args,
    1, Iclass_AE_NSA64_stateArgs, 0, 0 },
  { 2, Iclass_AE_NSAZ16_0_args,
    1, Iclass_AE_NSAZ16_0_stateArgs, 0, 0 },
  { 2, Iclass_AE_NSAZ32_L_args,
    1, Iclass_AE_NSAZ32_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32F48P16S_LL_args,
    2, Iclass_AE_MULS32F48P16S_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32S_LL_args,
    2, Iclass_AE_MULF32S_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32_LL_args,
    1, Iclass_AE_MUL32_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32F48P16S_LL_S2_args,
    2, Iclass_AE_MULS32F48P16S_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32R_LL_args,
    1, Iclass_AE_MULF32R_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32F48P16S_LH_args,
    2, Iclass_AE_MULS32F48P16S_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32S_LH_args,
    2, Iclass_AE_MULF32S_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32_LH_args,
    1, Iclass_AE_MUL32_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32F48P16S_LH_S2_args,
    2, Iclass_AE_MULS32F48P16S_LH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32R_LH_args,
    1, Iclass_AE_MULF32R_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32F48P16S_HH_args,
    2, Iclass_AE_MULS32F48P16S_HH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32S_HH_args,
    2, Iclass_AE_MULF32S_HH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32_HH_args,
    1, Iclass_AE_MUL32_HH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32F48P16S_HH_S2_args,
    2, Iclass_AE_MULS32F48P16S_HH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32R_HH_args,
    1, Iclass_AE_MULF32R_HH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32R_LL_S2_args,
    1, Iclass_AE_MULF32R_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAS32F48P16S_LL_args,
    2, Iclass_AE_MULAS32F48P16S_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32S_LL_args,
    2, Iclass_AE_MULAF32S_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32_LL_args,
    1, Iclass_AE_MULA32_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAS32F48P16S_LL_S2_args,
    2, Iclass_AE_MULAS32F48P16S_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32R_LL_args,
    1, Iclass_AE_MULAF32R_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAS32F48P16S_LH_args,
    2, Iclass_AE_MULAS32F48P16S_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32S_LH_args,
    2, Iclass_AE_MULAF32S_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32_LH_args,
    1, Iclass_AE_MULA32_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAS32F48P16S_LH_S2_args,
    2, Iclass_AE_MULAS32F48P16S_LH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32R_LH_args,
    1, Iclass_AE_MULAF32R_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAS32F48P16S_HH_args,
    2, Iclass_AE_MULAS32F48P16S_HH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32S_HH_args,
    2, Iclass_AE_MULAF32S_HH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32_HH_args,
    1, Iclass_AE_MULA32_HH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAS32F48P16S_HH_S2_args,
    2, Iclass_AE_MULAS32F48P16S_HH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32R_HH_args,
    1, Iclass_AE_MULAF32R_HH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32R_LL_S2_args,
    1, Iclass_AE_MULAF32R_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSS32F48P16S_LL_args,
    2, Iclass_AE_MULSS32F48P16S_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32S_LL_args,
    2, Iclass_AE_MULSF32S_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32_LL_args,
    1, Iclass_AE_MULS32_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSS32F48P16S_LL_S2_args,
    2, Iclass_AE_MULSS32F48P16S_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32R_LL_args,
    1, Iclass_AE_MULSF32R_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSS32F48P16S_LH_args,
    2, Iclass_AE_MULSS32F48P16S_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32S_LH_args,
    2, Iclass_AE_MULSF32S_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32_LH_args,
    1, Iclass_AE_MULS32_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSS32F48P16S_LH_S2_args,
    2, Iclass_AE_MULSS32F48P16S_LH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32R_LH_args,
    1, Iclass_AE_MULSF32R_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSS32F48P16S_HH_args,
    2, Iclass_AE_MULSS32F48P16S_HH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32S_HH_args,
    2, Iclass_AE_MULSF32S_HH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32_HH_args,
    1, Iclass_AE_MULS32_HH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSS32F48P16S_HH_S2_args,
    2, Iclass_AE_MULSS32F48P16S_HH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32R_HH_args,
    1, Iclass_AE_MULSF32R_HH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32R_LL_S2_args,
    1, Iclass_AE_MULSF32R_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32S_LL_S2_args,
    2, Iclass_AE_MULF32S_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32S_LL_S2_args,
    2, Iclass_AE_MULAF32S_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32_LL_S2_args,
    1, Iclass_AE_MUL32_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32_LL_S2_args,
    1, Iclass_AE_MULA32_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32U_LL_args,
    1, Iclass_AE_MUL32U_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32U_LL_args,
    1, Iclass_AE_MULA32U_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32U_LL_args,
    1, Iclass_AE_MULS32U_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF16SS_33_args,
    2, Iclass_AE_MULF16SS_33_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF16SS_22_args,
    2, Iclass_AE_MULF16SS_22_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF16SS_32_args,
    2, Iclass_AE_MULF16SS_32_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF16SS_21_args,
    2, Iclass_AE_MULF16SS_21_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF16SS_31_args,
    2, Iclass_AE_MULF16SS_31_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF16SS_30_args,
    2, Iclass_AE_MULF16SS_30_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF16SS_10_args,
    2, Iclass_AE_MULF16SS_10_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF16SS_20_args,
    2, Iclass_AE_MULF16SS_20_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF16SS_11_args,
    2, Iclass_AE_MULF16SS_11_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF16SS_00_args,
    2, Iclass_AE_MULF16SS_00_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF16SS_00_S2_args,
    2, Iclass_AE_MULF16SS_00_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF16SS_33_args,
    2, Iclass_AE_MULSF16SS_33_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF16SS_22_args,
    2, Iclass_AE_MULSF16SS_22_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF16SS_32_args,
    2, Iclass_AE_MULSF16SS_32_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF16SS_21_args,
    2, Iclass_AE_MULSF16SS_21_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF16SS_31_args,
    2, Iclass_AE_MULSF16SS_31_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF16SS_30_args,
    2, Iclass_AE_MULSF16SS_30_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF16SS_10_args,
    2, Iclass_AE_MULSF16SS_10_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF16SS_20_args,
    2, Iclass_AE_MULSF16SS_20_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF16SS_11_args,
    2, Iclass_AE_MULSF16SS_11_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF16SS_00_args,
    2, Iclass_AE_MULSF16SS_00_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF16SS_00_S2_args,
    2, Iclass_AE_MULSF16SS_00_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF16SS_33_args,
    2, Iclass_AE_MULAF16SS_33_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF16SS_22_args,
    2, Iclass_AE_MULAF16SS_22_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF16SS_32_args,
    2, Iclass_AE_MULAF16SS_32_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF16SS_21_args,
    2, Iclass_AE_MULAF16SS_21_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF16SS_31_args,
    2, Iclass_AE_MULAF16SS_31_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF16SS_30_args,
    2, Iclass_AE_MULAF16SS_30_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF16SS_10_args,
    2, Iclass_AE_MULAF16SS_10_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF16SS_20_args,
    2, Iclass_AE_MULAF16SS_20_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF16SS_11_args,
    2, Iclass_AE_MULAF16SS_11_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF16SS_00_args,
    2, Iclass_AE_MULAF16SS_00_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF16SS_00_S2_args,
    2, Iclass_AE_MULAF16SS_00_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD16SS_33_22_args,
    2, Iclass_AE_MULAAFD16SS_33_22_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD16SS_33_22_S2_args,
    2, Iclass_AE_MULAAFD16SS_33_22_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD16SS_13_02_args,
    2, Iclass_AE_MULAAFD16SS_13_02_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD16SS_13_02_S2_args,
    2, Iclass_AE_MULAAFD16SS_13_02_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD16SS_11_00_args,
    2, Iclass_AE_MULAAFD16SS_11_00_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD16SS_11_00_S2_args,
    2, Iclass_AE_MULAAFD16SS_11_00_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSFD16SS_33_22_args,
    2, Iclass_AE_MULSSFD16SS_33_22_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSFD16SS_33_22_S2_args,
    2, Iclass_AE_MULSSFD16SS_33_22_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSFD16SS_13_02_args,
    2, Iclass_AE_MULSSFD16SS_13_02_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSFD16SS_13_02_S2_args,
    2, Iclass_AE_MULSSFD16SS_13_02_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSFD16SS_11_00_args,
    2, Iclass_AE_MULSSFD16SS_11_00_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSFD16SS_11_00_S2_args,
    2, Iclass_AE_MULSSFD16SS_11_00_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD16SS_33_22_args,
    2, Iclass_AE_MULZAAFD16SS_33_22_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD16SS_33_22_S2_args,
    2, Iclass_AE_MULZAAFD16SS_33_22_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD16SS_13_02_args,
    2, Iclass_AE_MULZAAFD16SS_13_02_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD16SS_13_02_S2_args,
    2, Iclass_AE_MULZAAFD16SS_13_02_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD16SS_11_00_args,
    2, Iclass_AE_MULZAAFD16SS_11_00_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD16SS_11_00_S2_args,
    2, Iclass_AE_MULZAAFD16SS_11_00_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSFD16SS_33_22_args,
    2, Iclass_AE_MULZSSFD16SS_33_22_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSFD16SS_33_22_S2_args,
    2, Iclass_AE_MULZSSFD16SS_33_22_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSFD16SS_13_02_args,
    2, Iclass_AE_MULZSSFD16SS_13_02_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSFD16SS_13_02_S2_args,
    2, Iclass_AE_MULZSSFD16SS_13_02_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSFD16SS_11_00_args,
    2, Iclass_AE_MULZSSFD16SS_11_00_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSFD16SS_11_00_S2_args,
    2, Iclass_AE_MULZSSFD16SS_11_00_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF48Q32SP16S_L_args,
    1, Iclass_AE_MULF48Q32SP16S_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF48Q32SP16S_L_S2_args,
    1, Iclass_AE_MULF48Q32SP16S_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF48Q32SP16U_L_args,
    1, Iclass_AE_MULF48Q32SP16U_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF48Q32SP16U_L_S2_args,
    1, Iclass_AE_MULF48Q32SP16U_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULQ32SP16S_L_args,
    1, Iclass_AE_MULQ32SP16S_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULQ32SP16S_L_S2_args,
    1, Iclass_AE_MULQ32SP16S_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULQ32SP16U_L_args,
    1, Iclass_AE_MULQ32SP16U_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULQ32SP16U_L_S2_args,
    1, Iclass_AE_MULQ32SP16U_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF48Q32SP16S_L_args,
    1, Iclass_AE_MULAF48Q32SP16S_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF48Q32SP16S_L_S2_args,
    1, Iclass_AE_MULAF48Q32SP16S_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF48Q32SP16U_L_args,
    1, Iclass_AE_MULAF48Q32SP16U_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF48Q32SP16U_L_S2_args,
    1, Iclass_AE_MULAF48Q32SP16U_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAQ32SP16S_L_args,
    1, Iclass_AE_MULAQ32SP16S_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAQ32SP16S_L_S2_args,
    1, Iclass_AE_MULAQ32SP16S_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAQ32SP16U_L_args,
    1, Iclass_AE_MULAQ32SP16U_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAQ32SP16U_L_S2_args,
    1, Iclass_AE_MULAQ32SP16U_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF48Q32SP16S_L_args,
    1, Iclass_AE_MULSF48Q32SP16S_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF48Q32SP16S_L_S2_args,
    1, Iclass_AE_MULSF48Q32SP16S_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF48Q32SP16U_L_args,
    1, Iclass_AE_MULSF48Q32SP16U_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF48Q32SP16U_L_S2_args,
    1, Iclass_AE_MULSF48Q32SP16U_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSQ32SP16S_L_args,
    1, Iclass_AE_MULSQ32SP16S_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSQ32SP16S_L_S2_args,
    1, Iclass_AE_MULSQ32SP16S_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSQ32SP16U_L_args,
    1, Iclass_AE_MULSQ32SP16U_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSQ32SP16U_L_S2_args,
    1, Iclass_AE_MULSQ32SP16U_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFP24X2RA_args,
    1, Iclass_AE_MULFP24X2RA_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFP24X2R_args,
    1, Iclass_AE_MULFP24X2R_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULP24X2_args,
    1, Iclass_AE_MULP24X2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFP24X2RA_S2_args,
    1, Iclass_AE_MULFP24X2RA_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFP24X2R_S2_args,
    1, Iclass_AE_MULFP24X2R_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULP24X2_S2_args,
    1, Iclass_AE_MULP24X2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFP24X2RA_args,
    1, Iclass_AE_MULAFP24X2RA_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFP24X2R_args,
    1, Iclass_AE_MULAFP24X2R_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAP24X2_args,
    1, Iclass_AE_MULAP24X2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFP24X2RA_S2_args,
    1, Iclass_AE_MULAFP24X2RA_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFP24X2R_S2_args,
    1, Iclass_AE_MULAFP24X2R_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAP24X2_S2_args,
    1, Iclass_AE_MULAP24X2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFP24X2RA_args,
    1, Iclass_AE_MULSFP24X2RA_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFP24X2R_args,
    1, Iclass_AE_MULSFP24X2R_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSP24X2_args,
    1, Iclass_AE_MULSP24X2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFP24X2RA_S2_args,
    1, Iclass_AE_MULSFP24X2RA_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFP24X2R_S2_args,
    1, Iclass_AE_MULSFP24X2R_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSP24X2_S2_args,
    1, Iclass_AE_MULSP24X2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD24_HH_LL_args,
    1, Iclass_AE_MULZAAFD24_HH_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAD24_HH_LL_args,
    1, Iclass_AE_MULZAAD24_HH_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD24_HH_LL_S2_args,
    1, Iclass_AE_MULZAAFD24_HH_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAD24_HH_LL_S2_args,
    1, Iclass_AE_MULZAAD24_HH_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD24_HL_LH_args,
    1, Iclass_AE_MULZAAFD24_HL_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAD24_HL_LH_args,
    1, Iclass_AE_MULZAAD24_HL_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD24_HL_LH_S2_args,
    1, Iclass_AE_MULZAAFD24_HL_LH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAD24_HL_LH_S2_args,
    1, Iclass_AE_MULZAAD24_HL_LH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZASFD24_HH_LL_args,
    1, Iclass_AE_MULZASFD24_HH_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZASD24_HH_LL_args,
    1, Iclass_AE_MULZASD24_HH_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZASFD24_HH_LL_S2_args,
    1, Iclass_AE_MULZASFD24_HH_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZASD24_HH_LL_S2_args,
    1, Iclass_AE_MULZASD24_HH_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZASFD24_HL_LH_args,
    1, Iclass_AE_MULZASFD24_HL_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZASD24_HL_LH_args,
    1, Iclass_AE_MULZASD24_HL_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZASFD24_HL_LH_S2_args,
    1, Iclass_AE_MULZASFD24_HL_LH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZASD24_HL_LH_S2_args,
    1, Iclass_AE_MULZASD24_HL_LH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSAFD24_HH_LL_args,
    1, Iclass_AE_MULZSAFD24_HH_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSAD24_HH_LL_args,
    1, Iclass_AE_MULZSAD24_HH_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSAFD24_HH_LL_S2_args,
    1, Iclass_AE_MULZSAFD24_HH_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSAD24_HH_LL_S2_args,
    1, Iclass_AE_MULZSAD24_HH_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSFD24_HH_LL_args,
    1, Iclass_AE_MULZSSFD24_HH_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSD24_HH_LL_args,
    1, Iclass_AE_MULZSSD24_HH_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSFD24_HH_LL_S2_args,
    1, Iclass_AE_MULZSSFD24_HH_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSD24_HH_LL_S2_args,
    1, Iclass_AE_MULZSSD24_HH_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSFD24_HL_LH_args,
    1, Iclass_AE_MULZSSFD24_HL_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSD24_HL_LH_args,
    1, Iclass_AE_MULZSSD24_HL_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSFD24_HL_LH_S2_args,
    1, Iclass_AE_MULZSSFD24_HL_LH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSD24_HL_LH_S2_args,
    1, Iclass_AE_MULZSSD24_HL_LH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD24_HH_LL_args,
    1, Iclass_AE_MULAAFD24_HH_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAD24_HH_LL_args,
    1, Iclass_AE_MULAAD24_HH_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD24_HH_LL_S2_args,
    1, Iclass_AE_MULAAFD24_HH_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAD24_HH_LL_S2_args,
    1, Iclass_AE_MULAAD24_HH_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD24_HL_LH_args,
    1, Iclass_AE_MULAAFD24_HL_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAD24_HL_LH_args,
    1, Iclass_AE_MULAAD24_HL_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD24_HL_LH_S2_args,
    1, Iclass_AE_MULAAFD24_HL_LH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAD24_HL_LH_S2_args,
    1, Iclass_AE_MULAAD24_HL_LH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULASFD24_HH_LL_args,
    1, Iclass_AE_MULASFD24_HH_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULASD24_HH_LL_args,
    1, Iclass_AE_MULASD24_HH_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULASFD24_HH_LL_S2_args,
    1, Iclass_AE_MULASFD24_HH_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULASD24_HH_LL_S2_args,
    1, Iclass_AE_MULASD24_HH_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULASFD24_HL_LH_args,
    1, Iclass_AE_MULASFD24_HL_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULASD24_HL_LH_args,
    1, Iclass_AE_MULASD24_HL_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULASFD24_HL_LH_S2_args,
    1, Iclass_AE_MULASFD24_HL_LH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULASD24_HL_LH_S2_args,
    1, Iclass_AE_MULASD24_HL_LH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSAFD24_HH_LL_args,
    1, Iclass_AE_MULSAFD24_HH_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSAD24_HH_LL_args,
    1, Iclass_AE_MULSAD24_HH_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSAFD24_HH_LL_S2_args,
    1, Iclass_AE_MULSAFD24_HH_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSAD24_HH_LL_S2_args,
    1, Iclass_AE_MULSAD24_HH_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSFD24_HH_LL_args,
    1, Iclass_AE_MULSSFD24_HH_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSD24_HH_LL_args,
    1, Iclass_AE_MULSSD24_HH_LL_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSFD24_HH_LL_S2_args,
    1, Iclass_AE_MULSSFD24_HH_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSD24_HH_LL_S2_args,
    1, Iclass_AE_MULSSD24_HH_LL_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSFD24_HL_LH_args,
    1, Iclass_AE_MULSSFD24_HL_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSD24_HL_LH_args,
    1, Iclass_AE_MULSSD24_HL_LH_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSFD24_HL_LH_S2_args,
    1, Iclass_AE_MULSSFD24_HL_LH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSD24_HL_LH_S2_args,
    1, Iclass_AE_MULSSD24_HL_LH_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSRFQ32SP24S_H_args,
    1, Iclass_AE_MULSRFQ32SP24S_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSRFQ32SP24S_L_args,
    1, Iclass_AE_MULSRFQ32SP24S_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSRFQ32SP24S_H_S2_args,
    1, Iclass_AE_MULSRFQ32SP24S_H_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSRFQ32SP24S_L_S2_args,
    1, Iclass_AE_MULSRFQ32SP24S_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULARFQ32SP24S_H_args,
    1, Iclass_AE_MULARFQ32SP24S_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULARFQ32SP24S_L_args,
    1, Iclass_AE_MULARFQ32SP24S_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULARFQ32SP24S_H_S2_args,
    1, Iclass_AE_MULARFQ32SP24S_H_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULARFQ32SP24S_L_S2_args,
    1, Iclass_AE_MULARFQ32SP24S_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULRFQ32SP24S_H_args,
    1, Iclass_AE_MULRFQ32SP24S_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULRFQ32SP24S_L_args,
    1, Iclass_AE_MULRFQ32SP24S_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULRFQ32SP24S_H_S2_args,
    1, Iclass_AE_MULRFQ32SP24S_H_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULRFQ32SP24S_L_S2_args,
    1, Iclass_AE_MULRFQ32SP24S_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFQ32SP24S_H_args,
    1, Iclass_AE_MULSFQ32SP24S_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFQ32SP24S_L_args,
    1, Iclass_AE_MULSFQ32SP24S_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFQ32SP24S_H_S2_args,
    1, Iclass_AE_MULSFQ32SP24S_H_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFQ32SP24S_L_S2_args,
    1, Iclass_AE_MULSFQ32SP24S_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFQ32SP24S_H_args,
    1, Iclass_AE_MULAFQ32SP24S_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFQ32SP24S_L_args,
    1, Iclass_AE_MULAFQ32SP24S_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFQ32SP24S_H_S2_args,
    1, Iclass_AE_MULAFQ32SP24S_H_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFQ32SP24S_L_S2_args,
    1, Iclass_AE_MULAFQ32SP24S_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFQ32SP24S_H_args,
    1, Iclass_AE_MULFQ32SP24S_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFQ32SP24S_L_args,
    1, Iclass_AE_MULFQ32SP24S_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFQ32SP24S_H_S2_args,
    1, Iclass_AE_MULFQ32SP24S_H_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFQ32SP24S_L_S2_args,
    1, Iclass_AE_MULFQ32SP24S_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32X16_L0_args,
    1, Iclass_AE_MULF32X16_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32X16_L0_args,
    1, Iclass_AE_MUL32X16_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32X16_L0_S2_args,
    1, Iclass_AE_MULF32X16_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32X16_L0_S2_args,
    1, Iclass_AE_MUL32X16_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32X16_L1_args,
    1, Iclass_AE_MULF32X16_L1_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32X16_L1_args,
    1, Iclass_AE_MUL32X16_L1_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32X16_L1_S2_args,
    1, Iclass_AE_MULF32X16_L1_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32X16_L1_S2_args,
    1, Iclass_AE_MUL32X16_L1_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32X16_L2_args,
    1, Iclass_AE_MULF32X16_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32X16_L2_args,
    1, Iclass_AE_MUL32X16_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32X16_L2_S2_args,
    1, Iclass_AE_MULF32X16_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32X16_L2_S2_args,
    1, Iclass_AE_MUL32X16_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32X16_L3_args,
    1, Iclass_AE_MULF32X16_L3_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32X16_L3_args,
    1, Iclass_AE_MUL32X16_L3_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32X16_L3_S2_args,
    1, Iclass_AE_MULF32X16_L3_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32X16_L3_S2_args,
    1, Iclass_AE_MUL32X16_L3_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32X16_H0_args,
    1, Iclass_AE_MULF32X16_H0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32X16_H0_args,
    1, Iclass_AE_MUL32X16_H0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32X16_H0_S2_args,
    1, Iclass_AE_MULF32X16_H0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32X16_H0_S2_args,
    1, Iclass_AE_MUL32X16_H0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32X16_H1_args,
    1, Iclass_AE_MULF32X16_H1_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32X16_H1_args,
    1, Iclass_AE_MUL32X16_H1_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32X16_H1_S2_args,
    1, Iclass_AE_MULF32X16_H1_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32X16_H1_S2_args,
    1, Iclass_AE_MUL32X16_H1_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32X16_H2_args,
    1, Iclass_AE_MULF32X16_H2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32X16_H2_args,
    1, Iclass_AE_MUL32X16_H2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32X16_H2_S2_args,
    1, Iclass_AE_MULF32X16_H2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32X16_H2_S2_args,
    1, Iclass_AE_MUL32X16_H2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32X16_H3_args,
    1, Iclass_AE_MULF32X16_H3_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32X16_H3_args,
    1, Iclass_AE_MUL32X16_H3_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULF32X16_H3_S2_args,
    1, Iclass_AE_MULF32X16_H3_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MUL32X16_H3_S2_args,
    1, Iclass_AE_MUL32X16_H3_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32X16_L0_args,
    1, Iclass_AE_MULAF32X16_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32X16_L0_args,
    1, Iclass_AE_MULA32X16_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32X16_L0_S2_args,
    1, Iclass_AE_MULAF32X16_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32X16_L0_S2_args,
    1, Iclass_AE_MULA32X16_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32X16_L1_args,
    1, Iclass_AE_MULAF32X16_L1_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32X16_L1_args,
    1, Iclass_AE_MULA32X16_L1_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32X16_L1_S2_args,
    1, Iclass_AE_MULAF32X16_L1_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32X16_L1_S2_args,
    1, Iclass_AE_MULA32X16_L1_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32X16_L2_args,
    1, Iclass_AE_MULAF32X16_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32X16_L2_args,
    1, Iclass_AE_MULA32X16_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32X16_L2_S2_args,
    1, Iclass_AE_MULAF32X16_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32X16_L2_S2_args,
    1, Iclass_AE_MULA32X16_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32X16_L3_args,
    1, Iclass_AE_MULAF32X16_L3_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32X16_L3_args,
    1, Iclass_AE_MULA32X16_L3_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32X16_L3_S2_args,
    1, Iclass_AE_MULAF32X16_L3_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32X16_L3_S2_args,
    1, Iclass_AE_MULA32X16_L3_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32X16_H0_args,
    1, Iclass_AE_MULAF32X16_H0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32X16_H0_args,
    1, Iclass_AE_MULA32X16_H0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32X16_H0_S2_args,
    1, Iclass_AE_MULAF32X16_H0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32X16_H0_S2_args,
    1, Iclass_AE_MULA32X16_H0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32X16_H1_args,
    1, Iclass_AE_MULAF32X16_H1_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32X16_H1_args,
    1, Iclass_AE_MULA32X16_H1_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32X16_H1_S2_args,
    1, Iclass_AE_MULAF32X16_H1_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32X16_H1_S2_args,
    1, Iclass_AE_MULA32X16_H1_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32X16_H2_args,
    1, Iclass_AE_MULAF32X16_H2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32X16_H2_args,
    1, Iclass_AE_MULA32X16_H2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32X16_H2_S2_args,
    1, Iclass_AE_MULAF32X16_H2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32X16_H2_S2_args,
    1, Iclass_AE_MULA32X16_H2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32X16_H3_args,
    1, Iclass_AE_MULAF32X16_H3_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32X16_H3_args,
    1, Iclass_AE_MULA32X16_H3_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAF32X16_H3_S2_args,
    1, Iclass_AE_MULAF32X16_H3_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULA32X16_H3_S2_args,
    1, Iclass_AE_MULA32X16_H3_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32X16_L0_args,
    1, Iclass_AE_MULSF32X16_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32X16_L0_args,
    1, Iclass_AE_MULS32X16_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32X16_L0_S2_args,
    1, Iclass_AE_MULSF32X16_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32X16_L0_S2_args,
    1, Iclass_AE_MULS32X16_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32X16_L1_args,
    1, Iclass_AE_MULSF32X16_L1_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32X16_L1_args,
    1, Iclass_AE_MULS32X16_L1_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32X16_L1_S2_args,
    1, Iclass_AE_MULSF32X16_L1_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32X16_L1_S2_args,
    1, Iclass_AE_MULS32X16_L1_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32X16_L2_args,
    1, Iclass_AE_MULSF32X16_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32X16_L2_args,
    1, Iclass_AE_MULS32X16_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32X16_L2_S2_args,
    1, Iclass_AE_MULSF32X16_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32X16_L2_S2_args,
    1, Iclass_AE_MULS32X16_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32X16_L3_args,
    1, Iclass_AE_MULSF32X16_L3_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32X16_L3_args,
    1, Iclass_AE_MULS32X16_L3_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32X16_L3_S2_args,
    1, Iclass_AE_MULSF32X16_L3_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32X16_L3_S2_args,
    1, Iclass_AE_MULS32X16_L3_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32X16_H0_args,
    1, Iclass_AE_MULSF32X16_H0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32X16_H0_args,
    1, Iclass_AE_MULS32X16_H0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32X16_H0_S2_args,
    1, Iclass_AE_MULSF32X16_H0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32X16_H0_S2_args,
    1, Iclass_AE_MULS32X16_H0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32X16_H1_args,
    1, Iclass_AE_MULSF32X16_H1_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32X16_H1_args,
    1, Iclass_AE_MULS32X16_H1_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32X16_H1_S2_args,
    1, Iclass_AE_MULSF32X16_H1_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32X16_H1_S2_args,
    1, Iclass_AE_MULS32X16_H1_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32X16_H2_args,
    1, Iclass_AE_MULSF32X16_H2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32X16_H2_args,
    1, Iclass_AE_MULS32X16_H2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32X16_H2_S2_args,
    1, Iclass_AE_MULSF32X16_H2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32X16_H2_S2_args,
    1, Iclass_AE_MULS32X16_H2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32X16_H3_args,
    1, Iclass_AE_MULSF32X16_H3_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32X16_H3_args,
    1, Iclass_AE_MULS32X16_H3_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSF32X16_H3_S2_args,
    1, Iclass_AE_MULSF32X16_H3_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULS32X16_H3_S2_args,
    1, Iclass_AE_MULS32X16_H3_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD32X16_H3_L2_args,
    1, Iclass_AE_MULAAFD32X16_H3_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAD32X16_H3_L2_args,
    1, Iclass_AE_MULAAD32X16_H3_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD32X16_H3_L2_S2_args,
    1, Iclass_AE_MULAAFD32X16_H3_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAD32X16_H3_L2_S2_args,
    1, Iclass_AE_MULAAD32X16_H3_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD32X16_H1_L0_args,
    1, Iclass_AE_MULAAFD32X16_H1_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAD32X16_H1_L0_args,
    1, Iclass_AE_MULAAD32X16_H1_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD32X16_H1_L0_S2_args,
    1, Iclass_AE_MULAAFD32X16_H1_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAD32X16_H1_L0_S2_args,
    1, Iclass_AE_MULAAD32X16_H1_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULASFD32X16_H3_L2_args,
    1, Iclass_AE_MULASFD32X16_H3_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULASD32X16_H3_L2_args,
    1, Iclass_AE_MULASD32X16_H3_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULASFD32X16_H3_L2_S2_args,
    1, Iclass_AE_MULASFD32X16_H3_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULASD32X16_H3_L2_S2_args,
    1, Iclass_AE_MULASD32X16_H3_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULASFD32X16_H1_L0_args,
    1, Iclass_AE_MULASFD32X16_H1_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULASD32X16_H1_L0_args,
    1, Iclass_AE_MULASD32X16_H1_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULASFD32X16_H1_L0_S2_args,
    1, Iclass_AE_MULASFD32X16_H1_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULASD32X16_H1_L0_S2_args,
    1, Iclass_AE_MULASD32X16_H1_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSAFD32X16_H3_L2_args,
    1, Iclass_AE_MULSAFD32X16_H3_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSAD32X16_H3_L2_args,
    1, Iclass_AE_MULSAD32X16_H3_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSAFD32X16_H3_L2_S2_args,
    1, Iclass_AE_MULSAFD32X16_H3_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSAD32X16_H3_L2_S2_args,
    1, Iclass_AE_MULSAD32X16_H3_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSAFD32X16_H1_L0_args,
    1, Iclass_AE_MULSAFD32X16_H1_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSAD32X16_H1_L0_args,
    1, Iclass_AE_MULSAD32X16_H1_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSAFD32X16_H1_L0_S2_args,
    1, Iclass_AE_MULSAFD32X16_H1_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSAD32X16_H1_L0_S2_args,
    1, Iclass_AE_MULSAD32X16_H1_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSFD32X16_H3_L2_args,
    1, Iclass_AE_MULSSFD32X16_H3_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSD32X16_H3_L2_args,
    1, Iclass_AE_MULSSD32X16_H3_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSFD32X16_H3_L2_S2_args,
    1, Iclass_AE_MULSSFD32X16_H3_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSD32X16_H3_L2_S2_args,
    1, Iclass_AE_MULSSD32X16_H3_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSFD32X16_H1_L0_args,
    1, Iclass_AE_MULSSFD32X16_H1_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSD32X16_H1_L0_args,
    1, Iclass_AE_MULSSD32X16_H1_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSFD32X16_H1_L0_S2_args,
    1, Iclass_AE_MULSSFD32X16_H1_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSSD32X16_H1_L0_S2_args,
    1, Iclass_AE_MULSSD32X16_H1_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD32X16_H3_L2_args,
    1, Iclass_AE_MULZAAFD32X16_H3_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAD32X16_H3_L2_args,
    1, Iclass_AE_MULZAAD32X16_H3_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD32X16_H3_L2_S2_args,
    1, Iclass_AE_MULZAAFD32X16_H3_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAD32X16_H3_L2_S2_args,
    1, Iclass_AE_MULZAAD32X16_H3_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD32X16_H1_L0_args,
    1, Iclass_AE_MULZAAFD32X16_H1_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAD32X16_H1_L0_args,
    1, Iclass_AE_MULZAAD32X16_H1_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD32X16_H1_L0_S2_args,
    1, Iclass_AE_MULZAAFD32X16_H1_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAD32X16_H1_L0_S2_args,
    1, Iclass_AE_MULZAAD32X16_H1_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZASFD32X16_H3_L2_args,
    1, Iclass_AE_MULZASFD32X16_H3_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZASD32X16_H3_L2_args,
    1, Iclass_AE_MULZASD32X16_H3_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZASFD32X16_H3_L2_S2_args,
    1, Iclass_AE_MULZASFD32X16_H3_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZASD32X16_H3_L2_S2_args,
    1, Iclass_AE_MULZASD32X16_H3_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZASFD32X16_H1_L0_args,
    1, Iclass_AE_MULZASFD32X16_H1_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZASD32X16_H1_L0_args,
    1, Iclass_AE_MULZASD32X16_H1_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZASFD32X16_H1_L0_S2_args,
    1, Iclass_AE_MULZASFD32X16_H1_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZASD32X16_H1_L0_S2_args,
    1, Iclass_AE_MULZASD32X16_H1_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSAFD32X16_H3_L2_args,
    1, Iclass_AE_MULZSAFD32X16_H3_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSAD32X16_H3_L2_args,
    1, Iclass_AE_MULZSAD32X16_H3_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSAFD32X16_H3_L2_S2_args,
    1, Iclass_AE_MULZSAFD32X16_H3_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSAD32X16_H3_L2_S2_args,
    1, Iclass_AE_MULZSAD32X16_H3_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSAFD32X16_H1_L0_args,
    1, Iclass_AE_MULZSAFD32X16_H1_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSAD32X16_H1_L0_args,
    1, Iclass_AE_MULZSAD32X16_H1_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSAFD32X16_H1_L0_S2_args,
    1, Iclass_AE_MULZSAFD32X16_H1_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSAD32X16_H1_L0_S2_args,
    1, Iclass_AE_MULZSAD32X16_H1_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSFD32X16_H3_L2_args,
    1, Iclass_AE_MULZSSFD32X16_H3_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSD32X16_H3_L2_args,
    1, Iclass_AE_MULZSSD32X16_H3_L2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSFD32X16_H3_L2_S2_args,
    1, Iclass_AE_MULZSSFD32X16_H3_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSD32X16_H3_L2_S2_args,
    1, Iclass_AE_MULZSSD32X16_H3_L2_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSFD32X16_H1_L0_args,
    1, Iclass_AE_MULZSSFD32X16_H1_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSD32X16_H1_L0_args,
    1, Iclass_AE_MULZSSD32X16_H1_L0_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSFD32X16_H1_L0_S2_args,
    1, Iclass_AE_MULZSSFD32X16_H1_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZSSD32X16_H1_L0_S2_args,
    1, Iclass_AE_MULZSSD32X16_H1_L0_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD32X16_H2_L3_args,
    1, Iclass_AE_MULZAAFD32X16_H2_L3_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD32X16_H0_L1_args,
    1, Iclass_AE_MULZAAFD32X16_H0_L1_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD32X16_H2_L3_args,
    1, Iclass_AE_MULAAFD32X16_H2_L3_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD32X16_H0_L1_args,
    1, Iclass_AE_MULAAFD32X16_H0_L1_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAD32X16_H2_L3_args,
    1, Iclass_AE_MULZAAD32X16_H2_L3_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAD32X16_H0_L1_args,
    1, Iclass_AE_MULZAAD32X16_H0_L1_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAD32X16_H2_L3_args,
    1, Iclass_AE_MULAAD32X16_H2_L3_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAD32X16_H0_L1_args,
    1, Iclass_AE_MULAAD32X16_H0_L1_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD32X16_H2_L3_S2_args,
    1, Iclass_AE_MULZAAFD32X16_H2_L3_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAFD32X16_H0_L1_S2_args,
    1, Iclass_AE_MULZAAFD32X16_H0_L1_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD32X16_H2_L3_S2_args,
    1, Iclass_AE_MULAAFD32X16_H2_L3_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAFD32X16_H0_L1_S2_args,
    1, Iclass_AE_MULAAFD32X16_H0_L1_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAD32X16_H2_L3_S2_args,
    1, Iclass_AE_MULZAAD32X16_H2_L3_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULZAAD32X16_H0_L1_S2_args,
    1, Iclass_AE_MULZAAD32X16_H0_L1_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAD32X16_H2_L3_S2_args,
    1, Iclass_AE_MULAAD32X16_H2_L3_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAAD32X16_H0_L1_S2_args,
    1, Iclass_AE_MULAAD32X16_H0_L1_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULP32X16X2_H_args,
    1, Iclass_AE_MULP32X16X2_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFP32X16X2RS_H_args,
    2, Iclass_AE_MULFP32X16X2RS_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFP32X16X2RAS_H_args,
    2, Iclass_AE_MULFP32X16X2RAS_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFP32X16X2RS_H_S2_args,
    2, Iclass_AE_MULFP32X16X2RS_H_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFP32X16X2RAS_H_S2_args,
    2, Iclass_AE_MULFP32X16X2RAS_H_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULP32X16X2_L_args,
    1, Iclass_AE_MULP32X16X2_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFP32X16X2RS_L_args,
    2, Iclass_AE_MULFP32X16X2RS_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFP32X16X2RAS_L_args,
    2, Iclass_AE_MULFP32X16X2RAS_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFP32X16X2RS_L_S2_args,
    2, Iclass_AE_MULFP32X16X2RS_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFP32X16X2RAS_L_S2_args,
    2, Iclass_AE_MULFP32X16X2RAS_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAP32X16X2_H_args,
    1, Iclass_AE_MULAP32X16X2_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFP32X16X2RS_H_args,
    2, Iclass_AE_MULAFP32X16X2RS_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFP32X16X2RAS_H_args,
    2, Iclass_AE_MULAFP32X16X2RAS_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFP32X16X2RS_H_S2_args,
    2, Iclass_AE_MULAFP32X16X2RS_H_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFP32X16X2RAS_H_S2_args,
    2, Iclass_AE_MULAFP32X16X2RAS_H_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAP32X16X2_L_args,
    1, Iclass_AE_MULAP32X16X2_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFP32X16X2RS_L_args,
    2, Iclass_AE_MULAFP32X16X2RS_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFP32X16X2RAS_L_args,
    2, Iclass_AE_MULAFP32X16X2RAS_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFP32X16X2RS_L_S2_args,
    2, Iclass_AE_MULAFP32X16X2RS_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFP32X16X2RAS_L_S2_args,
    2, Iclass_AE_MULAFP32X16X2RAS_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSP32X16X2_H_args,
    1, Iclass_AE_MULSP32X16X2_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFP32X16X2RS_H_args,
    2, Iclass_AE_MULSFP32X16X2RS_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFP32X16X2RAS_H_args,
    2, Iclass_AE_MULSFP32X16X2RAS_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFP32X16X2RS_H_S2_args,
    2, Iclass_AE_MULSFP32X16X2RS_H_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFP32X16X2RAS_H_S2_args,
    2, Iclass_AE_MULSFP32X16X2RAS_H_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSP32X16X2_L_args,
    1, Iclass_AE_MULSP32X16X2_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFP32X16X2RS_L_args,
    2, Iclass_AE_MULSFP32X16X2RS_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFP32X16X2RAS_L_args,
    2, Iclass_AE_MULSFP32X16X2RAS_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFP32X16X2RS_L_S2_args,
    2, Iclass_AE_MULSFP32X16X2RS_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFP32X16X2RAS_L_S2_args,
    2, Iclass_AE_MULSFP32X16X2RAS_L_S2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULP32X2_args,
    1, Iclass_AE_MULP32X2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFP32X2RS_args,
    2, Iclass_AE_MULFP32X2RS_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFP32X2RAS_args,
    2, Iclass_AE_MULFP32X2RAS_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAP32X2_args,
    1, Iclass_AE_MULAP32X2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFP32X2RS_args,
    2, Iclass_AE_MULAFP32X2RS_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFP32X2RAS_args,
    2, Iclass_AE_MULAFP32X2RAS_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSP32X2_args,
    1, Iclass_AE_MULSP32X2_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFP32X2RS_args,
    2, Iclass_AE_MULSFP32X2RS_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULSFP32X2RAS_args,
    2, Iclass_AE_MULSFP32X2RAS_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFP16X4S_args,
    2, Iclass_AE_MULFP16X4S_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFP16X4RAS_args,
    2, Iclass_AE_MULFP16X4RAS_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULC24_args,
    1, Iclass_AE_MULC24_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFC24RA_args,
    1, Iclass_AE_MULFC24RA_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULC32X16_L_args,
    1, Iclass_AE_MULC32X16_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFC32X16RAS_L_args,
    2, Iclass_AE_MULFC32X16RAS_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULC32X16_H_args,
    1, Iclass_AE_MULC32X16_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULFC32X16RAS_H_args,
    2, Iclass_AE_MULFC32X16RAS_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAC24_args,
    1, Iclass_AE_MULAC24_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFC24RA_args,
    1, Iclass_AE_MULAFC24RA_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAC32X16_L_args,
    1, Iclass_AE_MULAC32X16_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFC32X16RAS_L_args,
    2, Iclass_AE_MULAFC32X16RAS_L_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAC32X16_H_args,
    1, Iclass_AE_MULAC32X16_H_stateArgs, 0, 0 },
  { 3, Iclass_AE_MULAFC32X16RAS_H_args,
    2, Iclass_AE_MULAFC32X16RAS_H_stateArgs, 0, 0 },
  { 4, Iclass_AE_MULF16X4SS_args,
    2, Iclass_AE_MULF16X4SS_stateArgs, 0, 0 },
  { 4, Iclass_AE_MULAF16X4SS_args,
    2, Iclass_AE_MULAF16X4SS_stateArgs, 0, 0 },
  { 4, Iclass_AE_MULSF16X4SS_args,
    2, Iclass_AE_MULSF16X4SS_stateArgs, 0, 0 },
  { 4, Iclass_AE_MUL16X4_args,
    1, Iclass_AE_MUL16X4_stateArgs, 0, 0 },
  { 4, Iclass_AE_MULA16X4_args,
    1, Iclass_AE_MULA16X4_stateArgs, 0, 0 },
  { 4, Iclass_AE_MULS16X4_args,
    1, Iclass_AE_MULS16X4_stateArgs, 0, 0 },
  { 5, Iclass_AE_MULFD24X2_FIR_H_args,
    1, Iclass_AE_MULFD24X2_FIR_H_stateArgs, 0, 0 },
  { 5, Iclass_AE_MULFD24X2_FIR_L_args,
    1, Iclass_AE_MULFD24X2_FIR_L_stateArgs, 0, 0 },
  { 5, Iclass_AE_MULFD32X16X2_FIR_HH_args,
    1, Iclass_AE_MULFD32X16X2_FIR_HH_stateArgs, 0, 0 },
  { 5, Iclass_AE_MULFD32X16X2_FIR_HL_args,
    1, Iclass_AE_MULFD32X16X2_FIR_HL_stateArgs, 0, 0 },
  { 5, Iclass_AE_MULFD32X16X2_FIR_LH_args,
    1, Iclass_AE_MULFD32X16X2_FIR_LH_stateArgs, 0, 0 },
  { 5, Iclass_AE_MULFD32X16X2_FIR_LL_args,
    1, Iclass_AE_MULFD32X16X2_FIR_LL_stateArgs, 0, 0 },
  { 5, Iclass_AE_MULAFD24X2_FIR_H_args,
    1, Iclass_AE_MULAFD24X2_FIR_H_stateArgs, 0, 0 },
  { 5, Iclass_AE_MULAFD24X2_FIR_L_args,
    1, Iclass_AE_MULAFD24X2_FIR_L_stateArgs, 0, 0 },
  { 5, Iclass_AE_MULAFD32X16X2_FIR_HH_args,
    1, Iclass_AE_MULAFD32X16X2_FIR_HH_stateArgs, 0, 0 },
  { 5, Iclass_AE_MULAFD32X16X2_FIR_HL_args,
    1, Iclass_AE_MULAFD32X16X2_FIR_HL_stateArgs, 0, 0 },
  { 5, Iclass_AE_MULAFD32X16X2_FIR_LH_args,
    1, Iclass_AE_MULAFD32X16X2_FIR_LH_stateArgs, 0, 0 },
  { 5, Iclass_AE_MULAFD32X16X2_FIR_LL_args,
    1, Iclass_AE_MULAFD32X16X2_FIR_LL_stateArgs, 0, 0 },
  { 2, Iclass_AE_DIV64D32_H_args,
    1, Iclass_AE_DIV64D32_H_stateArgs, 0, 0 },
  { 2, Iclass_AE_DIV64D32_L_args,
    1, Iclass_AE_DIV64D32_L_stateArgs, 0, 0 },
  { 2, Iclass_AE_SHA32_args,
    0, 0, 0, 0 },
  { 3, Iclass_AE_VLDL32T_args,
    5, Iclass_AE_VLDL32T_stateArgs, 0, 0 },
  { 3, Iclass_AE_VLDL16T_args,
    5, Iclass_AE_VLDL16T_stateArgs, 0, 0 },
  { 1, Iclass_AE_VLDL16C_args,
    8, Iclass_AE_VLDL16C_stateArgs, 0, 0 },
  { 1, Iclass_AE_VLDL16C_IP_args,
    8, Iclass_AE_VLDL16C_IP_stateArgs, 0, 0 },
  { 1, Iclass_AE_VLDL16C_IC_args,
    11, Iclass_AE_VLDL16C_IC_stateArgs, 0, 0 },
  { 1, Iclass_AE_VLDSHT_args,
    6, Iclass_AE_VLDSHT_stateArgs, 0, 0 },
  { 2, Iclass_AE_LB_args,
    3, Iclass_AE_LB_stateArgs, 0, 0 },
  { 2, Iclass_AE_LBI_args,
    3, Iclass_AE_LBI_stateArgs, 0, 0 },
  { 3, Iclass_AE_LBK_args,
    3, Iclass_AE_LBK_stateArgs, 0, 0 },
  { 3, Iclass_AE_LBKI_args,
    3, Iclass_AE_LBKI_stateArgs, 0, 0 },
  { 2, Iclass_AE_LBS_args,
    3, Iclass_AE_LBS_stateArgs, 0, 0 },
  { 2, Iclass_AE_LBSI_args,
    3, Iclass_AE_LBSI_stateArgs, 0, 0 },
  { 2, Iclass_AE_DB_args,
    3, Iclass_AE_DB_stateArgs, 0, 0 },
  { 2, Iclass_AE_DBI_args,
    3, Iclass_AE_DBI_stateArgs, 0, 0 },
  { 2, Iclass_AE_DB_IC_args,
    6, Iclass_AE_DB_IC_stateArgs, 0, 0 },
  { 2, Iclass_AE_DBI_IC_args,
    6, Iclass_AE_DBI_IC_stateArgs, 0, 0 },
  { 2, Iclass_AE_DB_IP_args,
    3, Iclass_AE_DB_IP_stateArgs, 0, 0 },
  { 2, Iclass_AE_DBI_IP_args,
    3, Iclass_AE_DBI_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_VLEL32T_args,
    3, Iclass_AE_VLEL32T_stateArgs, 0, 0 },
  { 3, Iclass_AE_VLEL16T_args,
    3, Iclass_AE_VLEL16T_stateArgs, 0, 0 },
  { 2, Iclass_AE_SB_args,
    4, Iclass_AE_SB_stateArgs, 0, 0 },
  { 3, Iclass_AE_SBI_args,
    3, Iclass_AE_SBI_stateArgs, 0, 0 },
  { 1, Iclass_AE_VLES16C_args,
    5, Iclass_AE_VLES16C_stateArgs, 0, 0 },
  { 1, Iclass_AE_SBF_args,
    3, Iclass_AE_SBF_stateArgs, 0, 0 },
  { 2, Iclass_AE_SB_IC_args,
    7, Iclass_AE_SB_IC_stateArgs, 0, 0 },
  { 3, Iclass_AE_SBI_IC_args,
    6, Iclass_AE_SBI_IC_stateArgs, 0, 0 },
  { 1, Iclass_AE_VLES16C_IC_args,
    8, Iclass_AE_VLES16C_IC_stateArgs, 0, 0 },
  { 1, Iclass_AE_SBF_IC_args,
    6, Iclass_AE_SBF_IC_stateArgs, 0, 0 },
  { 2, Iclass_AE_SB_IP_args,
    4, Iclass_AE_SB_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_SBI_IP_args,
    3, Iclass_AE_SBI_IP_stateArgs, 0, 0 },
  { 1, Iclass_AE_VLES16C_IP_args,
    5, Iclass_AE_VLES16C_IP_stateArgs, 0, 0 },
  { 1, Iclass_AE_SBF_IP_args,
    3, Iclass_AE_SBF_IP_stateArgs, 0, 0 },
  { 3, Iclass_AE_SEXT32_args,
    1, Iclass_AE_SEXT32_stateArgs, 0, 0 },
  { 3, Iclass_LSI_args,
    1, Iclass_LSI_stateArgs, 0, 0 },
  { 3, Iclass_LSIP_args,
    1, Iclass_LSIP_stateArgs, 0, 0 },
  { 3, Iclass_LSX_args,
    1, Iclass_LSX_stateArgs, 0, 0 },
  { 3, Iclass_LSXP_args,
    1, Iclass_LSXP_stateArgs, 0, 0 },
  { 3, Iclass_SSI_args,
    1, Iclass_SSI_stateArgs, 0, 0 },
  { 3, Iclass_SSIP_args,
    1, Iclass_SSIP_stateArgs, 0, 0 },
  { 3, Iclass_SSX_args,
    1, Iclass_SSX_stateArgs, 0, 0 },
  { 3, Iclass_SSXP_args,
    1, Iclass_SSXP_stateArgs, 0, 0 },
  { 2, Iclass_ABS_S_args,
    1, Iclass_ABS_S_stateArgs, 0, 0 },
  { 2, Iclass_NEG_S_args,
    1, Iclass_NEG_S_stateArgs, 0, 0 },
  { 2, Iclass_MOV_S_args,
    1, Iclass_MOV_S_stateArgs, 0, 0 },
  { 3, Iclass_MOVEQZ_S_args,
    1, Iclass_MOVEQZ_S_stateArgs, 0, 0 },
  { 3, Iclass_MOVNEZ_S_args,
    1, Iclass_MOVNEZ_S_stateArgs, 0, 0 },
  { 3, Iclass_MOVLTZ_S_args,
    1, Iclass_MOVLTZ_S_stateArgs, 0, 0 },
  { 3, Iclass_MOVGEZ_S_args,
    1, Iclass_MOVGEZ_S_stateArgs, 0, 0 },
  { 3, Iclass_MOVF_S_args,
    1, Iclass_MOVF_S_stateArgs, 0, 0 },
  { 3, Iclass_MOVT_S_args,
    1, Iclass_MOVT_S_stateArgs, 0, 0 },
  { 2, Iclass_WFR_args,
    1, Iclass_WFR_stateArgs, 0, 0 },
  { 2, Iclass_RFR_args,
    1, Iclass_RFR_stateArgs, 0, 0 },
  { 3, Iclass_ROUND_S_args,
    3, Iclass_ROUND_S_stateArgs, 0, 0 },
  { 3, Iclass_CEIL_S_args,
    3, Iclass_CEIL_S_stateArgs, 0, 0 },
  { 3, Iclass_FLOOR_S_args,
    3, Iclass_FLOOR_S_stateArgs, 0, 0 },
  { 3, Iclass_TRUNC_S_args,
    3, Iclass_TRUNC_S_stateArgs, 0, 0 },
  { 3, Iclass_UTRUNC_S_args,
    3, Iclass_UTRUNC_S_stateArgs, 0, 0 },
  { 3, Iclass_FLOAT_S_args,
    3, Iclass_FLOAT_S_stateArgs, 0, 0 },
  { 3, Iclass_UFLOAT_S_args,
    3, Iclass_UFLOAT_S_stateArgs, 0, 0 },
  { 3, Iclass_UN_S_args,
    2, Iclass_UN_S_stateArgs, 0, 0 },
  { 3, Iclass_ULT_S_args,
    2, Iclass_ULT_S_stateArgs, 0, 0 },
  { 3, Iclass_ULE_S_args,
    2, Iclass_ULE_S_stateArgs, 0, 0 },
  { 3, Iclass_UEQ_S_args,
    2, Iclass_UEQ_S_stateArgs, 0, 0 },
  { 3, Iclass_OLT_S_args,
    2, Iclass_OLT_S_stateArgs, 0, 0 },
  { 3, Iclass_OLE_S_args,
    2, Iclass_OLE_S_stateArgs, 0, 0 },
  { 3, Iclass_OEQ_S_args,
    2, Iclass_OEQ_S_stateArgs, 0, 0 },
  { 3, Iclass_ADD_S_args,
    6, Iclass_ADD_S_stateArgs, 0, 0 },
  { 3, Iclass_SUB_S_args,
    6, Iclass_SUB_S_stateArgs, 0, 0 },
  { 3, Iclass_MUL_S_args,
    6, Iclass_MUL_S_stateArgs, 0, 0 },
  { 3, Iclass_MADD_S_args,
    6, Iclass_MADD_S_stateArgs, 0, 0 },
  { 3, Iclass_MSUB_S_args,
    6, Iclass_MSUB_S_stateArgs, 0, 0 },
  { 2, Iclass_SQRT0_S_args,
    1, Iclass_SQRT0_S_stateArgs, 0, 0 },
  { 2, Iclass_DIV0_S_args,
    1, Iclass_DIV0_S_stateArgs, 0, 0 },
  { 2, Iclass_RECIP0_S_args,
    3, Iclass_RECIP0_S_stateArgs, 0, 0 },
  { 2, Iclass_RSQRT0_S_args,
    3, Iclass_RSQRT0_S_stateArgs, 0, 0 },
  { 3, Iclass_MADDN_S_args,
    1, Iclass_MADDN_S_stateArgs, 0, 0 },
  { 3, Iclass_DIVN_S_args,
    5, Iclass_DIVN_S_stateArgs, 0, 0 },
  { 2, Iclass_CONST_S_args,
    1, Iclass_CONST_S_stateArgs, 0, 0 },
  { 2, Iclass_NEXP01_S_args,
    1, Iclass_NEXP01_S_stateArgs, 0, 0 },
  { 2, Iclass_ADDEXP_S_args,
    1, Iclass_ADDEXP_S_stateArgs, 0, 0 },
  { 2, Iclass_ADDEXPM_S_args,
    1, Iclass_ADDEXPM_S_stateArgs, 0, 0 },
  { 2, Iclass_MKDADJ_S_args,
    3, Iclass_MKDADJ_S_stateArgs, 0, 0 },
  { 2, Iclass_MKSADJ_S_args,
    2, Iclass_MKSADJ_S_stateArgs, 0, 0 }
};

enum xtensa_iclass_id {
  ICLASS_xt_iclass_excw,
  ICLASS_xt_iclass_rfe,
  ICLASS_xt_iclass_rfde,
  ICLASS_xt_iclass_syscall,
  ICLASS_xt_iclass_call12,
  ICLASS_xt_iclass_call8,
  ICLASS_xt_iclass_call4,
  ICLASS_xt_iclass_callx12,
  ICLASS_xt_iclass_callx8,
  ICLASS_xt_iclass_callx4,
  ICLASS_xt_iclass_entry,
  ICLASS_xt_iclass_movsp,
  ICLASS_xt_iclass_rotw,
  ICLASS_xt_iclass_retw,
  ICLASS_xt_iclass_rfwou,
  ICLASS_xt_iclass_l32e,
  ICLASS_xt_iclass_s32e,
  ICLASS_xt_iclass_rsr_windowbase,
  ICLASS_xt_iclass_wsr_windowbase,
  ICLASS_xt_iclass_xsr_windowbase,
  ICLASS_xt_iclass_rsr_windowstart,
  ICLASS_xt_iclass_wsr_windowstart,
  ICLASS_xt_iclass_xsr_windowstart,
  ICLASS_xt_iclass_rfme,
  ICLASS_xt_iclass_rsr_mesr,
  ICLASS_xt_iclass_wsr_mesr,
  ICLASS_xt_iclass_xsr_mesr,
  ICLASS_xt_iclass_rsr_mecr,
  ICLASS_xt_iclass_wsr_mecr,
  ICLASS_xt_iclass_xsr_mecr,
  ICLASS_xt_iclass_rsr_mepc,
  ICLASS_xt_iclass_wsr_mepc,
  ICLASS_xt_iclass_xsr_mepc,
  ICLASS_xt_iclass_rsr_meps,
  ICLASS_xt_iclass_wsr_meps,
  ICLASS_xt_iclass_xsr_meps,
  ICLASS_xt_iclass_rsr_mesave,
  ICLASS_xt_iclass_wsr_mesave,
  ICLASS_xt_iclass_xsr_mesave,
  ICLASS_xt_iclass_rsr_mevaddr,
  ICLASS_xt_iclass_wsr_mevaddr,
  ICLASS_xt_iclass_xsr_mevaddr,
  ICLASS_xt_iclass_add_n,
  ICLASS_xt_iclass_addi_n,
  ICLASS_xt_iclass_bz6,
  ICLASS_xt_iclass_ill_n,
  ICLASS_xt_iclass_loadi4,
  ICLASS_xt_iclass_mov_n,
  ICLASS_xt_iclass_movi_n,
  ICLASS_xt_iclass_nopn,
  ICLASS_xt_iclass_retn,
  ICLASS_xt_iclass_storei4,
  ICLASS_rur_threadptr,
  ICLASS_wur_threadptr,
  ICLASS_xt_iclass_addi,
  ICLASS_xt_iclass_addmi,
  ICLASS_xt_iclass_addsub,
  ICLASS_xt_iclass_bit,
  ICLASS_xt_iclass_bsi8,
  ICLASS_xt_iclass_bsi8b,
  ICLASS_xt_iclass_bsi8u,
  ICLASS_xt_iclass_bst8,
  ICLASS_xt_iclass_bsz12,
  ICLASS_xt_iclass_call0,
  ICLASS_xt_iclass_callx0,
  ICLASS_xt_iclass_exti,
  ICLASS_xt_iclass_ill,
  ICLASS_xt_iclass_jump,
  ICLASS_xt_iclass_jumpx,
  ICLASS_xt_iclass_l16ui,
  ICLASS_xt_iclass_l16si,
  ICLASS_xt_iclass_l32i,
  ICLASS_xt_iclass_l32r,
  ICLASS_xt_iclass_l8i,
  ICLASS_xt_iclass_loop,
  ICLASS_xt_iclass_loopz,
  ICLASS_xt_iclass_movi,
  ICLASS_xt_iclass_movz,
  ICLASS_xt_iclass_neg,
  ICLASS_xt_iclass_nop,
  ICLASS_xt_iclass_return,
  ICLASS_xt_iclass_simcall,
  ICLASS_xt_iclass_s16i,
  ICLASS_xt_iclass_s32i,
  ICLASS_xt_iclass_s32nb,
  ICLASS_xt_iclass_s8i,
  ICLASS_xt_iclass_sar,
  ICLASS_xt_iclass_sari,
  ICLASS_xt_iclass_shifts,
  ICLASS_xt_iclass_shiftst,
  ICLASS_xt_iclass_shiftt,
  ICLASS_xt_iclass_slli,
  ICLASS_xt_iclass_srai,
  ICLASS_xt_iclass_srli,
  ICLASS_xt_iclass_memw,
  ICLASS_xt_iclass_extw,
  ICLASS_xt_iclass_isync,
  ICLASS_xt_iclass_sync,
  ICLASS_xt_iclass_rsil,
  ICLASS_xt_iclass_rsr_lend,
  ICLASS_xt_iclass_wsr_lend,
  ICLASS_xt_iclass_xsr_lend,
  ICLASS_xt_iclass_rsr_lcount,
  ICLASS_xt_iclass_wsr_lcount,
  ICLASS_xt_iclass_xsr_lcount,
  ICLASS_xt_iclass_rsr_lbeg,
  ICLASS_xt_iclass_wsr_lbeg,
  ICLASS_xt_iclass_xsr_lbeg,
  ICLASS_xt_iclass_rsr_sar,
  ICLASS_xt_iclass_wsr_sar,
  ICLASS_xt_iclass_xsr_sar,
  ICLASS_xt_iclass_rsr_memctl,
  ICLASS_xt_iclass_wsr_memctl,
  ICLASS_xt_iclass_xsr_memctl,
  ICLASS_xt_iclass_rsr_litbase,
  ICLASS_xt_iclass_wsr_litbase,
  ICLASS_xt_iclass_xsr_litbase,
  ICLASS_xt_iclass_rsr_configid0,
  ICLASS_xt_iclass_wsr_configid0,
  ICLASS_xt_iclass_rsr_configid1,
  ICLASS_xt_iclass_rsr_243,
  ICLASS_xt_iclass_rsr_ps,
  ICLASS_xt_iclass_wsr_ps,
  ICLASS_xt_iclass_xsr_ps,
  ICLASS_xt_iclass_rsr_epc1,
  ICLASS_xt_iclass_wsr_epc1,
  ICLASS_xt_iclass_xsr_epc1,
  ICLASS_xt_iclass_rsr_excsave1,
  ICLASS_xt_iclass_wsr_excsave1,
  ICLASS_xt_iclass_xsr_excsave1,
  ICLASS_xt_iclass_rsr_epc2,
  ICLASS_xt_iclass_wsr_epc2,
  ICLASS_xt_iclass_xsr_epc2,
  ICLASS_xt_iclass_rsr_excsave2,
  ICLASS_xt_iclass_wsr_excsave2,
  ICLASS_xt_iclass_xsr_excsave2,
  ICLASS_xt_iclass_rsr_epc3,
  ICLASS_xt_iclass_wsr_epc3,
  ICLASS_xt_iclass_xsr_epc3,
  ICLASS_xt_iclass_rsr_excsave3,
  ICLASS_xt_iclass_wsr_excsave3,
  ICLASS_xt_iclass_xsr_excsave3,
  ICLASS_xt_iclass_rsr_epc4,
  ICLASS_xt_iclass_wsr_epc4,
  ICLASS_xt_iclass_xsr_epc4,
  ICLASS_xt_iclass_rsr_excsave4,
  ICLASS_xt_iclass_wsr_excsave4,
  ICLASS_xt_iclass_xsr_excsave4,
  ICLASS_xt_iclass_rsr_epc5,
  ICLASS_xt_iclass_wsr_epc5,
  ICLASS_xt_iclass_xsr_epc5,
  ICLASS_xt_iclass_rsr_excsave5,
  ICLASS_xt_iclass_wsr_excsave5,
  ICLASS_xt_iclass_xsr_excsave5,
  ICLASS_xt_iclass_rsr_epc6,
  ICLASS_xt_iclass_wsr_epc6,
  ICLASS_xt_iclass_xsr_epc6,
  ICLASS_xt_iclass_rsr_excsave6,
  ICLASS_xt_iclass_wsr_excsave6,
  ICLASS_xt_iclass_xsr_excsave6,
  ICLASS_xt_iclass_rsr_epc7,
  ICLASS_xt_iclass_wsr_epc7,
  ICLASS_xt_iclass_xsr_epc7,
  ICLASS_xt_iclass_rsr_excsave7,
  ICLASS_xt_iclass_wsr_excsave7,
  ICLASS_xt_iclass_xsr_excsave7,
  ICLASS_xt_iclass_rsr_eps2,
  ICLASS_xt_iclass_wsr_eps2,
  ICLASS_xt_iclass_xsr_eps2,
  ICLASS_xt_iclass_rsr_eps3,
  ICLASS_xt_iclass_wsr_eps3,
  ICLASS_xt_iclass_xsr_eps3,
  ICLASS_xt_iclass_rsr_eps4,
  ICLASS_xt_iclass_wsr_eps4,
  ICLASS_xt_iclass_xsr_eps4,
  ICLASS_xt_iclass_rsr_eps5,
  ICLASS_xt_iclass_wsr_eps5,
  ICLASS_xt_iclass_xsr_eps5,
  ICLASS_xt_iclass_rsr_eps6,
  ICLASS_xt_iclass_wsr_eps6,
  ICLASS_xt_iclass_xsr_eps6,
  ICLASS_xt_iclass_rsr_eps7,
  ICLASS_xt_iclass_wsr_eps7,
  ICLASS_xt_iclass_xsr_eps7,
  ICLASS_xt_iclass_rsr_excvaddr,
  ICLASS_xt_iclass_wsr_excvaddr,
  ICLASS_xt_iclass_xsr_excvaddr,
  ICLASS_xt_iclass_rsr_depc,
  ICLASS_xt_iclass_wsr_depc,
  ICLASS_xt_iclass_xsr_depc,
  ICLASS_xt_iclass_rsr_exccause,
  ICLASS_xt_iclass_wsr_exccause,
  ICLASS_xt_iclass_xsr_exccause,
  ICLASS_xt_iclass_rsr_prid,
  ICLASS_xt_iclass_rsr_vecbase,
  ICLASS_xt_iclass_wsr_vecbase,
  ICLASS_xt_iclass_xsr_vecbase,
  ICLASS_xt_mul16,
  ICLASS_xt_mul32,
  ICLASS_xt_mul32h,
  ICLASS_xt_iclass_rfi,
  ICLASS_xt_iclass_wait,
  ICLASS_xt_iclass_rsr_interrupt,
  ICLASS_xt_iclass_wsr_intset,
  ICLASS_xt_iclass_wsr_intclear,
  ICLASS_xt_iclass_rsr_intenable,
  ICLASS_xt_iclass_wsr_intenable,
  ICLASS_xt_iclass_xsr_intenable,
  ICLASS_xt_iclass_break,
  ICLASS_xt_iclass_break_n,
  ICLASS_xt_iclass_rsr_dbreaka0,
  ICLASS_xt_iclass_wsr_dbreaka0,
  ICLASS_xt_iclass_xsr_dbreaka0,
  ICLASS_xt_iclass_rsr_dbreakc0,
  ICLASS_xt_iclass_wsr_dbreakc0,
  ICLASS_xt_iclass_xsr_dbreakc0,
  ICLASS_xt_iclass_rsr_dbreaka1,
  ICLASS_xt_iclass_wsr_dbreaka1,
  ICLASS_xt_iclass_xsr_dbreaka1,
  ICLASS_xt_iclass_rsr_dbreakc1,
  ICLASS_xt_iclass_wsr_dbreakc1,
  ICLASS_xt_iclass_xsr_dbreakc1,
  ICLASS_xt_iclass_rsr_ibreaka0,
  ICLASS_xt_iclass_wsr_ibreaka0,
  ICLASS_xt_iclass_xsr_ibreaka0,
  ICLASS_xt_iclass_rsr_ibreaka1,
  ICLASS_xt_iclass_wsr_ibreaka1,
  ICLASS_xt_iclass_xsr_ibreaka1,
  ICLASS_xt_iclass_rsr_ibreakenable,
  ICLASS_xt_iclass_wsr_ibreakenable,
  ICLASS_xt_iclass_xsr_ibreakenable,
  ICLASS_xt_iclass_rsr_debugcause,
  ICLASS_xt_iclass_wsr_debugcause,
  ICLASS_xt_iclass_xsr_debugcause,
  ICLASS_xt_iclass_rsr_icount,
  ICLASS_xt_iclass_wsr_icount,
  ICLASS_xt_iclass_xsr_icount,
  ICLASS_xt_iclass_rsr_icountlevel,
  ICLASS_xt_iclass_wsr_icountlevel,
  ICLASS_xt_iclass_xsr_icountlevel,
  ICLASS_xt_iclass_rsr_ddr,
  ICLASS_xt_iclass_wsr_ddr,
  ICLASS_xt_iclass_xsr_ddr,
  ICLASS_xt_iclass_lddr32_p,
  ICLASS_xt_iclass_sddr32_p,
  ICLASS_xt_iclass_rfdo,
  ICLASS_xt_iclass_rfdd,
  ICLASS_xt_iclass_wsr_mmid,
  ICLASS_xt_iclass_bbool1,
  ICLASS_xt_iclass_bbool4,
  ICLASS_xt_iclass_bbool8,
  ICLASS_xt_iclass_bbranch,
  ICLASS_xt_iclass_bmove,
  ICLASS_xt_iclass_RSR_BR,
  ICLASS_xt_iclass_WSR_BR,
  ICLASS_xt_iclass_XSR_BR,
  ICLASS_xt_iclass_rsr_ccount,
  ICLASS_xt_iclass_wsr_ccount,
  ICLASS_xt_iclass_xsr_ccount,
  ICLASS_xt_iclass_rsr_ccompare0,
  ICLASS_xt_iclass_wsr_ccompare0,
  ICLASS_xt_iclass_xsr_ccompare0,
  ICLASS_xt_iclass_rsr_ccompare1,
  ICLASS_xt_iclass_wsr_ccompare1,
  ICLASS_xt_iclass_xsr_ccompare1,
  ICLASS_xt_iclass_rsr_ccompare2,
  ICLASS_xt_iclass_wsr_ccompare2,
  ICLASS_xt_iclass_xsr_ccompare2,
  ICLASS_xt_iclass_icache,
  ICLASS_xt_iclass_icache_lock,
  ICLASS_xt_iclass_icache_inv,
  ICLASS_xt_iclass_licx,
  ICLASS_xt_iclass_sicx,
  ICLASS_xt_iclass_dcache,
  ICLASS_xt_iclass_dcache_dyn,
  ICLASS_xt_iclass_dcache_ind,
  ICLASS_xt_iclass_dcache_inv,
  ICLASS_xt_iclass_dpf,
  ICLASS_xt_iclass_dcache_lock,
  ICLASS_xt_iclass_sdct,
  ICLASS_xt_iclass_ldct,
  ICLASS_xt_iclass_rsr_prefctl,
  ICLASS_xt_iclass_wsr_prefctl,
  ICLASS_xt_iclass_xsr_prefctl,
  ICLASS_xt_iclass_idtlb,
  ICLASS_xt_iclass_rdtlb,
  ICLASS_xt_iclass_wdtlb,
  ICLASS_xt_iclass_iitlb,
  ICLASS_xt_iclass_ritlb,
  ICLASS_xt_iclass_witlb,
  ICLASS_xt_iclass_rsr_cpenable,
  ICLASS_xt_iclass_wsr_cpenable,
  ICLASS_xt_iclass_xsr_cpenable,
  ICLASS_xt_iclass_clamp,
  ICLASS_xt_iclass_minmax,
  ICLASS_xt_iclass_nsa,
  ICLASS_xt_iclass_sx,
  ICLASS_xt_iclass_l32ai,
  ICLASS_xt_iclass_s32ri,
  ICLASS_xt_iclass_s32c1i,
  ICLASS_xt_iclass_rsr_scompare1,
  ICLASS_xt_iclass_wsr_scompare1,
  ICLASS_xt_iclass_xsr_scompare1,
  ICLASS_xt_iclass_rsr_atomctl,
  ICLASS_xt_iclass_wsr_atomctl,
  ICLASS_xt_iclass_xsr_atomctl,
  ICLASS_xt_iclass_div,
  ICLASS_xt_iclass_rer,
  ICLASS_xt_iclass_wer,
  ICLASS_xt_iclass_wb18_0,
  ICLASS_xt_iclass_wb18_1,
  ICLASS_xt_iclass_wb18_2,
  ICLASS_xt_iclass_wb18_3,
  ICLASS_xt_iclass_wb18_4,
  ICLASS_rur_ae_ovf_sar,
  ICLASS_wur_ae_ovf_sar,
  ICLASS_rur_ae_bithead,
  ICLASS_wur_ae_bithead,
  ICLASS_rur_ae_ts_fts_bu_bp,
  ICLASS_wur_ae_ts_fts_bu_bp,
  ICLASS_rur_ae_cw_sd_no,
  ICLASS_wur_ae_cw_sd_no,
  ICLASS_rur_ae_cbegin0,
  ICLASS_wur_ae_cbegin0,
  ICLASS_rur_ae_cend0,
  ICLASS_wur_ae_cend0,
  ICLASS_rur_fcr,
  ICLASS_wur_fcr,
  ICLASS_rur_fsr,
  ICLASS_wur_fsr,
  ICLASS_RUR_AE_OVERFLOW,
  ICLASS_WUR_AE_OVERFLOW,
  ICLASS_RUR_AE_SAR,
  ICLASS_WUR_AE_SAR,
  ICLASS_RUR_AE_BITPTR,
  ICLASS_WUR_AE_BITPTR,
  ICLASS_RUR_AE_BITSUSED,
  ICLASS_WUR_AE_BITSUSED,
  ICLASS_RUR_AE_TABLESIZE,
  ICLASS_WUR_AE_TABLESIZE,
  ICLASS_RUR_AE_FIRST_TS,
  ICLASS_WUR_AE_FIRST_TS,
  ICLASS_RUR_AE_NEXTOFFSET,
  ICLASS_WUR_AE_NEXTOFFSET,
  ICLASS_RUR_AE_SEARCHDONE,
  ICLASS_WUR_AE_SEARCHDONE,
  ICLASS_RUR_AE_CWRAP,
  ICLASS_WUR_AE_CWRAP,
  ICLASS_AE_L16M_XC,
  ICLASS_AE_L16M_I,
  ICLASS_AE_L16M_IU,
  ICLASS_AE_L16M_X,
  ICLASS_AE_L16M_XU,
  ICLASS_AE_L16_XC,
  ICLASS_AE_L16_I,
  ICLASS_AE_L16_IP,
  ICLASS_AE_L16_X,
  ICLASS_AE_L16_XP,
  ICLASS_AE_L32F24_XC,
  ICLASS_AE_L32F24_I,
  ICLASS_AE_L32F24_IP,
  ICLASS_AE_L32F24_X,
  ICLASS_AE_L32F24_XP,
  ICLASS_AE_L32_XC,
  ICLASS_AE_L32_I,
  ICLASS_AE_L32_IP,
  ICLASS_AE_L32_X,
  ICLASS_AE_L32_XP,
  ICLASS_AE_L32M_XC,
  ICLASS_AE_L32M_I,
  ICLASS_AE_L32M_IU,
  ICLASS_AE_L32M_X,
  ICLASS_AE_L32M_XU,
  ICLASS_AE_L16X2M_XC,
  ICLASS_AE_L16X2M_I,
  ICLASS_AE_L16X2M_IU,
  ICLASS_AE_L16X2M_X,
  ICLASS_AE_L16X2M_XU,
  ICLASS_AE_L32X2F24_XC,
  ICLASS_AE_L32X2F24_I,
  ICLASS_AE_L32X2F24_IP,
  ICLASS_AE_L32X2F24_RIP,
  ICLASS_AE_L32X2F24_RIC,
  ICLASS_AE_L32X2F24_X,
  ICLASS_AE_L32X2F24_XP,
  ICLASS_AE_L32X2_XC,
  ICLASS_AE_L32X2_I,
  ICLASS_AE_L32X2_IP,
  ICLASS_AE_L32X2_RIP,
  ICLASS_AE_L32X2_RIC,
  ICLASS_AE_L32X2_X,
  ICLASS_AE_L32X2_XP,
  ICLASS_AE_L16X4_XC,
  ICLASS_AE_L16X4_I,
  ICLASS_AE_L16X4_IP,
  ICLASS_AE_L16X4_RIP,
  ICLASS_AE_L16X4_RIC,
  ICLASS_AE_L16X4_X,
  ICLASS_AE_L16X4_XP,
  ICLASS_AE_L64_XC,
  ICLASS_AE_L64_I,
  ICLASS_AE_L64_IP,
  ICLASS_AE_L64_X,
  ICLASS_AE_L64_XP,
  ICLASS_AE_S16X2M_XC,
  ICLASS_AE_S16X2M_I,
  ICLASS_AE_S16X2M_IU,
  ICLASS_AE_S16X2M_X,
  ICLASS_AE_S16X2M_XU,
  ICLASS_AE_S32X2F24_XC,
  ICLASS_AE_S32X2F24_I,
  ICLASS_AE_S32X2F24_IP,
  ICLASS_AE_S32X2F24_RIP,
  ICLASS_AE_S32X2F24_RIC,
  ICLASS_AE_S32X2F24_X,
  ICLASS_AE_S32X2F24_XP,
  ICLASS_AE_S32X2_XC,
  ICLASS_AE_S32X2_I,
  ICLASS_AE_S32X2_IP,
  ICLASS_AE_S32X2_RIP,
  ICLASS_AE_S32X2_RIC,
  ICLASS_AE_S32X2_X,
  ICLASS_AE_S32X2_XP,
  ICLASS_AE_S16X4_XC,
  ICLASS_AE_S16X4_I,
  ICLASS_AE_S16X4_IP,
  ICLASS_AE_S16X4_RIP,
  ICLASS_AE_S16X4_RIC,
  ICLASS_AE_S16X4_X,
  ICLASS_AE_S16X4_XP,
  ICLASS_AE_S16M_L_XC,
  ICLASS_AE_S16M_L_I,
  ICLASS_AE_S16M_L_IU,
  ICLASS_AE_S16M_L_X,
  ICLASS_AE_S16M_L_XU,
  ICLASS_AE_S32F24_L_XC,
  ICLASS_AE_S32F24_L_I,
  ICLASS_AE_S32F24_L_IP,
  ICLASS_AE_S32F24_L_X,
  ICLASS_AE_S32F24_L_XP,
  ICLASS_AE_S32_L_XC,
  ICLASS_AE_S32_L_I,
  ICLASS_AE_S32_L_IP,
  ICLASS_AE_S32_L_X,
  ICLASS_AE_S32_L_XP,
  ICLASS_AE_S16_0_XC,
  ICLASS_AE_S16_0_I,
  ICLASS_AE_S16_0_IP,
  ICLASS_AE_S16_0_X,
  ICLASS_AE_S16_0_XP,
  ICLASS_AE_S64_XC,
  ICLASS_AE_S64_I,
  ICLASS_AE_S64_IP,
  ICLASS_AE_S64_X,
  ICLASS_AE_S64_XP,
  ICLASS_AE_S32M_XC,
  ICLASS_AE_S32M_I,
  ICLASS_AE_S32M_IU,
  ICLASS_AE_S32M_X,
  ICLASS_AE_S32M_XU,
  ICLASS_AE_ZALIGN64,
  ICLASS_AE_LALIGN64_I,
  ICLASS_AE_SALIGN64_I,
  ICLASS_AE_MOVALIGN,
  ICLASS_AE_LA64_PP,
  ICLASS_AE_LA24POS_PC,
  ICLASS_AE_LA24X2POS_PC,
  ICLASS_AE_LA32X2POS_PC,
  ICLASS_AE_LA16X4POS_PC,
  ICLASS_AE_LA24NEG_PC,
  ICLASS_AE_LA24X2NEG_PC,
  ICLASS_AE_LA32X2NEG_PC,
  ICLASS_AE_LA16X4NEG_PC,
  ICLASS_AE_SA64POS_FP,
  ICLASS_AE_SA64NEG_FP,
  ICLASS_AE_LA32X2_IC,
  ICLASS_AE_LA32X2_IP,
  ICLASS_AE_LA32X2_RIP,
  ICLASS_AE_LA32X2_RIC,
  ICLASS_AE_LA16X4_IC,
  ICLASS_AE_LA16X4_IP,
  ICLASS_AE_LA16X4_RIP,
  ICLASS_AE_LA16X4_RIC,
  ICLASS_AE_LA32X2F24_IC,
  ICLASS_AE_LA32X2F24_IP,
  ICLASS_AE_LA32X2F24_RIP,
  ICLASS_AE_LA32X2F24_RIC,
  ICLASS_AE_LA24_IC,
  ICLASS_AE_LA24_IP,
  ICLASS_AE_LA24_RIP,
  ICLASS_AE_LA24_RIC,
  ICLASS_AE_LA24X2_IC,
  ICLASS_AE_LA24X2_IP,
  ICLASS_AE_LA24X2_RIP,
  ICLASS_AE_LA24X2_RIC,
  ICLASS_AE_SA32X2_IC,
  ICLASS_AE_SA32X2_IP,
  ICLASS_AE_SA32X2_RIP,
  ICLASS_AE_SA32X2_RIC,
  ICLASS_AE_SA16X4_IC,
  ICLASS_AE_SA16X4_IP,
  ICLASS_AE_SA16X4_RIP,
  ICLASS_AE_SA16X4_RIC,
  ICLASS_AE_SA32X2F24_IC,
  ICLASS_AE_SA32X2F24_IP,
  ICLASS_AE_SA32X2F24_RIP,
  ICLASS_AE_SA32X2F24_RIC,
  ICLASS_AE_SA24_L_IC,
  ICLASS_AE_SA24_L_IP,
  ICLASS_AE_SA24_L_RIP,
  ICLASS_AE_SA24_L_RIC,
  ICLASS_AE_SA24X2_IC,
  ICLASS_AE_SA24X2_IP,
  ICLASS_AE_SA24X2_RIP,
  ICLASS_AE_SA24X2_RIC,
  ICLASS_AE_S32RA64S_I,
  ICLASS_AE_S32RA64S_IP,
  ICLASS_AE_S32RA64S_X,
  ICLASS_AE_S32RA64S_XP,
  ICLASS_AE_S32RA64S_XC,
  ICLASS_AE_S24RA64S_I,
  ICLASS_AE_S24RA64S_IP,
  ICLASS_AE_S24RA64S_X,
  ICLASS_AE_S24RA64S_XP,
  ICLASS_AE_S24RA64S_XC,
  ICLASS_AE_S32X2RA64S_IP,
  ICLASS_AE_S24X2RA64S_IP,
  ICLASS_AE_ADDBRBA32,
  ICLASS_AE_SEL16I,
  ICLASS_AE_SEL16I_N,
  ICLASS_AE_SHORTSWAP,
  ICLASS_AE_MOVT16X4,
  ICLASS_AE_MOVF16X4,
  ICLASS_AE_MOVT32X2,
  ICLASS_AE_MOVF32X2,
  ICLASS_AE_MOVDA32X2,
  ICLASS_AE_MOVDA32,
  ICLASS_AE_MOVDA16X2,
  ICLASS_AE_MOVDA16,
  ICLASS_AE_MOVI,
  ICLASS_AE_TRUNCP24A32X2,
  ICLASS_AE_SAT16X4,
  ICLASS_AE_CVT32X2F16_32,
  ICLASS_AE_CVT32X2F16_10,
  ICLASS_AE_SEXT32X2D16_32,
  ICLASS_AE_SEXT32X2D16_10,
  ICLASS_AE_CVTA32F24S_L,
  ICLASS_AE_CVTA32F24S_H,
  ICLASS_AE_CVTP24A16X2_LL,
  ICLASS_AE_CVTP24A16X2_LH,
  ICLASS_AE_CVTP24A16X2_HL,
  ICLASS_AE_CVTP24A16X2_HH,
  ICLASS_AE_TRUNCP24Q48X2,
  ICLASS_AE_TRUNCA32X2F64S,
  ICLASS_AE_TRUNCI32X2F64S,
  ICLASS_AE_TRUNCA32F64S_L,
  ICLASS_AE_TRUNCI32F64S_L,
  ICLASS_AE_TRUNCP16,
  ICLASS_AE_ROUND32X2F64SSYM,
  ICLASS_AE_ROUND32X2F64SASYM,
  ICLASS_AE_ROUND32X2F48SSYM,
  ICLASS_AE_ROUND32X2F48SASYM,
  ICLASS_AE_ROUND16X4F32SSYM,
  ICLASS_AE_ROUND16X4F32SASYM,
  ICLASS_AE_ROUND24X2F48SSYM,
  ICLASS_AE_ROUND24X2F48SASYM,
  ICLASS_AE_ROUNDSP16Q48X2SYM,
  ICLASS_AE_ROUNDSP16Q48X2ASYM,
  ICLASS_AE_MINABS32S,
  ICLASS_AE_MAXABS32S,
  ICLASS_AE_ROUNDSP16F24SYM,
  ICLASS_AE_ROUNDSP16F24ASYM,
  ICLASS_AE_MOV,
  ICLASS_AE_MOVT64,
  ICLASS_AE_MOVF64,
  ICLASS_AE_CVTQ56A32S,
  ICLASS_AE_CVT48A32,
  ICLASS_AE_CVT64A32,
  ICLASS_AE_CVTQ56P32S_L,
  ICLASS_AE_CVTQ56P32S_H,
  ICLASS_AE_CVT64F32_H,
  ICLASS_AE_SAT48S,
  ICLASS_AE_SATQ56S,
  ICLASS_AE_SAT24S,
  ICLASS_AE_TRUNCQ32,
  ICLASS_AE_MINABS64S,
  ICLASS_AE_MAXABS64S,
  ICLASS_AE_ROUNDSQ32F48SYM,
  ICLASS_AE_ROUNDSQ32F48ASYM,
  ICLASS_AE_TRUNCA32Q48,
  ICLASS_AE_MOVAD32_L,
  ICLASS_AE_MOVAD32_H,
  ICLASS_AE_MOVAD16_3,
  ICLASS_AE_MOVAD16_2,
  ICLASS_AE_MOVAD16_1,
  ICLASS_AE_MOVAD16_0,
  ICLASS_AE_SRA64_32,
  ICLASS_AE_PKSR32,
  ICLASS_AE_PKSR24,
  ICLASS_AE_TRUNCA16P24S_L,
  ICLASS_AE_TRUNCA16P24S_H,
  ICLASS_AE_ADD32,
  ICLASS_AE_SUB32,
  ICLASS_AE_ADDSUB32,
  ICLASS_AE_SUBADD32,
  ICLASS_AE_ADD16,
  ICLASS_AE_SUB16,
  ICLASS_AE_ADD32_HL_LH,
  ICLASS_AE_NEG32,
  ICLASS_AE_ABS32,
  ICLASS_AE_ADD24S,
  ICLASS_AE_SUB24S,
  ICLASS_AE_ADD32S,
  ICLASS_AE_SUB32S,
  ICLASS_AE_ADDSUB32S,
  ICLASS_AE_SUBADD32S,
  ICLASS_AE_ADD16S,
  ICLASS_AE_SUB16S,
  ICLASS_AE_NEG24S,
  ICLASS_AE_ABS24S,
  ICLASS_AE_NEG32S,
  ICLASS_AE_ABS32S,
  ICLASS_AE_NEG16S,
  ICLASS_AE_ABS16S,
  ICLASS_AE_LT16,
  ICLASS_AE_LE16,
  ICLASS_AE_EQ16,
  ICLASS_AE_LT32,
  ICLASS_AE_LE32,
  ICLASS_AE_EQ32,
  ICLASS_AE_MIN32,
  ICLASS_AE_MAX32,
  ICLASS_AE_ADD64,
  ICLASS_AE_SUB64,
  ICLASS_AE_NEG64,
  ICLASS_AE_ABS64,
  ICLASS_AE_ADDSQ56S,
  ICLASS_AE_SUBSQ56S,
  ICLASS_AE_ADD64S,
  ICLASS_AE_SUB64S,
  ICLASS_AE_NEGSQ56S,
  ICLASS_AE_ABSSQ56S,
  ICLASS_AE_NEG64S,
  ICLASS_AE_ABS64S,
  ICLASS_AE_AND,
  ICLASS_AE_NAND,
  ICLASS_AE_OR,
  ICLASS_AE_XOR,
  ICLASS_AE_SLAI24,
  ICLASS_AE_SRLI24,
  ICLASS_AE_SRAI24,
  ICLASS_AE_SLAS24,
  ICLASS_AE_SRLS24,
  ICLASS_AE_SRAS24,
  ICLASS_AE_SRAI16,
  ICLASS_AE_SRAI16R,
  ICLASS_AE_SLAI32,
  ICLASS_AE_SRLI32,
  ICLASS_AE_SRAI32,
  ICLASS_AE_SRAI32R,
  ICLASS_AE_SLAS32,
  ICLASS_AE_SRLS32,
  ICLASS_AE_SRAS32,
  ICLASS_AE_SLAA32,
  ICLASS_AE_SRLA32,
  ICLASS_AE_SRAA32,
  ICLASS_AE_SLAI16S,
  ICLASS_AE_SLAA16S,
  ICLASS_AE_SRAA16S,
  ICLASS_AE_SRAA16RS,
  ICLASS_AE_SLAI24S,
  ICLASS_AE_SLAS24S,
  ICLASS_AE_SLAI32S,
  ICLASS_AE_SLAS32S,
  ICLASS_AE_SLAA32S,
  ICLASS_AE_SRAA32S,
  ICLASS_AE_SRAA32RS,
  ICLASS_AE_SLASQ56,
  ICLASS_AE_SRLSQ56,
  ICLASS_AE_SRASQ56,
  ICLASS_AE_SLAAQ56,
  ICLASS_AE_SRLAQ56,
  ICLASS_AE_SRAAQ56,
  ICLASS_AE_SLAI64,
  ICLASS_AE_SRLI64,
  ICLASS_AE_SRAI64,
  ICLASS_AE_SLAS64,
  ICLASS_AE_SRLS64,
  ICLASS_AE_SRAS64,
  ICLASS_AE_SLAA64,
  ICLASS_AE_SRLA64,
  ICLASS_AE_SRAA64,
  ICLASS_AE_SLAISQ56S,
  ICLASS_AE_SLASSQ56S,
  ICLASS_AE_SLAASQ56S,
  ICLASS_AE_SLAI64S,
  ICLASS_AE_SLAS64S,
  ICLASS_AE_SLAA64S,
  ICLASS_AE_LT64,
  ICLASS_AE_LE64,
  ICLASS_AE_EQ64,
  ICLASS_AE_MAX64,
  ICLASS_AE_MIN64,
  ICLASS_AE_NSA64,
  ICLASS_AE_NSAZ16_0,
  ICLASS_AE_NSAZ32_L,
  ICLASS_AE_MULS32F48P16S_LL,
  ICLASS_AE_MULF32S_LL,
  ICLASS_AE_MUL32_LL,
  ICLASS_AE_MULS32F48P16S_LL_S2,
  ICLASS_AE_MULF32R_LL,
  ICLASS_AE_MULS32F48P16S_LH,
  ICLASS_AE_MULF32S_LH,
  ICLASS_AE_MUL32_LH,
  ICLASS_AE_MULS32F48P16S_LH_S2,
  ICLASS_AE_MULF32R_LH,
  ICLASS_AE_MULS32F48P16S_HH,
  ICLASS_AE_MULF32S_HH,
  ICLASS_AE_MUL32_HH,
  ICLASS_AE_MULS32F48P16S_HH_S2,
  ICLASS_AE_MULF32R_HH,
  ICLASS_AE_MULF32R_LL_S2,
  ICLASS_AE_MULAS32F48P16S_LL,
  ICLASS_AE_MULAF32S_LL,
  ICLASS_AE_MULA32_LL,
  ICLASS_AE_MULAS32F48P16S_LL_S2,
  ICLASS_AE_MULAF32R_LL,
  ICLASS_AE_MULAS32F48P16S_LH,
  ICLASS_AE_MULAF32S_LH,
  ICLASS_AE_MULA32_LH,
  ICLASS_AE_MULAS32F48P16S_LH_S2,
  ICLASS_AE_MULAF32R_LH,
  ICLASS_AE_MULAS32F48P16S_HH,
  ICLASS_AE_MULAF32S_HH,
  ICLASS_AE_MULA32_HH,
  ICLASS_AE_MULAS32F48P16S_HH_S2,
  ICLASS_AE_MULAF32R_HH,
  ICLASS_AE_MULAF32R_LL_S2,
  ICLASS_AE_MULSS32F48P16S_LL,
  ICLASS_AE_MULSF32S_LL,
  ICLASS_AE_MULS32_LL,
  ICLASS_AE_MULSS32F48P16S_LL_S2,
  ICLASS_AE_MULSF32R_LL,
  ICLASS_AE_MULSS32F48P16S_LH,
  ICLASS_AE_MULSF32S_LH,
  ICLASS_AE_MULS32_LH,
  ICLASS_AE_MULSS32F48P16S_LH_S2,
  ICLASS_AE_MULSF32R_LH,
  ICLASS_AE_MULSS32F48P16S_HH,
  ICLASS_AE_MULSF32S_HH,
  ICLASS_AE_MULS32_HH,
  ICLASS_AE_MULSS32F48P16S_HH_S2,
  ICLASS_AE_MULSF32R_HH,
  ICLASS_AE_MULSF32R_LL_S2,
  ICLASS_AE_MULF32S_LL_S2,
  ICLASS_AE_MULAF32S_LL_S2,
  ICLASS_AE_MUL32_LL_S2,
  ICLASS_AE_MULA32_LL_S2,
  ICLASS_AE_MUL32U_LL,
  ICLASS_AE_MULA32U_LL,
  ICLASS_AE_MULS32U_LL,
  ICLASS_AE_MULF16SS_33,
  ICLASS_AE_MULF16SS_22,
  ICLASS_AE_MULF16SS_32,
  ICLASS_AE_MULF16SS_21,
  ICLASS_AE_MULF16SS_31,
  ICLASS_AE_MULF16SS_30,
  ICLASS_AE_MULF16SS_10,
  ICLASS_AE_MULF16SS_20,
  ICLASS_AE_MULF16SS_11,
  ICLASS_AE_MULF16SS_00,
  ICLASS_AE_MULF16SS_00_S2,
  ICLASS_AE_MULSF16SS_33,
  ICLASS_AE_MULSF16SS_22,
  ICLASS_AE_MULSF16SS_32,
  ICLASS_AE_MULSF16SS_21,
  ICLASS_AE_MULSF16SS_31,
  ICLASS_AE_MULSF16SS_30,
  ICLASS_AE_MULSF16SS_10,
  ICLASS_AE_MULSF16SS_20,
  ICLASS_AE_MULSF16SS_11,
  ICLASS_AE_MULSF16SS_00,
  ICLASS_AE_MULSF16SS_00_S2,
  ICLASS_AE_MULAF16SS_33,
  ICLASS_AE_MULAF16SS_22,
  ICLASS_AE_MULAF16SS_32,
  ICLASS_AE_MULAF16SS_21,
  ICLASS_AE_MULAF16SS_31,
  ICLASS_AE_MULAF16SS_30,
  ICLASS_AE_MULAF16SS_10,
  ICLASS_AE_MULAF16SS_20,
  ICLASS_AE_MULAF16SS_11,
  ICLASS_AE_MULAF16SS_00,
  ICLASS_AE_MULAF16SS_00_S2,
  ICLASS_AE_MULAAFD16SS_33_22,
  ICLASS_AE_MULAAFD16SS_33_22_S2,
  ICLASS_AE_MULAAFD16SS_13_02,
  ICLASS_AE_MULAAFD16SS_13_02_S2,
  ICLASS_AE_MULAAFD16SS_11_00,
  ICLASS_AE_MULAAFD16SS_11_00_S2,
  ICLASS_AE_MULSSFD16SS_33_22,
  ICLASS_AE_MULSSFD16SS_33_22_S2,
  ICLASS_AE_MULSSFD16SS_13_02,
  ICLASS_AE_MULSSFD16SS_13_02_S2,
  ICLASS_AE_MULSSFD16SS_11_00,
  ICLASS_AE_MULSSFD16SS_11_00_S2,
  ICLASS_AE_MULZAAFD16SS_33_22,
  ICLASS_AE_MULZAAFD16SS_33_22_S2,
  ICLASS_AE_MULZAAFD16SS_13_02,
  ICLASS_AE_MULZAAFD16SS_13_02_S2,
  ICLASS_AE_MULZAAFD16SS_11_00,
  ICLASS_AE_MULZAAFD16SS_11_00_S2,
  ICLASS_AE_MULZSSFD16SS_33_22,
  ICLASS_AE_MULZSSFD16SS_33_22_S2,
  ICLASS_AE_MULZSSFD16SS_13_02,
  ICLASS_AE_MULZSSFD16SS_13_02_S2,
  ICLASS_AE_MULZSSFD16SS_11_00,
  ICLASS_AE_MULZSSFD16SS_11_00_S2,
  ICLASS_AE_MULF48Q32SP16S_L,
  ICLASS_AE_MULF48Q32SP16S_L_S2,
  ICLASS_AE_MULF48Q32SP16U_L,
  ICLASS_AE_MULF48Q32SP16U_L_S2,
  ICLASS_AE_MULQ32SP16S_L,
  ICLASS_AE_MULQ32SP16S_L_S2,
  ICLASS_AE_MULQ32SP16U_L,
  ICLASS_AE_MULQ32SP16U_L_S2,
  ICLASS_AE_MULAF48Q32SP16S_L,
  ICLASS_AE_MULAF48Q32SP16S_L_S2,
  ICLASS_AE_MULAF48Q32SP16U_L,
  ICLASS_AE_MULAF48Q32SP16U_L_S2,
  ICLASS_AE_MULAQ32SP16S_L,
  ICLASS_AE_MULAQ32SP16S_L_S2,
  ICLASS_AE_MULAQ32SP16U_L,
  ICLASS_AE_MULAQ32SP16U_L_S2,
  ICLASS_AE_MULSF48Q32SP16S_L,
  ICLASS_AE_MULSF48Q32SP16S_L_S2,
  ICLASS_AE_MULSF48Q32SP16U_L,
  ICLASS_AE_MULSF48Q32SP16U_L_S2,
  ICLASS_AE_MULSQ32SP16S_L,
  ICLASS_AE_MULSQ32SP16S_L_S2,
  ICLASS_AE_MULSQ32SP16U_L,
  ICLASS_AE_MULSQ32SP16U_L_S2,
  ICLASS_AE_MULFP24X2RA,
  ICLASS_AE_MULFP24X2R,
  ICLASS_AE_MULP24X2,
  ICLASS_AE_MULFP24X2RA_S2,
  ICLASS_AE_MULFP24X2R_S2,
  ICLASS_AE_MULP24X2_S2,
  ICLASS_AE_MULAFP24X2RA,
  ICLASS_AE_MULAFP24X2R,
  ICLASS_AE_MULAP24X2,
  ICLASS_AE_MULAFP24X2RA_S2,
  ICLASS_AE_MULAFP24X2R_S2,
  ICLASS_AE_MULAP24X2_S2,
  ICLASS_AE_MULSFP24X2RA,
  ICLASS_AE_MULSFP24X2R,
  ICLASS_AE_MULSP24X2,
  ICLASS_AE_MULSFP24X2RA_S2,
  ICLASS_AE_MULSFP24X2R_S2,
  ICLASS_AE_MULSP24X2_S2,
  ICLASS_AE_MULZAAFD24_HH_LL,
  ICLASS_AE_MULZAAD24_HH_LL,
  ICLASS_AE_MULZAAFD24_HH_LL_S2,
  ICLASS_AE_MULZAAD24_HH_LL_S2,
  ICLASS_AE_MULZAAFD24_HL_LH,
  ICLASS_AE_MULZAAD24_HL_LH,
  ICLASS_AE_MULZAAFD24_HL_LH_S2,
  ICLASS_AE_MULZAAD24_HL_LH_S2,
  ICLASS_AE_MULZASFD24_HH_LL,
  ICLASS_AE_MULZASD24_HH_LL,
  ICLASS_AE_MULZASFD24_HH_LL_S2,
  ICLASS_AE_MULZASD24_HH_LL_S2,
  ICLASS_AE_MULZASFD24_HL_LH,
  ICLASS_AE_MULZASD24_HL_LH,
  ICLASS_AE_MULZASFD24_HL_LH_S2,
  ICLASS_AE_MULZASD24_HL_LH_S2,
  ICLASS_AE_MULZSAFD24_HH_LL,
  ICLASS_AE_MULZSAD24_HH_LL,
  ICLASS_AE_MULZSAFD24_HH_LL_S2,
  ICLASS_AE_MULZSAD24_HH_LL_S2,
  ICLASS_AE_MULZSSFD24_HH_LL,
  ICLASS_AE_MULZSSD24_HH_LL,
  ICLASS_AE_MULZSSFD24_HH_LL_S2,
  ICLASS_AE_MULZSSD24_HH_LL_S2,
  ICLASS_AE_MULZSSFD24_HL_LH,
  ICLASS_AE_MULZSSD24_HL_LH,
  ICLASS_AE_MULZSSFD24_HL_LH_S2,
  ICLASS_AE_MULZSSD24_HL_LH_S2,
  ICLASS_AE_MULAAFD24_HH_LL,
  ICLASS_AE_MULAAD24_HH_LL,
  ICLASS_AE_MULAAFD24_HH_LL_S2,
  ICLASS_AE_MULAAD24_HH_LL_S2,
  ICLASS_AE_MULAAFD24_HL_LH,
  ICLASS_AE_MULAAD24_HL_LH,
  ICLASS_AE_MULAAFD24_HL_LH_S2,
  ICLASS_AE_MULAAD24_HL_LH_S2,
  ICLASS_AE_MULASFD24_HH_LL,
  ICLASS_AE_MULASD24_HH_LL,
  ICLASS_AE_MULASFD24_HH_LL_S2,
  ICLASS_AE_MULASD24_HH_LL_S2,
  ICLASS_AE_MULASFD24_HL_LH,
  ICLASS_AE_MULASD24_HL_LH,
  ICLASS_AE_MULASFD24_HL_LH_S2,
  ICLASS_AE_MULASD24_HL_LH_S2,
  ICLASS_AE_MULSAFD24_HH_LL,
  ICLASS_AE_MULSAD24_HH_LL,
  ICLASS_AE_MULSAFD24_HH_LL_S2,
  ICLASS_AE_MULSAD24_HH_LL_S2,
  ICLASS_AE_MULSSFD24_HH_LL,
  ICLASS_AE_MULSSD24_HH_LL,
  ICLASS_AE_MULSSFD24_HH_LL_S2,
  ICLASS_AE_MULSSD24_HH_LL_S2,
  ICLASS_AE_MULSSFD24_HL_LH,
  ICLASS_AE_MULSSD24_HL_LH,
  ICLASS_AE_MULSSFD24_HL_LH_S2,
  ICLASS_AE_MULSSD24_HL_LH_S2,
  ICLASS_AE_MULSRFQ32SP24S_H,
  ICLASS_AE_MULSRFQ32SP24S_L,
  ICLASS_AE_MULSRFQ32SP24S_H_S2,
  ICLASS_AE_MULSRFQ32SP24S_L_S2,
  ICLASS_AE_MULARFQ32SP24S_H,
  ICLASS_AE_MULARFQ32SP24S_L,
  ICLASS_AE_MULARFQ32SP24S_H_S2,
  ICLASS_AE_MULARFQ32SP24S_L_S2,
  ICLASS_AE_MULRFQ32SP24S_H,
  ICLASS_AE_MULRFQ32SP24S_L,
  ICLASS_AE_MULRFQ32SP24S_H_S2,
  ICLASS_AE_MULRFQ32SP24S_L_S2,
  ICLASS_AE_MULSFQ32SP24S_H,
  ICLASS_AE_MULSFQ32SP24S_L,
  ICLASS_AE_MULSFQ32SP24S_H_S2,
  ICLASS_AE_MULSFQ32SP24S_L_S2,
  ICLASS_AE_MULAFQ32SP24S_H,
  ICLASS_AE_MULAFQ32SP24S_L,
  ICLASS_AE_MULAFQ32SP24S_H_S2,
  ICLASS_AE_MULAFQ32SP24S_L_S2,
  ICLASS_AE_MULFQ32SP24S_H,
  ICLASS_AE_MULFQ32SP24S_L,
  ICLASS_AE_MULFQ32SP24S_H_S2,
  ICLASS_AE_MULFQ32SP24S_L_S2,
  ICLASS_AE_MULF32X16_L0,
  ICLASS_AE_MUL32X16_L0,
  ICLASS_AE_MULF32X16_L0_S2,
  ICLASS_AE_MUL32X16_L0_S2,
  ICLASS_AE_MULF32X16_L1,
  ICLASS_AE_MUL32X16_L1,
  ICLASS_AE_MULF32X16_L1_S2,
  ICLASS_AE_MUL32X16_L1_S2,
  ICLASS_AE_MULF32X16_L2,
  ICLASS_AE_MUL32X16_L2,
  ICLASS_AE_MULF32X16_L2_S2,
  ICLASS_AE_MUL32X16_L2_S2,
  ICLASS_AE_MULF32X16_L3,
  ICLASS_AE_MUL32X16_L3,
  ICLASS_AE_MULF32X16_L3_S2,
  ICLASS_AE_MUL32X16_L3_S2,
  ICLASS_AE_MULF32X16_H0,
  ICLASS_AE_MUL32X16_H0,
  ICLASS_AE_MULF32X16_H0_S2,
  ICLASS_AE_MUL32X16_H0_S2,
  ICLASS_AE_MULF32X16_H1,
  ICLASS_AE_MUL32X16_H1,
  ICLASS_AE_MULF32X16_H1_S2,
  ICLASS_AE_MUL32X16_H1_S2,
  ICLASS_AE_MULF32X16_H2,
  ICLASS_AE_MUL32X16_H2,
  ICLASS_AE_MULF32X16_H2_S2,
  ICLASS_AE_MUL32X16_H2_S2,
  ICLASS_AE_MULF32X16_H3,
  ICLASS_AE_MUL32X16_H3,
  ICLASS_AE_MULF32X16_H3_S2,
  ICLASS_AE_MUL32X16_H3_S2,
  ICLASS_AE_MULAF32X16_L0,
  ICLASS_AE_MULA32X16_L0,
  ICLASS_AE_MULAF32X16_L0_S2,
  ICLASS_AE_MULA32X16_L0_S2,
  ICLASS_AE_MULAF32X16_L1,
  ICLASS_AE_MULA32X16_L1,
  ICLASS_AE_MULAF32X16_L1_S2,
  ICLASS_AE_MULA32X16_L1_S2,
  ICLASS_AE_MULAF32X16_L2,
  ICLASS_AE_MULA32X16_L2,
  ICLASS_AE_MULAF32X16_L2_S2,
  ICLASS_AE_MULA32X16_L2_S2,
  ICLASS_AE_MULAF32X16_L3,
  ICLASS_AE_MULA32X16_L3,
  ICLASS_AE_MULAF32X16_L3_S2,
  ICLASS_AE_MULA32X16_L3_S2,
  ICLASS_AE_MULAF32X16_H0,
  ICLASS_AE_MULA32X16_H0,
  ICLASS_AE_MULAF32X16_H0_S2,
  ICLASS_AE_MULA32X16_H0_S2,
  ICLASS_AE_MULAF32X16_H1,
  ICLASS_AE_MULA32X16_H1,
  ICLASS_AE_MULAF32X16_H1_S2,
  ICLASS_AE_MULA32X16_H1_S2,
  ICLASS_AE_MULAF32X16_H2,
  ICLASS_AE_MULA32X16_H2,
  ICLASS_AE_MULAF32X16_H2_S2,
  ICLASS_AE_MULA32X16_H2_S2,
  ICLASS_AE_MULAF32X16_H3,
  ICLASS_AE_MULA32X16_H3,
  ICLASS_AE_MULAF32X16_H3_S2,
  ICLASS_AE_MULA32X16_H3_S2,
  ICLASS_AE_MULSF32X16_L0,
  ICLASS_AE_MULS32X16_L0,
  ICLASS_AE_MULSF32X16_L0_S2,
  ICLASS_AE_MULS32X16_L0_S2,
  ICLASS_AE_MULSF32X16_L1,
  ICLASS_AE_MULS32X16_L1,
  ICLASS_AE_MULSF32X16_L1_S2,
  ICLASS_AE_MULS32X16_L1_S2,
  ICLASS_AE_MULSF32X16_L2,
  ICLASS_AE_MULS32X16_L2,
  ICLASS_AE_MULSF32X16_L2_S2,
  ICLASS_AE_MULS32X16_L2_S2,
  ICLASS_AE_MULSF32X16_L3,
  ICLASS_AE_MULS32X16_L3,
  ICLASS_AE_MULSF32X16_L3_S2,
  ICLASS_AE_MULS32X16_L3_S2,
  ICLASS_AE_MULSF32X16_H0,
  ICLASS_AE_MULS32X16_H0,
  ICLASS_AE_MULSF32X16_H0_S2,
  ICLASS_AE_MULS32X16_H0_S2,
  ICLASS_AE_MULSF32X16_H1,
  ICLASS_AE_MULS32X16_H1,
  ICLASS_AE_MULSF32X16_H1_S2,
  ICLASS_AE_MULS32X16_H1_S2,
  ICLASS_AE_MULSF32X16_H2,
  ICLASS_AE_MULS32X16_H2,
  ICLASS_AE_MULSF32X16_H2_S2,
  ICLASS_AE_MULS32X16_H2_S2,
  ICLASS_AE_MULSF32X16_H3,
  ICLASS_AE_MULS32X16_H3,
  ICLASS_AE_MULSF32X16_H3_S2,
  ICLASS_AE_MULS32X16_H3_S2,
  ICLASS_AE_MULAAFD32X16_H3_L2,
  ICLASS_AE_MULAAD32X16_H3_L2,
  ICLASS_AE_MULAAFD32X16_H3_L2_S2,
  ICLASS_AE_MULAAD32X16_H3_L2_S2,
  ICLASS_AE_MULAAFD32X16_H1_L0,
  ICLASS_AE_MULAAD32X16_H1_L0,
  ICLASS_AE_MULAAFD32X16_H1_L0_S2,
  ICLASS_AE_MULAAD32X16_H1_L0_S2,
  ICLASS_AE_MULASFD32X16_H3_L2,
  ICLASS_AE_MULASD32X16_H3_L2,
  ICLASS_AE_MULASFD32X16_H3_L2_S2,
  ICLASS_AE_MULASD32X16_H3_L2_S2,
  ICLASS_AE_MULASFD32X16_H1_L0,
  ICLASS_AE_MULASD32X16_H1_L0,
  ICLASS_AE_MULASFD32X16_H1_L0_S2,
  ICLASS_AE_MULASD32X16_H1_L0_S2,
  ICLASS_AE_MULSAFD32X16_H3_L2,
  ICLASS_AE_MULSAD32X16_H3_L2,
  ICLASS_AE_MULSAFD32X16_H3_L2_S2,
  ICLASS_AE_MULSAD32X16_H3_L2_S2,
  ICLASS_AE_MULSAFD32X16_H1_L0,
  ICLASS_AE_MULSAD32X16_H1_L0,
  ICLASS_AE_MULSAFD32X16_H1_L0_S2,
  ICLASS_AE_MULSAD32X16_H1_L0_S2,
  ICLASS_AE_MULSSFD32X16_H3_L2,
  ICLASS_AE_MULSSD32X16_H3_L2,
  ICLASS_AE_MULSSFD32X16_H3_L2_S2,
  ICLASS_AE_MULSSD32X16_H3_L2_S2,
  ICLASS_AE_MULSSFD32X16_H1_L0,
  ICLASS_AE_MULSSD32X16_H1_L0,
  ICLASS_AE_MULSSFD32X16_H1_L0_S2,
  ICLASS_AE_MULSSD32X16_H1_L0_S2,
  ICLASS_AE_MULZAAFD32X16_H3_L2,
  ICLASS_AE_MULZAAD32X16_H3_L2,
  ICLASS_AE_MULZAAFD32X16_H3_L2_S2,
  ICLASS_AE_MULZAAD32X16_H3_L2_S2,
  ICLASS_AE_MULZAAFD32X16_H1_L0,
  ICLASS_AE_MULZAAD32X16_H1_L0,
  ICLASS_AE_MULZAAFD32X16_H1_L0_S2,
  ICLASS_AE_MULZAAD32X16_H1_L0_S2,
  ICLASS_AE_MULZASFD32X16_H3_L2,
  ICLASS_AE_MULZASD32X16_H3_L2,
  ICLASS_AE_MULZASFD32X16_H3_L2_S2,
  ICLASS_AE_MULZASD32X16_H3_L2_S2,
  ICLASS_AE_MULZASFD32X16_H1_L0,
  ICLASS_AE_MULZASD32X16_H1_L0,
  ICLASS_AE_MULZASFD32X16_H1_L0_S2,
  ICLASS_AE_MULZASD32X16_H1_L0_S2,
  ICLASS_AE_MULZSAFD32X16_H3_L2,
  ICLASS_AE_MULZSAD32X16_H3_L2,
  ICLASS_AE_MULZSAFD32X16_H3_L2_S2,
  ICLASS_AE_MULZSAD32X16_H3_L2_S2,
  ICLASS_AE_MULZSAFD32X16_H1_L0,
  ICLASS_AE_MULZSAD32X16_H1_L0,
  ICLASS_AE_MULZSAFD32X16_H1_L0_S2,
  ICLASS_AE_MULZSAD32X16_H1_L0_S2,
  ICLASS_AE_MULZSSFD32X16_H3_L2,
  ICLASS_AE_MULZSSD32X16_H3_L2,
  ICLASS_AE_MULZSSFD32X16_H3_L2_S2,
  ICLASS_AE_MULZSSD32X16_H3_L2_S2,
  ICLASS_AE_MULZSSFD32X16_H1_L0,
  ICLASS_AE_MULZSSD32X16_H1_L0,
  ICLASS_AE_MULZSSFD32X16_H1_L0_S2,
  ICLASS_AE_MULZSSD32X16_H1_L0_S2,
  ICLASS_AE_MULZAAFD32X16_H2_L3,
  ICLASS_AE_MULZAAFD32X16_H0_L1,
  ICLASS_AE_MULAAFD32X16_H2_L3,
  ICLASS_AE_MULAAFD32X16_H0_L1,
  ICLASS_AE_MULZAAD32X16_H2_L3,
  ICLASS_AE_MULZAAD32X16_H0_L1,
  ICLASS_AE_MULAAD32X16_H2_L3,
  ICLASS_AE_MULAAD32X16_H0_L1,
  ICLASS_AE_MULZAAFD32X16_H2_L3_S2,
  ICLASS_AE_MULZAAFD32X16_H0_L1_S2,
  ICLASS_AE_MULAAFD32X16_H2_L3_S2,
  ICLASS_AE_MULAAFD32X16_H0_L1_S2,
  ICLASS_AE_MULZAAD32X16_H2_L3_S2,
  ICLASS_AE_MULZAAD32X16_H0_L1_S2,
  ICLASS_AE_MULAAD32X16_H2_L3_S2,
  ICLASS_AE_MULAAD32X16_H0_L1_S2,
  ICLASS_AE_MULP32X16X2_H,
  ICLASS_AE_MULFP32X16X2RS_H,
  ICLASS_AE_MULFP32X16X2RAS_H,
  ICLASS_AE_MULFP32X16X2RS_H_S2,
  ICLASS_AE_MULFP32X16X2RAS_H_S2,
  ICLASS_AE_MULP32X16X2_L,
  ICLASS_AE_MULFP32X16X2RS_L,
  ICLASS_AE_MULFP32X16X2RAS_L,
  ICLASS_AE_MULFP32X16X2RS_L_S2,
  ICLASS_AE_MULFP32X16X2RAS_L_S2,
  ICLASS_AE_MULAP32X16X2_H,
  ICLASS_AE_MULAFP32X16X2RS_H,
  ICLASS_AE_MULAFP32X16X2RAS_H,
  ICLASS_AE_MULAFP32X16X2RS_H_S2,
  ICLASS_AE_MULAFP32X16X2RAS_H_S2,
  ICLASS_AE_MULAP32X16X2_L,
  ICLASS_AE_MULAFP32X16X2RS_L,
  ICLASS_AE_MULAFP32X16X2RAS_L,
  ICLASS_AE_MULAFP32X16X2RS_L_S2,
  ICLASS_AE_MULAFP32X16X2RAS_L_S2,
  ICLASS_AE_MULSP32X16X2_H,
  ICLASS_AE_MULSFP32X16X2RS_H,
  ICLASS_AE_MULSFP32X16X2RAS_H,
  ICLASS_AE_MULSFP32X16X2RS_H_S2,
  ICLASS_AE_MULSFP32X16X2RAS_H_S2,
  ICLASS_AE_MULSP32X16X2_L,
  ICLASS_AE_MULSFP32X16X2RS_L,
  ICLASS_AE_MULSFP32X16X2RAS_L,
  ICLASS_AE_MULSFP32X16X2RS_L_S2,
  ICLASS_AE_MULSFP32X16X2RAS_L_S2,
  ICLASS_AE_MULP32X2,
  ICLASS_AE_MULFP32X2RS,
  ICLASS_AE_MULFP32X2RAS,
  ICLASS_AE_MULAP32X2,
  ICLASS_AE_MULAFP32X2RS,
  ICLASS_AE_MULAFP32X2RAS,
  ICLASS_AE_MULSP32X2,
  ICLASS_AE_MULSFP32X2RS,
  ICLASS_AE_MULSFP32X2RAS,
  ICLASS_AE_MULFP16X4S,
  ICLASS_AE_MULFP16X4RAS,
  ICLASS_AE_MULC24,
  ICLASS_AE_MULFC24RA,
  ICLASS_AE_MULC32X16_L,
  ICLASS_AE_MULFC32X16RAS_L,
  ICLASS_AE_MULC32X16_H,
  ICLASS_AE_MULFC32X16RAS_H,
  ICLASS_AE_MULAC24,
  ICLASS_AE_MULAFC24RA,
  ICLASS_AE_MULAC32X16_L,
  ICLASS_AE_MULAFC32X16RAS_L,
  ICLASS_AE_MULAC32X16_H,
  ICLASS_AE_MULAFC32X16RAS_H,
  ICLASS_AE_MULF16X4SS,
  ICLASS_AE_MULAF16X4SS,
  ICLASS_AE_MULSF16X4SS,
  ICLASS_AE_MUL16X4,
  ICLASS_AE_MULA16X4,
  ICLASS_AE_MULS16X4,
  ICLASS_AE_MULFD24X2_FIR_H,
  ICLASS_AE_MULFD24X2_FIR_L,
  ICLASS_AE_MULFD32X16X2_FIR_HH,
  ICLASS_AE_MULFD32X16X2_FIR_HL,
  ICLASS_AE_MULFD32X16X2_FIR_LH,
  ICLASS_AE_MULFD32X16X2_FIR_LL,
  ICLASS_AE_MULAFD24X2_FIR_H,
  ICLASS_AE_MULAFD24X2_FIR_L,
  ICLASS_AE_MULAFD32X16X2_FIR_HH,
  ICLASS_AE_MULAFD32X16X2_FIR_HL,
  ICLASS_AE_MULAFD32X16X2_FIR_LH,
  ICLASS_AE_MULAFD32X16X2_FIR_LL,
  ICLASS_AE_DIV64D32_H,
  ICLASS_AE_DIV64D32_L,
  ICLASS_AE_SHA32,
  ICLASS_AE_VLDL32T,
  ICLASS_AE_VLDL16T,
  ICLASS_AE_VLDL16C,
  ICLASS_AE_VLDL16C_IP,
  ICLASS_AE_VLDL16C_IC,
  ICLASS_AE_VLDSHT,
  ICLASS_AE_LB,
  ICLASS_AE_LBI,
  ICLASS_AE_LBK,
  ICLASS_AE_LBKI,
  ICLASS_AE_LBS,
  ICLASS_AE_LBSI,
  ICLASS_AE_DB,
  ICLASS_AE_DBI,
  ICLASS_AE_DB_IC,
  ICLASS_AE_DBI_IC,
  ICLASS_AE_DB_IP,
  ICLASS_AE_DBI_IP,
  ICLASS_AE_VLEL32T,
  ICLASS_AE_VLEL16T,
  ICLASS_AE_SB,
  ICLASS_AE_SBI,
  ICLASS_AE_VLES16C,
  ICLASS_AE_SBF,
  ICLASS_AE_SB_IC,
  ICLASS_AE_SBI_IC,
  ICLASS_AE_VLES16C_IC,
  ICLASS_AE_SBF_IC,
  ICLASS_AE_SB_IP,
  ICLASS_AE_SBI_IP,
  ICLASS_AE_VLES16C_IP,
  ICLASS_AE_SBF_IP,
  ICLASS_AE_SEXT32,
  ICLASS_LSI,
  ICLASS_LSIP,
  ICLASS_LSX,
  ICLASS_LSXP,
  ICLASS_SSI,
  ICLASS_SSIP,
  ICLASS_SSX,
  ICLASS_SSXP,
  ICLASS_ABS_S,
  ICLASS_NEG_S,
  ICLASS_MOV_S,
  ICLASS_MOVEQZ_S,
  ICLASS_MOVNEZ_S,
  ICLASS_MOVLTZ_S,
  ICLASS_MOVGEZ_S,
  ICLASS_MOVF_S,
  ICLASS_MOVT_S,
  ICLASS_WFR,
  ICLASS_RFR,
  ICLASS_ROUND_S,
  ICLASS_CEIL_S,
  ICLASS_FLOOR_S,
  ICLASS_TRUNC_S,
  ICLASS_UTRUNC_S,
  ICLASS_FLOAT_S,
  ICLASS_UFLOAT_S,
  ICLASS_UN_S,
  ICLASS_ULT_S,
  ICLASS_ULE_S,
  ICLASS_UEQ_S,
  ICLASS_OLT_S,
  ICLASS_OLE_S,
  ICLASS_OEQ_S,
  ICLASS_ADD_S,
  ICLASS_SUB_S,
  ICLASS_MUL_S,
  ICLASS_MADD_S,
  ICLASS_MSUB_S,
  ICLASS_SQRT0_S,
  ICLASS_DIV0_S,
  ICLASS_RECIP0_S,
  ICLASS_RSQRT0_S,
  ICLASS_MADDN_S,
  ICLASS_DIVN_S,
  ICLASS_CONST_S,
  ICLASS_NEXP01_S,
  ICLASS_ADDEXP_S,
  ICLASS_ADDEXPM_S,
  ICLASS_MKDADJ_S,
  ICLASS_MKSADJ_S
};


/*  Opcode encodings.  */

static void
Opcode_excw_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2080;
}

static void
Opcode_rfe_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3000;
}

static void
Opcode_rfde_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3200;
}

static void
Opcode_syscall_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5000;
}

static void
Opcode_call12_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x35;
}

static void
Opcode_call8_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x25;
}

static void
Opcode_call4_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x15;
}

static void
Opcode_callx12_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf0;
}

static void
Opcode_callx8_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe0;
}

static void
Opcode_callx4_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd0;
}

static void
Opcode_entry_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x36;
}

static void
Opcode_movsp_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1000;
}

static void
Opcode_rotw_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x408000;
}

static void
Opcode_retw_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x90;
}

static void
Opcode_retw_n_Slot_inst16b_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf01d;
}

static void
Opcode_rfwo_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3400;
}

static void
Opcode_rfwu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3500;
}

static void
Opcode_l32e_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x90000;
}

static void
Opcode_s32e_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x490000;
}

static void
Opcode_rsr_windowbase_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x34800;
}

static void
Opcode_wsr_windowbase_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x134800;
}

static void
Opcode_xsr_windowbase_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x614800;
}

static void
Opcode_rsr_windowstart_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x34900;
}

static void
Opcode_wsr_windowstart_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x134900;
}

static void
Opcode_xsr_windowstart_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x614900;
}

static void
Opcode_rfme_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3020;
}

static void
Opcode_rsr_mesr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x36d00;
}

static void
Opcode_wsr_mesr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x136d00;
}

static void
Opcode_xsr_mesr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x616d00;
}

static void
Opcode_rsr_mecr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x36e00;
}

static void
Opcode_wsr_mecr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x136e00;
}

static void
Opcode_xsr_mecr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x616e00;
}

static void
Opcode_rsr_mepc_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x36a00;
}

static void
Opcode_wsr_mepc_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x136a00;
}

static void
Opcode_xsr_mepc_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x616a00;
}

static void
Opcode_rsr_meps_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x36b00;
}

static void
Opcode_wsr_meps_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x136b00;
}

static void
Opcode_xsr_meps_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x616b00;
}

static void
Opcode_rsr_mesave_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x36c00;
}

static void
Opcode_wsr_mesave_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x136c00;
}

static void
Opcode_xsr_mesave_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x616c00;
}

static void
Opcode_rsr_mevaddr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x36f00;
}

static void
Opcode_wsr_mevaddr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x136f00;
}

static void
Opcode_xsr_mevaddr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x616f00;
}

static void
Opcode_add_n_Slot_inst16a_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa;
}

static void
Opcode_addi_n_Slot_inst16a_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb;
}

static void
Opcode_addi_n_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3000;
}

static void
Opcode_beqz_n_Slot_inst16b_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8c;
}

static void
Opcode_bnez_n_Slot_inst16b_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc;
}

static void
Opcode_ill_n_Slot_inst16b_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf06d;
}

static void
Opcode_l32i_n_Slot_inst16a_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8;
}

static void
Opcode_mov_n_Slot_inst16b_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd;
}

static void
Opcode_mov_n_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1df000;
}

static void
Opcode_mov_n_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa7000;
}

static void
Opcode_mov_n_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe000;
}

static void
Opcode_movi_n_Slot_inst16b_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc;
}

static void
Opcode_movi_n_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc000;
}

static void
Opcode_nop_n_Slot_inst16b_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf03d;
}

static void
Opcode_ret_n_Slot_inst16b_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf00d;
}

static void
Opcode_s32i_n_Slot_inst16a_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9;
}

static void
Opcode_rur_threadptr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe30e70;
}

static void
Opcode_wur_threadptr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf3e700;
}

static void
Opcode_addi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc002;
}

static void
Opcode_addi_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80040000;
}

static void
Opcode_addi_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0;
}

static void
Opcode_addi_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x20000;
}

static void
Opcode_addi_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x120000;
}

static void
Opcode_addi_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x60000;
}

static void
Opcode_addmi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd002;
}

static void
Opcode_addmi_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80050000;
}

static void
Opcode_addmi_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x10000;
}

static void
Opcode_addmi_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x30000;
}

static void
Opcode_addmi_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x130000;
}

static void
Opcode_addmi_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x70000;
}

static void
Opcode_add_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800000;
}

static void
Opcode_add_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800d0000;
}

static void
Opcode_add_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50000;
}

static void
Opcode_add_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1c4000;
}

static void
Opcode_add_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x94000;
}

static void
Opcode_add_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2000;
}

static void
Opcode_addx2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x900000;
}

static void
Opcode_addx2_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800d1000;
}

static void
Opcode_addx2_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x51000;
}

static void
Opcode_addx2_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1c5000;
}

static void
Opcode_addx2_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x95000;
}

static void
Opcode_addx2_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4000;
}

static void
Opcode_addx4_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa00000;
}

static void
Opcode_addx4_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800d2000;
}

static void
Opcode_addx4_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x52000;
}

static void
Opcode_addx4_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1c6000;
}

static void
Opcode_addx4_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x96000;
}

static void
Opcode_addx4_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5000;
}

static void
Opcode_addx8_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb00000;
}

static void
Opcode_addx8_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800d3000;
}

static void
Opcode_addx8_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x53000;
}

static void
Opcode_addx8_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1c7000;
}

static void
Opcode_addx8_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x97000;
}

static void
Opcode_sub_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc00000;
}

static void
Opcode_sub_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800da000;
}

static void
Opcode_sub_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5a000;
}

static void
Opcode_sub_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1d6000;
}

static void
Opcode_sub_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa2000;
}

static void
Opcode_sub_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9000;
}

static void
Opcode_subx2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd00000;
}

static void
Opcode_subx2_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800db000;
}

static void
Opcode_subx2_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5b000;
}

static void
Opcode_subx2_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1d7000;
}

static void
Opcode_subx4_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe00000;
}

static void
Opcode_subx4_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800dc000;
}

static void
Opcode_subx4_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5c000;
}

static void
Opcode_subx4_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1d8000;
}

static void
Opcode_subx8_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf00000;
}

static void
Opcode_subx8_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800dd000;
}

static void
Opcode_subx8_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5d000;
}

static void
Opcode_subx8_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1d9000;
}

static void
Opcode_and_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x100000;
}

static void
Opcode_and_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1c8000;
}

static void
Opcode_and_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x98000;
}

static void
Opcode_and_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6000;
}

static void
Opcode_or_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x200000;
}

static void
Opcode_or_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800d9000;
}

static void
Opcode_or_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x59000;
}

static void
Opcode_or_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1d4000;
}

static void
Opcode_or_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa0000;
}

static void
Opcode_or_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7000;
}

static void
Opcode_xor_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x300000;
}

static void
Opcode_xor_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1da000;
}

static void
Opcode_xor_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa3000;
}

static void
Opcode_xor_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa000;
}

static void
Opcode_beqi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x26;
}

static void
Opcode_bgei_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe6;
}

static void
Opcode_blti_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa6;
}

static void
Opcode_bnei_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x66;
}

static void
Opcode_bbci_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6007;
}

static void
Opcode_bbsi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe007;
}

static void
Opcode_bgeui_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf6;
}

static void
Opcode_bltui_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb6;
}

static void
Opcode_ball_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4007;
}

static void
Opcode_bany_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8007;
}

static void
Opcode_bbc_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5007;
}

static void
Opcode_bbs_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd007;
}

static void
Opcode_beq_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1007;
}

static void
Opcode_bge_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa007;
}

static void
Opcode_bgeu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb007;
}

static void
Opcode_blt_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2007;
}

static void
Opcode_bltu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3007;
}

static void
Opcode_bnall_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc007;
}

static void
Opcode_bne_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9007;
}

static void
Opcode_bnone_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7;
}

static void
Opcode_beqz_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x16;
}

static void
Opcode_bgez_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd6;
}

static void
Opcode_bltz_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x96;
}

static void
Opcode_bnez_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x56;
}

static void
Opcode_call0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5;
}

static void
Opcode_callx0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc0;
}

static void
Opcode_extui_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x40000;
}

static void
Opcode_extui_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80000000;
}

static void
Opcode_extui_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0;
}

static void
Opcode_extui_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x100000;
}

static void
Opcode_extui_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x40000;
}

static void
Opcode_ill_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0;
}

static void
Opcode_j_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6;
}

static void
Opcode_j_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0;
}

static void
Opcode_jx_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa0;
}

static void
Opcode_jx_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa8001;
}

static void
Opcode_l16ui_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1002;
}

static void
Opcode_l16ui_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x150000;
}

static void
Opcode_l16si_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9002;
}

static void
Opcode_l16si_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x140000;
}

static void
Opcode_l32i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2002;
}

static void
Opcode_l32i_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x160000;
}

static void
Opcode_l32r_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1;
}

static void
Opcode_l32r_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0;
}

static void
Opcode_l8ui_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2;
}

static void
Opcode_l8ui_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x170000;
}

static void
Opcode_loop_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8076;
}

static void
Opcode_loopgtz_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa076;
}

static void
Opcode_loopnez_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9076;
}

static void
Opcode_movi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa002;
}

static void
Opcode_movi_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80060000;
}

static void
Opcode_movi_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x40000;
}

static void
Opcode_movi_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x40000;
}

static void
Opcode_movi_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1b0000;
}

static void
Opcode_movi_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80000;
}

static void
Opcode_moveqz_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x830000;
}

static void
Opcode_moveqz_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800d5000;
}

static void
Opcode_moveqz_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x55000;
}

static void
Opcode_moveqz_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1cd000;
}

static void
Opcode_moveqz_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x99000;
}

static void
Opcode_movgez_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb30000;
}

static void
Opcode_movgez_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800d6000;
}

static void
Opcode_movgez_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x56000;
}

static void
Opcode_movgez_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1ce000;
}

static void
Opcode_movgez_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9a000;
}

static void
Opcode_movltz_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa30000;
}

static void
Opcode_movltz_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800d7000;
}

static void
Opcode_movltz_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x57000;
}

static void
Opcode_movltz_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1cf000;
}

static void
Opcode_movltz_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9b000;
}

static void
Opcode_movnez_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x930000;
}

static void
Opcode_movnez_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800d8000;
}

static void
Opcode_movnez_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x58000;
}

static void
Opcode_movnez_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1d0000;
}

static void
Opcode_movnez_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9c000;
}

static void
Opcode_abs_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x600100;
}

static void
Opcode_abs_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1de000;
}

static void
Opcode_abs_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd000;
}

static void
Opcode_neg_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x600000;
}

static void
Opcode_neg_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1de010;
}

static void
Opcode_neg_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa6000;
}

static void
Opcode_neg_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd010;
}

static void
Opcode_nop_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x20f0;
}

static void
Opcode_nop_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a3995;
}

static void
Opcode_nop_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd410b0;
}

static void
Opcode_nop_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x14600;
}

static void
Opcode_nop_Slot_ae_minislot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0;
}

static void
Opcode_nop_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50b50;
}

static void
Opcode_nop_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdd295;
}

static void
Opcode_nop_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfb0f0;
}

static void
Opcode_nop_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xeb000;
}

static void
Opcode_nop_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x48600;
}

static void
Opcode_nop_Slot_xt_dummy_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0;
}

static void
Opcode_nop_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1df320;
}

static void
Opcode_nop_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa8201;
}

static void
Opcode_nop_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe100;
}

static void
Opcode_nop_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x58000040;
}

static void
Opcode_ret_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80;
}

static void
Opcode_simcall_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5100;
}

static void
Opcode_s16i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5002;
}

static void
Opcode_s16i_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x180000;
}

static void
Opcode_s32i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6002;
}

static void
Opcode_s32i_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x190000;
}

static void
Opcode_s32nb_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x590000;
}

static void
Opcode_s8i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4002;
}

static void
Opcode_s8i_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1a0000;
}

static void
Opcode_ssa8b_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x403000;
}

static void
Opcode_ssa8b_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1e0001;
}

static void
Opcode_ssa8l_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x402000;
}

static void
Opcode_ssa8l_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1e0101;
}

static void
Opcode_ssl_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x401000;
}

static void
Opcode_ssl_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1e0201;
}

static void
Opcode_ssl_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa8101;
}

static void
Opcode_ssr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x400000;
}

static void
Opcode_ssr_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1e0301;
}

static void
Opcode_ssai_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x404000;
}

static void
Opcode_ssai_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1df300;
}

static void
Opcode_sll_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa10000;
}

static void
Opcode_sll_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1e0000;
}

static void
Opcode_sll_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa8000;
}

static void
Opcode_src_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x810000;
}

static void
Opcode_src_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1d5000;
}

static void
Opcode_src_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa1000;
}

static void
Opcode_sra_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb10000;
}

static void
Opcode_sra_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1de020;
}

static void
Opcode_sra_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa6010;
}

static void
Opcode_sra_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd020;
}

static void
Opcode_srl_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x910000;
}

static void
Opcode_srl_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1de030;
}

static void
Opcode_srl_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa6020;
}

static void
Opcode_srl_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd030;
}

static void
Opcode_slli_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x10000;
}

static void
Opcode_slli_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1c0000;
}

static void
Opcode_slli_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x90000;
}

static void
Opcode_srai_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x210000;
}

static void
Opcode_srai_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1c2000;
}

static void
Opcode_srai_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x92000;
}

static void
Opcode_srai_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0;
}

static void
Opcode_srli_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x410000;
}

static void
Opcode_srli_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1dd000;
}

static void
Opcode_srli_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa5000;
}

static void
Opcode_srli_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb000;
}

static void
Opcode_memw_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x20c0;
}

static void
Opcode_extw_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x20d0;
}

static void
Opcode_isync_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2000;
}

static void
Opcode_dsync_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2030;
}

static void
Opcode_esync_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2020;
}

static void
Opcode_rsync_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2010;
}

static void
Opcode_rsil_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6000;
}

static void
Opcode_rsr_lend_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x30100;
}

static void
Opcode_wsr_lend_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x130100;
}

static void
Opcode_xsr_lend_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x610100;
}

static void
Opcode_rsr_lcount_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x30200;
}

static void
Opcode_wsr_lcount_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x130200;
}

static void
Opcode_xsr_lcount_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x610200;
}

static void
Opcode_rsr_lbeg_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x30000;
}

static void
Opcode_wsr_lbeg_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x130000;
}

static void
Opcode_xsr_lbeg_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x610000;
}

static void
Opcode_rsr_sar_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x30300;
}

static void
Opcode_wsr_sar_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x130300;
}

static void
Opcode_xsr_sar_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x610300;
}

static void
Opcode_rsr_memctl_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x36100;
}

static void
Opcode_wsr_memctl_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x136100;
}

static void
Opcode_xsr_memctl_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x616100;
}

static void
Opcode_rsr_litbase_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x30500;
}

static void
Opcode_wsr_litbase_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x130500;
}

static void
Opcode_xsr_litbase_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x610500;
}

static void
Opcode_rsr_configid0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3b000;
}

static void
Opcode_wsr_configid0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13b000;
}

static void
Opcode_rsr_configid1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3d000;
}

static void
Opcode_rsr_243_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3f300;
}

static void
Opcode_rsr_ps_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3e600;
}

static void
Opcode_wsr_ps_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13e600;
}

static void
Opcode_xsr_ps_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61e600;
}

static void
Opcode_rsr_epc1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3b100;
}

static void
Opcode_wsr_epc1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13b100;
}

static void
Opcode_xsr_epc1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61b100;
}

static void
Opcode_rsr_excsave1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3d100;
}

static void
Opcode_wsr_excsave1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13d100;
}

static void
Opcode_xsr_excsave1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61d100;
}

static void
Opcode_rsr_epc2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3b200;
}

static void
Opcode_wsr_epc2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13b200;
}

static void
Opcode_xsr_epc2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61b200;
}

static void
Opcode_rsr_excsave2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3d200;
}

static void
Opcode_wsr_excsave2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13d200;
}

static void
Opcode_xsr_excsave2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61d200;
}

static void
Opcode_rsr_epc3_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3b300;
}

static void
Opcode_wsr_epc3_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13b300;
}

static void
Opcode_xsr_epc3_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61b300;
}

static void
Opcode_rsr_excsave3_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3d300;
}

static void
Opcode_wsr_excsave3_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13d300;
}

static void
Opcode_xsr_excsave3_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61d300;
}

static void
Opcode_rsr_epc4_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3b400;
}

static void
Opcode_wsr_epc4_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13b400;
}

static void
Opcode_xsr_epc4_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61b400;
}

static void
Opcode_rsr_excsave4_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3d400;
}

static void
Opcode_wsr_excsave4_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13d400;
}

static void
Opcode_xsr_excsave4_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61d400;
}

static void
Opcode_rsr_epc5_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3b500;
}

static void
Opcode_wsr_epc5_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13b500;
}

static void
Opcode_xsr_epc5_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61b500;
}

static void
Opcode_rsr_excsave5_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3d500;
}

static void
Opcode_wsr_excsave5_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13d500;
}

static void
Opcode_xsr_excsave5_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61d500;
}

static void
Opcode_rsr_epc6_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3b600;
}

static void
Opcode_wsr_epc6_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13b600;
}

static void
Opcode_xsr_epc6_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61b600;
}

static void
Opcode_rsr_excsave6_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3d600;
}

static void
Opcode_wsr_excsave6_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13d600;
}

static void
Opcode_xsr_excsave6_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61d600;
}

static void
Opcode_rsr_epc7_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3b700;
}

static void
Opcode_wsr_epc7_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13b700;
}

static void
Opcode_xsr_epc7_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61b700;
}

static void
Opcode_rsr_excsave7_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3d700;
}

static void
Opcode_wsr_excsave7_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13d700;
}

static void
Opcode_xsr_excsave7_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61d700;
}

static void
Opcode_rsr_eps2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3c200;
}

static void
Opcode_wsr_eps2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13c200;
}

static void
Opcode_xsr_eps2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61c200;
}

static void
Opcode_rsr_eps3_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3c300;
}

static void
Opcode_wsr_eps3_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13c300;
}

static void
Opcode_xsr_eps3_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61c300;
}

static void
Opcode_rsr_eps4_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3c400;
}

static void
Opcode_wsr_eps4_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13c400;
}

static void
Opcode_xsr_eps4_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61c400;
}

static void
Opcode_rsr_eps5_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3c500;
}

static void
Opcode_wsr_eps5_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13c500;
}

static void
Opcode_xsr_eps5_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61c500;
}

static void
Opcode_rsr_eps6_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3c600;
}

static void
Opcode_wsr_eps6_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13c600;
}

static void
Opcode_xsr_eps6_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61c600;
}

static void
Opcode_rsr_eps7_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3c700;
}

static void
Opcode_wsr_eps7_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13c700;
}

static void
Opcode_xsr_eps7_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61c700;
}

static void
Opcode_rsr_excvaddr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3ee00;
}

static void
Opcode_wsr_excvaddr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13ee00;
}

static void
Opcode_xsr_excvaddr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61ee00;
}

static void
Opcode_rsr_depc_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3c000;
}

static void
Opcode_wsr_depc_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13c000;
}

static void
Opcode_xsr_depc_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61c000;
}

static void
Opcode_rsr_exccause_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3e800;
}

static void
Opcode_wsr_exccause_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13e800;
}

static void
Opcode_xsr_exccause_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61e800;
}

static void
Opcode_rsr_prid_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3eb00;
}

static void
Opcode_rsr_vecbase_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3e700;
}

static void
Opcode_wsr_vecbase_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13e700;
}

static void
Opcode_xsr_vecbase_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61e700;
}

static void
Opcode_mul16s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd10000;
}

static void
Opcode_mul16s_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1d1000;
}

static void
Opcode_mul16s_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9d000;
}

static void
Opcode_mul16u_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc10000;
}

static void
Opcode_mul16u_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1d2000;
}

static void
Opcode_mul16u_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9e000;
}

static void
Opcode_mull_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x820000;
}

static void
Opcode_mull_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1d3000;
}

static void
Opcode_mull_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9f000;
}

static void
Opcode_mulsh_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb20000;
}

static void
Opcode_muluh_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa20000;
}

static void
Opcode_rfi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3010;
}

static void
Opcode_waiti_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7000;
}

static void
Opcode_rsr_interrupt_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3e200;
}

static void
Opcode_wsr_intset_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13e200;
}

static void
Opcode_wsr_intclear_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13e300;
}

static void
Opcode_rsr_intenable_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3e400;
}

static void
Opcode_wsr_intenable_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13e400;
}

static void
Opcode_xsr_intenable_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61e400;
}

static void
Opcode_break_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4000;
}

static void
Opcode_break_n_Slot_inst16b_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf02d;
}

static void
Opcode_rsr_dbreaka0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x39000;
}

static void
Opcode_wsr_dbreaka0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x139000;
}

static void
Opcode_xsr_dbreaka0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x619000;
}

static void
Opcode_rsr_dbreakc0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3a000;
}

static void
Opcode_wsr_dbreakc0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13a000;
}

static void
Opcode_xsr_dbreakc0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61a000;
}

static void
Opcode_rsr_dbreaka1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x39100;
}

static void
Opcode_wsr_dbreaka1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x139100;
}

static void
Opcode_xsr_dbreaka1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x619100;
}

static void
Opcode_rsr_dbreakc1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3a100;
}

static void
Opcode_wsr_dbreakc1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13a100;
}

static void
Opcode_xsr_dbreakc1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61a100;
}

static void
Opcode_rsr_ibreaka0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x38000;
}

static void
Opcode_wsr_ibreaka0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x138000;
}

static void
Opcode_xsr_ibreaka0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x618000;
}

static void
Opcode_rsr_ibreaka1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x38100;
}

static void
Opcode_wsr_ibreaka1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x138100;
}

static void
Opcode_xsr_ibreaka1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x618100;
}

static void
Opcode_rsr_ibreakenable_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x36000;
}

static void
Opcode_wsr_ibreakenable_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x136000;
}

static void
Opcode_xsr_ibreakenable_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x616000;
}

static void
Opcode_rsr_debugcause_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3e900;
}

static void
Opcode_wsr_debugcause_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13e900;
}

static void
Opcode_xsr_debugcause_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61e900;
}

static void
Opcode_rsr_icount_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3ec00;
}

static void
Opcode_wsr_icount_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13ec00;
}

static void
Opcode_xsr_icount_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61ec00;
}

static void
Opcode_rsr_icountlevel_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3ed00;
}

static void
Opcode_wsr_icountlevel_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13ed00;
}

static void
Opcode_xsr_icountlevel_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61ed00;
}

static void
Opcode_rsr_ddr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x36800;
}

static void
Opcode_wsr_ddr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x136800;
}

static void
Opcode_xsr_ddr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x616800;
}

static void
Opcode_lddr32_p_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x70e0;
}

static void
Opcode_sddr32_p_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x70f0;
}

static void
Opcode_rfdo_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf1e000;
}

static void
Opcode_rfdd_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf1e010;
}

static void
Opcode_wsr_mmid_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x135900;
}

static void
Opcode_andb_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x20000;
}

static void
Opcode_andbc_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x120000;
}

static void
Opcode_orb_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x220000;
}

static void
Opcode_orbc_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x320000;
}

static void
Opcode_xorb_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x420000;
}

static void
Opcode_all4_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9000;
}

static void
Opcode_any4_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8000;
}

static void
Opcode_all8_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb000;
}

static void
Opcode_any8_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa000;
}

static void
Opcode_bf_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x76;
}

static void
Opcode_bt_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1076;
}

static void
Opcode_movf_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc30000;
}

static void
Opcode_movt_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd30000;
}

static void
Opcode_rsr_br_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x30400;
}

static void
Opcode_wsr_br_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x130400;
}

static void
Opcode_xsr_br_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x610400;
}

static void
Opcode_rsr_ccount_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3ea00;
}

static void
Opcode_wsr_ccount_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13ea00;
}

static void
Opcode_xsr_ccount_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61ea00;
}

static void
Opcode_rsr_ccompare0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3f000;
}

static void
Opcode_wsr_ccompare0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13f000;
}

static void
Opcode_xsr_ccompare0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61f000;
}

static void
Opcode_rsr_ccompare1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3f100;
}

static void
Opcode_wsr_ccompare1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13f100;
}

static void
Opcode_xsr_ccompare1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61f100;
}

static void
Opcode_rsr_ccompare2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3f200;
}

static void
Opcode_wsr_ccompare2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13f200;
}

static void
Opcode_xsr_ccompare2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61f200;
}

static void
Opcode_ihi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x70e2;
}

static void
Opcode_ipf_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x70c2;
}

static void
Opcode_ihu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x270d2;
}

static void
Opcode_iiu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x370d2;
}

static void
Opcode_ipfl_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x70d2;
}

static void
Opcode_iii_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x70f2;
}

static void
Opcode_lict_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf10000;
}

static void
Opcode_licw_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf12000;
}

static void
Opcode_sict_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf11000;
}

static void
Opcode_sicw_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf13000;
}

static void
Opcode_dhwb_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7042;
}

static void
Opcode_dhwbi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7052;
}

static void
Opcode_diwbui_p_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf7082;
}

static void
Opcode_diwb_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47082;
}

static void
Opcode_diwbi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x57082;
}

static void
Opcode_dhi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7062;
}

static void
Opcode_dii_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7072;
}

static void
Opcode_dpfr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7002;
}

static void
Opcode_dpfro_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7022;
}

static void
Opcode_dpfw_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7012;
}

static void
Opcode_dpfwo_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7032;
}

static void
Opcode_dhu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x27082;
}

static void
Opcode_diu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x37082;
}

static void
Opcode_dpfl_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7082;
}

static void
Opcode_sdct_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf19000;
}

static void
Opcode_ldct_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf18000;
}

static void
Opcode_rsr_prefctl_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x32800;
}

static void
Opcode_wsr_prefctl_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x132800;
}

static void
Opcode_xsr_prefctl_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x612800;
}

static void
Opcode_idtlb_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50c000;
}

static void
Opcode_pdtlb_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50d000;
}

static void
Opcode_rdtlb0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50b000;
}

static void
Opcode_rdtlb1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50f000;
}

static void
Opcode_wdtlb_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50e000;
}

static void
Opcode_iitlb_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x504000;
}

static void
Opcode_pitlb_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x505000;
}

static void
Opcode_ritlb0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x503000;
}

static void
Opcode_ritlb1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x507000;
}

static void
Opcode_witlb_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x506000;
}

static void
Opcode_rsr_cpenable_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3e000;
}

static void
Opcode_wsr_cpenable_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13e000;
}

static void
Opcode_xsr_cpenable_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61e000;
}

static void
Opcode_clamps_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x330000;
}

static void
Opcode_clamps_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800de000;
}

static void
Opcode_clamps_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5e000;
}

static void
Opcode_clamps_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1db000;
}

static void
Opcode_max_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x530000;
}

static void
Opcode_max_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1c9000;
}

static void
Opcode_maxu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x730000;
}

static void
Opcode_maxu_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1ca000;
}

static void
Opcode_min_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x430000;
}

static void
Opcode_min_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1cb000;
}

static void
Opcode_minu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x630000;
}

static void
Opcode_minu_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1cc000;
}

static void
Opcode_nsa_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x40e000;
}

static void
Opcode_nsa_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1df100;
}

static void
Opcode_nsau_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x40f000;
}

static void
Opcode_nsau_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1df200;
}

static void
Opcode_sext_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x230000;
}

static void
Opcode_sext_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800df000;
}

static void
Opcode_sext_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5f000;
}

static void
Opcode_sext_Slot_xt_flix64_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1dc000;
}

static void
Opcode_sext_Slot_xt_flix64_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa4000;
}

static void
Opcode_sext_Slot_xt_flix64_slot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8000;
}

static void
Opcode_l32ai_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb002;
}

static void
Opcode_s32ri_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf002;
}

static void
Opcode_s32c1i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe002;
}

static void
Opcode_rsr_scompare1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x30c00;
}

static void
Opcode_wsr_scompare1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x130c00;
}

static void
Opcode_xsr_scompare1_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x610c00;
}

static void
Opcode_rsr_atomctl_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x36300;
}

static void
Opcode_wsr_atomctl_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x136300;
}

static void
Opcode_xsr_atomctl_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x616300;
}

static void
Opcode_quos_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd20000;
}

static void
Opcode_quou_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc20000;
}

static void
Opcode_rems_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf20000;
}

static void
Opcode_remu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe20000;
}

static void
Opcode_rer_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x406000;
}

static void
Opcode_wer_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x407000;
}

static void
Opcode_beqz_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x400000a0;
}

static void
Opcode_beqz_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x58000000;
}

static void
Opcode_bgez_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x400004a0;
}

static void
Opcode_bgez_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x58000010;
}

static void
Opcode_bltz_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x400002a0;
}

static void
Opcode_bltz_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x58000020;
}

static void
Opcode_bnez_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x400006a0;
}

static void
Opcode_bnez_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x58000030;
}

static void
Opcode_beqi_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x40000000;
}

static void
Opcode_beqi_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x20000000;
}

static void
Opcode_bgei_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x40000040;
}

static void
Opcode_bgei_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x28000000;
}

static void
Opcode_blti_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x40000060;
}

static void
Opcode_blti_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x38000000;
}

static void
Opcode_bnei_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x400000c0;
}

static void
Opcode_bnei_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4c000000;
}

static void
Opcode_bgeui_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x40000020;
}

static void
Opcode_bgeui_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2c000000;
}

static void
Opcode_bltui_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x40000080;
}

static void
Opcode_bltui_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3c000000;
}

static void
Opcode_bbci_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0;
}

static void
Opcode_bbci_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0;
}

static void
Opcode_bbsi_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x200;
}

static void
Opcode_bbsi_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8000000;
}

static void
Opcode_ball_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x100;
}

static void
Opcode_ball_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x10000000;
}

static void
Opcode_bany_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x500;
}

static void
Opcode_bany_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x14000000;
}

static void
Opcode_bbc_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x300;
}

static void
Opcode_bbc_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x18000000;
}

static void
Opcode_bbs_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x700;
}

static void
Opcode_bbs_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1c000000;
}

static void
Opcode_beq_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800;
}

static void
Opcode_beq_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x24000000;
}

static void
Opcode_bgeu_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc00;
}

static void
Opcode_bgeu_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x30000000;
}

static void
Opcode_bge_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa00;
}

static void
Opcode_bge_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x34000000;
}

static void
Opcode_bltu_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe00;
}

static void
Opcode_bltu_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x40000000;
}

static void
Opcode_blt_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x900;
}

static void
Opcode_blt_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x44000000;
}

static void
Opcode_bnall_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd00;
}

static void
Opcode_bnall_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x48000000;
}

static void
Opcode_bne_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb00;
}

static void
Opcode_bne_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50000000;
}

static void
Opcode_bnone_w18_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf00;
}

static void
Opcode_bnone_w18_Slot_xt_flix64_slot3_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x54000000;
}

static void
Opcode_rur_ae_ovf_sar_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe30f00;
}

static void
Opcode_wur_ae_ovf_sar_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf3f000;
}

static void
Opcode_rur_ae_bithead_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe30f10;
}

static void
Opcode_wur_ae_bithead_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf3f100;
}

static void
Opcode_rur_ae_ts_fts_bu_bp_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe30f20;
}

static void
Opcode_wur_ae_ts_fts_bu_bp_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf3f200;
}

static void
Opcode_rur_ae_cw_sd_no_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe30f30;
}

static void
Opcode_wur_ae_cw_sd_no_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf3f300;
}

static void
Opcode_rur_ae_cbegin0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe30f60;
}

static void
Opcode_wur_ae_cbegin0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf3f600;
}

static void
Opcode_rur_ae_cend0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe30f70;
}

static void
Opcode_wur_ae_cend0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf3f700;
}

static void
Opcode_rur_fcr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe30e80;
}

static void
Opcode_wur_fcr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf3e800;
}

static void
Opcode_rur_fsr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe30e90;
}

static void
Opcode_wur_fsr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf3e900;
}

static void
Opcode_rur_ae_overflow_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67ea04;
}

static void
Opcode_wur_ae_overflow_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67eb04;
}

static void
Opcode_rur_ae_sar_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67ec04;
}

static void
Opcode_wur_ae_sar_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67ed04;
}

static void
Opcode_rur_ae_bitptr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67ee04;
}

static void
Opcode_wur_ae_bitptr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67ef04;
}

static void
Opcode_rur_ae_bitsused_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67f004;
}

static void
Opcode_wur_ae_bitsused_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67f104;
}

static void
Opcode_rur_ae_tablesize_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67f204;
}

static void
Opcode_wur_ae_tablesize_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67f304;
}

static void
Opcode_rur_ae_first_ts_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67f404;
}

static void
Opcode_wur_ae_first_ts_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67f504;
}

static void
Opcode_rur_ae_nextoffset_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67f604;
}

static void
Opcode_wur_ae_nextoffset_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67f704;
}

static void
Opcode_rur_ae_searchdone_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67f804;
}

static void
Opcode_wur_ae_searchdone_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67f904;
}

static void
Opcode_rur_ae_cwrap_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67fa04;
}

static void
Opcode_wur_ae_cwrap_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67fb04;
}

static void
Opcode_ae_l16m_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800e8000;
}

static void
Opcode_ae_l16m_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x63000;
}

static void
Opcode_ae_l16m_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb10004;
}

static void
Opcode_ae_l16m_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80160000;
}

static void
Opcode_ae_l16m_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0;
}

static void
Opcode_ae_l16m_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa4000;
}

static void
Opcode_ae_l16m_iu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb20004;
}

static void
Opcode_ae_l16m_iu_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80160040;
}

static void
Opcode_ae_l16m_iu_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa5000;
}

static void
Opcode_ae_l16m_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800e7000;
}

static void
Opcode_ae_l16m_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x62000;
}

static void
Opcode_ae_l16m_xu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb30004;
}

static void
Opcode_ae_l16m_xu_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800e9000;
}

static void
Opcode_ae_l16m_xu_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x64000;
}

static void
Opcode_ae_l16_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800f1000;
}

static void
Opcode_ae_l16_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6c000;
}

static void
Opcode_ae_l16_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb00004;
}

static void
Opcode_ae_l16_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80160050;
}

static void
Opcode_ae_l16_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2000;
}

static void
Opcode_ae_l16_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa8000;
}

static void
Opcode_ae_l16_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb40004;
}

static void
Opcode_ae_l16_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80160030;
}

static void
Opcode_ae_l16_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa9000;
}

static void
Opcode_ae_l16_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800f0000;
}

static void
Opcode_ae_l16_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6b000;
}

static void
Opcode_ae_l16_xp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800f2000;
}

static void
Opcode_ae_l16_xp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6d000;
}

static void
Opcode_ae_l32f24_xc_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb50004;
}

static void
Opcode_ae_l32f24_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800f4000;
}

static void
Opcode_ae_l32f24_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6f000;
}

static void
Opcode_ae_l32f24_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb60004;
}

static void
Opcode_ae_l32f24_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80160070;
}

static void
Opcode_ae_l32f24_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3000;
}

static void
Opcode_ae_l32f24_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xaa000;
}

static void
Opcode_ae_l32f24_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb70004;
}

static void
Opcode_ae_l32f24_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80168000;
}

static void
Opcode_ae_l32f24_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xab000;
}

static void
Opcode_ae_l32f24_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800f3000;
}

static void
Opcode_ae_l32f24_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6e000;
}

static void
Opcode_ae_l32f24_xp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800f5000;
}

static void
Opcode_ae_l32f24_xp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x70000;
}

static void
Opcode_ae_l32_xc_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbc0004;
}

static void
Opcode_ae_l32_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80100000;
}

static void
Opcode_ae_l32_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7b000;
}

static void
Opcode_ae_l32_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbd0004;
}

static void
Opcode_ae_l32_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80168050;
}

static void
Opcode_ae_l32_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7000;
}

static void
Opcode_ae_l32_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xae000;
}

static void
Opcode_ae_l32_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbe0004;
}

static void
Opcode_ae_l32_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80168030;
}

static void
Opcode_ae_l32_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xaf000;
}

static void
Opcode_ae_l32_x_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbf0004;
}

static void
Opcode_ae_l32_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800ff000;
}

static void
Opcode_ae_l32_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7a000;
}

static void
Opcode_ae_l32_xp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80101000;
}

static void
Opcode_ae_l32_xp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7c000;
}

static void
Opcode_ae_l32m_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800f7000;
}

static void
Opcode_ae_l32m_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x72000;
}

static void
Opcode_ae_l32m_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc80004;
}

static void
Opcode_ae_l32m_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80168040;
}

static void
Opcode_ae_l32m_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4000;
}

static void
Opcode_ae_l32m_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xac000;
}

static void
Opcode_ae_l32m_iu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc90004;
}

static void
Opcode_ae_l32m_iu_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80168020;
}

static void
Opcode_ae_l32m_iu_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xad000;
}

static void
Opcode_ae_l32m_x_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xca0004;
}

static void
Opcode_ae_l32m_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800f6000;
}

static void
Opcode_ae_l32m_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x71000;
}

static void
Opcode_ae_l32m_xu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcb0004;
}

static void
Opcode_ae_l32m_xu_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800f8000;
}

static void
Opcode_ae_l32m_xu_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x73000;
}

static void
Opcode_ae_l16x2m_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800eb000;
}

static void
Opcode_ae_l16x2m_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x66000;
}

static void
Opcode_ae_l16x2m_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb80004;
}

static void
Opcode_ae_l16x2m_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80160020;
}

static void
Opcode_ae_l16x2m_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1000;
}

static void
Opcode_ae_l16x2m_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa6000;
}

static void
Opcode_ae_l16x2m_iu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb90004;
}

static void
Opcode_ae_l16x2m_iu_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80160060;
}

static void
Opcode_ae_l16x2m_iu_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa7000;
}

static void
Opcode_ae_l16x2m_x_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xba0004;
}

static void
Opcode_ae_l16x2m_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800ea000;
}

static void
Opcode_ae_l16x2m_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x65000;
}

static void
Opcode_ae_l16x2m_xu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbb0004;
}

static void
Opcode_ae_l16x2m_xu_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800ec000;
}

static void
Opcode_ae_l16x2m_xu_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67000;
}

static void
Opcode_ae_l32x2f24_xc_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc40004;
}

static void
Opcode_ae_l32x2f24_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800fa000;
}

static void
Opcode_ae_l32x2f24_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x75000;
}

static void
Opcode_ae_l32x2f24_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc50004;
}

static void
Opcode_ae_l32x2f24_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80168060;
}

static void
Opcode_ae_l32x2f24_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5000;
}

static void
Opcode_ae_l32x2f24_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc0040;
}

static void
Opcode_ae_l32x2f24_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2c0084;
}

static void
Opcode_ae_l32x2f24_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80180070;
}

static void
Opcode_ae_l32x2f24_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc080;
}

static void
Opcode_ae_l32x2f24_rip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3d0024;
}

static void
Opcode_ae_l32x2f24_rip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018a020;
}

static void
Opcode_ae_l32x2f24_rip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd90e0;
}

static void
Opcode_ae_l32x2f24_ric_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80189060;
}

static void
Opcode_ae_l32x2f24_ric_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd90a0;
}

static void
Opcode_ae_l32x2f24_x_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc60004;
}

static void
Opcode_ae_l32x2f24_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800f9000;
}

static void
Opcode_ae_l32x2f24_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x74000;
}

static void
Opcode_ae_l32x2f24_xp_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc70004;
}

static void
Opcode_ae_l32x2f24_xp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800fb000;
}

static void
Opcode_ae_l32x2f24_xp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x76000;
}

static void
Opcode_ae_l32x2_xc_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc00004;
}

static void
Opcode_ae_l32x2_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800fd000;
}

static void
Opcode_ae_l32x2_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x78000;
}

static void
Opcode_ae_l32x2_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc10004;
}

static void
Opcode_ae_l32x2_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80168010;
}

static void
Opcode_ae_l32x2_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6000;
}

static void
Opcode_ae_l32x2_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc0020;
}

static void
Opcode_ae_l32x2_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3e0084;
}

static void
Opcode_ae_l32x2_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801800b0;
}

static void
Opcode_ae_l32x2_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd000;
}

static void
Opcode_ae_l32x2_rip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3d0014;
}

static void
Opcode_ae_l32x2_rip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018b020;
}

static void
Opcode_ae_l32x2_rip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd9030;
}

static void
Opcode_ae_l32x2_ric_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018a060;
}

static void
Opcode_ae_l32x2_ric_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd9010;
}

static void
Opcode_ae_l32x2_x_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc20004;
}

static void
Opcode_ae_l32x2_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800fc000;
}

static void
Opcode_ae_l32x2_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x77000;
}

static void
Opcode_ae_l32x2_xp_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc30004;
}

static void
Opcode_ae_l32x2_xp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800fe000;
}

static void
Opcode_ae_l32x2_xp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x79000;
}

static void
Opcode_ae_l16x4_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800ee000;
}

static void
Opcode_ae_l16x4_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x69000;
}

static void
Opcode_ae_l16x4_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc0004;
}

static void
Opcode_ae_l16x4_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80160010;
}

static void
Opcode_ae_l16x4_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc0000;
}

static void
Opcode_ae_l16x4_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x900084;
}

static void
Opcode_ae_l16x4_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80180030;
}

static void
Opcode_ae_l16x4_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc000;
}

static void
Opcode_ae_l16x4_rip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80189020;
}

static void
Opcode_ae_l16x4_rip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd9060;
}

static void
Opcode_ae_l16x4_ric_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80188060;
}

static void
Opcode_ae_l16x4_ric_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd9020;
}

static void
Opcode_ae_l16x4_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800ed000;
}

static void
Opcode_ae_l16x4_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x68000;
}

static void
Opcode_ae_l16x4_xp_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd0004;
}

static void
Opcode_ae_l16x4_xp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800ef000;
}

static void
Opcode_ae_l16x4_xp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6a000;
}

static void
Opcode_ae_l64_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80103000;
}

static void
Opcode_ae_l64_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7e000;
}

static void
Opcode_ae_l64_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf0004;
}

static void
Opcode_ae_l64_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80168070;
}

static void
Opcode_ae_l64_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8000;
}

static void
Opcode_ae_l64_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc0060;
}

static void
Opcode_ae_l64_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80170000;
}

static void
Opcode_ae_l64_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc4000;
}

static void
Opcode_ae_l64_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80102000;
}

static void
Opcode_ae_l64_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7d000;
}

static void
Opcode_ae_l64_xp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80104000;
}

static void
Opcode_ae_l64_xp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7f000;
}

static void
Opcode_ae_s16x2m_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80109000;
}

static void
Opcode_ae_s16x2m_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x84000;
}

static void
Opcode_ae_s16x2m_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd80004;
}

static void
Opcode_ae_s16x2m_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80170060;
}

static void
Opcode_ae_s16x2m_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa000;
}

static void
Opcode_ae_s16x2m_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb2000;
}

static void
Opcode_ae_s16x2m_iu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd90004;
}

static void
Opcode_ae_s16x2m_iu_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80170010;
}

static void
Opcode_ae_s16x2m_iu_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb3000;
}

static void
Opcode_ae_s16x2m_x_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda0004;
}

static void
Opcode_ae_s16x2m_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80108000;
}

static void
Opcode_ae_s16x2m_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x83000;
}

static void
Opcode_ae_s16x2m_xu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb0004;
}

static void
Opcode_ae_s16x2m_xu_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8010a000;
}

static void
Opcode_ae_s16x2m_xu_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x85000;
}

static void
Opcode_ae_s32x2f24_xc_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xec0004;
}

static void
Opcode_ae_s32x2f24_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8011e000;
}

static void
Opcode_ae_s32x2f24_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x99000;
}

static void
Opcode_ae_s32x2f24_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xed0004;
}

static void
Opcode_ae_s32x2f24_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80180000;
}

static void
Opcode_ae_s32x2f24_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x10000;
}

static void
Opcode_ae_s32x2f24_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc4020;
}

static void
Opcode_ae_s32x2f24_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x620084;
}

static void
Opcode_ae_s32x2f24_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80188000;
}

static void
Opcode_ae_s32x2f24_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce000;
}

static void
Opcode_ae_s32x2f24_rip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018d020;
}

static void
Opcode_ae_s32x2f24_rip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd90b0;
}

static void
Opcode_ae_s32x2f24_ric_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018c060;
}

static void
Opcode_ae_s32x2f24_ric_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd9090;
}

static void
Opcode_ae_s32x2f24_x_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xee0004;
}

static void
Opcode_ae_s32x2f24_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8011d000;
}

static void
Opcode_ae_s32x2f24_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x98000;
}

static void
Opcode_ae_s32x2f24_xp_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xef0004;
}

static void
Opcode_ae_s32x2f24_xp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8011f000;
}

static void
Opcode_ae_s32x2f24_xp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9a000;
}

static void
Opcode_ae_s32x2_xc_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe80004;
}

static void
Opcode_ae_s32x2_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80121000;
}

static void
Opcode_ae_s32x2_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9c000;
}

static void
Opcode_ae_s32x2_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe90004;
}

static void
Opcode_ae_s32x2_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80180040;
}

static void
Opcode_ae_s32x2_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x11000;
}

static void
Opcode_ae_s32x2_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc4060;
}

static void
Opcode_ae_s32x2_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x620004;
}

static void
Opcode_ae_s32x2_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80188040;
}

static void
Opcode_ae_s32x2_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce080;
}

static void
Opcode_ae_s32x2_rip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018e020;
}

static void
Opcode_ae_s32x2_rip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd90f0;
}

static void
Opcode_ae_s32x2_ric_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018d060;
}

static void
Opcode_ae_s32x2_ric_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd90d0;
}

static void
Opcode_ae_s32x2_x_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea0004;
}

static void
Opcode_ae_s32x2_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80120000;
}

static void
Opcode_ae_s32x2_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9b000;
}

static void
Opcode_ae_s32x2_xp_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xeb0004;
}

static void
Opcode_ae_s32x2_xp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80122000;
}

static void
Opcode_ae_s32x2_xp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9d000;
}

static void
Opcode_ae_s16x4_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8010c000;
}

static void
Opcode_ae_s16x4_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x87000;
}

static void
Opcode_ae_s16x4_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0004;
}

static void
Opcode_ae_s16x4_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80170050;
}

static void
Opcode_ae_s16x4_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc4040;
}

static void
Opcode_ae_s16x4_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800084;
}

static void
Opcode_ae_s16x4_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801800f0;
}

static void
Opcode_ae_s16x4_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd080;
}

static void
Opcode_ae_s16x4_rip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018c020;
}

static void
Opcode_ae_s16x4_rip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd9070;
}

static void
Opcode_ae_s16x4_ric_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018b060;
}

static void
Opcode_ae_s16x4_ric_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd9050;
}

static void
Opcode_ae_s16x4_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8010b000;
}

static void
Opcode_ae_s16x4_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x86000;
}

static void
Opcode_ae_s16x4_xp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8010d000;
}

static void
Opcode_ae_s16x4_xp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x88000;
}

static void
Opcode_ae_s16m_l_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80106000;
}

static void
Opcode_ae_s16m_l_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x81000;
}

static void
Opcode_ae_s16m_l_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd50004;
}

static void
Opcode_ae_s16m_l_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80170040;
}

static void
Opcode_ae_s16m_l_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9000;
}

static void
Opcode_ae_s16m_l_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb0000;
}

static void
Opcode_ae_s16m_l_iu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd60004;
}

static void
Opcode_ae_s16m_l_iu_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80170020;
}

static void
Opcode_ae_s16m_l_iu_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb1000;
}

static void
Opcode_ae_s16m_l_x_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd70004;
}

static void
Opcode_ae_s16m_l_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80105000;
}

static void
Opcode_ae_s16m_l_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80000;
}

static void
Opcode_ae_s16m_l_xu_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80107000;
}

static void
Opcode_ae_s16m_l_xu_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x82000;
}

static void
Opcode_ae_s32f24_l_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80115000;
}

static void
Opcode_ae_s32f24_l_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x90000;
}

static void
Opcode_ae_s32f24_l_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xde0004;
}

static void
Opcode_ae_s32f24_l_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80178020;
}

static void
Opcode_ae_s32f24_l_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd000;
}

static void
Opcode_ae_s32f24_l_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb8000;
}

static void
Opcode_ae_s32f24_l_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdf0004;
}

static void
Opcode_ae_s32f24_l_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80178060;
}

static void
Opcode_ae_s32f24_l_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb9000;
}

static void
Opcode_ae_s32f24_l_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80114000;
}

static void
Opcode_ae_s32f24_l_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8f000;
}

static void
Opcode_ae_s32f24_l_xp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80116000;
}

static void
Opcode_ae_s32f24_l_xp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x91000;
}

static void
Opcode_ae_s32_l_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80124000;
}

static void
Opcode_ae_s32_l_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9f000;
}

static void
Opcode_ae_s32_l_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe00004;
}

static void
Opcode_ae_s32_l_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80180020;
}

static void
Opcode_ae_s32_l_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x12000;
}

static void
Opcode_ae_s32_l_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbe000;
}

static void
Opcode_ae_s32_l_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe10004;
}

static void
Opcode_ae_s32_l_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80180060;
}

static void
Opcode_ae_s32_l_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbf000;
}

static void
Opcode_ae_s32_l_x_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe20004;
}

static void
Opcode_ae_s32_l_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80123000;
}

static void
Opcode_ae_s32_l_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9e000;
}

static void
Opcode_ae_s32_l_xp_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe30004;
}

static void
Opcode_ae_s32_l_xp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80125000;
}

static void
Opcode_ae_s32_l_xp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa0000;
}

static void
Opcode_ae_s16_0_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8010f000;
}

static void
Opcode_ae_s16_0_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8a000;
}

static void
Opcode_ae_s16_0_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd20004;
}

static void
Opcode_ae_s16_0_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80170030;
}

static void
Opcode_ae_s16_0_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb000;
}

static void
Opcode_ae_s16_0_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb4000;
}

static void
Opcode_ae_s16_0_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd30004;
}

static void
Opcode_ae_s16_0_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80170070;
}

static void
Opcode_ae_s16_0_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb5000;
}

static void
Opcode_ae_s16_0_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8010e000;
}

static void
Opcode_ae_s16_0_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x89000;
}

static void
Opcode_ae_s16_0_xp_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40004;
}

static void
Opcode_ae_s16_0_xp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80110000;
}

static void
Opcode_ae_s16_0_xp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8b000;
}

static void
Opcode_ae_s64_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80127000;
}

static void
Opcode_ae_s64_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa2000;
}

static void
Opcode_ae_s64_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x10004;
}

static void
Opcode_ae_s64_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80180010;
}

static void
Opcode_ae_s64_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13000;
}

static void
Opcode_ae_s64_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc8000;
}

static void
Opcode_ae_s64_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x20004;
}

static void
Opcode_ae_s64_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80180050;
}

static void
Opcode_ae_s64_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc8040;
}

static void
Opcode_ae_s64_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80126000;
}

static void
Opcode_ae_s64_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa1000;
}

static void
Opcode_ae_s64_xp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80128000;
}

static void
Opcode_ae_s64_xp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa3000;
}

static void
Opcode_ae_s32m_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80118000;
}

static void
Opcode_ae_s32m_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x93000;
}

static void
Opcode_ae_s32m_i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe40004;
}

static void
Opcode_ae_s32m_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80178010;
}

static void
Opcode_ae_s32m_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe000;
}

static void
Opcode_ae_s32m_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xba000;
}

static void
Opcode_ae_s32m_iu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe50004;
}

static void
Opcode_ae_s32m_iu_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80178050;
}

static void
Opcode_ae_s32m_iu_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbb000;
}

static void
Opcode_ae_s32m_x_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe60004;
}

static void
Opcode_ae_s32m_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80117000;
}

static void
Opcode_ae_s32m_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x92000;
}

static void
Opcode_ae_s32m_xu_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe70004;
}

static void
Opcode_ae_s32m_xu_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80119000;
}

static void
Opcode_ae_s32m_xu_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x94000;
}

static void
Opcode_ae_zalign64_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x281304;
}

static void
Opcode_ae_zalign64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a3994;
}

static void
Opcode_ae_zalign64_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdd294;
}

static void
Opcode_ae_lalign64_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190700;
}

static void
Opcode_ae_lalign64_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc000;
}

static void
Opcode_ae_salign64_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190710;
}

static void
Opcode_ae_salign64_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc100;
}

static void
Opcode_ae_movalign_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x280304;
}

static void
Opcode_ae_movalign_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a3990;
}

static void
Opcode_ae_movalign_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdd290;
}

static void
Opcode_ae_la64_pp_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7720c4;
}

static void
Opcode_ae_la64_pp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a3900;
}

static void
Opcode_ae_la64_pp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdd200;
}

static void
Opcode_ae_la24pos_pc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a3190;
}

static void
Opcode_ae_la24pos_pc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc290;
}

static void
Opcode_ae_la24x2pos_pc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a3510;
}

static void
Opcode_ae_la24x2pos_pc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc310;
}

static void
Opcode_ae_la32x2pos_pc_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7710c4;
}

static void
Opcode_ae_la32x2pos_pc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a3590;
}

static void
Opcode_ae_la32x2pos_pc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc390;
}

static void
Opcode_ae_la16x4pos_pc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a3110;
}

static void
Opcode_ae_la16x4pos_pc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc210;
}

static void
Opcode_ae_la24neg_pc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a3180;
}

static void
Opcode_ae_la24neg_pc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc280;
}

static void
Opcode_ae_la24x2neg_pc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a3500;
}

static void
Opcode_ae_la24x2neg_pc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc300;
}

static void
Opcode_ae_la32x2neg_pc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a3580;
}

static void
Opcode_ae_la32x2neg_pc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc380;
}

static void
Opcode_ae_la16x4neg_pc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a3100;
}

static void
Opcode_ae_la16x4neg_pc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc200;
}

static void
Opcode_ae_sa64pos_fp_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7730c4;
}

static void
Opcode_ae_sa64pos_fp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a3980;
}

static void
Opcode_ae_sa64pos_fp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdd280;
}

static void
Opcode_ae_sa64neg_fp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a3910;
}

static void
Opcode_ae_sa64neg_fp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdd210;
}

static void
Opcode_ae_la32x2_ic_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd0084;
}

static void
Opcode_ae_la32x2_ic_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a9000;
}

static void
Opcode_ae_la32x2_ic_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd3000;
}

static void
Opcode_ae_la32x2_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd00c4;
}

static void
Opcode_ae_la32x2_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a9080;
}

static void
Opcode_ae_la32x2_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd3080;
}

static void
Opcode_ae_la32x2_rip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a9090;
}

static void
Opcode_ae_la32x2_rip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd3090;
}

static void
Opcode_ae_la32x2_ric_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a9010;
}

static void
Opcode_ae_la32x2_ric_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd3010;
}

static void
Opcode_ae_la16x4_ic_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x370084;
}

static void
Opcode_ae_la16x4_ic_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a0010;
}

static void
Opcode_ae_la16x4_ic_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf000;
}

static void
Opcode_ae_la16x4_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3700c4;
}

static void
Opcode_ae_la16x4_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a0090;
}

static void
Opcode_ae_la16x4_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf080;
}

static void
Opcode_ae_la16x4_rip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x350084;
}

static void
Opcode_ae_la16x4_rip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a8090;
}

static void
Opcode_ae_la16x4_rip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf090;
}

static void
Opcode_ae_la16x4_ric_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a8010;
}

static void
Opcode_ae_la16x4_ric_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf010;
}

static void
Opcode_ae_la32x2f24_ic_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc0004;
}

static void
Opcode_ae_la32x2f24_ic_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a1000;
}

static void
Opcode_ae_la32x2f24_ic_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd2000;
}

static void
Opcode_ae_la32x2f24_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc0044;
}

static void
Opcode_ae_la32x2f24_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a1080;
}

static void
Opcode_ae_la32x2f24_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd2080;
}

static void
Opcode_ae_la32x2f24_rip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a1090;
}

static void
Opcode_ae_la32x2f24_rip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd2090;
}

static void
Opcode_ae_la32x2f24_ric_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a1010;
}

static void
Opcode_ae_la32x2f24_ric_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd2010;
}

static void
Opcode_ae_la24_ic_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018c080;
}

static void
Opcode_ae_la24_ic_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd1000;
}

static void
Opcode_ae_la24_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018d080;
}

static void
Opcode_ae_la24_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd1080;
}

static void
Opcode_ae_la24_rip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018f080;
}

static void
Opcode_ae_la24_rip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd1090;
}

static void
Opcode_ae_la24_ric_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018e080;
}

static void
Opcode_ae_la24_ric_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd1010;
}

static void
Opcode_ae_la24x2_ic_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd0004;
}

static void
Opcode_ae_la24x2_ic_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80188080;
}

static void
Opcode_ae_la24x2_ic_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd0000;
}

static void
Opcode_ae_la24x2_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd0044;
}

static void
Opcode_ae_la24x2_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80189080;
}

static void
Opcode_ae_la24x2_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd0080;
}

static void
Opcode_ae_la24x2_rip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018b080;
}

static void
Opcode_ae_la24x2_rip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd0090;
}

static void
Opcode_ae_la24x2_ric_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018a080;
}

static void
Opcode_ae_la24x2_ric_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd0010;
}

static void
Opcode_ae_sa32x2_ic_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a2000;
}

static void
Opcode_ae_sa32x2_ic_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd8000;
}

static void
Opcode_ae_sa32x2_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc00c4;
}

static void
Opcode_ae_sa32x2_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a2080;
}

static void
Opcode_ae_sa32x2_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd8080;
}

static void
Opcode_ae_sa32x2_rip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a2090;
}

static void
Opcode_ae_sa32x2_rip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd8090;
}

static void
Opcode_ae_sa32x2_ric_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a2010;
}

static void
Opcode_ae_sa32x2_ric_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd8010;
}

static void
Opcode_ae_sa16x4_ic_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80188010;
}

static void
Opcode_ae_sa16x4_ic_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd4000;
}

static void
Opcode_ae_sa16x4_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc0084;
}

static void
Opcode_ae_sa16x4_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80188090;
}

static void
Opcode_ae_sa16x4_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd4080;
}

static void
Opcode_ae_sa16x4_rip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80189090;
}

static void
Opcode_ae_sa16x4_rip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd4090;
}

static void
Opcode_ae_sa16x4_ric_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80189010;
}

static void
Opcode_ae_sa16x4_ric_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd4010;
}

static void
Opcode_ae_sa32x2f24_ic_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018e010;
}

static void
Opcode_ae_sa32x2f24_ic_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd7000;
}

static void
Opcode_ae_sa32x2f24_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3f00c4;
}

static void
Opcode_ae_sa32x2f24_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018e090;
}

static void
Opcode_ae_sa32x2f24_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd7080;
}

static void
Opcode_ae_sa32x2f24_rip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018f090;
}

static void
Opcode_ae_sa32x2f24_rip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd7090;
}

static void
Opcode_ae_sa32x2f24_ric_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018f010;
}

static void
Opcode_ae_sa32x2f24_ric_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd7010;
}

static void
Opcode_ae_sa24_l_ic_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018c010;
}

static void
Opcode_ae_sa24_l_ic_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd6000;
}

static void
Opcode_ae_sa24_l_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018c090;
}

static void
Opcode_ae_sa24_l_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd6080;
}

static void
Opcode_ae_sa24_l_rip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018d090;
}

static void
Opcode_ae_sa24_l_rip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd6090;
}

static void
Opcode_ae_sa24_l_ric_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018d010;
}

static void
Opcode_ae_sa24_l_ric_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd6010;
}

static void
Opcode_ae_sa24x2_ic_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018a010;
}

static void
Opcode_ae_sa24x2_ic_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd5000;
}

static void
Opcode_ae_sa24x2_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018a090;
}

static void
Opcode_ae_sa24x2_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd5080;
}

static void
Opcode_ae_sa24x2_rip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018b090;
}

static void
Opcode_ae_sa24x2_rip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd5090;
}

static void
Opcode_ae_sa24x2_ric_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018b010;
}

static void
Opcode_ae_sa24x2_ric_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd5010;
}

static void
Opcode_ae_s32ra64s_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80178030;
}

static void
Opcode_ae_s32ra64s_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf000;
}

static void
Opcode_ae_s32ra64s_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbc000;
}

static void
Opcode_ae_s32ra64s_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80178070;
}

static void
Opcode_ae_s32ra64s_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbd000;
}

static void
Opcode_ae_s32ra64s_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8011a000;
}

static void
Opcode_ae_s32ra64s_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x95000;
}

static void
Opcode_ae_s32ra64s_xp_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x40004;
}

static void
Opcode_ae_s32ra64s_xp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8011c000;
}

static void
Opcode_ae_s32ra64s_xp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x97000;
}

static void
Opcode_ae_s32ra64s_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8011b000;
}

static void
Opcode_ae_s32ra64s_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x96000;
}

static void
Opcode_ae_s24ra64s_i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80178000;
}

static void
Opcode_ae_s24ra64s_i_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc000;
}

static void
Opcode_ae_s24ra64s_i_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb6000;
}

static void
Opcode_ae_s24ra64s_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80178040;
}

static void
Opcode_ae_s24ra64s_ip_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb7000;
}

static void
Opcode_ae_s24ra64s_x_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80111000;
}

static void
Opcode_ae_s24ra64s_x_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8c000;
}

static void
Opcode_ae_s24ra64s_xp_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdd0004;
}

static void
Opcode_ae_s24ra64s_xp_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80113000;
}

static void
Opcode_ae_s24ra64s_xp_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8e000;
}

static void
Opcode_ae_s24ra64s_xc_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80112000;
}

static void
Opcode_ae_s24ra64s_xc_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8d000;
}

static void
Opcode_ae_s32x2ra64s_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4;
}

static void
Opcode_ae_s32x2ra64s_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8012a000;
}

static void
Opcode_ae_s24x2ra64s_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x30004;
}

static void
Opcode_ae_s24x2ra64s_ip_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80129000;
}

static void
Opcode_ae_addbrba32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800d4000;
}

static void
Opcode_ae_addbrba32_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x54000;
}

static void
Opcode_ae_sel16i_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa00004;
}

static void
Opcode_ae_sel16i_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80090000;
}

static void
Opcode_ae_sel16i_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc30000;
}

static void
Opcode_ae_sel16i_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0;
}

static void
Opcode_ae_sel16i_n_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0;
}

static void
Opcode_ae_shortswap_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0fb0;
}

static void
Opcode_ae_shortswap_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x49070;
}

static void
Opcode_ae_movt16x4_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a4040;
}

static void
Opcode_ae_movt16x4_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x45100;
}

static void
Opcode_ae_movf16x4_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a4000;
}

static void
Opcode_ae_movf16x4_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x45000;
}

static void
Opcode_ae_movt32x2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3b0014;
}

static void
Opcode_ae_movt32x2_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a0020;
}

static void
Opcode_ae_movt32x2_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x44100;
}

static void
Opcode_ae_movf32x2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3a0014;
}

static void
Opcode_ae_movf32x2_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a0000;
}

static void
Opcode_ae_movf32x2_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x44000;
}

static void
Opcode_ae_movda32x2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x150004;
}

static void
Opcode_ae_movda32x2_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800e5000;
}

static void
Opcode_ae_movda32x2_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x60000;
}

static void
Opcode_ae_movda32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3c0034;
}

static void
Opcode_ae_movda32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80188020;
}

static void
Opcode_ae_movda32_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x14500;
}

static void
Opcode_ae_movda32_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50b40;
}

static void
Opcode_ae_movda16x2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x140004;
}

static void
Opcode_ae_movda16x2_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800e4000;
}

static void
Opcode_ae_movda16_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3c0024;
}

static void
Opcode_ae_movda16_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ac0e0;
}

static void
Opcode_ae_movda16_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x14400;
}

static void
Opcode_ae_movda16_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50b30;
}

static void
Opcode_ae_movi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3d0084;
}

static void
Opcode_ae_movi_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a4020;
}

static void
Opcode_ae_movi_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd400b0;
}

static void
Opcode_ae_movi_Slot_ae_minislot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x14000;
}

static void
Opcode_ae_movi_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x60000;
}

static void
Opcode_ae_movi_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd9000;
}

static void
Opcode_ae_movi_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfa000;
}

static void
Opcode_ae_movi_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x45200;
}

static void
Opcode_ae_truncp24a32x2_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800e6000;
}

static void
Opcode_ae_truncp24a32x2_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61000;
}

static void
Opcode_ae_sat16x4_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80140000;
}

static void
Opcode_ae_sat16x4_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x25000;
}

static void
Opcode_ae_cvt32x2f16_32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801aa060;
}

static void
Opcode_ae_cvt32x2f16_32_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc9070;
}

static void
Opcode_ae_cvt32x2f16_32_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x49030;
}

static void
Opcode_ae_cvt32x2f16_10_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801aa040;
}

static void
Opcode_ae_cvt32x2f16_10_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc9030;
}

static void
Opcode_ae_cvt32x2f16_10_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x49020;
}

static void
Opcode_ae_sext32x2d16_32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1c0014;
}

static void
Opcode_ae_sext32x2d16_32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801aa050;
}

static void
Opcode_ae_sext32x2d16_32_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc90b0;
}

static void
Opcode_ae_sext32x2d16_32_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x49060;
}

static void
Opcode_ae_sext32x2d16_10_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801aa030;
}

static void
Opcode_ae_sext32x2d16_10_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc90e0;
}

static void
Opcode_ae_sext32x2d16_10_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x49050;
}

static void
Opcode_ae_cvta32f24s_l_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a4010;
}

static void
Opcode_ae_cvta32f24s_l_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc8060;
}

static void
Opcode_ae_cvta32f24s_h_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018f060;
}

static void
Opcode_ae_cvta32f24s_h_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc8020;
}

static void
Opcode_ae_cvtp24a16x2_ll_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x130004;
}

static void
Opcode_ae_cvtp24a16x2_ll_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800e3000;
}

static void
Opcode_ae_cvtp24a16x2_lh_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x120004;
}

static void
Opcode_ae_cvtp24a16x2_lh_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800e2000;
}

static void
Opcode_ae_cvtp24a16x2_hl_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x110004;
}

static void
Opcode_ae_cvtp24a16x2_hl_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800e1000;
}

static void
Opcode_ae_cvtp24a16x2_hh_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x100004;
}

static void
Opcode_ae_cvtp24a16x2_hh_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800e0000;
}

static void
Opcode_ae_truncp24q48x2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1d0004;
}

static void
Opcode_ae_truncp24q48x2_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8015a000;
}

static void
Opcode_ae_truncp24q48x2_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3e000;
}

static void
Opcode_ae_trunca32x2f64s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf00004;
}

static void
Opcode_ae_trunca32x2f64s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80030000;
}

static void
Opcode_ae_trunca32x2f64s_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x30000;
}

static void
Opcode_ae_trunci32x2f64s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80080000;
}

static void
Opcode_ae_trunca32f64s_l_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80020000;
}

static void
Opcode_ae_trunca32f64s_l_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x20000;
}

static void
Opcode_ae_trunci32f64s_l_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80070000;
}

static void
Opcode_ae_truncp16_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1c0004;
}

static void
Opcode_ae_truncp16_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801aa000;
}

static void
Opcode_ae_truncp16_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x48400;
}

static void
Opcode_ae_round32x2f64ssym_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8013d000;
}

static void
Opcode_ae_round32x2f64ssym_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x22000;
}

static void
Opcode_ae_round32x2f64sasym_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x470004;
}

static void
Opcode_ae_round32x2f64sasym_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8013c000;
}

static void
Opcode_ae_round32x2f64sasym_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x21000;
}

static void
Opcode_ae_round32x2f48ssym_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8013b000;
}

static void
Opcode_ae_round32x2f48ssym_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x20000;
}

static void
Opcode_ae_round32x2f48sasym_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8013a000;
}

static void
Opcode_ae_round32x2f48sasym_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1f000;
}

static void
Opcode_ae_round16x4f32ssym_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80137000;
}

static void
Opcode_ae_round16x4f32ssym_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1c000;
}

static void
Opcode_ae_round16x4f32sasym_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x420004;
}

static void
Opcode_ae_round16x4f32sasym_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80136000;
}

static void
Opcode_ae_round16x4f32sasym_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1b000;
}

static void
Opcode_ae_round24x2f48ssym_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x450004;
}

static void
Opcode_ae_round24x2f48ssym_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80139000;
}

static void
Opcode_ae_round24x2f48ssym_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1e000;
}

static void
Opcode_ae_round24x2f48sasym_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x440004;
}

static void
Opcode_ae_round24x2f48sasym_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80138000;
}

static void
Opcode_ae_round24x2f48sasym_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1d000;
}

static void
Opcode_ae_roundsp16q48x2sym_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8013f000;
}

static void
Opcode_ae_roundsp16q48x2sym_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x24000;
}

static void
Opcode_ae_roundsp16q48x2asym_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x430004;
}

static void
Opcode_ae_roundsp16q48x2asym_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8013e000;
}

static void
Opcode_ae_roundsp16q48x2asym_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x23000;
}

static void
Opcode_ae_minabs32s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80154000;
}

static void
Opcode_ae_minabs32s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x39000;
}

static void
Opcode_ae_maxabs32s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80150000;
}

static void
Opcode_ae_maxabs32s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x35000;
}

static void
Opcode_ae_roundsp16f24sym_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018f020;
}

static void
Opcode_ae_roundsp16f24sym_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x49010;
}

static void
Opcode_ae_roundsp16f24asym_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8018e060;
}

static void
Opcode_ae_roundsp16f24asym_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x49000;
}

static void
Opcode_ae_mov_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3e0014;
}

static void
Opcode_ae_mov_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801aa010;
}

static void
Opcode_ae_mov_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0eb0;
}

static void
Opcode_ae_mov_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc90a0;
}

static void
Opcode_ae_mov_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfb0e0;
}

static void
Opcode_ae_mov_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x49040;
}

static void
Opcode_ae_movt64_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x600004;
}

static void
Opcode_ae_movt64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8015d000;
}

static void
Opcode_ae_movt64_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x41000;
}

static void
Opcode_ae_movf64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8015c000;
}

static void
Opcode_ae_movf64_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x40000;
}

static void
Opcode_ae_cvtq56a32s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ac0a0;
}

static void
Opcode_ae_cvtq56a32s_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50b20;
}

static void
Opcode_ae_cvt48a32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3c0014;
}

static void
Opcode_ae_cvt48a32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ac020;
}

static void
Opcode_ae_cvt48a32_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50b00;
}

static void
Opcode_ae_cvt64a32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ac060;
}

static void
Opcode_ae_cvt64a32_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50b10;
}

static void
Opcode_ae_cvtq56p32s_l_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3e0034;
}

static void
Opcode_ae_cvtq56p32s_l_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ac0f0;
}

static void
Opcode_ae_cvtq56p32s_l_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x48300;
}

static void
Opcode_ae_cvtq56p32s_h_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3e0024;
}

static void
Opcode_ae_cvtq56p32s_h_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ac0d0;
}

static void
Opcode_ae_cvtq56p32s_h_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x48200;
}

static void
Opcode_ae_cvt64f32_h_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ac0b0;
}

static void
Opcode_ae_cvt64f32_h_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x48100;
}

static void
Opcode_ae_sat48s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2b0a04;
}

static void
Opcode_ae_sat48s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ad001;
}

static void
Opcode_ae_sat48s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47f00;
}

static void
Opcode_ae_satq56s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a5002;
}

static void
Opcode_ae_satq56s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x48000;
}

static void
Opcode_ae_sat24s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a5001;
}

static void
Opcode_ae_sat24s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47e00;
}

static void
Opcode_ae_truncq32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1c0024;
}

static void
Opcode_ae_truncq32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801aa020;
}

static void
Opcode_ae_truncq32_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x48500;
}

static void
Opcode_ae_minabs64s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80155000;
}

static void
Opcode_ae_minabs64s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3a000;
}

static void
Opcode_ae_maxabs64s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80151000;
}

static void
Opcode_ae_maxabs64s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x36000;
}

static void
Opcode_ae_roundsq32f48sym_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2b0904;
}

static void
Opcode_ae_roundsq32f48sym_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ad000;
}

static void
Opcode_ae_roundsq32f48sym_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47d00;
}

static void
Opcode_ae_roundsq32f48asym_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2b0804;
}

static void
Opcode_ae_roundsq32f48asym_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a5000;
}

static void
Opcode_ae_roundsq32f48asym_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47c00;
}

static void
Opcode_ae_trunca32q48_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x250034;
}

static void
Opcode_ae_trunca32q48_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ac090;
}

static void
Opcode_ae_trunca32q48_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc9060;
}

static void
Opcode_ae_movad32_l_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2500c4;
}

static void
Opcode_ae_movad32_l_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a40d0;
}

static void
Opcode_ae_movad32_l_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x55700;
}

static void
Opcode_ae_movad32_l_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc8070;
}

static void
Opcode_ae_movad32_h_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2500b4;
}

static void
Opcode_ae_movad32_h_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a40b0;
}

static void
Opcode_ae_movad32_h_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x54700;
}

static void
Opcode_ae_movad32_h_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc8030;
}

static void
Opcode_ae_movad16_3_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2500a4;
}

static void
Opcode_ae_movad16_3_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a4090;
}

static void
Opcode_ae_movad16_3_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x53700;
}

static void
Opcode_ae_movad16_2_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x250094;
}

static void
Opcode_ae_movad16_2_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a4070;
}

static void
Opcode_ae_movad16_2_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x52700;
}

static void
Opcode_ae_movad16_1_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a4050;
}

static void
Opcode_ae_movad16_1_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x51700;
}

static void
Opcode_ae_movad16_0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x250084;
}

static void
Opcode_ae_movad16_0_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a4030;
}

static void
Opcode_ae_movad16_0_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50700;
}

static void
Opcode_ae_sra64_32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800c0f00;
}

static void
Opcode_ae_pksr32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x270204;
}

static void
Opcode_ae_pksr32_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd400a1;
}

static void
Opcode_ae_pksr32_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf9001;
}

static void
Opcode_ae_pksr24_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x260204;
}

static void
Opcode_ae_pksr24_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd400a0;
}

static void
Opcode_ae_pksr24_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf9000;
}

static void
Opcode_ae_trunca16p24s_l_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x250024;
}

static void
Opcode_ae_trunca16p24s_l_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ac070;
}

static void
Opcode_ae_trunca16p24s_l_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc9020;
}

static void
Opcode_ae_trunca16p24s_h_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x250014;
}

static void
Opcode_ae_trunca16p24s_h_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ac050;
}

static void
Opcode_ae_trunca16p24s_h_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc80f0;
}

static void
Opcode_ae_add32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x300004;
}

static void
Opcode_ae_add32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8012e000;
}

static void
Opcode_ae_add32_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40010;
}

static void
Opcode_ae_add32_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe7000;
}

static void
Opcode_ae_add32_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13000;
}

static void
Opcode_ae_sub32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4c0004;
}

static void
Opcode_ae_sub32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80144000;
}

static void
Opcode_ae_sub32_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0060;
}

static void
Opcode_ae_sub32_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf2000;
}

static void
Opcode_ae_sub32_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x29000;
}

static void
Opcode_ae_addsub32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80134000;
}

static void
Opcode_ae_addsub32_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40040;
}

static void
Opcode_ae_addsub32_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xed000;
}

static void
Opcode_ae_addsub32_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x19000;
}

static void
Opcode_ae_subadd32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80148000;
}

static void
Opcode_ae_subadd32_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0080;
}

static void
Opcode_ae_subadd32_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf6000;
}

static void
Opcode_ae_subadd32_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2d000;
}

static void
Opcode_ae_add16_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8012b000;
}

static void
Opcode_ae_add16_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb00f0;
}

static void
Opcode_ae_add16_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe4000;
}

static void
Opcode_ae_add16_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x10000;
}

static void
Opcode_ae_sub16_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80141000;
}

static void
Opcode_ae_sub16_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40050;
}

static void
Opcode_ae_sub16_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xef000;
}

static void
Opcode_ae_sub16_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x26000;
}

static void
Opcode_ae_add32_hl_lh_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80130000;
}

static void
Opcode_ae_add32_hl_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40020;
}

static void
Opcode_ae_add32_hl_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe9000;
}

static void
Opcode_ae_add32_hl_lh_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x15000;
}

static void
Opcode_ae_neg32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ab00b;
}

static void
Opcode_ae_neg32_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc09b0;
}

static void
Opcode_ae_neg32_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfb090;
}

static void
Opcode_ae_neg32_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47700;
}

static void
Opcode_ae_abs32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ab002;
}

static void
Opcode_ae_abs32_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40ab0;
}

static void
Opcode_ae_abs32_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfb020;
}

static void
Opcode_ae_abs32_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x45b00;
}

static void
Opcode_ae_add24s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x320004;
}

static void
Opcode_ae_add24s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8012d000;
}

static void
Opcode_ae_add24s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0000;
}

static void
Opcode_ae_add24s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe6000;
}

static void
Opcode_ae_add24s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x12000;
}

static void
Opcode_ae_sub24s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80143000;
}

static void
Opcode_ae_sub24s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40060;
}

static void
Opcode_ae_sub24s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf1000;
}

static void
Opcode_ae_sub24s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x28000;
}

static void
Opcode_ae_add32s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x400004;
}

static void
Opcode_ae_add32s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8012f000;
}

static void
Opcode_ae_add32s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0010;
}

static void
Opcode_ae_add32s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe8000;
}

static void
Opcode_ae_add32s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x14000;
}

static void
Opcode_ae_sub32s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4f0004;
}

static void
Opcode_ae_sub32s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80145000;
}

static void
Opcode_ae_sub32s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40070;
}

static void
Opcode_ae_sub32s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf3000;
}

static void
Opcode_ae_sub32s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2a000;
}

static void
Opcode_ae_addsub32s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80135000;
}

static void
Opcode_ae_addsub32s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0040;
}

static void
Opcode_ae_addsub32s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xee000;
}

static void
Opcode_ae_addsub32s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1a000;
}

static void
Opcode_ae_subadd32s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80149000;
}

static void
Opcode_ae_subadd32s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40090;
}

static void
Opcode_ae_subadd32s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf7000;
}

static void
Opcode_ae_subadd32s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2e000;
}

static void
Opcode_ae_add16s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x330004;
}

static void
Opcode_ae_add16s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8012c000;
}

static void
Opcode_ae_add16s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40000;
}

static void
Opcode_ae_add16s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe5000;
}

static void
Opcode_ae_add16s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x11000;
}

static void
Opcode_ae_sub16s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4e0004;
}

static void
Opcode_ae_sub16s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80142000;
}

static void
Opcode_ae_sub16s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0050;
}

static void
Opcode_ae_sub16s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf0000;
}

static void
Opcode_ae_sub16s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x27000;
}

static void
Opcode_ae_neg24s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ab00a;
}

static void
Opcode_ae_neg24s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc08b0;
}

static void
Opcode_ae_neg24s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfb080;
}

static void
Opcode_ae_neg24s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47600;
}

static void
Opcode_ae_abs24s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2b0104;
}

static void
Opcode_ae_abs24s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ab001;
}

static void
Opcode_ae_abs24s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd409b0;
}

static void
Opcode_ae_abs24s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfb010;
}

static void
Opcode_ae_abs24s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x45700;
}

static void
Opcode_ae_neg32s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2b0704;
}

static void
Opcode_ae_neg32s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ab00c;
}

static void
Opcode_ae_neg32s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0ab0;
}

static void
Opcode_ae_neg32s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfb0a0;
}

static void
Opcode_ae_neg32s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47800;
}

static void
Opcode_ae_abs32s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2b0304;
}

static void
Opcode_ae_abs32s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ab003;
}

static void
Opcode_ae_abs32s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40bb0;
}

static void
Opcode_ae_abs32s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfb030;
}

static void
Opcode_ae_abs32s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x45f00;
}

static void
Opcode_ae_neg16s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2b0604;
}

static void
Opcode_ae_neg16s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ab009;
}

static void
Opcode_ae_neg16s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40fb0;
}

static void
Opcode_ae_neg16s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfb070;
}

static void
Opcode_ae_neg16s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47500;
}

static void
Opcode_ae_abs16s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2b0204;
}

static void
Opcode_ae_abs16s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ab000;
}

static void
Opcode_ae_abs16s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd408b0;
}

static void
Opcode_ae_abs16s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfb000;
}

static void
Opcode_ae_abs16s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x45300;
}

static void
Opcode_ae_lt16_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a3000;
}

static void
Opcode_ae_lt16_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x46000;
}

static void
Opcode_ae_le16_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8015f300;
}

static void
Opcode_ae_le16_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x43003;
}

static void
Opcode_ae_eq16_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8015f100;
}

static void
Opcode_ae_eq16_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x43001;
}

static void
Opcode_ae_lt32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x541004;
}

static void
Opcode_ae_lt32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8015f000;
}

static void
Opcode_ae_lt32_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x43000;
}

static void
Opcode_ae_le32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8015e100;
}

static void
Opcode_ae_le32_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x42001;
}

static void
Opcode_ae_eq32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x540004;
}

static void
Opcode_ae_eq32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8015e000;
}

static void
Opcode_ae_eq32_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x42000;
}

static void
Opcode_ae_min32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x530004;
}

static void
Opcode_ae_min32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80152000;
}

static void
Opcode_ae_min32_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x37000;
}

static void
Opcode_ae_max32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x520004;
}

static void
Opcode_ae_max32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8014e000;
}

static void
Opcode_ae_max32_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x33000;
}

static void
Opcode_ae_add64_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x310004;
}

static void
Opcode_ae_add64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80131000;
}

static void
Opcode_ae_add64_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0020;
}

static void
Opcode_ae_add64_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea000;
}

static void
Opcode_ae_add64_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x16000;
}

static void
Opcode_ae_sub64_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4d0004;
}

static void
Opcode_ae_sub64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80146000;
}

static void
Opcode_ae_sub64_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0070;
}

static void
Opcode_ae_sub64_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf4000;
}

static void
Opcode_ae_sub64_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2b000;
}

static void
Opcode_ae_neg64_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2b0504;
}

static void
Opcode_ae_neg64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ab00d;
}

static void
Opcode_ae_neg64_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0bb0;
}

static void
Opcode_ae_neg64_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfb0b0;
}

static void
Opcode_ae_neg64_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47900;
}

static void
Opcode_ae_abs64_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x270804;
}

static void
Opcode_ae_abs64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ab004;
}

static void
Opcode_ae_abs64_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40cb0;
}

static void
Opcode_ae_abs64_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfb040;
}

static void
Opcode_ae_abs64_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47000;
}

static void
Opcode_ae_addsq56s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80133000;
}

static void
Opcode_ae_addsq56s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0030;
}

static void
Opcode_ae_addsq56s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xec000;
}

static void
Opcode_ae_addsq56s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x18000;
}

static void
Opcode_ae_subsq56s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8014a000;
}

static void
Opcode_ae_subsq56s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0090;
}

static void
Opcode_ae_subsq56s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf8000;
}

static void
Opcode_ae_subsq56s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2f000;
}

static void
Opcode_ae_add64s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80132000;
}

static void
Opcode_ae_add64s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40030;
}

static void
Opcode_ae_add64s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xeb000;
}

static void
Opcode_ae_add64s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x17000;
}

static void
Opcode_ae_sub64s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80147000;
}

static void
Opcode_ae_sub64s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40080;
}

static void
Opcode_ae_sub64s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf5000;
}

static void
Opcode_ae_sub64s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2c000;
}

static void
Opcode_ae_negsq56s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ab00f;
}

static void
Opcode_ae_negsq56s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0db0;
}

static void
Opcode_ae_negsq56s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfb0d0;
}

static void
Opcode_ae_negsq56s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47b00;
}

static void
Opcode_ae_abssq56s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ab006;
}

static void
Opcode_ae_abssq56s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40eb0;
}

static void
Opcode_ae_abssq56s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfb060;
}

static void
Opcode_ae_abssq56s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47200;
}

static void
Opcode_ae_neg64s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ab00e;
}

static void
Opcode_ae_neg64s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc0cb0;
}

static void
Opcode_ae_neg64s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfb0c0;
}

static void
Opcode_ae_neg64s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47a00;
}

static void
Opcode_ae_abs64s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ab005;
}

static void
Opcode_ae_abs64s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd40db0;
}

static void
Opcode_ae_abs64s_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfb050;
}

static void
Opcode_ae_abs64s_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47100;
}

static void
Opcode_ae_and_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x410004;
}

static void
Opcode_ae_and_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80156000;
}

static void
Opcode_ae_and_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3b000;
}

static void
Opcode_ae_nand_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80157000;
}

static void
Opcode_ae_nand_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3c000;
}

static void
Opcode_ae_or_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x160004;
}

static void
Opcode_ae_or_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80158000;
}

static void
Opcode_ae_or_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3d000;
}

static void
Opcode_ae_xor_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1e0004;
}

static void
Opcode_ae_xor_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8015b000;
}

static void
Opcode_ae_xor_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3f000;
}

static void
Opcode_ae_slai24_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x940004;
}

static void
Opcode_ae_slai24_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800b0001;
}

static void
Opcode_ae_slai24_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x14000;
}

static void
Opcode_ae_srli24_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800c0001;
}

static void
Opcode_ae_srli24_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x22000;
}

static void
Opcode_ae_srai24_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9c0004;
}

static void
Opcode_ae_srai24_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800b0802;
}

static void
Opcode_ae_srai24_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1c000;
}

static void
Opcode_ae_slas24_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x240b04;
}

static void
Opcode_ae_slas24_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190b00;
}

static void
Opcode_ae_slas24_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea000;
}

static void
Opcode_ae_srls24_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190b0c;
}

static void
Opcode_ae_srls24_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea0c0;
}

static void
Opcode_ae_sras24_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x240e04;
}

static void
Opcode_ae_sras24_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190b08;
}

static void
Opcode_ae_sras24_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea080;
}

static void
Opcode_ae_srai16_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190d00;
}

static void
Opcode_ae_srai16_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe7000;
}

static void
Opcode_ae_srai16r_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190300;
}

static void
Opcode_ae_srai16r_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe8000;
}

static void
Opcode_ae_slai32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x960004;
}

static void
Opcode_ae_slai32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800b0800;
}

static void
Opcode_ae_slai32_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x18000;
}

static void
Opcode_ae_srli32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x920004;
}

static void
Opcode_ae_srli32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800c0002;
}

static void
Opcode_ae_srli32_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x24000;
}

static void
Opcode_ae_srai32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9e0004;
}

static void
Opcode_ae_srai32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800b0803;
}

static void
Opcode_ae_srai32_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1e000;
}

static void
Opcode_ae_srai32r_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800c0000;
}

static void
Opcode_ae_srai32r_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x20000;
}

static void
Opcode_ae_slas32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190b02;
}

static void
Opcode_ae_slas32_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea020;
}

static void
Opcode_ae_srls32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190b0d;
}

static void
Opcode_ae_srls32_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea0d0;
}

static void
Opcode_ae_sras32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190b09;
}

static void
Opcode_ae_sras32_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea090;
}

static void
Opcode_ae_slaa32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x200004;
}

static void
Opcode_ae_slaa32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800c0c00;
}

static void
Opcode_ae_slaa32_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50400;
}

static void
Opcode_ae_srla32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190e00;
}

static void
Opcode_ae_sraa32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x70004;
}

static void
Opcode_ae_sraa32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190800;
}

static void
Opcode_ae_sraa32_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50200;
}

static void
Opcode_ae_slai16s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190900;
}

static void
Opcode_ae_slai16s_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe6000;
}

static void
Opcode_ae_slaa16s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x230004;
}

static void
Opcode_ae_slaa16s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800c0800;
}

static void
Opcode_ae_slaa16s_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50000;
}

static void
Opcode_ae_sraa16s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190400;
}

static void
Opcode_ae_sraa16s_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50d00;
}

static void
Opcode_ae_sraa16rs_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190000;
}

static void
Opcode_ae_sraa16rs_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50900;
}

static void
Opcode_ae_slai24s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x980004;
}

static void
Opcode_ae_slai24s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800b0003;
}

static void
Opcode_ae_slai24s_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x16000;
}

static void
Opcode_ae_slas24s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190b01;
}

static void
Opcode_ae_slas24s_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea010;
}

static void
Opcode_ae_slai32s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9a0004;
}

static void
Opcode_ae_slai32s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800b0801;
}

static void
Opcode_ae_slai32s_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1a000;
}

static void
Opcode_ae_slas32s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190b03;
}

static void
Opcode_ae_slas32s_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea030;
}

static void
Opcode_ae_slaa32s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50004;
}

static void
Opcode_ae_slaa32s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800c0a00;
}

static void
Opcode_ae_slaa32s_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50800;
}

static void
Opcode_ae_sraa32s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x820004;
}

static void
Opcode_ae_sraa32s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190200;
}

static void
Opcode_ae_sraa32s_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50a00;
}

static void
Opcode_ae_sraa32rs_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190c00;
}

static void
Opcode_ae_sraa32rs_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50600;
}

static void
Opcode_ae_slasq56_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x240c04;
}

static void
Opcode_ae_slasq56_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190b06;
}

static void
Opcode_ae_slasq56_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea060;
}

static void
Opcode_ae_srlsq56_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190b0f;
}

static void
Opcode_ae_srlsq56_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea0f0;
}

static void
Opcode_ae_srasq56_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x240f04;
}

static void
Opcode_ae_srasq56_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190b0b;
}

static void
Opcode_ae_srasq56_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea0b0;
}

static void
Opcode_ae_slaaq56_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x210004;
}

static void
Opcode_ae_slaaq56_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800c0d00;
}

static void
Opcode_ae_slaaq56_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50500;
}

static void
Opcode_ae_srlaq56_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x610004;
}

static void
Opcode_ae_srlaq56_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190500;
}

static void
Opcode_ae_sraaq56_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x910004;
}

static void
Opcode_ae_sraaq56_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190a00;
}

static void
Opcode_ae_sraaq56_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50300;
}

static void
Opcode_ae_slai64_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x880004;
}

static void
Opcode_ae_slai64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800a0000;
}

static void
Opcode_ae_slai64_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0;
}

static void
Opcode_ae_srli64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800b0000;
}

static void
Opcode_ae_srli64_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x10000;
}

static void
Opcode_ae_srai64_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8c0004;
}

static void
Opcode_ae_srai64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800a0801;
}

static void
Opcode_ae_srai64_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc000;
}

static void
Opcode_ae_slas64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190b04;
}

static void
Opcode_ae_slas64_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea040;
}

static void
Opcode_ae_srls64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190b0e;
}

static void
Opcode_ae_srls64_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea0e0;
}

static void
Opcode_ae_sras64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190b0a;
}

static void
Opcode_ae_sras64_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea0a0;
}

static void
Opcode_ae_slaa64_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x220004;
}

static void
Opcode_ae_slaa64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800c0e00;
}

static void
Opcode_ae_slaa64_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50c00;
}

static void
Opcode_ae_srla64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190100;
}

static void
Opcode_ae_sraa64_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x810004;
}

static void
Opcode_ae_sraa64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190600;
}

static void
Opcode_ae_sraa64_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50e00;
}

static void
Opcode_ae_slaisq56s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x840004;
}

static void
Opcode_ae_slaisq56s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800a0800;
}

static void
Opcode_ae_slaisq56s_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8000;
}

static void
Opcode_ae_slassq56s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190b07;
}

static void
Opcode_ae_slassq56s_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea070;
}

static void
Opcode_ae_slaasq56s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x60004;
}

static void
Opcode_ae_slaasq56s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800c0b00;
}

static void
Opcode_ae_slai64s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800a0001;
}

static void
Opcode_ae_slai64s_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4000;
}

static void
Opcode_ae_slas64s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x240d04;
}

static void
Opcode_ae_slas64s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80190b05;
}

static void
Opcode_ae_slas64s_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea050;
}

static void
Opcode_ae_slaa64s_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800c0900;
}

static void
Opcode_ae_slaa64s_Slot_ae_minislot2_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50100;
}

static void
Opcode_ae_lt64_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x510004;
}

static void
Opcode_ae_lt64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8014d000;
}

static void
Opcode_ae_lt64_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x32000;
}

static void
Opcode_ae_le64_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x500004;
}

static void
Opcode_ae_le64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8014c000;
}

static void
Opcode_ae_le64_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x31000;
}

static void
Opcode_ae_eq64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8014b000;
}

static void
Opcode_ae_eq64_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x30000;
}

static void
Opcode_ae_max64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8014f000;
}

static void
Opcode_ae_max64_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x34000;
}

static void
Opcode_ae_min64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80153000;
}

static void
Opcode_ae_min64_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x38000;
}

static void
Opcode_ae_nsa64_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2500d4;
}

static void
Opcode_ae_nsa64_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801a40f0;
}

static void
Opcode_ae_nsa64_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc80a0;
}

static void
Opcode_ae_nsaz16_0_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2500e4;
}

static void
Opcode_ae_nsaz16_0_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ac010;
}

static void
Opcode_ae_nsaz16_0_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc80e0;
}

static void
Opcode_ae_nsaz32_l_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2500f4;
}

static void
Opcode_ae_nsaz32_l_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ac030;
}

static void
Opcode_ae_nsaz32_l_Slot_ae_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc80b0;
}

static void
Opcode_ae_muls32f48p16s_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd00050;
}

static void
Opcode_ae_muls32f48p16s_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80000;
}

static void
Opcode_ae_mulf32s_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc70030;
}

static void
Opcode_ae_mulf32s_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x62000;
}

static void
Opcode_ae_mul32_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcb00d0;
}

static void
Opcode_ae_mul32_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf000;
}

static void
Opcode_ae_muls32f48p16s_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x88000;
}

static void
Opcode_ae_mulf32r_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf0010;
}

static void
Opcode_ae_mulf32r_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5f000;
}

static void
Opcode_ae_muls32f48p16s_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd80040;
}

static void
Opcode_ae_muls32f48p16s_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7f000;
}

static void
Opcode_ae_mulf32s_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf0020;
}

static void
Opcode_ae_mulf32s_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61000;
}

static void
Opcode_ae_mul32_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc300d0;
}

static void
Opcode_ae_mul32_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe000;
}

static void
Opcode_ae_muls32f48p16s_lh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x87000;
}

static void
Opcode_ae_mulf32r_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc70010;
}

static void
Opcode_ae_mulf32r_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5e000;
}

static void
Opcode_ae_muls32f48p16s_hh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd00040;
}

static void
Opcode_ae_muls32f48p16s_hh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7e000;
}

static void
Opcode_ae_mulf32s_hh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc70020;
}

static void
Opcode_ae_mulf32s_hh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x60000;
}

static void
Opcode_ae_mul32_hh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcb00c0;
}

static void
Opcode_ae_mul32_hh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd000;
}

static void
Opcode_ae_muls32f48p16s_hh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x86000;
}

static void
Opcode_ae_mulf32r_hh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf0000;
}

static void
Opcode_ae_mulf32r_hh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5d000;
}

static void
Opcode_ae_mulf32r_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6d000;
}

static void
Opcode_ae_mulas32f48p16s_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce0050;
}

static void
Opcode_ae_mulas32f48p16s_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50000;
}

static void
Opcode_ae_mulaf32s_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd0040;
}

static void
Opcode_ae_mulaf32s_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x34000;
}

static void
Opcode_ae_mula32_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc0030;
}

static void
Opcode_ae_mula32_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1b000;
}

static void
Opcode_ae_mulas32f48p16s_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x63000;
}

static void
Opcode_ae_mulaf32r_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc50030;
}

static void
Opcode_ae_mulaf32r_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x31000;
}

static void
Opcode_ae_mulas32f48p16s_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc60050;
}

static void
Opcode_ae_mulas32f48p16s_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4f000;
}

static void
Opcode_ae_mulaf32s_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc50040;
}

static void
Opcode_ae_mulaf32s_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x33000;
}

static void
Opcode_ae_mula32_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc40030;
}

static void
Opcode_ae_mula32_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1a000;
}

static void
Opcode_ae_mulas32f48p16s_lh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x62000;
}

static void
Opcode_ae_mulaf32r_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd0020;
}

static void
Opcode_ae_mulaf32r_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x30000;
}

static void
Opcode_ae_mulas32f48p16s_hh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce0040;
}

static void
Opcode_ae_mulas32f48p16s_hh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4e000;
}

static void
Opcode_ae_mulaf32s_hh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd0030;
}

static void
Opcode_ae_mulaf32s_hh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x32000;
}

static void
Opcode_ae_mula32_hh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc0020;
}

static void
Opcode_ae_mula32_hh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x19000;
}

static void
Opcode_ae_mulas32f48p16s_hh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x61000;
}

static void
Opcode_ae_mulaf32r_hh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc50020;
}

static void
Opcode_ae_mulaf32r_hh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2f000;
}

static void
Opcode_ae_mulaf32r_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x48000;
}

static void
Opcode_ae_mulss32f48p16s_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda0050;
}

static void
Opcode_ae_mulss32f48p16s_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb2000;
}

static void
Opcode_ae_mulsf32s_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd10060;
}

static void
Opcode_ae_mulsf32s_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x97000;
}

static void
Opcode_ae_muls32_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd000b0;
}

static void
Opcode_ae_muls32_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8c000;
}

static void
Opcode_ae_mulss32f48p16s_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb2000;
}

static void
Opcode_ae_mulsf32r_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd90040;
}

static void
Opcode_ae_mulsf32r_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x94000;
}

static void
Opcode_ae_mulss32f48p16s_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd20050;
}

static void
Opcode_ae_mulss32f48p16s_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb1000;
}

static void
Opcode_ae_mulsf32s_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd90050;
}

static void
Opcode_ae_mulsf32s_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x96000;
}

static void
Opcode_ae_muls32_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd800a0;
}

static void
Opcode_ae_muls32_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8b000;
}

static void
Opcode_ae_mulss32f48p16s_lh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb1000;
}

static void
Opcode_ae_mulsf32r_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd10040;
}

static void
Opcode_ae_mulsf32r_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x93000;
}

static void
Opcode_ae_mulss32f48p16s_hh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda0040;
}

static void
Opcode_ae_mulss32f48p16s_hh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb0000;
}

static void
Opcode_ae_mulsf32s_hh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd10050;
}

static void
Opcode_ae_mulsf32s_hh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x95000;
}

static void
Opcode_ae_muls32_hh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd000a0;
}

static void
Opcode_ae_muls32_hh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8a000;
}

static void
Opcode_ae_mulss32f48p16s_hh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb0000;
}

static void
Opcode_ae_mulsf32r_hh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd90030;
}

static void
Opcode_ae_mulsf32r_hh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x92000;
}

static void
Opcode_ae_mulsf32r_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x98000;
}

static void
Opcode_ae_mulf32s_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6e000;
}

static void
Opcode_ae_mulaf32s_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x49000;
}

static void
Opcode_ae_mul32_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2e000;
}

static void
Opcode_ae_mula32_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x37000;
}

static void
Opcode_ae_mul32u_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc30080;
}

static void
Opcode_ae_mul32u_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4000;
}

static void
Opcode_ae_mula32u_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc300e0;
}

static void
Opcode_ae_mula32u_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x10000;
}

static void
Opcode_ae_muls32u_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd80050;
}

static void
Opcode_ae_muls32u_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x81000;
}

static void
Opcode_ae_mulf16ss_33_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc70000;
}

static void
Opcode_ae_mulf16ss_22_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc600e0;
}

static void
Opcode_ae_mulf16ss_32_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce00f0;
}

static void
Opcode_ae_mulf16ss_21_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce00d0;
}

static void
Opcode_ae_mulf16ss_31_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc600f0;
}

static void
Opcode_ae_mulf16ss_30_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce00e0;
}

static void
Opcode_ae_mulf16ss_10_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc600c0;
}

static void
Opcode_ae_mulf16ss_20_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc600d0;
}

static void
Opcode_ae_mulf16ss_11_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce00c0;
}

static void
Opcode_ae_mulf16ss_00_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce00b0;
}

static void
Opcode_ae_mulf16ss_00_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5c000;
}

static void
Opcode_ae_mulf16ss_00_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6c000;
}

static void
Opcode_ae_mulsf16ss_33_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd10030;
}

static void
Opcode_ae_mulsf16ss_22_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd10010;
}

static void
Opcode_ae_mulsf16ss_32_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd90020;
}

static void
Opcode_ae_mulsf16ss_21_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd90000;
}

static void
Opcode_ae_mulsf16ss_31_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd10020;
}

static void
Opcode_ae_mulsf16ss_30_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd90010;
}

static void
Opcode_ae_mulsf16ss_10_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd000f0;
}

static void
Opcode_ae_mulsf16ss_20_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd10000;
}

static void
Opcode_ae_mulsf16ss_11_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd800f0;
}

static void
Opcode_ae_mulsf16ss_00_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd800e0;
}

static void
Opcode_ae_mulsf16ss_00_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x91000;
}

static void
Opcode_ae_mulsf16ss_00_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x97000;
}

static void
Opcode_ae_mulaf16ss_33_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd0010;
}

static void
Opcode_ae_mulaf16ss_22_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc00f0;
}

static void
Opcode_ae_mulaf16ss_32_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc50010;
}

static void
Opcode_ae_mulaf16ss_21_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc400f0;
}

static void
Opcode_ae_mulaf16ss_31_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd0000;
}

static void
Opcode_ae_mulaf16ss_30_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc50000;
}

static void
Opcode_ae_mulaf16ss_10_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc00d0;
}

static void
Opcode_ae_mulaf16ss_20_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc00e0;
}

static void
Opcode_ae_mulaf16ss_11_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc400e0;
}

static void
Opcode_ae_mulaf16ss_00_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc400d0;
}

static void
Opcode_ae_mulaf16ss_00_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2e000;
}

static void
Opcode_ae_mulaf16ss_00_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47000;
}

static void
Opcode_ae_mulaafd16ss_33_22_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc40080;
}

static void
Opcode_ae_mulaafd16ss_33_22_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x24000;
}

static void
Opcode_ae_mulaafd16ss_33_22_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x40000;
}

static void
Opcode_ae_mulaafd16ss_13_02_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc0070;
}

static void
Opcode_ae_mulaafd16ss_13_02_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x23000;
}

static void
Opcode_ae_mulaafd16ss_13_02_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3f000;
}

static void
Opcode_ae_mulaafd16ss_11_00_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc40070;
}

static void
Opcode_ae_mulaafd16ss_11_00_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x22000;
}

static void
Opcode_ae_mulaafd16ss_11_00_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3e000;
}

static void
Opcode_ae_mulssfd16ss_33_22_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd20090;
}

static void
Opcode_ae_mulssfd16ss_33_22_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb9000;
}

static void
Opcode_ae_mulssfd16ss_33_22_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb9000;
}

static void
Opcode_ae_mulssfd16ss_13_02_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda0080;
}

static void
Opcode_ae_mulssfd16ss_13_02_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb8000;
}

static void
Opcode_ae_mulssfd16ss_13_02_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb8000;
}

static void
Opcode_ae_mulssfd16ss_11_00_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd20080;
}

static void
Opcode_ae_mulssfd16ss_11_00_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb7000;
}

static void
Opcode_ae_mulssfd16ss_11_00_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb7000;
}

static void
Opcode_ae_mulzaafd16ss_33_22_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda00f0;
}

static void
Opcode_ae_mulzaafd16ss_33_22_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc6000;
}

static void
Opcode_ae_mulzaafd16ss_33_22_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc6000;
}

static void
Opcode_ae_mulzaafd16ss_13_02_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd200f0;
}

static void
Opcode_ae_mulzaafd16ss_13_02_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc5000;
}

static void
Opcode_ae_mulzaafd16ss_13_02_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc5000;
}

static void
Opcode_ae_mulzaafd16ss_11_00_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda00e0;
}

static void
Opcode_ae_mulzaafd16ss_11_00_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc4000;
}

static void
Opcode_ae_mulzaafd16ss_11_00_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc4000;
}

static void
Opcode_ae_mulzssfd16ss_33_22_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd300d0;
}

static void
Opcode_ae_mulzssfd16ss_33_22_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdf000;
}

static void
Opcode_ae_mulzssfd16ss_33_22_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe1000;
}

static void
Opcode_ae_mulzssfd16ss_13_02_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb00c0;
}

static void
Opcode_ae_mulzssfd16ss_13_02_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xde000;
}

static void
Opcode_ae_mulzssfd16ss_13_02_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe0000;
}

static void
Opcode_ae_mulzssfd16ss_11_00_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd300c0;
}

static void
Opcode_ae_mulzssfd16ss_11_00_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdd000;
}

static void
Opcode_ae_mulzssfd16ss_11_00_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdf000;
}

static void
Opcode_ae_mulf48q32sp16s_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf0070;
}

static void
Opcode_ae_mulf48q32sp16s_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6b000;
}

static void
Opcode_ae_mulf48q32sp16s_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x77000;
}

static void
Opcode_ae_mulf48q32sp16u_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc70080;
}

static void
Opcode_ae_mulf48q32sp16u_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6c000;
}

static void
Opcode_ae_mulf48q32sp16u_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x78000;
}

static void
Opcode_ae_mulq32sp16s_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd00020;
}

static void
Opcode_ae_mulq32sp16s_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7c000;
}

static void
Opcode_ae_mulq32sp16s_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x82000;
}

static void
Opcode_ae_mulq32sp16u_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd80020;
}

static void
Opcode_ae_mulq32sp16u_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7d000;
}

static void
Opcode_ae_mulq32sp16u_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x83000;
}

static void
Opcode_ae_mulaf48q32sp16s_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc50090;
}

static void
Opcode_ae_mulaf48q32sp16s_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3d000;
}

static void
Opcode_ae_mulaf48q32sp16s_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x52000;
}

static void
Opcode_ae_mulaf48q32sp16u_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd0090;
}

static void
Opcode_ae_mulaf48q32sp16u_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3e000;
}

static void
Opcode_ae_mulaf48q32sp16u_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x53000;
}

static void
Opcode_ae_mulaq32sp16s_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce0020;
}

static void
Opcode_ae_mulaq32sp16s_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4c000;
}

static void
Opcode_ae_mulaq32sp16s_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5d000;
}

static void
Opcode_ae_mulaq32sp16u_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc60030;
}

static void
Opcode_ae_mulaq32sp16u_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4d000;
}

static void
Opcode_ae_mulaq32sp16u_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5e000;
}

static void
Opcode_ae_mulsf48q32sp16s_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd900a0;
}

static void
Opcode_ae_mulsf48q32sp16s_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa0000;
}

static void
Opcode_ae_mulsf48q32sp16s_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa1000;
}

static void
Opcode_ae_mulsf48q32sp16u_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd100b0;
}

static void
Opcode_ae_mulsf48q32sp16u_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa1000;
}

static void
Opcode_ae_mulsf48q32sp16u_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa2000;
}

static void
Opcode_ae_mulsq32sp16s_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda0020;
}

static void
Opcode_ae_mulsq32sp16s_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xac000;
}

static void
Opcode_ae_mulsq32sp16s_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xac000;
}

static void
Opcode_ae_mulsq32sp16u_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd20030;
}

static void
Opcode_ae_mulsq32sp16u_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xad000;
}

static void
Opcode_ae_mulsq32sp16u_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xad000;
}

static void
Opcode_ae_mulfp24x2ra_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf00b0;
}

static void
Opcode_ae_mulfp24x2ra_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x71000;
}

static void
Opcode_ae_mulfp24x2r_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc700b0;
}

static void
Opcode_ae_mulfp24x2r_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x70000;
}

static void
Opcode_ae_mulp24x2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd00000;
}

static void
Opcode_ae_mulp24x2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7a000;
}

static void
Opcode_ae_mulfp24x2ra_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x79000;
}

static void
Opcode_ae_mulfp24x2r_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7a000;
}

static void
Opcode_ae_mulp24x2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x81000;
}

static void
Opcode_ae_mulafp24x2ra_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc500c0;
}

static void
Opcode_ae_mulafp24x2ra_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x43000;
}

static void
Opcode_ae_mulafp24x2r_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd00b0;
}

static void
Opcode_ae_mulafp24x2r_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x42000;
}

static void
Opcode_ae_mulap24x2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce0000;
}

static void
Opcode_ae_mulap24x2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4a000;
}

static void
Opcode_ae_mulafp24x2ra_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x54000;
}

static void
Opcode_ae_mulafp24x2r_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x55000;
}

static void
Opcode_ae_mulap24x2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5c000;
}

static void
Opcode_ae_mulsfp24x2ra_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd100c0;
}

static void
Opcode_ae_mulsfp24x2ra_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa3000;
}

static void
Opcode_ae_mulsfp24x2r_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd900b0;
}

static void
Opcode_ae_mulsfp24x2r_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa2000;
}

static void
Opcode_ae_mulsp24x2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda0000;
}

static void
Opcode_ae_mulsp24x2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xaa000;
}

static void
Opcode_ae_mulsfp24x2ra_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa3000;
}

static void
Opcode_ae_mulsfp24x2r_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa4000;
}

static void
Opcode_ae_mulsp24x2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xab000;
}

static void
Opcode_ae_mulzaafd24_hh_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd30000;
}

static void
Opcode_ae_mulzaafd24_hh_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc7000;
}

static void
Opcode_ae_mulzaad24_hh_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda00b0;
}

static void
Opcode_ae_mulzaad24_hh_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbe000;
}

static void
Opcode_ae_mulzaafd24_hh_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc7000;
}

static void
Opcode_ae_mulzaad24_hh_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbe000;
}

static void
Opcode_ae_mulzaafd24_hl_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb0000;
}

static void
Opcode_ae_mulzaafd24_hl_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc8000;
}

static void
Opcode_ae_mulzaad24_hl_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd200c0;
}

static void
Opcode_ae_mulzaad24_hl_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbf000;
}

static void
Opcode_ae_mulzaafd24_hl_lh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc8000;
}

static void
Opcode_ae_mulzaad24_hl_lh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbf000;
}

static void
Opcode_ae_mulzasfd24_hh_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd30050;
}

static void
Opcode_ae_mulzasfd24_hh_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd1000;
}

static void
Opcode_ae_mulzasd24_hh_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd30030;
}

static void
Opcode_ae_mulzasd24_hh_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd000;
}

static void
Opcode_ae_mulzasfd24_hh_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd1000;
}

static void
Opcode_ae_mulzasd24_hh_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd000;
}

static void
Opcode_ae_mulzasfd24_hl_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb0050;
}

static void
Opcode_ae_mulzasfd24_hl_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd2000;
}

static void
Opcode_ae_mulzasd24_hl_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb0030;
}

static void
Opcode_ae_mulzasd24_hl_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce000;
}

static void
Opcode_ae_mulzasfd24_hl_lh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd2000;
}

static void
Opcode_ae_mulzasd24_hl_lh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce000;
}

static void
Opcode_ae_mulzsafd24_hh_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb0080;
}

static void
Opcode_ae_mulzsafd24_hh_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd6000;
}

static void
Opcode_ae_mulzsad24_hh_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd30070;
}

static void
Opcode_ae_mulzsad24_hh_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd5000;
}

static void
Opcode_ae_mulzsafd24_hh_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd8000;
}

static void
Opcode_ae_mulzsad24_hh_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd5000;
}

static void
Opcode_ae_mulzssfd24_hh_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb00d0;
}

static void
Opcode_ae_mulzssfd24_hh_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe0000;
}

static void
Opcode_ae_mulzssd24_hh_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd300a0;
}

static void
Opcode_ae_mulzssd24_hh_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd9000;
}

static void
Opcode_ae_mulzssfd24_hh_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe2000;
}

static void
Opcode_ae_mulzssd24_hh_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb000;
}

static void
Opcode_ae_mulzssfd24_hl_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd300e0;
}

static void
Opcode_ae_mulzssfd24_hl_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe1000;
}

static void
Opcode_ae_mulzssd24_hl_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb00a0;
}

static void
Opcode_ae_mulzssd24_hl_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda000;
}

static void
Opcode_ae_mulzssfd24_hl_lh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe3000;
}

static void
Opcode_ae_mulzssd24_hl_lh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc000;
}

static void
Opcode_ae_mulaafd24_hh_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc0080;
}

static void
Opcode_ae_mulaafd24_hh_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x25000;
}

static void
Opcode_ae_mulaad24_hh_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc40040;
}

static void
Opcode_ae_mulaad24_hh_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1c000;
}

static void
Opcode_ae_mulaafd24_hh_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x41000;
}

static void
Opcode_ae_mulaad24_hh_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x38000;
}

static void
Opcode_ae_mulaafd24_hl_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc40090;
}

static void
Opcode_ae_mulaafd24_hl_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x26000;
}

static void
Opcode_ae_mulaad24_hl_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc0040;
}

static void
Opcode_ae_mulaad24_hl_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1d000;
}

static void
Opcode_ae_mulaafd24_hl_lh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x42000;
}

static void
Opcode_ae_mulaad24_hl_lh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x39000;
}

static void
Opcode_ae_mulasfd24_hh_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc60080;
}

static void
Opcode_ae_mulasfd24_hh_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x55000;
}

static void
Opcode_ae_mulasd24_hh_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc60060;
}

static void
Opcode_ae_mulasd24_hh_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x51000;
}

static void
Opcode_ae_mulasfd24_hh_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x68000;
}

static void
Opcode_ae_mulasd24_hh_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x64000;
}

static void
Opcode_ae_mulasfd24_hl_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce0080;
}

static void
Opcode_ae_mulasfd24_hl_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x56000;
}

static void
Opcode_ae_mulasd24_hl_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce0060;
}

static void
Opcode_ae_mulasd24_hl_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x52000;
}

static void
Opcode_ae_mulasfd24_hl_lh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x69000;
}

static void
Opcode_ae_mulasd24_hl_lh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x65000;
}

static void
Opcode_ae_mulsafd24_hh_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd000d0;
}

static void
Opcode_ae_mulsafd24_hh_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8e000;
}

static void
Opcode_ae_mulsad24_hh_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd800b0;
}

static void
Opcode_ae_mulsad24_hh_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8d000;
}

static void
Opcode_ae_mulsafd24_hh_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x94000;
}

static void
Opcode_ae_mulsad24_hh_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x91000;
}

static void
Opcode_ae_mulssfd24_hh_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda0090;
}

static void
Opcode_ae_mulssfd24_hh_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xba000;
}

static void
Opcode_ae_mulssd24_hh_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd20060;
}

static void
Opcode_ae_mulssd24_hh_ll_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb3000;
}

static void
Opcode_ae_mulssfd24_hh_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xba000;
}

static void
Opcode_ae_mulssd24_hh_ll_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb3000;
}

static void
Opcode_ae_mulssfd24_hl_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd200a0;
}

static void
Opcode_ae_mulssfd24_hl_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbb000;
}

static void
Opcode_ae_mulssd24_hl_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda0060;
}

static void
Opcode_ae_mulssd24_hl_lh_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb4000;
}

static void
Opcode_ae_mulssfd24_hl_lh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbb000;
}

static void
Opcode_ae_mulssd24_hl_lh_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb4000;
}

static void
Opcode_ae_mulsrfq32sp24s_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda0030;
}

static void
Opcode_ae_mulsrfq32sp24s_h_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xae000;
}

static void
Opcode_ae_mulsrfq32sp24s_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd20040;
}

static void
Opcode_ae_mulsrfq32sp24s_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xaf000;
}

static void
Opcode_ae_mulsrfq32sp24s_h_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xae000;
}

static void
Opcode_ae_mulsrfq32sp24s_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xaf000;
}

static void
Opcode_ae_mularfq32sp24s_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce0030;
}

static void
Opcode_ae_mularfq32sp24s_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc60040;
}

static void
Opcode_ae_mularfq32sp24s_h_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5f000;
}

static void
Opcode_ae_mularfq32sp24s_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x60000;
}

static void
Opcode_ae_mulrfq32sp24s_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd00030;
}

static void
Opcode_ae_mulrfq32sp24s_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd80030;
}

static void
Opcode_ae_mulrfq32sp24s_h_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x84000;
}

static void
Opcode_ae_mulrfq32sp24s_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x85000;
}

static void
Opcode_ae_mulsfq32sp24s_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd900f0;
}

static void
Opcode_ae_mulsfq32sp24s_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd20000;
}

static void
Opcode_ae_mulsfq32sp24s_h_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa9000;
}

static void
Opcode_ae_mulsfq32sp24s_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xaa000;
}

static void
Opcode_ae_mulafq32sp24s_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd00f0;
}

static void
Opcode_ae_mulafq32sp24s_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc60000;
}

static void
Opcode_ae_mulafq32sp24s_h_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5a000;
}

static void
Opcode_ae_mulafq32sp24s_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5b000;
}

static void
Opcode_ae_mulfq32sp24s_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc700f0;
}

static void
Opcode_ae_mulfq32sp24s_h_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x78000;
}

static void
Opcode_ae_mulfq32sp24s_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf00f0;
}

static void
Opcode_ae_mulfq32sp24s_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x79000;
}

static void
Opcode_ae_mulfq32sp24s_h_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7f000;
}

static void
Opcode_ae_mulfq32sp24s_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80000;
}

static void
Opcode_ae_mulf32x16_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf0050;
}

static void
Opcode_ae_mulf32x16_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67000;
}

static void
Opcode_ae_mul32x16_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcb00a0;
}

static void
Opcode_ae_mul32x16_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9000;
}

static void
Opcode_ae_mulf32x16_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x73000;
}

static void
Opcode_ae_mul32x16_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2a000;
}

static void
Opcode_ae_mulf32x16_l1_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc70060;
}

static void
Opcode_ae_mulf32x16_l1_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x68000;
}

static void
Opcode_ae_mul32x16_l1_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc300b0;
}

static void
Opcode_ae_mul32x16_l1_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa000;
}

static void
Opcode_ae_mulf32x16_l1_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x74000;
}

static void
Opcode_ae_mul32x16_l1_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2b000;
}

static void
Opcode_ae_mulf32x16_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf0060;
}

static void
Opcode_ae_mulf32x16_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x69000;
}

static void
Opcode_ae_mul32x16_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcb00b0;
}

static void
Opcode_ae_mul32x16_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb000;
}

static void
Opcode_ae_mulf32x16_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x75000;
}

static void
Opcode_ae_mul32x16_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2c000;
}

static void
Opcode_ae_mulf32x16_l3_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc70070;
}

static void
Opcode_ae_mulf32x16_l3_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6a000;
}

static void
Opcode_ae_mul32x16_l3_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc300c0;
}

static void
Opcode_ae_mul32x16_l3_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc000;
}

static void
Opcode_ae_mulf32x16_l3_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x76000;
}

static void
Opcode_ae_mul32x16_l3_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2d000;
}

static void
Opcode_ae_mulf32x16_h0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf0030;
}

static void
Opcode_ae_mulf32x16_h0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x63000;
}

static void
Opcode_ae_mul32x16_h0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcb0080;
}

static void
Opcode_ae_mul32x16_h0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5000;
}

static void
Opcode_ae_mulf32x16_h0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6f000;
}

static void
Opcode_ae_mul32x16_h0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x26000;
}

static void
Opcode_ae_mulf32x16_h1_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc70040;
}

static void
Opcode_ae_mulf32x16_h1_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x64000;
}

static void
Opcode_ae_mul32x16_h1_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc30090;
}

static void
Opcode_ae_mul32x16_h1_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6000;
}

static void
Opcode_ae_mulf32x16_h1_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x70000;
}

static void
Opcode_ae_mul32x16_h1_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x27000;
}

static void
Opcode_ae_mulf32x16_h2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf0040;
}

static void
Opcode_ae_mulf32x16_h2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x65000;
}

static void
Opcode_ae_mul32x16_h2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcb0090;
}

static void
Opcode_ae_mul32x16_h2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7000;
}

static void
Opcode_ae_mulf32x16_h2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x71000;
}

static void
Opcode_ae_mul32x16_h2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x28000;
}

static void
Opcode_ae_mulf32x16_h3_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc70050;
}

static void
Opcode_ae_mulf32x16_h3_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x66000;
}

static void
Opcode_ae_mul32x16_h3_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc300a0;
}

static void
Opcode_ae_mul32x16_h3_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8000;
}

static void
Opcode_ae_mulf32x16_h3_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x72000;
}

static void
Opcode_ae_mul32x16_h3_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x29000;
}

static void
Opcode_ae_mulaf32x16_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc50070;
}

static void
Opcode_ae_mulaf32x16_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x39000;
}

static void
Opcode_ae_mula32x16_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc0000;
}

static void
Opcode_ae_mula32x16_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x15000;
}

static void
Opcode_ae_mulaf32x16_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4e000;
}

static void
Opcode_ae_mula32x16_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x33000;
}

static void
Opcode_ae_mulaf32x16_l1_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd0070;
}

static void
Opcode_ae_mulaf32x16_l1_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3a000;
}

static void
Opcode_ae_mula32x16_l1_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc40010;
}

static void
Opcode_ae_mula32x16_l1_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x16000;
}

static void
Opcode_ae_mulaf32x16_l1_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4f000;
}

static void
Opcode_ae_mula32x16_l1_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x34000;
}

static void
Opcode_ae_mulaf32x16_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc50080;
}

static void
Opcode_ae_mulaf32x16_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3b000;
}

static void
Opcode_ae_mula32x16_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc0010;
}

static void
Opcode_ae_mula32x16_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x17000;
}

static void
Opcode_ae_mulaf32x16_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x50000;
}

static void
Opcode_ae_mula32x16_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x35000;
}

static void
Opcode_ae_mulaf32x16_l3_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd0080;
}

static void
Opcode_ae_mulaf32x16_l3_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3c000;
}

static void
Opcode_ae_mula32x16_l3_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc40020;
}

static void
Opcode_ae_mula32x16_l3_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x18000;
}

static void
Opcode_ae_mulaf32x16_l3_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x51000;
}

static void
Opcode_ae_mula32x16_l3_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x36000;
}

static void
Opcode_ae_mulaf32x16_h0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc50050;
}

static void
Opcode_ae_mulaf32x16_h0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x35000;
}

static void
Opcode_ae_mula32x16_h0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcb00e0;
}

static void
Opcode_ae_mula32x16_h0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x11000;
}

static void
Opcode_ae_mulaf32x16_h0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4a000;
}

static void
Opcode_ae_mula32x16_h0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2f000;
}

static void
Opcode_ae_mulaf32x16_h1_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd0050;
}

static void
Opcode_ae_mulaf32x16_h1_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x36000;
}

static void
Opcode_ae_mula32x16_h1_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc300f0;
}

static void
Opcode_ae_mula32x16_h1_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x12000;
}

static void
Opcode_ae_mulaf32x16_h1_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4b000;
}

static void
Opcode_ae_mula32x16_h1_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x30000;
}

static void
Opcode_ae_mulaf32x16_h2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc50060;
}

static void
Opcode_ae_mulaf32x16_h2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x37000;
}

static void
Opcode_ae_mula32x16_h2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcb00f0;
}

static void
Opcode_ae_mula32x16_h2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x13000;
}

static void
Opcode_ae_mulaf32x16_h2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4c000;
}

static void
Opcode_ae_mula32x16_h2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x31000;
}

static void
Opcode_ae_mulaf32x16_h3_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd0060;
}

static void
Opcode_ae_mulaf32x16_h3_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x38000;
}

static void
Opcode_ae_mula32x16_h3_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc40000;
}

static void
Opcode_ae_mula32x16_h3_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x14000;
}

static void
Opcode_ae_mulaf32x16_h3_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4d000;
}

static void
Opcode_ae_mula32x16_h3_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x32000;
}

static void
Opcode_ae_mulsf32x16_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd90080;
}

static void
Opcode_ae_mulsf32x16_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9c000;
}

static void
Opcode_ae_muls32x16_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd00080;
}

static void
Opcode_ae_muls32x16_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x86000;
}

static void
Opcode_ae_mulsf32x16_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9d000;
}

static void
Opcode_ae_muls32x16_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8d000;
}

static void
Opcode_ae_mulsf32x16_l1_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd10090;
}

static void
Opcode_ae_mulsf32x16_l1_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9d000;
}

static void
Opcode_ae_muls32x16_l1_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd80080;
}

static void
Opcode_ae_muls32x16_l1_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x87000;
}

static void
Opcode_ae_mulsf32x16_l1_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9e000;
}

static void
Opcode_ae_muls32x16_l1_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8e000;
}

static void
Opcode_ae_mulsf32x16_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd90090;
}

static void
Opcode_ae_mulsf32x16_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9e000;
}

static void
Opcode_ae_muls32x16_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd00090;
}

static void
Opcode_ae_muls32x16_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x88000;
}

static void
Opcode_ae_mulsf32x16_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9f000;
}

static void
Opcode_ae_muls32x16_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8f000;
}

static void
Opcode_ae_mulsf32x16_l3_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd100a0;
}

static void
Opcode_ae_mulsf32x16_l3_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9f000;
}

static void
Opcode_ae_muls32x16_l3_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd80090;
}

static void
Opcode_ae_muls32x16_l3_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x89000;
}

static void
Opcode_ae_mulsf32x16_l3_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa0000;
}

static void
Opcode_ae_muls32x16_l3_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x90000;
}

static void
Opcode_ae_mulsf32x16_h0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd90060;
}

static void
Opcode_ae_mulsf32x16_h0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x98000;
}

static void
Opcode_ae_muls32x16_h0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd00060;
}

static void
Opcode_ae_muls32x16_h0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x82000;
}

static void
Opcode_ae_mulsf32x16_h0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x99000;
}

static void
Opcode_ae_muls32x16_h0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x89000;
}

static void
Opcode_ae_mulsf32x16_h1_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd10070;
}

static void
Opcode_ae_mulsf32x16_h1_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x99000;
}

static void
Opcode_ae_muls32x16_h1_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd80060;
}

static void
Opcode_ae_muls32x16_h1_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x83000;
}

static void
Opcode_ae_mulsf32x16_h1_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9a000;
}

static void
Opcode_ae_muls32x16_h1_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8a000;
}

static void
Opcode_ae_mulsf32x16_h2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd90070;
}

static void
Opcode_ae_mulsf32x16_h2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9a000;
}

static void
Opcode_ae_muls32x16_h2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd00070;
}

static void
Opcode_ae_muls32x16_h2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x84000;
}

static void
Opcode_ae_mulsf32x16_h2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9b000;
}

static void
Opcode_ae_muls32x16_h2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8b000;
}

static void
Opcode_ae_mulsf32x16_h3_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd10080;
}

static void
Opcode_ae_mulsf32x16_h3_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9b000;
}

static void
Opcode_ae_muls32x16_h3_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd80070;
}

static void
Opcode_ae_muls32x16_h3_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x85000;
}

static void
Opcode_ae_mulsf32x16_h3_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9c000;
}

static void
Opcode_ae_muls32x16_h3_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8c000;
}

static void
Opcode_ae_mulaafd32x16_h3_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc400b0;
}

static void
Opcode_ae_mulaafd32x16_h3_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2a000;
}

static void
Opcode_ae_mulaad32x16_h3_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc0060;
}

static void
Opcode_ae_mulaad32x16_h3_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x21000;
}

static void
Opcode_ae_mulaafd32x16_h3_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x46000;
}

static void
Opcode_ae_mulaad32x16_h3_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3d000;
}

static void
Opcode_ae_mulaafd32x16_h1_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc400a0;
}

static void
Opcode_ae_mulaafd32x16_h1_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x28000;
}

static void
Opcode_ae_mulaad32x16_h1_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc0050;
}

static void
Opcode_ae_mulaad32x16_h1_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1f000;
}

static void
Opcode_ae_mulaafd32x16_h1_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x44000;
}

static void
Opcode_ae_mulaad32x16_h1_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3b000;
}

static void
Opcode_ae_mulasfd32x16_h3_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce0090;
}

static void
Opcode_ae_mulasfd32x16_h3_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x58000;
}

static void
Opcode_ae_mulasd32x16_h3_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce0070;
}

static void
Opcode_ae_mulasd32x16_h3_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x54000;
}

static void
Opcode_ae_mulasfd32x16_h3_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6b000;
}

static void
Opcode_ae_mulasd32x16_h3_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x67000;
}

static void
Opcode_ae_mulasfd32x16_h1_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc60090;
}

static void
Opcode_ae_mulasfd32x16_h1_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x57000;
}

static void
Opcode_ae_mulasd32x16_h1_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc60070;
}

static void
Opcode_ae_mulasd32x16_h1_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x53000;
}

static void
Opcode_ae_mulasfd32x16_h1_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6a000;
}

static void
Opcode_ae_mulasd32x16_h1_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x66000;
}

static void
Opcode_ae_mulsafd32x16_h3_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd000e0;
}

static void
Opcode_ae_mulsafd32x16_h3_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x90000;
}

static void
Opcode_ae_mulsad32x16_h3_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd800c0;
}

static void
Opcode_ae_mulsafd32x16_h3_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x96000;
}

static void
Opcode_ae_mulsad32x16_h3_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x93000;
}

static void
Opcode_ae_mulsafd32x16_h1_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd800d0;
}

static void
Opcode_ae_mulsafd32x16_h1_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8f000;
}

static void
Opcode_ae_mulsad32x16_h1_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd000c0;
}

static void
Opcode_ae_mulsafd32x16_h1_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x95000;
}

static void
Opcode_ae_mulsad32x16_h1_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x92000;
}

static void
Opcode_ae_mulssfd32x16_h3_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd200b0;
}

static void
Opcode_ae_mulssfd32x16_h3_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbd000;
}

static void
Opcode_ae_mulssd32x16_h3_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda0070;
}

static void
Opcode_ae_mulssd32x16_h3_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb6000;
}

static void
Opcode_ae_mulssfd32x16_h3_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbd000;
}

static void
Opcode_ae_mulssd32x16_h3_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb6000;
}

static void
Opcode_ae_mulssfd32x16_h1_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda00a0;
}

static void
Opcode_ae_mulssfd32x16_h1_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbc000;
}

static void
Opcode_ae_mulssd32x16_h1_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd20070;
}

static void
Opcode_ae_mulssd32x16_h1_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb5000;
}

static void
Opcode_ae_mulssfd32x16_h1_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbc000;
}

static void
Opcode_ae_mulssd32x16_h1_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb5000;
}

static void
Opcode_ae_mulzaafd32x16_h3_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb0020;
}

static void
Opcode_ae_mulzaafd32x16_h3_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc000;
}

static void
Opcode_ae_mulzaad32x16_h3_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd200e0;
}

static void
Opcode_ae_mulzaad32x16_h3_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc3000;
}

static void
Opcode_ae_mulzaafd32x16_h3_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc000;
}

static void
Opcode_ae_mulzaad32x16_h3_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc3000;
}

static void
Opcode_ae_mulzaafd32x16_h1_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb0010;
}

static void
Opcode_ae_mulzaafd32x16_h1_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xca000;
}

static void
Opcode_ae_mulzaad32x16_h1_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd200d0;
}

static void
Opcode_ae_mulzaad32x16_h1_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc1000;
}

static void
Opcode_ae_mulzaafd32x16_h1_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xca000;
}

static void
Opcode_ae_mulzaad32x16_h1_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc1000;
}

static void
Opcode_ae_mulzasfd32x16_h3_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb0060;
}

static void
Opcode_ae_mulzasfd32x16_h3_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd4000;
}

static void
Opcode_ae_mulzasd32x16_h3_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb0040;
}

static void
Opcode_ae_mulzasd32x16_h3_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd0000;
}

static void
Opcode_ae_mulzasfd32x16_h3_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd4000;
}

static void
Opcode_ae_mulzasd32x16_h3_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd0000;
}

static void
Opcode_ae_mulzasfd32x16_h1_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd30060;
}

static void
Opcode_ae_mulzasfd32x16_h1_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd3000;
}

static void
Opcode_ae_mulzasd32x16_h1_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd30040;
}

static void
Opcode_ae_mulzasd32x16_h1_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf000;
}

static void
Opcode_ae_mulzasfd32x16_h1_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd3000;
}

static void
Opcode_ae_mulzasd32x16_h1_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf000;
}

static void
Opcode_ae_mulzsafd32x16_h3_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb0090;
}

static void
Opcode_ae_mulzsafd32x16_h3_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd8000;
}

static void
Opcode_ae_mulzsad32x16_h3_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd30080;
}

static void
Opcode_ae_mulzsafd32x16_h3_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda000;
}

static void
Opcode_ae_mulzsad32x16_h3_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd7000;
}

static void
Opcode_ae_mulzsafd32x16_h1_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd30090;
}

static void
Opcode_ae_mulzsafd32x16_h1_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd7000;
}

static void
Opcode_ae_mulzsad32x16_h1_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb0070;
}

static void
Opcode_ae_mulzsafd32x16_h1_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd9000;
}

static void
Opcode_ae_mulzsad32x16_h1_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd6000;
}

static void
Opcode_ae_mulzssfd32x16_h3_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd300f0;
}

static void
Opcode_ae_mulzssfd32x16_h3_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe3000;
}

static void
Opcode_ae_mulzssd32x16_h3_l2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb00b0;
}

static void
Opcode_ae_mulzssd32x16_h3_l2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdc000;
}

static void
Opcode_ae_mulzssfd32x16_h3_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe5000;
}

static void
Opcode_ae_mulzssd32x16_h3_l2_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xde000;
}

static void
Opcode_ae_mulzssfd32x16_h1_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb00e0;
}

static void
Opcode_ae_mulzssfd32x16_h1_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe2000;
}

static void
Opcode_ae_mulzssd32x16_h1_l0_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd300b0;
}

static void
Opcode_ae_mulzssd32x16_h1_l0_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb000;
}

static void
Opcode_ae_mulzssfd32x16_h1_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe4000;
}

static void
Opcode_ae_mulzssd32x16_h1_l0_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdd000;
}

static void
Opcode_ae_mulzaafd32x16_h2_l3_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd30020;
}

static void
Opcode_ae_mulzaafd32x16_h2_l3_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcb000;
}

static void
Opcode_ae_mulzaafd32x16_h0_l1_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd30010;
}

static void
Opcode_ae_mulzaafd32x16_h0_l1_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc9000;
}

static void
Opcode_ae_mulaafd32x16_h2_l3_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc00a0;
}

static void
Opcode_ae_mulaafd32x16_h2_l3_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x29000;
}

static void
Opcode_ae_mulaafd32x16_h0_l1_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc0090;
}

static void
Opcode_ae_mulaafd32x16_h0_l1_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x27000;
}

static void
Opcode_ae_mulzaad32x16_h2_l3_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda00d0;
}

static void
Opcode_ae_mulzaad32x16_h2_l3_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc2000;
}

static void
Opcode_ae_mulzaad32x16_h0_l1_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda00c0;
}

static void
Opcode_ae_mulzaad32x16_h0_l1_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc0000;
}

static void
Opcode_ae_mulaad32x16_h2_l3_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc40060;
}

static void
Opcode_ae_mulaad32x16_h2_l3_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x20000;
}

static void
Opcode_ae_mulaad32x16_h0_l1_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc40050;
}

static void
Opcode_ae_mulaad32x16_h0_l1_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1e000;
}

static void
Opcode_ae_mulzaafd32x16_h2_l3_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcb000;
}

static void
Opcode_ae_mulzaafd32x16_h0_l1_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc9000;
}

static void
Opcode_ae_mulaafd32x16_h2_l3_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x45000;
}

static void
Opcode_ae_mulaafd32x16_h0_l1_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x43000;
}

static void
Opcode_ae_mulzaad32x16_h2_l3_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc2000;
}

static void
Opcode_ae_mulzaad32x16_h0_l1_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc0000;
}

static void
Opcode_ae_mulaad32x16_h2_l3_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3c000;
}

static void
Opcode_ae_mulaad32x16_h0_l1_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3a000;
}

static void
Opcode_ae_mulp32x16x2_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd80000;
}

static void
Opcode_ae_mulfp32x16x2rs_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc700d0;
}

static void
Opcode_ae_mulfp32x16x2rs_h_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x74000;
}

static void
Opcode_ae_mulfp32x16x2ras_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc700c0;
}

static void
Opcode_ae_mulfp32x16x2ras_h_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x72000;
}

static void
Opcode_ae_mulfp32x16x2rs_h_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7d000;
}

static void
Opcode_ae_mulfp32x16x2ras_h_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7b000;
}

static void
Opcode_ae_mulp32x16x2_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd00010;
}

static void
Opcode_ae_mulfp32x16x2rs_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf00d0;
}

static void
Opcode_ae_mulfp32x16x2rs_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x75000;
}

static void
Opcode_ae_mulfp32x16x2ras_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf00c0;
}

static void
Opcode_ae_mulfp32x16x2ras_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x73000;
}

static void
Opcode_ae_mulfp32x16x2rs_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7e000;
}

static void
Opcode_ae_mulfp32x16x2ras_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7c000;
}

static void
Opcode_ae_mulap32x16x2_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc60010;
}

static void
Opcode_ae_mulafp32x16x2rs_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd00d0;
}

static void
Opcode_ae_mulafp32x16x2rs_h_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x46000;
}

static void
Opcode_ae_mulafp32x16x2ras_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd00c0;
}

static void
Opcode_ae_mulafp32x16x2ras_h_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x44000;
}

static void
Opcode_ae_mulafp32x16x2rs_h_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x58000;
}

static void
Opcode_ae_mulafp32x16x2ras_h_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x56000;
}

static void
Opcode_ae_mulap32x16x2_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce0010;
}

static void
Opcode_ae_mulafp32x16x2rs_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc500e0;
}

static void
Opcode_ae_mulafp32x16x2rs_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47000;
}

static void
Opcode_ae_mulafp32x16x2ras_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc500d0;
}

static void
Opcode_ae_mulafp32x16x2ras_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x45000;
}

static void
Opcode_ae_mulafp32x16x2rs_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x59000;
}

static void
Opcode_ae_mulafp32x16x2ras_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x57000;
}

static void
Opcode_ae_mulsp32x16x2_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd20010;
}

static void
Opcode_ae_mulsfp32x16x2rs_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd900d0;
}

static void
Opcode_ae_mulsfp32x16x2rs_h_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa6000;
}

static void
Opcode_ae_mulsfp32x16x2ras_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd900c0;
}

static void
Opcode_ae_mulsfp32x16x2ras_h_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa4000;
}

static void
Opcode_ae_mulsfp32x16x2rs_h_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa7000;
}

static void
Opcode_ae_mulsfp32x16x2ras_h_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa5000;
}

static void
Opcode_ae_mulsp32x16x2_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda0010;
}

static void
Opcode_ae_mulsfp32x16x2rs_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd100e0;
}

static void
Opcode_ae_mulsfp32x16x2rs_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa7000;
}

static void
Opcode_ae_mulsfp32x16x2ras_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd100d0;
}

static void
Opcode_ae_mulsfp32x16x2ras_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa5000;
}

static void
Opcode_ae_mulsfp32x16x2rs_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa8000;
}

static void
Opcode_ae_mulsfp32x16x2ras_l_s2_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa6000;
}

static void
Opcode_ae_mulp32x2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd80010;
}

static void
Opcode_ae_mulp32x2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7b000;
}

static void
Opcode_ae_mulfp32x2rs_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf00e0;
}

static void
Opcode_ae_mulfp32x2rs_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x77000;
}

static void
Opcode_ae_mulfp32x2ras_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc700e0;
}

static void
Opcode_ae_mulfp32x2ras_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x76000;
}

static void
Opcode_ae_mulap32x2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc60020;
}

static void
Opcode_ae_mulap32x2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4b000;
}

static void
Opcode_ae_mulafp32x2rs_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc500f0;
}

static void
Opcode_ae_mulafp32x2rs_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x49000;
}

static void
Opcode_ae_mulafp32x2ras_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd00e0;
}

static void
Opcode_ae_mulafp32x2ras_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x48000;
}

static void
Opcode_ae_mulsp32x2_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd20020;
}

static void
Opcode_ae_mulsp32x2_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xab000;
}

static void
Opcode_ae_mulsfp32x2rs_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd100f0;
}

static void
Opcode_ae_mulsfp32x2rs_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa9000;
}

static void
Opcode_ae_mulsfp32x2ras_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd900e0;
}

static void
Opcode_ae_mulsfp32x2ras_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa8000;
}

static void
Opcode_ae_mulfp16x4s_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf00a0;
}

static void
Opcode_ae_mulfp16x4ras_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc700a0;
}

static void
Opcode_ae_mulc24_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc600a0;
}

static void
Opcode_ae_mulc24_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x59000;
}

static void
Opcode_ae_mulfc24ra_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf0080;
}

static void
Opcode_ae_mulfc24ra_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6d000;
}

static void
Opcode_ae_mulc32x16_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc600b0;
}

static void
Opcode_ae_mulc32x16_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5b000;
}

static void
Opcode_ae_mulfc32x16ras_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcf0090;
}

static void
Opcode_ae_mulfc32x16ras_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6f000;
}

static void
Opcode_ae_mulc32x16_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce00a0;
}

static void
Opcode_ae_mulc32x16_h_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5a000;
}

static void
Opcode_ae_mulfc32x16ras_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc70090;
}

static void
Opcode_ae_mulfc32x16ras_h_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6e000;
}

static void
Opcode_ae_mulac24_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc00b0;
}

static void
Opcode_ae_mulac24_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2b000;
}

static void
Opcode_ae_mulafc24ra_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc500a0;
}

static void
Opcode_ae_mulafc24ra_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3f000;
}

static void
Opcode_ae_mulac32x16_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcc00c0;
}

static void
Opcode_ae_mulac32x16_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2d000;
}

static void
Opcode_ae_mulafc32x16ras_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc500b0;
}

static void
Opcode_ae_mulafc32x16ras_l_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x41000;
}

static void
Opcode_ae_mulac32x16_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc400c0;
}

static void
Opcode_ae_mulac32x16_h_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2c000;
}

static void
Opcode_ae_mulafc32x16ras_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcd00a0;
}

static void
Opcode_ae_mulafc32x16ras_h_Slot_ae_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x40000;
}

static void
Opcode_ae_mulf16x4ss_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc90000;
}

static void
Opcode_ae_mulaf16x4ss_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc10000;
}

static void
Opcode_ae_mulsf16x4ss_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xca0000;
}

static void
Opcode_ae_mul16x4_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc00000;
}

static void
Opcode_ae_mula16x4_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc80000;
}

static void
Opcode_ae_muls16x4_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc20000;
}

static void
Opcode_ae_mulfd24x2_fir_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x600000;
}

static void
Opcode_ae_mulfd24x2_fir_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x700000;
}

static void
Opcode_ae_mulfd32x16x2_fir_hh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x800000;
}

static void
Opcode_ae_mulfd32x16x2_fir_hl_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x900000;
}

static void
Opcode_ae_mulfd32x16x2_fir_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa00000;
}

static void
Opcode_ae_mulfd32x16x2_fir_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xb00000;
}

static void
Opcode_ae_mulafd24x2_fir_h_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0;
}

static void
Opcode_ae_mulafd24x2_fir_l_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x100000;
}

static void
Opcode_ae_mulafd32x16x2_fir_hh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x200000;
}

static void
Opcode_ae_mulafd32x16x2_fir_hl_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x300000;
}

static void
Opcode_ae_mulafd32x16x2_fir_lh_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x400000;
}

static void
Opcode_ae_mulafd32x16x2_fir_ll_Slot_ae2_slot1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x500000;
}

static void
Opcode_ae_div64d32_h_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ab007;
}

static void
Opcode_ae_div64d32_h_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47300;
}

static void
Opcode_ae_div64d32_l_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2b0404;
}

static void
Opcode_ae_div64d32_l_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x801ab008;
}

static void
Opcode_ae_div64d32_l_Slot_ae_slot2_1_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x47400;
}

static void
Opcode_ae_sha32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x360084;
}

static void
Opcode_ae_vldl32t_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe0004;
}

static void
Opcode_ae_vldl16t_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xf0004;
}

static void
Opcode_ae_vldl16c_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x77e064;
}

static void
Opcode_ae_vldl16c_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x77e084;
}

static void
Opcode_ae_vldl16c_ic_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x77e074;
}

static void
Opcode_ae_vldsht_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x341004;
}

static void
Opcode_ae_lb_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x690204;
}

static void
Opcode_ae_lbi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x690304;
}

static void
Opcode_ae_lbk_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x830004;
}

static void
Opcode_ae_lbki_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xce0004;
}

static void
Opcode_ae_lbs_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x690604;
}

static void
Opcode_ae_lbsi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x690704;
}

static void
Opcode_ae_db_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x774004;
}

static void
Opcode_ae_dbi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x775004;
}

static void
Opcode_ae_db_ic_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x776004;
}

static void
Opcode_ae_dbi_ic_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x777004;
}

static void
Opcode_ae_db_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x778004;
}

static void
Opcode_ae_dbi_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x779004;
}

static void
Opcode_ae_vlel32t_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd00004;
}

static void
Opcode_ae_vlel16t_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xd10004;
}

static void
Opcode_ae_sb_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x77a004;
}

static void
Opcode_ae_sbi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x630004;
}

static void
Opcode_ae_vles16c_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x77e004;
}

static void
Opcode_ae_sbf_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x77e014;
}

static void
Opcode_ae_sb_ic_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x77b004;
}

static void
Opcode_ae_sbi_ic_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x560004;
}

static void
Opcode_ae_vles16c_ic_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x77e024;
}

static void
Opcode_ae_sbf_ic_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x77e034;
}

static void
Opcode_ae_sb_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x77c004;
}

static void
Opcode_ae_sbi_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x570004;
}

static void
Opcode_ae_vles16c_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x77e044;
}

static void
Opcode_ae_sbf_ip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x77e054;
}

static void
Opcode_ae_sext32_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x170004;
}

static void
Opcode_ae_sext32_Slot_ae2_slot0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80159000;
}

static void
Opcode_ae_sext32_Slot_ae_slot2_0_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xe9000;
}

static void
Opcode_lsi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3;
}

static void
Opcode_lsip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8003;
}

static void
Opcode_lsx_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x80000;
}

static void
Opcode_lsxp_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x180000;
}

static void
Opcode_ssi_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4003;
}

static void
Opcode_ssip_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xc003;
}

static void
Opcode_ssx_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x480000;
}

static void
Opcode_ssxp_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x580000;
}

static void
Opcode_abs_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfa0010;
}

static void
Opcode_neg_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfa0060;
}

static void
Opcode_mov_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfa0000;
}

static void
Opcode_moveqz_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8b0000;
}

static void
Opcode_movnez_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9b0000;
}

static void
Opcode_movltz_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xab0000;
}

static void
Opcode_movgez_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xbb0000;
}

static void
Opcode_movf_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xcb0000;
}

static void
Opcode_movt_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xdb0000;
}

static void
Opcode_wfr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfa0050;
}

static void
Opcode_rfr_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfa0040;
}

static void
Opcode_round_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x8a0000;
}

static void
Opcode_ceil_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xba0000;
}

static void
Opcode_floor_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xaa0000;
}

static void
Opcode_trunc_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x9a0000;
}

static void
Opcode_utrunc_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xea0000;
}

static void
Opcode_float_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xca0000;
}

static void
Opcode_ufloat_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xda0000;
}

static void
Opcode_un_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1b0000;
}

static void
Opcode_ult_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5b0000;
}

static void
Opcode_ule_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7b0000;
}

static void
Opcode_ueq_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x3b0000;
}

static void
Opcode_olt_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4b0000;
}

static void
Opcode_ole_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6b0000;
}

static void
Opcode_oeq_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2b0000;
}

static void
Opcode_add_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xa0000;
}

static void
Opcode_sub_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x1a0000;
}

static void
Opcode_mul_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x2a0000;
}

static void
Opcode_madd_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x4a0000;
}

static void
Opcode_msub_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x5a0000;
}

static void
Opcode_sqrt0_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfa0090;
}

static void
Opcode_div0_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfa0070;
}

static void
Opcode_recip0_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfa0080;
}

static void
Opcode_rsqrt0_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfa00a0;
}

static void
Opcode_maddn_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x6a0000;
}

static void
Opcode_divn_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0x7a0000;
}

static void
Opcode_const_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfa0030;
}

static void
Opcode_nexp01_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfa00b0;
}

static void
Opcode_addexp_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfa00e0;
}

static void
Opcode_addexpm_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfa00f0;
}

static void
Opcode_mkdadj_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfa00d0;
}

static void
Opcode_mksadj_s_Slot_inst_encode (xtensa_insnbuf slotbuf)
{
  slotbuf[0] = 0xfa00c0;
}

static xtensa_opcode_encode_fn Opcode_excw_encode_fns[] = {
  Opcode_excw_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rfe_encode_fns[] = {
  Opcode_rfe_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rfde_encode_fns[] = {
  Opcode_rfde_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_syscall_encode_fns[] = {
  Opcode_syscall_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_call12_encode_fns[] = {
  Opcode_call12_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_call8_encode_fns[] = {
  Opcode_call8_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_call4_encode_fns[] = {
  Opcode_call4_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_callx12_encode_fns[] = {
  Opcode_callx12_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_callx8_encode_fns[] = {
  Opcode_callx8_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_callx4_encode_fns[] = {
  Opcode_callx4_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_entry_encode_fns[] = {
  Opcode_entry_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_movsp_encode_fns[] = {
  Opcode_movsp_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rotw_encode_fns[] = {
  Opcode_rotw_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_retw_encode_fns[] = {
  Opcode_retw_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_retw_n_encode_fns[] = {
  0, 0, Opcode_retw_n_Slot_inst16b_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rfwo_encode_fns[] = {
  Opcode_rfwo_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rfwu_encode_fns[] = {
  Opcode_rfwu_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_l32e_encode_fns[] = {
  Opcode_l32e_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_s32e_encode_fns[] = {
  Opcode_s32e_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_windowbase_encode_fns[] = {
  Opcode_rsr_windowbase_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_windowbase_encode_fns[] = {
  Opcode_wsr_windowbase_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_windowbase_encode_fns[] = {
  Opcode_xsr_windowbase_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_windowstart_encode_fns[] = {
  Opcode_rsr_windowstart_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_windowstart_encode_fns[] = {
  Opcode_wsr_windowstart_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_windowstart_encode_fns[] = {
  Opcode_xsr_windowstart_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rfme_encode_fns[] = {
  Opcode_rfme_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_mesr_encode_fns[] = {
  Opcode_rsr_mesr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_mesr_encode_fns[] = {
  Opcode_wsr_mesr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_mesr_encode_fns[] = {
  Opcode_xsr_mesr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_mecr_encode_fns[] = {
  Opcode_rsr_mecr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_mecr_encode_fns[] = {
  Opcode_wsr_mecr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_mecr_encode_fns[] = {
  Opcode_xsr_mecr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_mepc_encode_fns[] = {
  Opcode_rsr_mepc_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_mepc_encode_fns[] = {
  Opcode_wsr_mepc_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_mepc_encode_fns[] = {
  Opcode_xsr_mepc_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_meps_encode_fns[] = {
  Opcode_rsr_meps_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_meps_encode_fns[] = {
  Opcode_wsr_meps_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_meps_encode_fns[] = {
  Opcode_xsr_meps_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_mesave_encode_fns[] = {
  Opcode_rsr_mesave_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_mesave_encode_fns[] = {
  Opcode_wsr_mesave_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_mesave_encode_fns[] = {
  Opcode_xsr_mesave_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_mevaddr_encode_fns[] = {
  Opcode_rsr_mevaddr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_mevaddr_encode_fns[] = {
  Opcode_wsr_mevaddr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_mevaddr_encode_fns[] = {
  Opcode_xsr_mevaddr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_add_n_encode_fns[] = {
  0, Opcode_add_n_Slot_inst16a_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_addi_n_encode_fns[] = {
  0, Opcode_addi_n_Slot_inst16a_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_addi_n_Slot_xt_flix64_slot2_encode, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_beqz_n_encode_fns[] = {
  0, 0, Opcode_beqz_n_Slot_inst16b_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bnez_n_encode_fns[] = {
  0, 0, Opcode_bnez_n_Slot_inst16b_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ill_n_encode_fns[] = {
  0, 0, Opcode_ill_n_Slot_inst16b_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_l32i_n_encode_fns[] = {
  0, Opcode_l32i_n_Slot_inst16a_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_mov_n_encode_fns[] = {
  0, 0, Opcode_mov_n_Slot_inst16b_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_mov_n_Slot_xt_flix64_slot2_encode, 0, Opcode_mov_n_Slot_xt_flix64_slot1_encode, Opcode_mov_n_Slot_xt_flix64_slot0_encode, Opcode_mov_n_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_movi_n_encode_fns[] = {
  0, 0, Opcode_movi_n_Slot_inst16b_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_movi_n_Slot_xt_flix64_slot2_encode, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_nop_n_encode_fns[] = {
  0, 0, Opcode_nop_n_Slot_inst16b_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ret_n_encode_fns[] = {
  0, 0, Opcode_ret_n_Slot_inst16b_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_s32i_n_encode_fns[] = {
  0, Opcode_s32i_n_Slot_inst16a_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_threadptr_encode_fns[] = {
  Opcode_rur_threadptr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_threadptr_encode_fns[] = {
  Opcode_wur_threadptr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_addi_encode_fns[] = {
  Opcode_addi_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_addi_Slot_ae_slot0_encode, Opcode_addi_Slot_ae_slot0_encode, 0, 0, Opcode_addi_Slot_ae2_slot0_encode, Opcode_addi_Slot_ae_minislot2_encode, 0, 0, 0, 0, Opcode_addi_Slot_xt_flix64_slot1_encode, Opcode_addi_Slot_xt_flix64_slot0_encode, Opcode_addi_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_addmi_encode_fns[] = {
  Opcode_addmi_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_addmi_Slot_ae_slot0_encode, Opcode_addmi_Slot_ae_slot0_encode, 0, 0, Opcode_addmi_Slot_ae2_slot0_encode, Opcode_addmi_Slot_ae_minislot2_encode, 0, 0, 0, 0, Opcode_addmi_Slot_xt_flix64_slot1_encode, Opcode_addmi_Slot_xt_flix64_slot0_encode, Opcode_addmi_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_add_encode_fns[] = {
  Opcode_add_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_add_Slot_ae_slot0_encode, Opcode_add_Slot_ae_slot0_encode, 0, 0, Opcode_add_Slot_ae2_slot0_encode, 0, 0, 0, Opcode_add_Slot_xt_flix64_slot2_encode, 0, Opcode_add_Slot_xt_flix64_slot1_encode, Opcode_add_Slot_xt_flix64_slot0_encode, Opcode_add_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_addx2_encode_fns[] = {
  Opcode_addx2_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_addx2_Slot_ae_slot0_encode, Opcode_addx2_Slot_ae_slot0_encode, 0, 0, Opcode_addx2_Slot_ae2_slot0_encode, 0, 0, 0, Opcode_addx2_Slot_xt_flix64_slot2_encode, 0, Opcode_addx2_Slot_xt_flix64_slot1_encode, Opcode_addx2_Slot_xt_flix64_slot0_encode, Opcode_addx2_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_addx4_encode_fns[] = {
  Opcode_addx4_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_addx4_Slot_ae_slot0_encode, Opcode_addx4_Slot_ae_slot0_encode, 0, 0, Opcode_addx4_Slot_ae2_slot0_encode, 0, 0, 0, Opcode_addx4_Slot_xt_flix64_slot2_encode, 0, Opcode_addx4_Slot_xt_flix64_slot1_encode, Opcode_addx4_Slot_xt_flix64_slot0_encode, Opcode_addx4_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_addx8_encode_fns[] = {
  Opcode_addx8_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_addx8_Slot_ae_slot0_encode, Opcode_addx8_Slot_ae_slot0_encode, 0, 0, Opcode_addx8_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, Opcode_addx8_Slot_xt_flix64_slot1_encode, Opcode_addx8_Slot_xt_flix64_slot0_encode, Opcode_addx8_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_sub_encode_fns[] = {
  Opcode_sub_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_sub_Slot_ae_slot0_encode, Opcode_sub_Slot_ae_slot0_encode, 0, 0, Opcode_sub_Slot_ae2_slot0_encode, 0, 0, 0, Opcode_sub_Slot_xt_flix64_slot2_encode, 0, Opcode_sub_Slot_xt_flix64_slot1_encode, Opcode_sub_Slot_xt_flix64_slot0_encode, Opcode_sub_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_subx2_encode_fns[] = {
  Opcode_subx2_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_subx2_Slot_ae_slot0_encode, Opcode_subx2_Slot_ae_slot0_encode, 0, 0, Opcode_subx2_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, Opcode_subx2_Slot_xt_flix64_slot0_encode, Opcode_subx2_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_subx4_encode_fns[] = {
  Opcode_subx4_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_subx4_Slot_ae_slot0_encode, Opcode_subx4_Slot_ae_slot0_encode, 0, 0, Opcode_subx4_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, Opcode_subx4_Slot_xt_flix64_slot0_encode, Opcode_subx4_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_subx8_encode_fns[] = {
  Opcode_subx8_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_subx8_Slot_ae_slot0_encode, Opcode_subx8_Slot_ae_slot0_encode, 0, 0, Opcode_subx8_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, Opcode_subx8_Slot_xt_flix64_slot0_encode, Opcode_subx8_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_and_encode_fns[] = {
  Opcode_and_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_and_Slot_xt_flix64_slot2_encode, 0, Opcode_and_Slot_xt_flix64_slot1_encode, Opcode_and_Slot_xt_flix64_slot0_encode, Opcode_and_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_or_encode_fns[] = {
  Opcode_or_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_or_Slot_ae_slot0_encode, Opcode_or_Slot_ae_slot0_encode, 0, 0, Opcode_or_Slot_ae2_slot0_encode, 0, 0, 0, Opcode_or_Slot_xt_flix64_slot2_encode, 0, Opcode_or_Slot_xt_flix64_slot1_encode, Opcode_or_Slot_xt_flix64_slot0_encode, Opcode_or_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_xor_encode_fns[] = {
  Opcode_xor_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_xor_Slot_xt_flix64_slot2_encode, 0, Opcode_xor_Slot_xt_flix64_slot1_encode, Opcode_xor_Slot_xt_flix64_slot0_encode, Opcode_xor_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_beqi_encode_fns[] = {
  Opcode_beqi_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bgei_encode_fns[] = {
  Opcode_bgei_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_blti_encode_fns[] = {
  Opcode_blti_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bnei_encode_fns[] = {
  Opcode_bnei_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bbci_encode_fns[] = {
  Opcode_bbci_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bbsi_encode_fns[] = {
  Opcode_bbsi_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bgeui_encode_fns[] = {
  Opcode_bgeui_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bltui_encode_fns[] = {
  Opcode_bltui_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ball_encode_fns[] = {
  Opcode_ball_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bany_encode_fns[] = {
  Opcode_bany_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bbc_encode_fns[] = {
  Opcode_bbc_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bbs_encode_fns[] = {
  Opcode_bbs_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_beq_encode_fns[] = {
  Opcode_beq_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bge_encode_fns[] = {
  Opcode_bge_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bgeu_encode_fns[] = {
  Opcode_bgeu_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_blt_encode_fns[] = {
  Opcode_blt_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bltu_encode_fns[] = {
  Opcode_bltu_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bnall_encode_fns[] = {
  Opcode_bnall_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bne_encode_fns[] = {
  Opcode_bne_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bnone_encode_fns[] = {
  Opcode_bnone_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_beqz_encode_fns[] = {
  Opcode_beqz_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bgez_encode_fns[] = {
  Opcode_bgez_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bltz_encode_fns[] = {
  Opcode_bltz_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bnez_encode_fns[] = {
  Opcode_bnez_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_call0_encode_fns[] = {
  Opcode_call0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_callx0_encode_fns[] = {
  Opcode_callx0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_extui_encode_fns[] = {
  Opcode_extui_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_extui_Slot_ae_slot0_encode, Opcode_extui_Slot_ae_slot0_encode, 0, 0, Opcode_extui_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, Opcode_extui_Slot_xt_flix64_slot1_encode, Opcode_extui_Slot_xt_flix64_slot0_encode, Opcode_extui_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_ill_encode_fns[] = {
  Opcode_ill_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_j_encode_fns[] = {
  Opcode_j_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_j_Slot_xt_flix64_slot1_encode, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_jx_encode_fns[] = {
  Opcode_jx_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_jx_Slot_xt_flix64_slot1_encode, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_l16ui_encode_fns[] = {
  Opcode_l16ui_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_l16ui_Slot_xt_flix64_slot0_encode, Opcode_l16ui_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_l16si_encode_fns[] = {
  Opcode_l16si_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_l16si_Slot_xt_flix64_slot0_encode, Opcode_l16si_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_l32i_encode_fns[] = {
  Opcode_l32i_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_l32i_Slot_xt_flix64_slot0_encode, Opcode_l32i_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_l32r_encode_fns[] = {
  Opcode_l32r_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_l32r_Slot_xt_flix64_slot0_encode, Opcode_l32r_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_l8ui_encode_fns[] = {
  Opcode_l8ui_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_l8ui_Slot_xt_flix64_slot0_encode, Opcode_l8ui_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_loop_encode_fns[] = {
  Opcode_loop_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_loopgtz_encode_fns[] = {
  Opcode_loopgtz_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_loopnez_encode_fns[] = {
  Opcode_loopnez_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_movi_encode_fns[] = {
  Opcode_movi_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_movi_Slot_ae_slot0_encode, Opcode_movi_Slot_ae_slot0_encode, 0, 0, Opcode_movi_Slot_ae2_slot0_encode, Opcode_movi_Slot_ae_minislot2_encode, 0, 0, 0, 0, Opcode_movi_Slot_xt_flix64_slot1_encode, Opcode_movi_Slot_xt_flix64_slot0_encode, Opcode_movi_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_moveqz_encode_fns[] = {
  Opcode_moveqz_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_moveqz_Slot_ae_slot0_encode, Opcode_moveqz_Slot_ae_slot0_encode, 0, 0, Opcode_moveqz_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, Opcode_moveqz_Slot_xt_flix64_slot1_encode, Opcode_moveqz_Slot_xt_flix64_slot0_encode, Opcode_moveqz_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_movgez_encode_fns[] = {
  Opcode_movgez_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_movgez_Slot_ae_slot0_encode, Opcode_movgez_Slot_ae_slot0_encode, 0, 0, Opcode_movgez_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, Opcode_movgez_Slot_xt_flix64_slot1_encode, Opcode_movgez_Slot_xt_flix64_slot0_encode, Opcode_movgez_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_movltz_encode_fns[] = {
  Opcode_movltz_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_movltz_Slot_ae_slot0_encode, Opcode_movltz_Slot_ae_slot0_encode, 0, 0, Opcode_movltz_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, Opcode_movltz_Slot_xt_flix64_slot1_encode, Opcode_movltz_Slot_xt_flix64_slot0_encode, Opcode_movltz_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_movnez_encode_fns[] = {
  Opcode_movnez_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_movnez_Slot_ae_slot0_encode, Opcode_movnez_Slot_ae_slot0_encode, 0, 0, Opcode_movnez_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, Opcode_movnez_Slot_xt_flix64_slot1_encode, Opcode_movnez_Slot_xt_flix64_slot0_encode, Opcode_movnez_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_abs_encode_fns[] = {
  Opcode_abs_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_abs_Slot_xt_flix64_slot2_encode, 0, 0, Opcode_abs_Slot_xt_flix64_slot0_encode, Opcode_abs_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_neg_encode_fns[] = {
  Opcode_neg_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_neg_Slot_xt_flix64_slot2_encode, 0, Opcode_neg_Slot_xt_flix64_slot1_encode, Opcode_neg_Slot_xt_flix64_slot0_encode, Opcode_neg_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_nop_encode_fns[] = {
  Opcode_nop_Slot_inst_encode, 0, 0, Opcode_nop_Slot_ae_slot2_0_encode, Opcode_nop_Slot_ae_slot1_encode, Opcode_nop_Slot_ae_slot1_encode, Opcode_nop_Slot_ae_slot0_encode, Opcode_nop_Slot_ae_slot0_encode, Opcode_nop_Slot_ae_slot2_1_encode, Opcode_nop_Slot_ae2_slot1_encode, Opcode_nop_Slot_ae2_slot0_encode, Opcode_nop_Slot_ae_minislot2_encode, Opcode_nop_Slot_ae_minislot1_encode, Opcode_nop_Slot_ae_minislot0_encode, Opcode_nop_Slot_xt_flix64_slot2_encode, Opcode_nop_Slot_xt_dummy_encode, Opcode_nop_Slot_xt_flix64_slot1_encode, Opcode_nop_Slot_xt_flix64_slot0_encode, Opcode_nop_Slot_xt_flix64_slot0_encode, Opcode_nop_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_ret_encode_fns[] = {
  Opcode_ret_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_simcall_encode_fns[] = {
  Opcode_simcall_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_s16i_encode_fns[] = {
  Opcode_s16i_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_s16i_Slot_xt_flix64_slot0_encode, Opcode_s16i_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_s32i_encode_fns[] = {
  Opcode_s32i_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_s32i_Slot_xt_flix64_slot0_encode, Opcode_s32i_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_s32nb_encode_fns[] = {
  Opcode_s32nb_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_s8i_encode_fns[] = {
  Opcode_s8i_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_s8i_Slot_xt_flix64_slot0_encode, Opcode_s8i_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_ssa8b_encode_fns[] = {
  Opcode_ssa8b_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ssa8b_Slot_xt_flix64_slot0_encode, Opcode_ssa8b_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_ssa8l_encode_fns[] = {
  Opcode_ssa8l_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ssa8l_Slot_xt_flix64_slot0_encode, Opcode_ssa8l_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_ssl_encode_fns[] = {
  Opcode_ssl_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ssl_Slot_xt_flix64_slot1_encode, Opcode_ssl_Slot_xt_flix64_slot0_encode, Opcode_ssl_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_ssr_encode_fns[] = {
  Opcode_ssr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ssr_Slot_xt_flix64_slot0_encode, Opcode_ssr_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_ssai_encode_fns[] = {
  Opcode_ssai_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ssai_Slot_xt_flix64_slot0_encode, Opcode_ssai_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_sll_encode_fns[] = {
  Opcode_sll_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_sll_Slot_xt_flix64_slot1_encode, Opcode_sll_Slot_xt_flix64_slot0_encode, Opcode_sll_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_src_encode_fns[] = {
  Opcode_src_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_src_Slot_xt_flix64_slot1_encode, Opcode_src_Slot_xt_flix64_slot0_encode, Opcode_src_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_sra_encode_fns[] = {
  Opcode_sra_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_sra_Slot_xt_flix64_slot2_encode, 0, Opcode_sra_Slot_xt_flix64_slot1_encode, Opcode_sra_Slot_xt_flix64_slot0_encode, Opcode_sra_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_srl_encode_fns[] = {
  Opcode_srl_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_srl_Slot_xt_flix64_slot2_encode, 0, Opcode_srl_Slot_xt_flix64_slot1_encode, Opcode_srl_Slot_xt_flix64_slot0_encode, Opcode_srl_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_slli_encode_fns[] = {
  Opcode_slli_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_slli_Slot_xt_flix64_slot1_encode, Opcode_slli_Slot_xt_flix64_slot0_encode, Opcode_slli_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_srai_encode_fns[] = {
  Opcode_srai_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_srai_Slot_xt_flix64_slot2_encode, 0, Opcode_srai_Slot_xt_flix64_slot1_encode, Opcode_srai_Slot_xt_flix64_slot0_encode, Opcode_srai_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_srli_encode_fns[] = {
  Opcode_srli_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_srli_Slot_xt_flix64_slot2_encode, 0, Opcode_srli_Slot_xt_flix64_slot1_encode, Opcode_srli_Slot_xt_flix64_slot0_encode, Opcode_srli_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_memw_encode_fns[] = {
  Opcode_memw_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_extw_encode_fns[] = {
  Opcode_extw_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_isync_encode_fns[] = {
  Opcode_isync_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_dsync_encode_fns[] = {
  Opcode_dsync_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_esync_encode_fns[] = {
  Opcode_esync_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsync_encode_fns[] = {
  Opcode_rsync_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsil_encode_fns[] = {
  Opcode_rsil_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_lend_encode_fns[] = {
  Opcode_rsr_lend_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_lend_encode_fns[] = {
  Opcode_wsr_lend_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_lend_encode_fns[] = {
  Opcode_xsr_lend_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_lcount_encode_fns[] = {
  Opcode_rsr_lcount_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_lcount_encode_fns[] = {
  Opcode_wsr_lcount_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_lcount_encode_fns[] = {
  Opcode_xsr_lcount_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_lbeg_encode_fns[] = {
  Opcode_rsr_lbeg_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_lbeg_encode_fns[] = {
  Opcode_wsr_lbeg_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_lbeg_encode_fns[] = {
  Opcode_xsr_lbeg_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_sar_encode_fns[] = {
  Opcode_rsr_sar_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_sar_encode_fns[] = {
  Opcode_wsr_sar_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_sar_encode_fns[] = {
  Opcode_xsr_sar_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_memctl_encode_fns[] = {
  Opcode_rsr_memctl_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_memctl_encode_fns[] = {
  Opcode_wsr_memctl_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_memctl_encode_fns[] = {
  Opcode_xsr_memctl_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_litbase_encode_fns[] = {
  Opcode_rsr_litbase_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_litbase_encode_fns[] = {
  Opcode_wsr_litbase_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_litbase_encode_fns[] = {
  Opcode_xsr_litbase_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_configid0_encode_fns[] = {
  Opcode_rsr_configid0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_configid0_encode_fns[] = {
  Opcode_wsr_configid0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_configid1_encode_fns[] = {
  Opcode_rsr_configid1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_243_encode_fns[] = {
  Opcode_rsr_243_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_ps_encode_fns[] = {
  Opcode_rsr_ps_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_ps_encode_fns[] = {
  Opcode_wsr_ps_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_ps_encode_fns[] = {
  Opcode_xsr_ps_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_epc1_encode_fns[] = {
  Opcode_rsr_epc1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_epc1_encode_fns[] = {
  Opcode_wsr_epc1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_epc1_encode_fns[] = {
  Opcode_xsr_epc1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_excsave1_encode_fns[] = {
  Opcode_rsr_excsave1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_excsave1_encode_fns[] = {
  Opcode_wsr_excsave1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_excsave1_encode_fns[] = {
  Opcode_xsr_excsave1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_epc2_encode_fns[] = {
  Opcode_rsr_epc2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_epc2_encode_fns[] = {
  Opcode_wsr_epc2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_epc2_encode_fns[] = {
  Opcode_xsr_epc2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_excsave2_encode_fns[] = {
  Opcode_rsr_excsave2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_excsave2_encode_fns[] = {
  Opcode_wsr_excsave2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_excsave2_encode_fns[] = {
  Opcode_xsr_excsave2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_epc3_encode_fns[] = {
  Opcode_rsr_epc3_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_epc3_encode_fns[] = {
  Opcode_wsr_epc3_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_epc3_encode_fns[] = {
  Opcode_xsr_epc3_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_excsave3_encode_fns[] = {
  Opcode_rsr_excsave3_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_excsave3_encode_fns[] = {
  Opcode_wsr_excsave3_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_excsave3_encode_fns[] = {
  Opcode_xsr_excsave3_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_epc4_encode_fns[] = {
  Opcode_rsr_epc4_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_epc4_encode_fns[] = {
  Opcode_wsr_epc4_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_epc4_encode_fns[] = {
  Opcode_xsr_epc4_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_excsave4_encode_fns[] = {
  Opcode_rsr_excsave4_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_excsave4_encode_fns[] = {
  Opcode_wsr_excsave4_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_excsave4_encode_fns[] = {
  Opcode_xsr_excsave4_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_epc5_encode_fns[] = {
  Opcode_rsr_epc5_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_epc5_encode_fns[] = {
  Opcode_wsr_epc5_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_epc5_encode_fns[] = {
  Opcode_xsr_epc5_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_excsave5_encode_fns[] = {
  Opcode_rsr_excsave5_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_excsave5_encode_fns[] = {
  Opcode_wsr_excsave5_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_excsave5_encode_fns[] = {
  Opcode_xsr_excsave5_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_epc6_encode_fns[] = {
  Opcode_rsr_epc6_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_epc6_encode_fns[] = {
  Opcode_wsr_epc6_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_epc6_encode_fns[] = {
  Opcode_xsr_epc6_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_excsave6_encode_fns[] = {
  Opcode_rsr_excsave6_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_excsave6_encode_fns[] = {
  Opcode_wsr_excsave6_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_excsave6_encode_fns[] = {
  Opcode_xsr_excsave6_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_epc7_encode_fns[] = {
  Opcode_rsr_epc7_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_epc7_encode_fns[] = {
  Opcode_wsr_epc7_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_epc7_encode_fns[] = {
  Opcode_xsr_epc7_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_excsave7_encode_fns[] = {
  Opcode_rsr_excsave7_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_excsave7_encode_fns[] = {
  Opcode_wsr_excsave7_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_excsave7_encode_fns[] = {
  Opcode_xsr_excsave7_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_eps2_encode_fns[] = {
  Opcode_rsr_eps2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_eps2_encode_fns[] = {
  Opcode_wsr_eps2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_eps2_encode_fns[] = {
  Opcode_xsr_eps2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_eps3_encode_fns[] = {
  Opcode_rsr_eps3_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_eps3_encode_fns[] = {
  Opcode_wsr_eps3_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_eps3_encode_fns[] = {
  Opcode_xsr_eps3_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_eps4_encode_fns[] = {
  Opcode_rsr_eps4_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_eps4_encode_fns[] = {
  Opcode_wsr_eps4_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_eps4_encode_fns[] = {
  Opcode_xsr_eps4_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_eps5_encode_fns[] = {
  Opcode_rsr_eps5_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_eps5_encode_fns[] = {
  Opcode_wsr_eps5_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_eps5_encode_fns[] = {
  Opcode_xsr_eps5_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_eps6_encode_fns[] = {
  Opcode_rsr_eps6_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_eps6_encode_fns[] = {
  Opcode_wsr_eps6_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_eps6_encode_fns[] = {
  Opcode_xsr_eps6_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_eps7_encode_fns[] = {
  Opcode_rsr_eps7_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_eps7_encode_fns[] = {
  Opcode_wsr_eps7_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_eps7_encode_fns[] = {
  Opcode_xsr_eps7_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_excvaddr_encode_fns[] = {
  Opcode_rsr_excvaddr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_excvaddr_encode_fns[] = {
  Opcode_wsr_excvaddr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_excvaddr_encode_fns[] = {
  Opcode_xsr_excvaddr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_depc_encode_fns[] = {
  Opcode_rsr_depc_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_depc_encode_fns[] = {
  Opcode_wsr_depc_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_depc_encode_fns[] = {
  Opcode_xsr_depc_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_exccause_encode_fns[] = {
  Opcode_rsr_exccause_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_exccause_encode_fns[] = {
  Opcode_wsr_exccause_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_exccause_encode_fns[] = {
  Opcode_xsr_exccause_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_prid_encode_fns[] = {
  Opcode_rsr_prid_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_vecbase_encode_fns[] = {
  Opcode_rsr_vecbase_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_vecbase_encode_fns[] = {
  Opcode_wsr_vecbase_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_vecbase_encode_fns[] = {
  Opcode_xsr_vecbase_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_mul16s_encode_fns[] = {
  Opcode_mul16s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_mul16s_Slot_xt_flix64_slot1_encode, Opcode_mul16s_Slot_xt_flix64_slot0_encode, Opcode_mul16s_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_mul16u_encode_fns[] = {
  Opcode_mul16u_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_mul16u_Slot_xt_flix64_slot1_encode, Opcode_mul16u_Slot_xt_flix64_slot0_encode, Opcode_mul16u_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_mull_encode_fns[] = {
  Opcode_mull_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_mull_Slot_xt_flix64_slot1_encode, Opcode_mull_Slot_xt_flix64_slot0_encode, Opcode_mull_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_mulsh_encode_fns[] = {
  Opcode_mulsh_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_muluh_encode_fns[] = {
  Opcode_muluh_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rfi_encode_fns[] = {
  Opcode_rfi_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_waiti_encode_fns[] = {
  Opcode_waiti_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_interrupt_encode_fns[] = {
  Opcode_rsr_interrupt_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_intset_encode_fns[] = {
  Opcode_wsr_intset_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_intclear_encode_fns[] = {
  Opcode_wsr_intclear_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_intenable_encode_fns[] = {
  Opcode_rsr_intenable_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_intenable_encode_fns[] = {
  Opcode_wsr_intenable_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_intenable_encode_fns[] = {
  Opcode_xsr_intenable_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_break_encode_fns[] = {
  Opcode_break_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_break_n_encode_fns[] = {
  0, 0, Opcode_break_n_Slot_inst16b_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_dbreaka0_encode_fns[] = {
  Opcode_rsr_dbreaka0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_dbreaka0_encode_fns[] = {
  Opcode_wsr_dbreaka0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_dbreaka0_encode_fns[] = {
  Opcode_xsr_dbreaka0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_dbreakc0_encode_fns[] = {
  Opcode_rsr_dbreakc0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_dbreakc0_encode_fns[] = {
  Opcode_wsr_dbreakc0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_dbreakc0_encode_fns[] = {
  Opcode_xsr_dbreakc0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_dbreaka1_encode_fns[] = {
  Opcode_rsr_dbreaka1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_dbreaka1_encode_fns[] = {
  Opcode_wsr_dbreaka1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_dbreaka1_encode_fns[] = {
  Opcode_xsr_dbreaka1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_dbreakc1_encode_fns[] = {
  Opcode_rsr_dbreakc1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_dbreakc1_encode_fns[] = {
  Opcode_wsr_dbreakc1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_dbreakc1_encode_fns[] = {
  Opcode_xsr_dbreakc1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_ibreaka0_encode_fns[] = {
  Opcode_rsr_ibreaka0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_ibreaka0_encode_fns[] = {
  Opcode_wsr_ibreaka0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_ibreaka0_encode_fns[] = {
  Opcode_xsr_ibreaka0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_ibreaka1_encode_fns[] = {
  Opcode_rsr_ibreaka1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_ibreaka1_encode_fns[] = {
  Opcode_wsr_ibreaka1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_ibreaka1_encode_fns[] = {
  Opcode_xsr_ibreaka1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_ibreakenable_encode_fns[] = {
  Opcode_rsr_ibreakenable_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_ibreakenable_encode_fns[] = {
  Opcode_wsr_ibreakenable_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_ibreakenable_encode_fns[] = {
  Opcode_xsr_ibreakenable_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_debugcause_encode_fns[] = {
  Opcode_rsr_debugcause_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_debugcause_encode_fns[] = {
  Opcode_wsr_debugcause_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_debugcause_encode_fns[] = {
  Opcode_xsr_debugcause_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_icount_encode_fns[] = {
  Opcode_rsr_icount_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_icount_encode_fns[] = {
  Opcode_wsr_icount_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_icount_encode_fns[] = {
  Opcode_xsr_icount_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_icountlevel_encode_fns[] = {
  Opcode_rsr_icountlevel_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_icountlevel_encode_fns[] = {
  Opcode_wsr_icountlevel_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_icountlevel_encode_fns[] = {
  Opcode_xsr_icountlevel_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_ddr_encode_fns[] = {
  Opcode_rsr_ddr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_ddr_encode_fns[] = {
  Opcode_wsr_ddr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_ddr_encode_fns[] = {
  Opcode_xsr_ddr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_lddr32_p_encode_fns[] = {
  Opcode_lddr32_p_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_sddr32_p_encode_fns[] = {
  Opcode_sddr32_p_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rfdo_encode_fns[] = {
  Opcode_rfdo_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rfdd_encode_fns[] = {
  Opcode_rfdd_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_mmid_encode_fns[] = {
  Opcode_wsr_mmid_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_andb_encode_fns[] = {
  Opcode_andb_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_andbc_encode_fns[] = {
  Opcode_andbc_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_orb_encode_fns[] = {
  Opcode_orb_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_orbc_encode_fns[] = {
  Opcode_orbc_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xorb_encode_fns[] = {
  Opcode_xorb_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_all4_encode_fns[] = {
  Opcode_all4_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_any4_encode_fns[] = {
  Opcode_any4_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_all8_encode_fns[] = {
  Opcode_all8_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_any8_encode_fns[] = {
  Opcode_any8_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bf_encode_fns[] = {
  Opcode_bf_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_bt_encode_fns[] = {
  Opcode_bt_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_movf_encode_fns[] = {
  Opcode_movf_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_movt_encode_fns[] = {
  Opcode_movt_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_br_encode_fns[] = {
  Opcode_rsr_br_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_br_encode_fns[] = {
  Opcode_wsr_br_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_br_encode_fns[] = {
  Opcode_xsr_br_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_ccount_encode_fns[] = {
  Opcode_rsr_ccount_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_ccount_encode_fns[] = {
  Opcode_wsr_ccount_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_ccount_encode_fns[] = {
  Opcode_xsr_ccount_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_ccompare0_encode_fns[] = {
  Opcode_rsr_ccompare0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_ccompare0_encode_fns[] = {
  Opcode_wsr_ccompare0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_ccompare0_encode_fns[] = {
  Opcode_xsr_ccompare0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_ccompare1_encode_fns[] = {
  Opcode_rsr_ccompare1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_ccompare1_encode_fns[] = {
  Opcode_wsr_ccompare1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_ccompare1_encode_fns[] = {
  Opcode_xsr_ccompare1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_ccompare2_encode_fns[] = {
  Opcode_rsr_ccompare2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_ccompare2_encode_fns[] = {
  Opcode_wsr_ccompare2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_ccompare2_encode_fns[] = {
  Opcode_xsr_ccompare2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ihi_encode_fns[] = {
  Opcode_ihi_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ipf_encode_fns[] = {
  Opcode_ipf_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ihu_encode_fns[] = {
  Opcode_ihu_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_iiu_encode_fns[] = {
  Opcode_iiu_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ipfl_encode_fns[] = {
  Opcode_ipfl_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_iii_encode_fns[] = {
  Opcode_iii_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_lict_encode_fns[] = {
  Opcode_lict_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_licw_encode_fns[] = {
  Opcode_licw_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_sict_encode_fns[] = {
  Opcode_sict_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_sicw_encode_fns[] = {
  Opcode_sicw_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_dhwb_encode_fns[] = {
  Opcode_dhwb_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_dhwbi_encode_fns[] = {
  Opcode_dhwbi_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_diwbui_p_encode_fns[] = {
  Opcode_diwbui_p_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_diwb_encode_fns[] = {
  Opcode_diwb_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_diwbi_encode_fns[] = {
  Opcode_diwbi_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_dhi_encode_fns[] = {
  Opcode_dhi_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_dii_encode_fns[] = {
  Opcode_dii_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_dpfr_encode_fns[] = {
  Opcode_dpfr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_dpfro_encode_fns[] = {
  Opcode_dpfro_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_dpfw_encode_fns[] = {
  Opcode_dpfw_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_dpfwo_encode_fns[] = {
  Opcode_dpfwo_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_dhu_encode_fns[] = {
  Opcode_dhu_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_diu_encode_fns[] = {
  Opcode_diu_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_dpfl_encode_fns[] = {
  Opcode_dpfl_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_sdct_encode_fns[] = {
  Opcode_sdct_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ldct_encode_fns[] = {
  Opcode_ldct_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_prefctl_encode_fns[] = {
  Opcode_rsr_prefctl_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_prefctl_encode_fns[] = {
  Opcode_wsr_prefctl_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_prefctl_encode_fns[] = {
  Opcode_xsr_prefctl_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_idtlb_encode_fns[] = {
  Opcode_idtlb_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_pdtlb_encode_fns[] = {
  Opcode_pdtlb_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rdtlb0_encode_fns[] = {
  Opcode_rdtlb0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rdtlb1_encode_fns[] = {
  Opcode_rdtlb1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wdtlb_encode_fns[] = {
  Opcode_wdtlb_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_iitlb_encode_fns[] = {
  Opcode_iitlb_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_pitlb_encode_fns[] = {
  Opcode_pitlb_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ritlb0_encode_fns[] = {
  Opcode_ritlb0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ritlb1_encode_fns[] = {
  Opcode_ritlb1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_witlb_encode_fns[] = {
  Opcode_witlb_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_cpenable_encode_fns[] = {
  Opcode_rsr_cpenable_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_cpenable_encode_fns[] = {
  Opcode_wsr_cpenable_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_cpenable_encode_fns[] = {
  Opcode_xsr_cpenable_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_clamps_encode_fns[] = {
  Opcode_clamps_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_clamps_Slot_ae_slot0_encode, Opcode_clamps_Slot_ae_slot0_encode, 0, 0, Opcode_clamps_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, Opcode_clamps_Slot_xt_flix64_slot0_encode, Opcode_clamps_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_max_encode_fns[] = {
  Opcode_max_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_max_Slot_xt_flix64_slot0_encode, Opcode_max_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_maxu_encode_fns[] = {
  Opcode_maxu_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_maxu_Slot_xt_flix64_slot0_encode, Opcode_maxu_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_min_encode_fns[] = {
  Opcode_min_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_min_Slot_xt_flix64_slot0_encode, Opcode_min_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_minu_encode_fns[] = {
  Opcode_minu_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_minu_Slot_xt_flix64_slot0_encode, Opcode_minu_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_nsa_encode_fns[] = {
  Opcode_nsa_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_nsa_Slot_xt_flix64_slot0_encode, Opcode_nsa_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_nsau_encode_fns[] = {
  Opcode_nsau_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_nsau_Slot_xt_flix64_slot0_encode, Opcode_nsau_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_sext_encode_fns[] = {
  Opcode_sext_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_sext_Slot_ae_slot0_encode, Opcode_sext_Slot_ae_slot0_encode, 0, 0, Opcode_sext_Slot_ae2_slot0_encode, 0, 0, 0, Opcode_sext_Slot_xt_flix64_slot2_encode, 0, Opcode_sext_Slot_xt_flix64_slot1_encode, Opcode_sext_Slot_xt_flix64_slot0_encode, Opcode_sext_Slot_xt_flix64_slot0_encode, 0
};

static xtensa_opcode_encode_fn Opcode_l32ai_encode_fns[] = {
  Opcode_l32ai_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_s32ri_encode_fns[] = {
  Opcode_s32ri_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_s32c1i_encode_fns[] = {
  Opcode_s32c1i_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_scompare1_encode_fns[] = {
  Opcode_rsr_scompare1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_scompare1_encode_fns[] = {
  Opcode_wsr_scompare1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_scompare1_encode_fns[] = {
  Opcode_xsr_scompare1_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsr_atomctl_encode_fns[] = {
  Opcode_rsr_atomctl_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wsr_atomctl_encode_fns[] = {
  Opcode_wsr_atomctl_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_xsr_atomctl_encode_fns[] = {
  Opcode_xsr_atomctl_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_quos_encode_fns[] = {
  Opcode_quos_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_quou_encode_fns[] = {
  Opcode_quou_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rems_encode_fns[] = {
  Opcode_rems_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_remu_encode_fns[] = {
  Opcode_remu_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rer_encode_fns[] = {
  Opcode_rer_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wer_encode_fns[] = {
  Opcode_wer_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_beqz_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_beqz_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_beqz_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bgez_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bgez_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bgez_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bltz_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bltz_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bltz_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bnez_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bnez_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bnez_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_beqi_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_beqi_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_beqi_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bgei_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bgei_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bgei_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_blti_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_blti_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_blti_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bnei_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bnei_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bnei_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bgeui_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bgeui_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bgeui_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bltui_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bltui_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bltui_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bbci_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bbci_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bbci_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bbsi_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bbsi_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bbsi_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_ball_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ball_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ball_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bany_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bany_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bany_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bbc_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bbc_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bbc_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bbs_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bbs_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bbs_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_beq_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_beq_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_beq_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bgeu_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bgeu_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bgeu_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bge_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bge_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bge_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bltu_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bltu_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bltu_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_blt_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_blt_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_blt_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bnall_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bnall_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bnall_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bne_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bne_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bne_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_bnone_w18_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bnone_w18_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_bnone_w18_Slot_xt_flix64_slot3_encode
};

static xtensa_opcode_encode_fn Opcode_rur_ae_ovf_sar_encode_fns[] = {
  Opcode_rur_ae_ovf_sar_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_ae_ovf_sar_encode_fns[] = {
  Opcode_wur_ae_ovf_sar_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_ae_bithead_encode_fns[] = {
  Opcode_rur_ae_bithead_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_ae_bithead_encode_fns[] = {
  Opcode_wur_ae_bithead_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_ae_ts_fts_bu_bp_encode_fns[] = {
  Opcode_rur_ae_ts_fts_bu_bp_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_ae_ts_fts_bu_bp_encode_fns[] = {
  Opcode_wur_ae_ts_fts_bu_bp_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_ae_cw_sd_no_encode_fns[] = {
  Opcode_rur_ae_cw_sd_no_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_ae_cw_sd_no_encode_fns[] = {
  Opcode_wur_ae_cw_sd_no_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_ae_cbegin0_encode_fns[] = {
  Opcode_rur_ae_cbegin0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_ae_cbegin0_encode_fns[] = {
  Opcode_wur_ae_cbegin0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_ae_cend0_encode_fns[] = {
  Opcode_rur_ae_cend0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_ae_cend0_encode_fns[] = {
  Opcode_wur_ae_cend0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_fcr_encode_fns[] = {
  Opcode_rur_fcr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_fcr_encode_fns[] = {
  Opcode_wur_fcr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_fsr_encode_fns[] = {
  Opcode_rur_fsr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_fsr_encode_fns[] = {
  Opcode_wur_fsr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_ae_overflow_encode_fns[] = {
  Opcode_rur_ae_overflow_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_ae_overflow_encode_fns[] = {
  Opcode_wur_ae_overflow_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_ae_sar_encode_fns[] = {
  Opcode_rur_ae_sar_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_ae_sar_encode_fns[] = {
  Opcode_wur_ae_sar_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_ae_bitptr_encode_fns[] = {
  Opcode_rur_ae_bitptr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_ae_bitptr_encode_fns[] = {
  Opcode_wur_ae_bitptr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_ae_bitsused_encode_fns[] = {
  Opcode_rur_ae_bitsused_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_ae_bitsused_encode_fns[] = {
  Opcode_wur_ae_bitsused_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_ae_tablesize_encode_fns[] = {
  Opcode_rur_ae_tablesize_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_ae_tablesize_encode_fns[] = {
  Opcode_wur_ae_tablesize_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_ae_first_ts_encode_fns[] = {
  Opcode_rur_ae_first_ts_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_ae_first_ts_encode_fns[] = {
  Opcode_wur_ae_first_ts_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_ae_nextoffset_encode_fns[] = {
  Opcode_rur_ae_nextoffset_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_ae_nextoffset_encode_fns[] = {
  Opcode_wur_ae_nextoffset_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_ae_searchdone_encode_fns[] = {
  Opcode_rur_ae_searchdone_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_ae_searchdone_encode_fns[] = {
  Opcode_wur_ae_searchdone_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rur_ae_cwrap_encode_fns[] = {
  Opcode_rur_ae_cwrap_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wur_ae_cwrap_encode_fns[] = {
  Opcode_wur_ae_cwrap_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16m_xc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l16m_xc_Slot_ae_slot0_encode, Opcode_ae_l16m_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16m_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16m_i_encode_fns[] = {
  Opcode_ae_l16m_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l16m_i_Slot_ae_slot0_encode, Opcode_ae_l16m_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16m_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_l16m_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16m_iu_encode_fns[] = {
  Opcode_ae_l16m_iu_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l16m_iu_Slot_ae_slot0_encode, Opcode_ae_l16m_iu_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16m_iu_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16m_x_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l16m_x_Slot_ae_slot0_encode, Opcode_ae_l16m_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16m_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16m_xu_encode_fns[] = {
  Opcode_ae_l16m_xu_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l16m_xu_Slot_ae_slot0_encode, Opcode_ae_l16m_xu_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16m_xu_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16_xc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l16_xc_Slot_ae_slot0_encode, Opcode_ae_l16_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16_i_encode_fns[] = {
  Opcode_ae_l16_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l16_i_Slot_ae_slot0_encode, Opcode_ae_l16_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_l16_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16_ip_encode_fns[] = {
  Opcode_ae_l16_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l16_ip_Slot_ae_slot0_encode, Opcode_ae_l16_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16_x_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l16_x_Slot_ae_slot0_encode, Opcode_ae_l16_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16_xp_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l16_xp_Slot_ae_slot0_encode, Opcode_ae_l16_xp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16_xp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32f24_xc_encode_fns[] = {
  Opcode_ae_l32f24_xc_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32f24_xc_Slot_ae_slot0_encode, Opcode_ae_l32f24_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32f24_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32f24_i_encode_fns[] = {
  Opcode_ae_l32f24_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32f24_i_Slot_ae_slot0_encode, Opcode_ae_l32f24_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32f24_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_l32f24_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32f24_ip_encode_fns[] = {
  Opcode_ae_l32f24_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32f24_ip_Slot_ae_slot0_encode, Opcode_ae_l32f24_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32f24_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32f24_x_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l32f24_x_Slot_ae_slot0_encode, Opcode_ae_l32f24_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32f24_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32f24_xp_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l32f24_xp_Slot_ae_slot0_encode, Opcode_ae_l32f24_xp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32f24_xp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32_xc_encode_fns[] = {
  Opcode_ae_l32_xc_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32_xc_Slot_ae_slot0_encode, Opcode_ae_l32_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32_i_encode_fns[] = {
  Opcode_ae_l32_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32_i_Slot_ae_slot0_encode, Opcode_ae_l32_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_l32_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32_ip_encode_fns[] = {
  Opcode_ae_l32_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32_ip_Slot_ae_slot0_encode, Opcode_ae_l32_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32_x_encode_fns[] = {
  Opcode_ae_l32_x_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32_x_Slot_ae_slot0_encode, Opcode_ae_l32_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32_xp_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l32_xp_Slot_ae_slot0_encode, Opcode_ae_l32_xp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32_xp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32m_xc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l32m_xc_Slot_ae_slot0_encode, Opcode_ae_l32m_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32m_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32m_i_encode_fns[] = {
  Opcode_ae_l32m_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32m_i_Slot_ae_slot0_encode, Opcode_ae_l32m_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32m_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_l32m_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32m_iu_encode_fns[] = {
  Opcode_ae_l32m_iu_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32m_iu_Slot_ae_slot0_encode, Opcode_ae_l32m_iu_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32m_iu_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32m_x_encode_fns[] = {
  Opcode_ae_l32m_x_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32m_x_Slot_ae_slot0_encode, Opcode_ae_l32m_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32m_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32m_xu_encode_fns[] = {
  Opcode_ae_l32m_xu_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32m_xu_Slot_ae_slot0_encode, Opcode_ae_l32m_xu_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32m_xu_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16x2m_xc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l16x2m_xc_Slot_ae_slot0_encode, Opcode_ae_l16x2m_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16x2m_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16x2m_i_encode_fns[] = {
  Opcode_ae_l16x2m_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l16x2m_i_Slot_ae_slot0_encode, Opcode_ae_l16x2m_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16x2m_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_l16x2m_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16x2m_iu_encode_fns[] = {
  Opcode_ae_l16x2m_iu_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l16x2m_iu_Slot_ae_slot0_encode, Opcode_ae_l16x2m_iu_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16x2m_iu_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16x2m_x_encode_fns[] = {
  Opcode_ae_l16x2m_x_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l16x2m_x_Slot_ae_slot0_encode, Opcode_ae_l16x2m_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16x2m_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16x2m_xu_encode_fns[] = {
  Opcode_ae_l16x2m_xu_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l16x2m_xu_Slot_ae_slot0_encode, Opcode_ae_l16x2m_xu_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16x2m_xu_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32x2f24_xc_encode_fns[] = {
  Opcode_ae_l32x2f24_xc_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32x2f24_xc_Slot_ae_slot0_encode, Opcode_ae_l32x2f24_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32x2f24_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32x2f24_i_encode_fns[] = {
  Opcode_ae_l32x2f24_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32x2f24_i_Slot_ae_slot0_encode, Opcode_ae_l32x2f24_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32x2f24_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_l32x2f24_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32x2f24_ip_encode_fns[] = {
  Opcode_ae_l32x2f24_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32x2f24_ip_Slot_ae_slot0_encode, Opcode_ae_l32x2f24_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32x2f24_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32x2f24_rip_encode_fns[] = {
  Opcode_ae_l32x2f24_rip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32x2f24_rip_Slot_ae_slot0_encode, Opcode_ae_l32x2f24_rip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32x2f24_rip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32x2f24_ric_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l32x2f24_ric_Slot_ae_slot0_encode, Opcode_ae_l32x2f24_ric_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32x2f24_ric_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32x2f24_x_encode_fns[] = {
  Opcode_ae_l32x2f24_x_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32x2f24_x_Slot_ae_slot0_encode, Opcode_ae_l32x2f24_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32x2f24_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32x2f24_xp_encode_fns[] = {
  Opcode_ae_l32x2f24_xp_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32x2f24_xp_Slot_ae_slot0_encode, Opcode_ae_l32x2f24_xp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32x2f24_xp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32x2_xc_encode_fns[] = {
  Opcode_ae_l32x2_xc_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32x2_xc_Slot_ae_slot0_encode, Opcode_ae_l32x2_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32x2_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32x2_i_encode_fns[] = {
  Opcode_ae_l32x2_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32x2_i_Slot_ae_slot0_encode, Opcode_ae_l32x2_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32x2_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_l32x2_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32x2_ip_encode_fns[] = {
  Opcode_ae_l32x2_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32x2_ip_Slot_ae_slot0_encode, Opcode_ae_l32x2_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32x2_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32x2_rip_encode_fns[] = {
  Opcode_ae_l32x2_rip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32x2_rip_Slot_ae_slot0_encode, Opcode_ae_l32x2_rip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32x2_rip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32x2_ric_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l32x2_ric_Slot_ae_slot0_encode, Opcode_ae_l32x2_ric_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32x2_ric_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32x2_x_encode_fns[] = {
  Opcode_ae_l32x2_x_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32x2_x_Slot_ae_slot0_encode, Opcode_ae_l32x2_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32x2_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l32x2_xp_encode_fns[] = {
  Opcode_ae_l32x2_xp_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l32x2_xp_Slot_ae_slot0_encode, Opcode_ae_l32x2_xp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l32x2_xp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16x4_xc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l16x4_xc_Slot_ae_slot0_encode, Opcode_ae_l16x4_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16x4_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16x4_i_encode_fns[] = {
  Opcode_ae_l16x4_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l16x4_i_Slot_ae_slot0_encode, Opcode_ae_l16x4_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16x4_i_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16x4_ip_encode_fns[] = {
  Opcode_ae_l16x4_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l16x4_ip_Slot_ae_slot0_encode, Opcode_ae_l16x4_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16x4_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16x4_rip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l16x4_rip_Slot_ae_slot0_encode, Opcode_ae_l16x4_rip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16x4_rip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16x4_ric_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l16x4_ric_Slot_ae_slot0_encode, Opcode_ae_l16x4_ric_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16x4_ric_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16x4_x_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l16x4_x_Slot_ae_slot0_encode, Opcode_ae_l16x4_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16x4_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l16x4_xp_encode_fns[] = {
  Opcode_ae_l16x4_xp_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l16x4_xp_Slot_ae_slot0_encode, Opcode_ae_l16x4_xp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l16x4_xp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l64_xc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l64_xc_Slot_ae_slot0_encode, Opcode_ae_l64_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l64_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l64_i_encode_fns[] = {
  Opcode_ae_l64_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_l64_i_Slot_ae_slot0_encode, Opcode_ae_l64_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l64_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_l64_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l64_ip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l64_ip_Slot_ae_slot0_encode, Opcode_ae_l64_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l64_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l64_x_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l64_x_Slot_ae_slot0_encode, Opcode_ae_l64_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l64_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_l64_xp_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_l64_xp_Slot_ae_slot0_encode, Opcode_ae_l64_xp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_l64_xp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16x2m_xc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s16x2m_xc_Slot_ae_slot0_encode, Opcode_ae_s16x2m_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16x2m_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16x2m_i_encode_fns[] = {
  Opcode_ae_s16x2m_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s16x2m_i_Slot_ae_slot0_encode, Opcode_ae_s16x2m_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16x2m_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_s16x2m_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16x2m_iu_encode_fns[] = {
  Opcode_ae_s16x2m_iu_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s16x2m_iu_Slot_ae_slot0_encode, Opcode_ae_s16x2m_iu_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16x2m_iu_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16x2m_x_encode_fns[] = {
  Opcode_ae_s16x2m_x_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s16x2m_x_Slot_ae_slot0_encode, Opcode_ae_s16x2m_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16x2m_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16x2m_xu_encode_fns[] = {
  Opcode_ae_s16x2m_xu_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s16x2m_xu_Slot_ae_slot0_encode, Opcode_ae_s16x2m_xu_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16x2m_xu_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32x2f24_xc_encode_fns[] = {
  Opcode_ae_s32x2f24_xc_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32x2f24_xc_Slot_ae_slot0_encode, Opcode_ae_s32x2f24_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32x2f24_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32x2f24_i_encode_fns[] = {
  Opcode_ae_s32x2f24_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32x2f24_i_Slot_ae_slot0_encode, Opcode_ae_s32x2f24_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32x2f24_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_s32x2f24_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32x2f24_ip_encode_fns[] = {
  Opcode_ae_s32x2f24_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32x2f24_ip_Slot_ae_slot0_encode, Opcode_ae_s32x2f24_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32x2f24_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32x2f24_rip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s32x2f24_rip_Slot_ae_slot0_encode, Opcode_ae_s32x2f24_rip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32x2f24_rip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32x2f24_ric_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s32x2f24_ric_Slot_ae_slot0_encode, Opcode_ae_s32x2f24_ric_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32x2f24_ric_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32x2f24_x_encode_fns[] = {
  Opcode_ae_s32x2f24_x_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32x2f24_x_Slot_ae_slot0_encode, Opcode_ae_s32x2f24_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32x2f24_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32x2f24_xp_encode_fns[] = {
  Opcode_ae_s32x2f24_xp_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32x2f24_xp_Slot_ae_slot0_encode, Opcode_ae_s32x2f24_xp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32x2f24_xp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32x2_xc_encode_fns[] = {
  Opcode_ae_s32x2_xc_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32x2_xc_Slot_ae_slot0_encode, Opcode_ae_s32x2_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32x2_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32x2_i_encode_fns[] = {
  Opcode_ae_s32x2_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32x2_i_Slot_ae_slot0_encode, Opcode_ae_s32x2_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32x2_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_s32x2_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32x2_ip_encode_fns[] = {
  Opcode_ae_s32x2_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32x2_ip_Slot_ae_slot0_encode, Opcode_ae_s32x2_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32x2_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32x2_rip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s32x2_rip_Slot_ae_slot0_encode, Opcode_ae_s32x2_rip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32x2_rip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32x2_ric_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s32x2_ric_Slot_ae_slot0_encode, Opcode_ae_s32x2_ric_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32x2_ric_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32x2_x_encode_fns[] = {
  Opcode_ae_s32x2_x_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32x2_x_Slot_ae_slot0_encode, Opcode_ae_s32x2_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32x2_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32x2_xp_encode_fns[] = {
  Opcode_ae_s32x2_xp_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32x2_xp_Slot_ae_slot0_encode, Opcode_ae_s32x2_xp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32x2_xp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16x4_xc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s16x4_xc_Slot_ae_slot0_encode, Opcode_ae_s16x4_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16x4_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16x4_i_encode_fns[] = {
  Opcode_ae_s16x4_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s16x4_i_Slot_ae_slot0_encode, Opcode_ae_s16x4_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16x4_i_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16x4_ip_encode_fns[] = {
  Opcode_ae_s16x4_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s16x4_ip_Slot_ae_slot0_encode, Opcode_ae_s16x4_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16x4_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16x4_rip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s16x4_rip_Slot_ae_slot0_encode, Opcode_ae_s16x4_rip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16x4_rip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16x4_ric_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s16x4_ric_Slot_ae_slot0_encode, Opcode_ae_s16x4_ric_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16x4_ric_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16x4_x_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s16x4_x_Slot_ae_slot0_encode, Opcode_ae_s16x4_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16x4_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16x4_xp_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s16x4_xp_Slot_ae_slot0_encode, Opcode_ae_s16x4_xp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16x4_xp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16m_l_xc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s16m_l_xc_Slot_ae_slot0_encode, Opcode_ae_s16m_l_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16m_l_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16m_l_i_encode_fns[] = {
  Opcode_ae_s16m_l_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s16m_l_i_Slot_ae_slot0_encode, Opcode_ae_s16m_l_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16m_l_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_s16m_l_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16m_l_iu_encode_fns[] = {
  Opcode_ae_s16m_l_iu_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s16m_l_iu_Slot_ae_slot0_encode, Opcode_ae_s16m_l_iu_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16m_l_iu_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16m_l_x_encode_fns[] = {
  Opcode_ae_s16m_l_x_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s16m_l_x_Slot_ae_slot0_encode, Opcode_ae_s16m_l_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16m_l_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16m_l_xu_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s16m_l_xu_Slot_ae_slot0_encode, Opcode_ae_s16m_l_xu_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16m_l_xu_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32f24_l_xc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s32f24_l_xc_Slot_ae_slot0_encode, Opcode_ae_s32f24_l_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32f24_l_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32f24_l_i_encode_fns[] = {
  Opcode_ae_s32f24_l_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32f24_l_i_Slot_ae_slot0_encode, Opcode_ae_s32f24_l_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32f24_l_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_s32f24_l_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32f24_l_ip_encode_fns[] = {
  Opcode_ae_s32f24_l_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32f24_l_ip_Slot_ae_slot0_encode, Opcode_ae_s32f24_l_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32f24_l_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32f24_l_x_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s32f24_l_x_Slot_ae_slot0_encode, Opcode_ae_s32f24_l_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32f24_l_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32f24_l_xp_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s32f24_l_xp_Slot_ae_slot0_encode, Opcode_ae_s32f24_l_xp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32f24_l_xp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32_l_xc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s32_l_xc_Slot_ae_slot0_encode, Opcode_ae_s32_l_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32_l_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32_l_i_encode_fns[] = {
  Opcode_ae_s32_l_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32_l_i_Slot_ae_slot0_encode, Opcode_ae_s32_l_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32_l_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_s32_l_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32_l_ip_encode_fns[] = {
  Opcode_ae_s32_l_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32_l_ip_Slot_ae_slot0_encode, Opcode_ae_s32_l_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32_l_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32_l_x_encode_fns[] = {
  Opcode_ae_s32_l_x_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32_l_x_Slot_ae_slot0_encode, Opcode_ae_s32_l_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32_l_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32_l_xp_encode_fns[] = {
  Opcode_ae_s32_l_xp_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32_l_xp_Slot_ae_slot0_encode, Opcode_ae_s32_l_xp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32_l_xp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16_0_xc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s16_0_xc_Slot_ae_slot0_encode, Opcode_ae_s16_0_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16_0_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16_0_i_encode_fns[] = {
  Opcode_ae_s16_0_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s16_0_i_Slot_ae_slot0_encode, Opcode_ae_s16_0_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16_0_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_s16_0_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16_0_ip_encode_fns[] = {
  Opcode_ae_s16_0_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s16_0_ip_Slot_ae_slot0_encode, Opcode_ae_s16_0_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16_0_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16_0_x_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s16_0_x_Slot_ae_slot0_encode, Opcode_ae_s16_0_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16_0_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s16_0_xp_encode_fns[] = {
  Opcode_ae_s16_0_xp_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s16_0_xp_Slot_ae_slot0_encode, Opcode_ae_s16_0_xp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s16_0_xp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s64_xc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s64_xc_Slot_ae_slot0_encode, Opcode_ae_s64_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s64_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s64_i_encode_fns[] = {
  Opcode_ae_s64_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s64_i_Slot_ae_slot0_encode, Opcode_ae_s64_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s64_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_s64_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s64_ip_encode_fns[] = {
  Opcode_ae_s64_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s64_ip_Slot_ae_slot0_encode, Opcode_ae_s64_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s64_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s64_x_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s64_x_Slot_ae_slot0_encode, Opcode_ae_s64_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s64_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s64_xp_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s64_xp_Slot_ae_slot0_encode, Opcode_ae_s64_xp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s64_xp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32m_xc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s32m_xc_Slot_ae_slot0_encode, Opcode_ae_s32m_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32m_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32m_i_encode_fns[] = {
  Opcode_ae_s32m_i_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32m_i_Slot_ae_slot0_encode, Opcode_ae_s32m_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32m_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_s32m_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32m_iu_encode_fns[] = {
  Opcode_ae_s32m_iu_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32m_iu_Slot_ae_slot0_encode, Opcode_ae_s32m_iu_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32m_iu_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32m_x_encode_fns[] = {
  Opcode_ae_s32m_x_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32m_x_Slot_ae_slot0_encode, Opcode_ae_s32m_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32m_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32m_xu_encode_fns[] = {
  Opcode_ae_s32m_xu_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32m_xu_Slot_ae_slot0_encode, Opcode_ae_s32m_xu_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32m_xu_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_zalign64_encode_fns[] = {
  Opcode_ae_zalign64_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_zalign64_Slot_ae_slot0_encode, Opcode_ae_zalign64_Slot_ae_slot0_encode, 0, 0, Opcode_ae_zalign64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_lalign64_i_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_lalign64_i_Slot_ae_slot0_encode, Opcode_ae_lalign64_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_lalign64_i_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_salign64_i_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_salign64_i_Slot_ae_slot0_encode, Opcode_ae_salign64_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_salign64_i_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movalign_encode_fns[] = {
  Opcode_ae_movalign_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_movalign_Slot_ae_slot0_encode, Opcode_ae_movalign_Slot_ae_slot0_encode, 0, 0, Opcode_ae_movalign_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la64_pp_encode_fns[] = {
  Opcode_ae_la64_pp_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_la64_pp_Slot_ae_slot0_encode, Opcode_ae_la64_pp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la64_pp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la24pos_pc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la24pos_pc_Slot_ae_slot0_encode, Opcode_ae_la24pos_pc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la24pos_pc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la24x2pos_pc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la24x2pos_pc_Slot_ae_slot0_encode, Opcode_ae_la24x2pos_pc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la24x2pos_pc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la32x2pos_pc_encode_fns[] = {
  Opcode_ae_la32x2pos_pc_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_la32x2pos_pc_Slot_ae_slot0_encode, Opcode_ae_la32x2pos_pc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la32x2pos_pc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la16x4pos_pc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la16x4pos_pc_Slot_ae_slot0_encode, Opcode_ae_la16x4pos_pc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la16x4pos_pc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la24neg_pc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la24neg_pc_Slot_ae_slot0_encode, Opcode_ae_la24neg_pc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la24neg_pc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la24x2neg_pc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la24x2neg_pc_Slot_ae_slot0_encode, Opcode_ae_la24x2neg_pc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la24x2neg_pc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la32x2neg_pc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la32x2neg_pc_Slot_ae_slot0_encode, Opcode_ae_la32x2neg_pc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la32x2neg_pc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la16x4neg_pc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la16x4neg_pc_Slot_ae_slot0_encode, Opcode_ae_la16x4neg_pc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la16x4neg_pc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa64pos_fp_encode_fns[] = {
  Opcode_ae_sa64pos_fp_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_sa64pos_fp_Slot_ae_slot0_encode, Opcode_ae_sa64pos_fp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa64pos_fp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa64neg_fp_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa64neg_fp_Slot_ae_slot0_encode, Opcode_ae_sa64neg_fp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa64neg_fp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la32x2_ic_encode_fns[] = {
  Opcode_ae_la32x2_ic_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_la32x2_ic_Slot_ae_slot0_encode, Opcode_ae_la32x2_ic_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la32x2_ic_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la32x2_ip_encode_fns[] = {
  Opcode_ae_la32x2_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_la32x2_ip_Slot_ae_slot0_encode, Opcode_ae_la32x2_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la32x2_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la32x2_rip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la32x2_rip_Slot_ae_slot0_encode, Opcode_ae_la32x2_rip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la32x2_rip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la32x2_ric_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la32x2_ric_Slot_ae_slot0_encode, Opcode_ae_la32x2_ric_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la32x2_ric_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la16x4_ic_encode_fns[] = {
  Opcode_ae_la16x4_ic_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_la16x4_ic_Slot_ae_slot0_encode, Opcode_ae_la16x4_ic_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la16x4_ic_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la16x4_ip_encode_fns[] = {
  Opcode_ae_la16x4_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_la16x4_ip_Slot_ae_slot0_encode, Opcode_ae_la16x4_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la16x4_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la16x4_rip_encode_fns[] = {
  Opcode_ae_la16x4_rip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_la16x4_rip_Slot_ae_slot0_encode, Opcode_ae_la16x4_rip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la16x4_rip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la16x4_ric_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la16x4_ric_Slot_ae_slot0_encode, Opcode_ae_la16x4_ric_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la16x4_ric_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la32x2f24_ic_encode_fns[] = {
  Opcode_ae_la32x2f24_ic_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_la32x2f24_ic_Slot_ae_slot0_encode, Opcode_ae_la32x2f24_ic_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la32x2f24_ic_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la32x2f24_ip_encode_fns[] = {
  Opcode_ae_la32x2f24_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_la32x2f24_ip_Slot_ae_slot0_encode, Opcode_ae_la32x2f24_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la32x2f24_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la32x2f24_rip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la32x2f24_rip_Slot_ae_slot0_encode, Opcode_ae_la32x2f24_rip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la32x2f24_rip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la32x2f24_ric_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la32x2f24_ric_Slot_ae_slot0_encode, Opcode_ae_la32x2f24_ric_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la32x2f24_ric_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la24_ic_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la24_ic_Slot_ae_slot0_encode, Opcode_ae_la24_ic_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la24_ic_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la24_ip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la24_ip_Slot_ae_slot0_encode, Opcode_ae_la24_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la24_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la24_rip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la24_rip_Slot_ae_slot0_encode, Opcode_ae_la24_rip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la24_rip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la24_ric_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la24_ric_Slot_ae_slot0_encode, Opcode_ae_la24_ric_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la24_ric_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la24x2_ic_encode_fns[] = {
  Opcode_ae_la24x2_ic_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_la24x2_ic_Slot_ae_slot0_encode, Opcode_ae_la24x2_ic_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la24x2_ic_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la24x2_ip_encode_fns[] = {
  Opcode_ae_la24x2_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_la24x2_ip_Slot_ae_slot0_encode, Opcode_ae_la24x2_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la24x2_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la24x2_rip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la24x2_rip_Slot_ae_slot0_encode, Opcode_ae_la24x2_rip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la24x2_rip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_la24x2_ric_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_la24x2_ric_Slot_ae_slot0_encode, Opcode_ae_la24x2_ric_Slot_ae_slot0_encode, 0, 0, Opcode_ae_la24x2_ric_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa32x2_ic_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa32x2_ic_Slot_ae_slot0_encode, Opcode_ae_sa32x2_ic_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa32x2_ic_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa32x2_ip_encode_fns[] = {
  Opcode_ae_sa32x2_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_sa32x2_ip_Slot_ae_slot0_encode, Opcode_ae_sa32x2_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa32x2_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa32x2_rip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa32x2_rip_Slot_ae_slot0_encode, Opcode_ae_sa32x2_rip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa32x2_rip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa32x2_ric_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa32x2_ric_Slot_ae_slot0_encode, Opcode_ae_sa32x2_ric_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa32x2_ric_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa16x4_ic_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa16x4_ic_Slot_ae_slot0_encode, Opcode_ae_sa16x4_ic_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa16x4_ic_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa16x4_ip_encode_fns[] = {
  Opcode_ae_sa16x4_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_sa16x4_ip_Slot_ae_slot0_encode, Opcode_ae_sa16x4_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa16x4_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa16x4_rip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa16x4_rip_Slot_ae_slot0_encode, Opcode_ae_sa16x4_rip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa16x4_rip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa16x4_ric_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa16x4_ric_Slot_ae_slot0_encode, Opcode_ae_sa16x4_ric_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa16x4_ric_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa32x2f24_ic_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa32x2f24_ic_Slot_ae_slot0_encode, Opcode_ae_sa32x2f24_ic_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa32x2f24_ic_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa32x2f24_ip_encode_fns[] = {
  Opcode_ae_sa32x2f24_ip_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_sa32x2f24_ip_Slot_ae_slot0_encode, Opcode_ae_sa32x2f24_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa32x2f24_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa32x2f24_rip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa32x2f24_rip_Slot_ae_slot0_encode, Opcode_ae_sa32x2f24_rip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa32x2f24_rip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa32x2f24_ric_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa32x2f24_ric_Slot_ae_slot0_encode, Opcode_ae_sa32x2f24_ric_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa32x2f24_ric_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa24_l_ic_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa24_l_ic_Slot_ae_slot0_encode, Opcode_ae_sa24_l_ic_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa24_l_ic_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa24_l_ip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa24_l_ip_Slot_ae_slot0_encode, Opcode_ae_sa24_l_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa24_l_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa24_l_rip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa24_l_rip_Slot_ae_slot0_encode, Opcode_ae_sa24_l_rip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa24_l_rip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa24_l_ric_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa24_l_ric_Slot_ae_slot0_encode, Opcode_ae_sa24_l_ric_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa24_l_ric_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa24x2_ic_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa24x2_ic_Slot_ae_slot0_encode, Opcode_ae_sa24x2_ic_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa24x2_ic_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa24x2_ip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa24x2_ip_Slot_ae_slot0_encode, Opcode_ae_sa24x2_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa24x2_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa24x2_rip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa24x2_rip_Slot_ae_slot0_encode, Opcode_ae_sa24x2_rip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa24x2_rip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sa24x2_ric_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sa24x2_ric_Slot_ae_slot0_encode, Opcode_ae_sa24x2_ric_Slot_ae_slot0_encode, 0, 0, Opcode_ae_sa24x2_ric_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32ra64s_i_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s32ra64s_i_Slot_ae_slot0_encode, Opcode_ae_s32ra64s_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32ra64s_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_s32ra64s_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32ra64s_ip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s32ra64s_ip_Slot_ae_slot0_encode, Opcode_ae_s32ra64s_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32ra64s_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32ra64s_x_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s32ra64s_x_Slot_ae_slot0_encode, Opcode_ae_s32ra64s_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32ra64s_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32ra64s_xp_encode_fns[] = {
  Opcode_ae_s32ra64s_xp_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s32ra64s_xp_Slot_ae_slot0_encode, Opcode_ae_s32ra64s_xp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32ra64s_xp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32ra64s_xc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s32ra64s_xc_Slot_ae_slot0_encode, Opcode_ae_s32ra64s_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s32ra64s_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s24ra64s_i_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s24ra64s_i_Slot_ae_slot0_encode, Opcode_ae_s24ra64s_i_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s24ra64s_i_Slot_ae2_slot0_encode, 0, 0, Opcode_ae_s24ra64s_i_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s24ra64s_ip_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s24ra64s_ip_Slot_ae_slot0_encode, Opcode_ae_s24ra64s_ip_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s24ra64s_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s24ra64s_x_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s24ra64s_x_Slot_ae_slot0_encode, Opcode_ae_s24ra64s_x_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s24ra64s_x_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s24ra64s_xp_encode_fns[] = {
  Opcode_ae_s24ra64s_xp_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_s24ra64s_xp_Slot_ae_slot0_encode, Opcode_ae_s24ra64s_xp_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s24ra64s_xp_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s24ra64s_xc_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_s24ra64s_xc_Slot_ae_slot0_encode, Opcode_ae_s24ra64s_xc_Slot_ae_slot0_encode, 0, 0, Opcode_ae_s24ra64s_xc_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s32x2ra64s_ip_encode_fns[] = {
  Opcode_ae_s32x2ra64s_ip_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_s32x2ra64s_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_s24x2ra64s_ip_encode_fns[] = {
  Opcode_ae_s24x2ra64s_ip_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_s24x2ra64s_ip_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_addbrba32_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_addbrba32_Slot_ae_slot0_encode, Opcode_ae_addbrba32_Slot_ae_slot0_encode, 0, 0, Opcode_ae_addbrba32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sel16i_encode_fns[] = {
  Opcode_ae_sel16i_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_sel16i_Slot_ae_slot2_1_encode, Opcode_ae_sel16i_Slot_ae2_slot1_encode, Opcode_ae_sel16i_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sel16i_n_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_sel16i_n_Slot_ae_slot1_encode, Opcode_ae_sel16i_n_Slot_ae_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_shortswap_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_shortswap_Slot_ae_slot2_1_encode, Opcode_ae_shortswap_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movt16x4_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_movt16x4_Slot_ae_slot2_1_encode, 0, Opcode_ae_movt16x4_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movf16x4_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_movf16x4_Slot_ae_slot2_1_encode, 0, Opcode_ae_movf16x4_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movt32x2_encode_fns[] = {
  Opcode_ae_movt32x2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_movt32x2_Slot_ae_slot2_1_encode, 0, Opcode_ae_movt32x2_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movf32x2_encode_fns[] = {
  Opcode_ae_movf32x2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_movf32x2_Slot_ae_slot2_1_encode, 0, Opcode_ae_movf32x2_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movda32x2_encode_fns[] = {
  Opcode_ae_movda32x2_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_movda32x2_Slot_ae_slot0_encode, Opcode_ae_movda32x2_Slot_ae_slot0_encode, 0, 0, Opcode_ae_movda32x2_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movda32_encode_fns[] = {
  Opcode_ae_movda32_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_movda32_Slot_ae2_slot0_encode, Opcode_ae_movda32_Slot_ae_minislot2_encode, 0, Opcode_ae_movda32_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movda16x2_encode_fns[] = {
  Opcode_ae_movda16x2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_movda16x2_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movda16_encode_fns[] = {
  Opcode_ae_movda16_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_movda16_Slot_ae2_slot0_encode, Opcode_ae_movda16_Slot_ae_minislot2_encode, 0, Opcode_ae_movda16_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movi_encode_fns[] = {
  Opcode_ae_movi_Slot_inst_encode, 0, 0, 0, Opcode_ae_movi_Slot_ae_slot1_encode, Opcode_ae_movi_Slot_ae_slot1_encode, Opcode_ae_movi_Slot_ae_slot0_encode, Opcode_ae_movi_Slot_ae_slot0_encode, Opcode_ae_movi_Slot_ae_slot2_1_encode, Opcode_ae_movi_Slot_ae2_slot1_encode, Opcode_ae_movi_Slot_ae2_slot0_encode, Opcode_ae_movi_Slot_ae_minislot2_encode, 0, Opcode_ae_movi_Slot_ae_minislot0_encode, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_truncp24a32x2_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_truncp24a32x2_Slot_ae_slot0_encode, Opcode_ae_truncp24a32x2_Slot_ae_slot0_encode, 0, 0, Opcode_ae_truncp24a32x2_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sat16x4_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_sat16x4_Slot_ae_slot2_1_encode, 0, Opcode_ae_sat16x4_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_cvt32x2f16_32_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_cvt32x2f16_32_Slot_ae_slot0_encode, Opcode_ae_cvt32x2f16_32_Slot_ae_slot0_encode, Opcode_ae_cvt32x2f16_32_Slot_ae_slot2_1_encode, 0, Opcode_ae_cvt32x2f16_32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_cvt32x2f16_10_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_cvt32x2f16_10_Slot_ae_slot0_encode, Opcode_ae_cvt32x2f16_10_Slot_ae_slot0_encode, Opcode_ae_cvt32x2f16_10_Slot_ae_slot2_1_encode, 0, Opcode_ae_cvt32x2f16_10_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sext32x2d16_32_encode_fns[] = {
  Opcode_ae_sext32x2d16_32_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_sext32x2d16_32_Slot_ae_slot0_encode, Opcode_ae_sext32x2d16_32_Slot_ae_slot0_encode, Opcode_ae_sext32x2d16_32_Slot_ae_slot2_1_encode, 0, Opcode_ae_sext32x2d16_32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sext32x2d16_10_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_sext32x2d16_10_Slot_ae_slot0_encode, Opcode_ae_sext32x2d16_10_Slot_ae_slot0_encode, Opcode_ae_sext32x2d16_10_Slot_ae_slot2_1_encode, 0, Opcode_ae_sext32x2d16_10_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_cvta32f24s_l_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_cvta32f24s_l_Slot_ae_slot0_encode, Opcode_ae_cvta32f24s_l_Slot_ae_slot0_encode, 0, 0, Opcode_ae_cvta32f24s_l_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_cvta32f24s_h_encode_fns[] = {
  0, 0, 0, 0, 0, 0, Opcode_ae_cvta32f24s_h_Slot_ae_slot0_encode, Opcode_ae_cvta32f24s_h_Slot_ae_slot0_encode, 0, 0, Opcode_ae_cvta32f24s_h_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_cvtp24a16x2_ll_encode_fns[] = {
  Opcode_ae_cvtp24a16x2_ll_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_cvtp24a16x2_ll_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_cvtp24a16x2_lh_encode_fns[] = {
  Opcode_ae_cvtp24a16x2_lh_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_cvtp24a16x2_lh_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_cvtp24a16x2_hl_encode_fns[] = {
  Opcode_ae_cvtp24a16x2_hl_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_cvtp24a16x2_hl_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_cvtp24a16x2_hh_encode_fns[] = {
  Opcode_ae_cvtp24a16x2_hh_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_cvtp24a16x2_hh_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_truncp24q48x2_encode_fns[] = {
  Opcode_ae_truncp24q48x2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_truncp24q48x2_Slot_ae_slot2_1_encode, 0, Opcode_ae_truncp24q48x2_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_trunca32x2f64s_encode_fns[] = {
  Opcode_ae_trunca32x2f64s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_trunca32x2f64s_Slot_ae2_slot0_encode, Opcode_ae_trunca32x2f64s_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_trunci32x2f64s_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_trunci32x2f64s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_trunca32f64s_l_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_trunca32f64s_l_Slot_ae2_slot0_encode, Opcode_ae_trunca32f64s_l_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_trunci32f64s_l_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_trunci32f64s_l_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_truncp16_encode_fns[] = {
  Opcode_ae_truncp16_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_truncp16_Slot_ae_slot2_1_encode, 0, Opcode_ae_truncp16_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_round32x2f64ssym_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_round32x2f64ssym_Slot_ae_slot2_1_encode, 0, Opcode_ae_round32x2f64ssym_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_round32x2f64sasym_encode_fns[] = {
  Opcode_ae_round32x2f64sasym_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_round32x2f64sasym_Slot_ae_slot2_1_encode, 0, Opcode_ae_round32x2f64sasym_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_round32x2f48ssym_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_round32x2f48ssym_Slot_ae_slot2_1_encode, 0, Opcode_ae_round32x2f48ssym_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_round32x2f48sasym_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_round32x2f48sasym_Slot_ae_slot2_1_encode, 0, Opcode_ae_round32x2f48sasym_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_round16x4f32ssym_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_round16x4f32ssym_Slot_ae_slot2_1_encode, 0, Opcode_ae_round16x4f32ssym_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_round16x4f32sasym_encode_fns[] = {
  Opcode_ae_round16x4f32sasym_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_round16x4f32sasym_Slot_ae_slot2_1_encode, 0, Opcode_ae_round16x4f32sasym_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_round24x2f48ssym_encode_fns[] = {
  Opcode_ae_round24x2f48ssym_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_round24x2f48ssym_Slot_ae_slot2_1_encode, 0, Opcode_ae_round24x2f48ssym_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_round24x2f48sasym_encode_fns[] = {
  Opcode_ae_round24x2f48sasym_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_round24x2f48sasym_Slot_ae_slot2_1_encode, 0, Opcode_ae_round24x2f48sasym_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_roundsp16q48x2sym_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_roundsp16q48x2sym_Slot_ae_slot2_1_encode, 0, Opcode_ae_roundsp16q48x2sym_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_roundsp16q48x2asym_encode_fns[] = {
  Opcode_ae_roundsp16q48x2asym_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_roundsp16q48x2asym_Slot_ae_slot2_1_encode, 0, Opcode_ae_roundsp16q48x2asym_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_minabs32s_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_minabs32s_Slot_ae_slot2_1_encode, 0, Opcode_ae_minabs32s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_maxabs32s_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_maxabs32s_Slot_ae_slot2_1_encode, 0, Opcode_ae_maxabs32s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_roundsp16f24sym_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_roundsp16f24sym_Slot_ae_slot2_1_encode, 0, Opcode_ae_roundsp16f24sym_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_roundsp16f24asym_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_roundsp16f24asym_Slot_ae_slot2_1_encode, 0, Opcode_ae_roundsp16f24asym_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mov_encode_fns[] = {
  Opcode_ae_mov_Slot_inst_encode, 0, 0, 0, Opcode_ae_mov_Slot_ae_slot1_encode, Opcode_ae_mov_Slot_ae_slot1_encode, Opcode_ae_mov_Slot_ae_slot0_encode, Opcode_ae_mov_Slot_ae_slot0_encode, Opcode_ae_mov_Slot_ae_slot2_1_encode, Opcode_ae_mov_Slot_ae2_slot1_encode, Opcode_ae_mov_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movt64_encode_fns[] = {
  Opcode_ae_movt64_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_movt64_Slot_ae_slot2_1_encode, 0, Opcode_ae_movt64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movf64_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_movf64_Slot_ae_slot2_1_encode, 0, Opcode_ae_movf64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_cvtq56a32s_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_cvtq56a32s_Slot_ae2_slot0_encode, Opcode_ae_cvtq56a32s_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_cvt48a32_encode_fns[] = {
  Opcode_ae_cvt48a32_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_cvt48a32_Slot_ae2_slot0_encode, Opcode_ae_cvt48a32_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_cvt64a32_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_cvt64a32_Slot_ae2_slot0_encode, Opcode_ae_cvt64a32_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_cvtq56p32s_l_encode_fns[] = {
  Opcode_ae_cvtq56p32s_l_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_cvtq56p32s_l_Slot_ae_slot2_1_encode, 0, Opcode_ae_cvtq56p32s_l_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_cvtq56p32s_h_encode_fns[] = {
  Opcode_ae_cvtq56p32s_h_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_cvtq56p32s_h_Slot_ae_slot2_1_encode, 0, Opcode_ae_cvtq56p32s_h_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_cvt64f32_h_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_cvt64f32_h_Slot_ae_slot2_1_encode, 0, Opcode_ae_cvt64f32_h_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sat48s_encode_fns[] = {
  Opcode_ae_sat48s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_sat48s_Slot_ae_slot2_1_encode, 0, Opcode_ae_sat48s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_satq56s_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_satq56s_Slot_ae_slot2_1_encode, 0, Opcode_ae_satq56s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sat24s_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_sat24s_Slot_ae_slot2_1_encode, 0, Opcode_ae_sat24s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_truncq32_encode_fns[] = {
  Opcode_ae_truncq32_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_truncq32_Slot_ae_slot2_1_encode, 0, Opcode_ae_truncq32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_minabs64s_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_minabs64s_Slot_ae_slot2_1_encode, 0, Opcode_ae_minabs64s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_maxabs64s_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_maxabs64s_Slot_ae_slot2_1_encode, 0, Opcode_ae_maxabs64s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_roundsq32f48sym_encode_fns[] = {
  Opcode_ae_roundsq32f48sym_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_roundsq32f48sym_Slot_ae_slot2_1_encode, 0, Opcode_ae_roundsq32f48sym_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_roundsq32f48asym_encode_fns[] = {
  Opcode_ae_roundsq32f48asym_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_roundsq32f48asym_Slot_ae_slot2_1_encode, 0, Opcode_ae_roundsq32f48asym_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_trunca32q48_encode_fns[] = {
  Opcode_ae_trunca32q48_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_trunca32q48_Slot_ae_slot0_encode, Opcode_ae_trunca32q48_Slot_ae_slot0_encode, 0, 0, Opcode_ae_trunca32q48_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movad32_l_encode_fns[] = {
  Opcode_ae_movad32_l_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_movad32_l_Slot_ae_slot0_encode, Opcode_ae_movad32_l_Slot_ae_slot0_encode, 0, 0, Opcode_ae_movad32_l_Slot_ae2_slot0_encode, Opcode_ae_movad32_l_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movad32_h_encode_fns[] = {
  Opcode_ae_movad32_h_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_movad32_h_Slot_ae_slot0_encode, Opcode_ae_movad32_h_Slot_ae_slot0_encode, 0, 0, Opcode_ae_movad32_h_Slot_ae2_slot0_encode, Opcode_ae_movad32_h_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movad16_3_encode_fns[] = {
  Opcode_ae_movad16_3_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_movad16_3_Slot_ae2_slot0_encode, Opcode_ae_movad16_3_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movad16_2_encode_fns[] = {
  Opcode_ae_movad16_2_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_movad16_2_Slot_ae2_slot0_encode, Opcode_ae_movad16_2_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movad16_1_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_movad16_1_Slot_ae2_slot0_encode, Opcode_ae_movad16_1_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_movad16_0_encode_fns[] = {
  Opcode_ae_movad16_0_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_movad16_0_Slot_ae2_slot0_encode, Opcode_ae_movad16_0_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sra64_32_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_sra64_32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_pksr32_encode_fns[] = {
  Opcode_ae_pksr32_Slot_inst_encode, 0, 0, 0, Opcode_ae_pksr32_Slot_ae_slot1_encode, Opcode_ae_pksr32_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_pksr32_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_pksr24_encode_fns[] = {
  Opcode_ae_pksr24_Slot_inst_encode, 0, 0, 0, Opcode_ae_pksr24_Slot_ae_slot1_encode, Opcode_ae_pksr24_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_pksr24_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_trunca16p24s_l_encode_fns[] = {
  Opcode_ae_trunca16p24s_l_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_trunca16p24s_l_Slot_ae_slot0_encode, Opcode_ae_trunca16p24s_l_Slot_ae_slot0_encode, 0, 0, Opcode_ae_trunca16p24s_l_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_trunca16p24s_h_encode_fns[] = {
  Opcode_ae_trunca16p24s_h_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_trunca16p24s_h_Slot_ae_slot0_encode, Opcode_ae_trunca16p24s_h_Slot_ae_slot0_encode, 0, 0, Opcode_ae_trunca16p24s_h_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_add32_encode_fns[] = {
  Opcode_ae_add32_Slot_inst_encode, 0, 0, 0, Opcode_ae_add32_Slot_ae_slot1_encode, Opcode_ae_add32_Slot_ae_slot1_encode, 0, 0, Opcode_ae_add32_Slot_ae_slot2_1_encode, Opcode_ae_add32_Slot_ae2_slot1_encode, Opcode_ae_add32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sub32_encode_fns[] = {
  Opcode_ae_sub32_Slot_inst_encode, 0, 0, 0, Opcode_ae_sub32_Slot_ae_slot1_encode, Opcode_ae_sub32_Slot_ae_slot1_encode, 0, 0, Opcode_ae_sub32_Slot_ae_slot2_1_encode, Opcode_ae_sub32_Slot_ae2_slot1_encode, Opcode_ae_sub32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_addsub32_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_addsub32_Slot_ae_slot1_encode, Opcode_ae_addsub32_Slot_ae_slot1_encode, 0, 0, Opcode_ae_addsub32_Slot_ae_slot2_1_encode, Opcode_ae_addsub32_Slot_ae2_slot1_encode, Opcode_ae_addsub32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_subadd32_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_subadd32_Slot_ae_slot1_encode, Opcode_ae_subadd32_Slot_ae_slot1_encode, 0, 0, Opcode_ae_subadd32_Slot_ae_slot2_1_encode, Opcode_ae_subadd32_Slot_ae2_slot1_encode, Opcode_ae_subadd32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_add16_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_add16_Slot_ae_slot1_encode, Opcode_ae_add16_Slot_ae_slot1_encode, 0, 0, Opcode_ae_add16_Slot_ae_slot2_1_encode, Opcode_ae_add16_Slot_ae2_slot1_encode, Opcode_ae_add16_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sub16_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_sub16_Slot_ae_slot1_encode, Opcode_ae_sub16_Slot_ae_slot1_encode, 0, 0, Opcode_ae_sub16_Slot_ae_slot2_1_encode, Opcode_ae_sub16_Slot_ae2_slot1_encode, Opcode_ae_sub16_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_add32_hl_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_add32_hl_lh_Slot_ae_slot1_encode, Opcode_ae_add32_hl_lh_Slot_ae_slot1_encode, 0, 0, Opcode_ae_add32_hl_lh_Slot_ae_slot2_1_encode, Opcode_ae_add32_hl_lh_Slot_ae2_slot1_encode, Opcode_ae_add32_hl_lh_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_neg32_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_neg32_Slot_ae_slot1_encode, Opcode_ae_neg32_Slot_ae_slot1_encode, 0, 0, Opcode_ae_neg32_Slot_ae_slot2_1_encode, Opcode_ae_neg32_Slot_ae2_slot1_encode, Opcode_ae_neg32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_abs32_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_abs32_Slot_ae_slot1_encode, Opcode_ae_abs32_Slot_ae_slot1_encode, 0, 0, Opcode_ae_abs32_Slot_ae_slot2_1_encode, Opcode_ae_abs32_Slot_ae2_slot1_encode, Opcode_ae_abs32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_add24s_encode_fns[] = {
  Opcode_ae_add24s_Slot_inst_encode, 0, 0, 0, Opcode_ae_add24s_Slot_ae_slot1_encode, Opcode_ae_add24s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_add24s_Slot_ae_slot2_1_encode, Opcode_ae_add24s_Slot_ae2_slot1_encode, Opcode_ae_add24s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sub24s_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_sub24s_Slot_ae_slot1_encode, Opcode_ae_sub24s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_sub24s_Slot_ae_slot2_1_encode, Opcode_ae_sub24s_Slot_ae2_slot1_encode, Opcode_ae_sub24s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_add32s_encode_fns[] = {
  Opcode_ae_add32s_Slot_inst_encode, 0, 0, 0, Opcode_ae_add32s_Slot_ae_slot1_encode, Opcode_ae_add32s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_add32s_Slot_ae_slot2_1_encode, Opcode_ae_add32s_Slot_ae2_slot1_encode, Opcode_ae_add32s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sub32s_encode_fns[] = {
  Opcode_ae_sub32s_Slot_inst_encode, 0, 0, 0, Opcode_ae_sub32s_Slot_ae_slot1_encode, Opcode_ae_sub32s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_sub32s_Slot_ae_slot2_1_encode, Opcode_ae_sub32s_Slot_ae2_slot1_encode, Opcode_ae_sub32s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_addsub32s_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_addsub32s_Slot_ae_slot1_encode, Opcode_ae_addsub32s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_addsub32s_Slot_ae_slot2_1_encode, Opcode_ae_addsub32s_Slot_ae2_slot1_encode, Opcode_ae_addsub32s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_subadd32s_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_subadd32s_Slot_ae_slot1_encode, Opcode_ae_subadd32s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_subadd32s_Slot_ae_slot2_1_encode, Opcode_ae_subadd32s_Slot_ae2_slot1_encode, Opcode_ae_subadd32s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_add16s_encode_fns[] = {
  Opcode_ae_add16s_Slot_inst_encode, 0, 0, 0, Opcode_ae_add16s_Slot_ae_slot1_encode, Opcode_ae_add16s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_add16s_Slot_ae_slot2_1_encode, Opcode_ae_add16s_Slot_ae2_slot1_encode, Opcode_ae_add16s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sub16s_encode_fns[] = {
  Opcode_ae_sub16s_Slot_inst_encode, 0, 0, 0, Opcode_ae_sub16s_Slot_ae_slot1_encode, Opcode_ae_sub16s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_sub16s_Slot_ae_slot2_1_encode, Opcode_ae_sub16s_Slot_ae2_slot1_encode, Opcode_ae_sub16s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_neg24s_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_neg24s_Slot_ae_slot1_encode, Opcode_ae_neg24s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_neg24s_Slot_ae_slot2_1_encode, Opcode_ae_neg24s_Slot_ae2_slot1_encode, Opcode_ae_neg24s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_abs24s_encode_fns[] = {
  Opcode_ae_abs24s_Slot_inst_encode, 0, 0, 0, Opcode_ae_abs24s_Slot_ae_slot1_encode, Opcode_ae_abs24s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_abs24s_Slot_ae_slot2_1_encode, Opcode_ae_abs24s_Slot_ae2_slot1_encode, Opcode_ae_abs24s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_neg32s_encode_fns[] = {
  Opcode_ae_neg32s_Slot_inst_encode, 0, 0, 0, Opcode_ae_neg32s_Slot_ae_slot1_encode, Opcode_ae_neg32s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_neg32s_Slot_ae_slot2_1_encode, Opcode_ae_neg32s_Slot_ae2_slot1_encode, Opcode_ae_neg32s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_abs32s_encode_fns[] = {
  Opcode_ae_abs32s_Slot_inst_encode, 0, 0, 0, Opcode_ae_abs32s_Slot_ae_slot1_encode, Opcode_ae_abs32s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_abs32s_Slot_ae_slot2_1_encode, Opcode_ae_abs32s_Slot_ae2_slot1_encode, Opcode_ae_abs32s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_neg16s_encode_fns[] = {
  Opcode_ae_neg16s_Slot_inst_encode, 0, 0, 0, Opcode_ae_neg16s_Slot_ae_slot1_encode, Opcode_ae_neg16s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_neg16s_Slot_ae_slot2_1_encode, Opcode_ae_neg16s_Slot_ae2_slot1_encode, Opcode_ae_neg16s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_abs16s_encode_fns[] = {
  Opcode_ae_abs16s_Slot_inst_encode, 0, 0, 0, Opcode_ae_abs16s_Slot_ae_slot1_encode, Opcode_ae_abs16s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_abs16s_Slot_ae_slot2_1_encode, Opcode_ae_abs16s_Slot_ae2_slot1_encode, Opcode_ae_abs16s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_lt16_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_lt16_Slot_ae_slot2_1_encode, 0, Opcode_ae_lt16_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_le16_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_le16_Slot_ae_slot2_1_encode, 0, Opcode_ae_le16_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_eq16_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_eq16_Slot_ae_slot2_1_encode, 0, Opcode_ae_eq16_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_lt32_encode_fns[] = {
  Opcode_ae_lt32_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_lt32_Slot_ae_slot2_1_encode, 0, Opcode_ae_lt32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_le32_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_le32_Slot_ae_slot2_1_encode, 0, Opcode_ae_le32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_eq32_encode_fns[] = {
  Opcode_ae_eq32_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_eq32_Slot_ae_slot2_1_encode, 0, Opcode_ae_eq32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_min32_encode_fns[] = {
  Opcode_ae_min32_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_min32_Slot_ae_slot2_1_encode, 0, Opcode_ae_min32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_max32_encode_fns[] = {
  Opcode_ae_max32_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_max32_Slot_ae_slot2_1_encode, 0, Opcode_ae_max32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_add64_encode_fns[] = {
  Opcode_ae_add64_Slot_inst_encode, 0, 0, 0, Opcode_ae_add64_Slot_ae_slot1_encode, Opcode_ae_add64_Slot_ae_slot1_encode, 0, 0, Opcode_ae_add64_Slot_ae_slot2_1_encode, Opcode_ae_add64_Slot_ae2_slot1_encode, Opcode_ae_add64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sub64_encode_fns[] = {
  Opcode_ae_sub64_Slot_inst_encode, 0, 0, 0, Opcode_ae_sub64_Slot_ae_slot1_encode, Opcode_ae_sub64_Slot_ae_slot1_encode, 0, 0, Opcode_ae_sub64_Slot_ae_slot2_1_encode, Opcode_ae_sub64_Slot_ae2_slot1_encode, Opcode_ae_sub64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_neg64_encode_fns[] = {
  Opcode_ae_neg64_Slot_inst_encode, 0, 0, 0, Opcode_ae_neg64_Slot_ae_slot1_encode, Opcode_ae_neg64_Slot_ae_slot1_encode, 0, 0, Opcode_ae_neg64_Slot_ae_slot2_1_encode, Opcode_ae_neg64_Slot_ae2_slot1_encode, Opcode_ae_neg64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_abs64_encode_fns[] = {
  Opcode_ae_abs64_Slot_inst_encode, 0, 0, 0, Opcode_ae_abs64_Slot_ae_slot1_encode, Opcode_ae_abs64_Slot_ae_slot1_encode, 0, 0, Opcode_ae_abs64_Slot_ae_slot2_1_encode, Opcode_ae_abs64_Slot_ae2_slot1_encode, Opcode_ae_abs64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_addsq56s_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_addsq56s_Slot_ae_slot1_encode, Opcode_ae_addsq56s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_addsq56s_Slot_ae_slot2_1_encode, Opcode_ae_addsq56s_Slot_ae2_slot1_encode, Opcode_ae_addsq56s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_subsq56s_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_subsq56s_Slot_ae_slot1_encode, Opcode_ae_subsq56s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_subsq56s_Slot_ae_slot2_1_encode, Opcode_ae_subsq56s_Slot_ae2_slot1_encode, Opcode_ae_subsq56s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_add64s_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_add64s_Slot_ae_slot1_encode, Opcode_ae_add64s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_add64s_Slot_ae_slot2_1_encode, Opcode_ae_add64s_Slot_ae2_slot1_encode, Opcode_ae_add64s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sub64s_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_sub64s_Slot_ae_slot1_encode, Opcode_ae_sub64s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_sub64s_Slot_ae_slot2_1_encode, Opcode_ae_sub64s_Slot_ae2_slot1_encode, Opcode_ae_sub64s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_negsq56s_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_negsq56s_Slot_ae_slot1_encode, Opcode_ae_negsq56s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_negsq56s_Slot_ae_slot2_1_encode, Opcode_ae_negsq56s_Slot_ae2_slot1_encode, Opcode_ae_negsq56s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_abssq56s_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_abssq56s_Slot_ae_slot1_encode, Opcode_ae_abssq56s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_abssq56s_Slot_ae_slot2_1_encode, Opcode_ae_abssq56s_Slot_ae2_slot1_encode, Opcode_ae_abssq56s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_neg64s_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_neg64s_Slot_ae_slot1_encode, Opcode_ae_neg64s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_neg64s_Slot_ae_slot2_1_encode, Opcode_ae_neg64s_Slot_ae2_slot1_encode, Opcode_ae_neg64s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_abs64s_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_abs64s_Slot_ae_slot1_encode, Opcode_ae_abs64s_Slot_ae_slot1_encode, 0, 0, Opcode_ae_abs64s_Slot_ae_slot2_1_encode, Opcode_ae_abs64s_Slot_ae2_slot1_encode, Opcode_ae_abs64s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_and_encode_fns[] = {
  Opcode_ae_and_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_and_Slot_ae_slot2_1_encode, 0, Opcode_ae_and_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_nand_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_nand_Slot_ae_slot2_1_encode, 0, Opcode_ae_nand_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_or_encode_fns[] = {
  Opcode_ae_or_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_or_Slot_ae_slot2_1_encode, 0, Opcode_ae_or_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_xor_encode_fns[] = {
  Opcode_ae_xor_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_xor_Slot_ae_slot2_1_encode, 0, Opcode_ae_xor_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slai24_encode_fns[] = {
  Opcode_ae_slai24_Slot_inst_encode, 0, 0, Opcode_ae_slai24_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_slai24_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srli24_encode_fns[] = {
  0, 0, 0, Opcode_ae_srli24_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_srli24_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srai24_encode_fns[] = {
  Opcode_ae_srai24_Slot_inst_encode, 0, 0, Opcode_ae_srai24_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_srai24_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slas24_encode_fns[] = {
  Opcode_ae_slas24_Slot_inst_encode, 0, 0, Opcode_ae_slas24_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_slas24_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srls24_encode_fns[] = {
  0, 0, 0, Opcode_ae_srls24_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_srls24_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sras24_encode_fns[] = {
  Opcode_ae_sras24_Slot_inst_encode, 0, 0, Opcode_ae_sras24_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_sras24_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srai16_encode_fns[] = {
  0, 0, 0, Opcode_ae_srai16_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_srai16_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srai16r_encode_fns[] = {
  0, 0, 0, Opcode_ae_srai16r_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_srai16r_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slai32_encode_fns[] = {
  Opcode_ae_slai32_Slot_inst_encode, 0, 0, Opcode_ae_slai32_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_slai32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srli32_encode_fns[] = {
  Opcode_ae_srli32_Slot_inst_encode, 0, 0, Opcode_ae_srli32_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_srli32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srai32_encode_fns[] = {
  Opcode_ae_srai32_Slot_inst_encode, 0, 0, Opcode_ae_srai32_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_srai32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srai32r_encode_fns[] = {
  0, 0, 0, Opcode_ae_srai32r_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_srai32r_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slas32_encode_fns[] = {
  0, 0, 0, Opcode_ae_slas32_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_slas32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srls32_encode_fns[] = {
  0, 0, 0, Opcode_ae_srls32_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_srls32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sras32_encode_fns[] = {
  0, 0, 0, Opcode_ae_sras32_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_sras32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slaa32_encode_fns[] = {
  Opcode_ae_slaa32_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_slaa32_Slot_ae2_slot0_encode, Opcode_ae_slaa32_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srla32_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_srla32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sraa32_encode_fns[] = {
  Opcode_ae_sraa32_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_sraa32_Slot_ae2_slot0_encode, Opcode_ae_sraa32_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slai16s_encode_fns[] = {
  0, 0, 0, Opcode_ae_slai16s_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_slai16s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slaa16s_encode_fns[] = {
  Opcode_ae_slaa16s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_slaa16s_Slot_ae2_slot0_encode, Opcode_ae_slaa16s_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sraa16s_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_sraa16s_Slot_ae2_slot0_encode, Opcode_ae_sraa16s_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sraa16rs_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_sraa16rs_Slot_ae2_slot0_encode, Opcode_ae_sraa16rs_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slai24s_encode_fns[] = {
  Opcode_ae_slai24s_Slot_inst_encode, 0, 0, Opcode_ae_slai24s_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_slai24s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slas24s_encode_fns[] = {
  0, 0, 0, Opcode_ae_slas24s_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_slas24s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slai32s_encode_fns[] = {
  Opcode_ae_slai32s_Slot_inst_encode, 0, 0, Opcode_ae_slai32s_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_slai32s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slas32s_encode_fns[] = {
  0, 0, 0, Opcode_ae_slas32s_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_slas32s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slaa32s_encode_fns[] = {
  Opcode_ae_slaa32s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_slaa32s_Slot_ae2_slot0_encode, Opcode_ae_slaa32s_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sraa32s_encode_fns[] = {
  Opcode_ae_sraa32s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_sraa32s_Slot_ae2_slot0_encode, Opcode_ae_sraa32s_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sraa32rs_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_sraa32rs_Slot_ae2_slot0_encode, Opcode_ae_sraa32rs_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slasq56_encode_fns[] = {
  Opcode_ae_slasq56_Slot_inst_encode, 0, 0, Opcode_ae_slasq56_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_slasq56_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srlsq56_encode_fns[] = {
  0, 0, 0, Opcode_ae_srlsq56_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_srlsq56_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srasq56_encode_fns[] = {
  Opcode_ae_srasq56_Slot_inst_encode, 0, 0, Opcode_ae_srasq56_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_srasq56_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slaaq56_encode_fns[] = {
  Opcode_ae_slaaq56_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_slaaq56_Slot_ae2_slot0_encode, Opcode_ae_slaaq56_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srlaq56_encode_fns[] = {
  Opcode_ae_srlaq56_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_srlaq56_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sraaq56_encode_fns[] = {
  Opcode_ae_sraaq56_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_sraaq56_Slot_ae2_slot0_encode, Opcode_ae_sraaq56_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slai64_encode_fns[] = {
  Opcode_ae_slai64_Slot_inst_encode, 0, 0, Opcode_ae_slai64_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_slai64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srli64_encode_fns[] = {
  0, 0, 0, Opcode_ae_srli64_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_srli64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srai64_encode_fns[] = {
  Opcode_ae_srai64_Slot_inst_encode, 0, 0, Opcode_ae_srai64_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_srai64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slas64_encode_fns[] = {
  0, 0, 0, Opcode_ae_slas64_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_slas64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srls64_encode_fns[] = {
  0, 0, 0, Opcode_ae_srls64_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_srls64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sras64_encode_fns[] = {
  0, 0, 0, Opcode_ae_sras64_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_sras64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slaa64_encode_fns[] = {
  Opcode_ae_slaa64_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_slaa64_Slot_ae2_slot0_encode, Opcode_ae_slaa64_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_srla64_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_srla64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sraa64_encode_fns[] = {
  Opcode_ae_sraa64_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_sraa64_Slot_ae2_slot0_encode, Opcode_ae_sraa64_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slaisq56s_encode_fns[] = {
  Opcode_ae_slaisq56s_Slot_inst_encode, 0, 0, Opcode_ae_slaisq56s_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_slaisq56s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slassq56s_encode_fns[] = {
  0, 0, 0, Opcode_ae_slassq56s_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_slassq56s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slaasq56s_encode_fns[] = {
  Opcode_ae_slaasq56s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_slaasq56s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slai64s_encode_fns[] = {
  0, 0, 0, Opcode_ae_slai64s_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_slai64s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slas64s_encode_fns[] = {
  Opcode_ae_slas64s_Slot_inst_encode, 0, 0, Opcode_ae_slas64s_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_slas64s_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_slaa64s_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_slaa64s_Slot_ae2_slot0_encode, Opcode_ae_slaa64s_Slot_ae_minislot2_encode, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_lt64_encode_fns[] = {
  Opcode_ae_lt64_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_lt64_Slot_ae_slot2_1_encode, 0, Opcode_ae_lt64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_le64_encode_fns[] = {
  Opcode_ae_le64_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_le64_Slot_ae_slot2_1_encode, 0, Opcode_ae_le64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_eq64_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_eq64_Slot_ae_slot2_1_encode, 0, Opcode_ae_eq64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_max64_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_max64_Slot_ae_slot2_1_encode, 0, Opcode_ae_max64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_min64_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_min64_Slot_ae_slot2_1_encode, 0, Opcode_ae_min64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_nsa64_encode_fns[] = {
  Opcode_ae_nsa64_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_nsa64_Slot_ae_slot0_encode, Opcode_ae_nsa64_Slot_ae_slot0_encode, 0, 0, Opcode_ae_nsa64_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_nsaz16_0_encode_fns[] = {
  Opcode_ae_nsaz16_0_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_nsaz16_0_Slot_ae_slot0_encode, Opcode_ae_nsaz16_0_Slot_ae_slot0_encode, 0, 0, Opcode_ae_nsaz16_0_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_nsaz32_l_encode_fns[] = {
  Opcode_ae_nsaz32_l_Slot_inst_encode, 0, 0, 0, 0, 0, Opcode_ae_nsaz32_l_Slot_ae_slot0_encode, Opcode_ae_nsaz32_l_Slot_ae_slot0_encode, 0, 0, Opcode_ae_nsaz32_l_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32f48p16s_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_muls32f48p16s_ll_Slot_ae_slot1_encode, Opcode_ae_muls32f48p16s_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_muls32f48p16s_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32s_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf32s_ll_Slot_ae_slot1_encode, Opcode_ae_mulf32s_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf32s_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mul32_ll_Slot_ae_slot1_encode, Opcode_ae_mul32_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mul32_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32f48p16s_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_muls32f48p16s_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32r_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf32r_ll_Slot_ae_slot1_encode, Opcode_ae_mulf32r_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf32r_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32f48p16s_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_muls32f48p16s_lh_Slot_ae_slot1_encode, Opcode_ae_muls32f48p16s_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_muls32f48p16s_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32s_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf32s_lh_Slot_ae_slot1_encode, Opcode_ae_mulf32s_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf32s_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mul32_lh_Slot_ae_slot1_encode, Opcode_ae_mul32_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mul32_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32f48p16s_lh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_muls32f48p16s_lh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32r_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf32r_lh_Slot_ae_slot1_encode, Opcode_ae_mulf32r_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf32r_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32f48p16s_hh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_muls32f48p16s_hh_Slot_ae_slot1_encode, Opcode_ae_muls32f48p16s_hh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_muls32f48p16s_hh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32s_hh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf32s_hh_Slot_ae_slot1_encode, Opcode_ae_mulf32s_hh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf32s_hh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32_hh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mul32_hh_Slot_ae_slot1_encode, Opcode_ae_mul32_hh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mul32_hh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32f48p16s_hh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_muls32f48p16s_hh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32r_hh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf32r_hh_Slot_ae_slot1_encode, Opcode_ae_mulf32r_hh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf32r_hh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32r_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulf32r_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulas32f48p16s_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulas32f48p16s_ll_Slot_ae_slot1_encode, Opcode_ae_mulas32f48p16s_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulas32f48p16s_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32s_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf32s_ll_Slot_ae_slot1_encode, Opcode_ae_mulaf32s_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf32s_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mula32_ll_Slot_ae_slot1_encode, Opcode_ae_mula32_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mula32_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulas32f48p16s_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulas32f48p16s_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32r_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf32r_ll_Slot_ae_slot1_encode, Opcode_ae_mulaf32r_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf32r_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulas32f48p16s_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulas32f48p16s_lh_Slot_ae_slot1_encode, Opcode_ae_mulas32f48p16s_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulas32f48p16s_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32s_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf32s_lh_Slot_ae_slot1_encode, Opcode_ae_mulaf32s_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf32s_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mula32_lh_Slot_ae_slot1_encode, Opcode_ae_mula32_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mula32_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulas32f48p16s_lh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulas32f48p16s_lh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32r_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf32r_lh_Slot_ae_slot1_encode, Opcode_ae_mulaf32r_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf32r_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulas32f48p16s_hh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulas32f48p16s_hh_Slot_ae_slot1_encode, Opcode_ae_mulas32f48p16s_hh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulas32f48p16s_hh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32s_hh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf32s_hh_Slot_ae_slot1_encode, Opcode_ae_mulaf32s_hh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf32s_hh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32_hh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mula32_hh_Slot_ae_slot1_encode, Opcode_ae_mula32_hh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mula32_hh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulas32f48p16s_hh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulas32f48p16s_hh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32r_hh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf32r_hh_Slot_ae_slot1_encode, Opcode_ae_mulaf32r_hh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf32r_hh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32r_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaf32r_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulss32f48p16s_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulss32f48p16s_ll_Slot_ae_slot1_encode, Opcode_ae_mulss32f48p16s_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulss32f48p16s_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32s_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf32s_ll_Slot_ae_slot1_encode, Opcode_ae_mulsf32s_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf32s_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_muls32_ll_Slot_ae_slot1_encode, Opcode_ae_muls32_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_muls32_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulss32f48p16s_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulss32f48p16s_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32r_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf32r_ll_Slot_ae_slot1_encode, Opcode_ae_mulsf32r_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf32r_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulss32f48p16s_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulss32f48p16s_lh_Slot_ae_slot1_encode, Opcode_ae_mulss32f48p16s_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulss32f48p16s_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32s_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf32s_lh_Slot_ae_slot1_encode, Opcode_ae_mulsf32s_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf32s_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_muls32_lh_Slot_ae_slot1_encode, Opcode_ae_muls32_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_muls32_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulss32f48p16s_lh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulss32f48p16s_lh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32r_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf32r_lh_Slot_ae_slot1_encode, Opcode_ae_mulsf32r_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf32r_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulss32f48p16s_hh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulss32f48p16s_hh_Slot_ae_slot1_encode, Opcode_ae_mulss32f48p16s_hh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulss32f48p16s_hh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32s_hh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf32s_hh_Slot_ae_slot1_encode, Opcode_ae_mulsf32s_hh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf32s_hh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32_hh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_muls32_hh_Slot_ae_slot1_encode, Opcode_ae_muls32_hh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_muls32_hh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulss32f48p16s_hh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulss32f48p16s_hh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32r_hh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf32r_hh_Slot_ae_slot1_encode, Opcode_ae_mulsf32r_hh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf32r_hh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32r_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsf32r_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32s_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulf32s_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32s_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaf32s_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mul32_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mula32_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32u_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mul32u_ll_Slot_ae_slot1_encode, Opcode_ae_mul32u_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mul32u_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32u_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mula32u_ll_Slot_ae_slot1_encode, Opcode_ae_mula32u_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mula32u_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32u_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_muls32u_ll_Slot_ae_slot1_encode, Opcode_ae_muls32u_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_muls32u_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf16ss_33_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulf16ss_33_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf16ss_22_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulf16ss_22_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf16ss_32_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulf16ss_32_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf16ss_21_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulf16ss_21_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf16ss_31_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulf16ss_31_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf16ss_30_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulf16ss_30_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf16ss_10_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulf16ss_10_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf16ss_20_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulf16ss_20_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf16ss_11_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulf16ss_11_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf16ss_00_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf16ss_00_Slot_ae_slot1_encode, Opcode_ae_mulf16ss_00_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf16ss_00_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf16ss_00_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulf16ss_00_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf16ss_33_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulsf16ss_33_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf16ss_22_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulsf16ss_22_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf16ss_32_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulsf16ss_32_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf16ss_21_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulsf16ss_21_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf16ss_31_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulsf16ss_31_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf16ss_30_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulsf16ss_30_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf16ss_10_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulsf16ss_10_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf16ss_20_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulsf16ss_20_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf16ss_11_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulsf16ss_11_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf16ss_00_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf16ss_00_Slot_ae_slot1_encode, Opcode_ae_mulsf16ss_00_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf16ss_00_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf16ss_00_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsf16ss_00_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf16ss_33_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulaf16ss_33_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf16ss_22_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulaf16ss_22_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf16ss_32_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulaf16ss_32_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf16ss_21_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulaf16ss_21_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf16ss_31_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulaf16ss_31_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf16ss_30_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulaf16ss_30_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf16ss_10_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulaf16ss_10_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf16ss_20_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulaf16ss_20_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf16ss_11_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulaf16ss_11_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf16ss_00_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf16ss_00_Slot_ae_slot1_encode, Opcode_ae_mulaf16ss_00_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf16ss_00_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf16ss_00_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaf16ss_00_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd16ss_33_22_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaafd16ss_33_22_Slot_ae_slot1_encode, Opcode_ae_mulaafd16ss_33_22_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaafd16ss_33_22_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd16ss_33_22_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaafd16ss_33_22_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd16ss_13_02_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaafd16ss_13_02_Slot_ae_slot1_encode, Opcode_ae_mulaafd16ss_13_02_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaafd16ss_13_02_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd16ss_13_02_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaafd16ss_13_02_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd16ss_11_00_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaafd16ss_11_00_Slot_ae_slot1_encode, Opcode_ae_mulaafd16ss_11_00_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaafd16ss_11_00_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd16ss_11_00_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaafd16ss_11_00_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssfd16ss_33_22_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulssfd16ss_33_22_Slot_ae_slot1_encode, Opcode_ae_mulssfd16ss_33_22_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulssfd16ss_33_22_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssfd16ss_33_22_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulssfd16ss_33_22_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssfd16ss_13_02_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulssfd16ss_13_02_Slot_ae_slot1_encode, Opcode_ae_mulssfd16ss_13_02_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulssfd16ss_13_02_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssfd16ss_13_02_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulssfd16ss_13_02_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssfd16ss_11_00_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulssfd16ss_11_00_Slot_ae_slot1_encode, Opcode_ae_mulssfd16ss_11_00_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulssfd16ss_11_00_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssfd16ss_11_00_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulssfd16ss_11_00_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd16ss_33_22_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzaafd16ss_33_22_Slot_ae_slot1_encode, Opcode_ae_mulzaafd16ss_33_22_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzaafd16ss_33_22_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd16ss_33_22_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzaafd16ss_33_22_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd16ss_13_02_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzaafd16ss_13_02_Slot_ae_slot1_encode, Opcode_ae_mulzaafd16ss_13_02_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzaafd16ss_13_02_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd16ss_13_02_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzaafd16ss_13_02_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd16ss_11_00_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzaafd16ss_11_00_Slot_ae_slot1_encode, Opcode_ae_mulzaafd16ss_11_00_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzaafd16ss_11_00_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd16ss_11_00_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzaafd16ss_11_00_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssfd16ss_33_22_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzssfd16ss_33_22_Slot_ae_slot1_encode, Opcode_ae_mulzssfd16ss_33_22_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzssfd16ss_33_22_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssfd16ss_33_22_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzssfd16ss_33_22_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssfd16ss_13_02_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzssfd16ss_13_02_Slot_ae_slot1_encode, Opcode_ae_mulzssfd16ss_13_02_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzssfd16ss_13_02_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssfd16ss_13_02_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzssfd16ss_13_02_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssfd16ss_11_00_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzssfd16ss_11_00_Slot_ae_slot1_encode, Opcode_ae_mulzssfd16ss_11_00_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzssfd16ss_11_00_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssfd16ss_11_00_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzssfd16ss_11_00_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf48q32sp16s_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf48q32sp16s_l_Slot_ae_slot1_encode, Opcode_ae_mulf48q32sp16s_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf48q32sp16s_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf48q32sp16s_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulf48q32sp16s_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf48q32sp16u_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf48q32sp16u_l_Slot_ae_slot1_encode, Opcode_ae_mulf48q32sp16u_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf48q32sp16u_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf48q32sp16u_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulf48q32sp16u_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulq32sp16s_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulq32sp16s_l_Slot_ae_slot1_encode, Opcode_ae_mulq32sp16s_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulq32sp16s_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulq32sp16s_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulq32sp16s_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulq32sp16u_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulq32sp16u_l_Slot_ae_slot1_encode, Opcode_ae_mulq32sp16u_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulq32sp16u_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulq32sp16u_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulq32sp16u_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf48q32sp16s_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf48q32sp16s_l_Slot_ae_slot1_encode, Opcode_ae_mulaf48q32sp16s_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf48q32sp16s_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf48q32sp16s_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaf48q32sp16s_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf48q32sp16u_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf48q32sp16u_l_Slot_ae_slot1_encode, Opcode_ae_mulaf48q32sp16u_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf48q32sp16u_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf48q32sp16u_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaf48q32sp16u_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaq32sp16s_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaq32sp16s_l_Slot_ae_slot1_encode, Opcode_ae_mulaq32sp16s_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaq32sp16s_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaq32sp16s_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaq32sp16s_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaq32sp16u_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaq32sp16u_l_Slot_ae_slot1_encode, Opcode_ae_mulaq32sp16u_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaq32sp16u_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaq32sp16u_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaq32sp16u_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf48q32sp16s_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf48q32sp16s_l_Slot_ae_slot1_encode, Opcode_ae_mulsf48q32sp16s_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf48q32sp16s_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf48q32sp16s_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsf48q32sp16s_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf48q32sp16u_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf48q32sp16u_l_Slot_ae_slot1_encode, Opcode_ae_mulsf48q32sp16u_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf48q32sp16u_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf48q32sp16u_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsf48q32sp16u_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsq32sp16s_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsq32sp16s_l_Slot_ae_slot1_encode, Opcode_ae_mulsq32sp16s_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsq32sp16s_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsq32sp16s_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsq32sp16s_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsq32sp16u_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsq32sp16u_l_Slot_ae_slot1_encode, Opcode_ae_mulsq32sp16u_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsq32sp16u_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsq32sp16u_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsq32sp16u_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfp24x2ra_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulfp24x2ra_Slot_ae_slot1_encode, Opcode_ae_mulfp24x2ra_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulfp24x2ra_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfp24x2r_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulfp24x2r_Slot_ae_slot1_encode, Opcode_ae_mulfp24x2r_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulfp24x2r_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulp24x2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulp24x2_Slot_ae_slot1_encode, Opcode_ae_mulp24x2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulp24x2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfp24x2ra_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulfp24x2ra_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfp24x2r_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulfp24x2r_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulp24x2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulp24x2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafp24x2ra_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulafp24x2ra_Slot_ae_slot1_encode, Opcode_ae_mulafp24x2ra_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulafp24x2ra_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafp24x2r_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulafp24x2r_Slot_ae_slot1_encode, Opcode_ae_mulafp24x2r_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulafp24x2r_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulap24x2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulap24x2_Slot_ae_slot1_encode, Opcode_ae_mulap24x2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulap24x2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafp24x2ra_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulafp24x2ra_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafp24x2r_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulafp24x2r_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulap24x2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulap24x2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfp24x2ra_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsfp24x2ra_Slot_ae_slot1_encode, Opcode_ae_mulsfp24x2ra_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsfp24x2ra_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfp24x2r_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsfp24x2r_Slot_ae_slot1_encode, Opcode_ae_mulsfp24x2r_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsfp24x2r_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsp24x2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsp24x2_Slot_ae_slot1_encode, Opcode_ae_mulsp24x2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsp24x2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfp24x2ra_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsfp24x2ra_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfp24x2r_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsfp24x2r_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsp24x2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsp24x2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd24_hh_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzaafd24_hh_ll_Slot_ae_slot1_encode, Opcode_ae_mulzaafd24_hh_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzaafd24_hh_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaad24_hh_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzaad24_hh_ll_Slot_ae_slot1_encode, Opcode_ae_mulzaad24_hh_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzaad24_hh_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd24_hh_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzaafd24_hh_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaad24_hh_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzaad24_hh_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd24_hl_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzaafd24_hl_lh_Slot_ae_slot1_encode, Opcode_ae_mulzaafd24_hl_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzaafd24_hl_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaad24_hl_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzaad24_hl_lh_Slot_ae_slot1_encode, Opcode_ae_mulzaad24_hl_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzaad24_hl_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd24_hl_lh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzaafd24_hl_lh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaad24_hl_lh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzaad24_hl_lh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzasfd24_hh_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzasfd24_hh_ll_Slot_ae_slot1_encode, Opcode_ae_mulzasfd24_hh_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzasfd24_hh_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzasd24_hh_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzasd24_hh_ll_Slot_ae_slot1_encode, Opcode_ae_mulzasd24_hh_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzasd24_hh_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzasfd24_hh_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzasfd24_hh_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzasd24_hh_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzasd24_hh_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzasfd24_hl_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzasfd24_hl_lh_Slot_ae_slot1_encode, Opcode_ae_mulzasfd24_hl_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzasfd24_hl_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzasd24_hl_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzasd24_hl_lh_Slot_ae_slot1_encode, Opcode_ae_mulzasd24_hl_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzasd24_hl_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzasfd24_hl_lh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzasfd24_hl_lh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzasd24_hl_lh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzasd24_hl_lh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzsafd24_hh_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzsafd24_hh_ll_Slot_ae_slot1_encode, Opcode_ae_mulzsafd24_hh_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzsafd24_hh_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzsad24_hh_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzsad24_hh_ll_Slot_ae_slot1_encode, Opcode_ae_mulzsad24_hh_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzsad24_hh_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzsafd24_hh_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzsafd24_hh_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzsad24_hh_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzsad24_hh_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssfd24_hh_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzssfd24_hh_ll_Slot_ae_slot1_encode, Opcode_ae_mulzssfd24_hh_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzssfd24_hh_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssd24_hh_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzssd24_hh_ll_Slot_ae_slot1_encode, Opcode_ae_mulzssd24_hh_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzssd24_hh_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssfd24_hh_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzssfd24_hh_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssd24_hh_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzssd24_hh_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssfd24_hl_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzssfd24_hl_lh_Slot_ae_slot1_encode, Opcode_ae_mulzssfd24_hl_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzssfd24_hl_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssd24_hl_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzssd24_hl_lh_Slot_ae_slot1_encode, Opcode_ae_mulzssd24_hl_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzssd24_hl_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssfd24_hl_lh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzssfd24_hl_lh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssd24_hl_lh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzssd24_hl_lh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd24_hh_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaafd24_hh_ll_Slot_ae_slot1_encode, Opcode_ae_mulaafd24_hh_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaafd24_hh_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaad24_hh_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaad24_hh_ll_Slot_ae_slot1_encode, Opcode_ae_mulaad24_hh_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaad24_hh_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd24_hh_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaafd24_hh_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaad24_hh_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaad24_hh_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd24_hl_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaafd24_hl_lh_Slot_ae_slot1_encode, Opcode_ae_mulaafd24_hl_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaafd24_hl_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaad24_hl_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaad24_hl_lh_Slot_ae_slot1_encode, Opcode_ae_mulaad24_hl_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaad24_hl_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd24_hl_lh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaafd24_hl_lh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaad24_hl_lh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaad24_hl_lh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulasfd24_hh_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulasfd24_hh_ll_Slot_ae_slot1_encode, Opcode_ae_mulasfd24_hh_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulasfd24_hh_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulasd24_hh_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulasd24_hh_ll_Slot_ae_slot1_encode, Opcode_ae_mulasd24_hh_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulasd24_hh_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulasfd24_hh_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulasfd24_hh_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulasd24_hh_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulasd24_hh_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulasfd24_hl_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulasfd24_hl_lh_Slot_ae_slot1_encode, Opcode_ae_mulasfd24_hl_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulasfd24_hl_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulasd24_hl_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulasd24_hl_lh_Slot_ae_slot1_encode, Opcode_ae_mulasd24_hl_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulasd24_hl_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulasfd24_hl_lh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulasfd24_hl_lh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulasd24_hl_lh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulasd24_hl_lh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsafd24_hh_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsafd24_hh_ll_Slot_ae_slot1_encode, Opcode_ae_mulsafd24_hh_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsafd24_hh_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsad24_hh_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsad24_hh_ll_Slot_ae_slot1_encode, Opcode_ae_mulsad24_hh_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsad24_hh_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsafd24_hh_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsafd24_hh_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsad24_hh_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsad24_hh_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssfd24_hh_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulssfd24_hh_ll_Slot_ae_slot1_encode, Opcode_ae_mulssfd24_hh_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulssfd24_hh_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssd24_hh_ll_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulssd24_hh_ll_Slot_ae_slot1_encode, Opcode_ae_mulssd24_hh_ll_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulssd24_hh_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssfd24_hh_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulssfd24_hh_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssd24_hh_ll_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulssd24_hh_ll_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssfd24_hl_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulssfd24_hl_lh_Slot_ae_slot1_encode, Opcode_ae_mulssfd24_hl_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulssfd24_hl_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssd24_hl_lh_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulssd24_hl_lh_Slot_ae_slot1_encode, Opcode_ae_mulssd24_hl_lh_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulssd24_hl_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssfd24_hl_lh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulssfd24_hl_lh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssd24_hl_lh_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulssd24_hl_lh_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsrfq32sp24s_h_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsrfq32sp24s_h_Slot_ae_slot1_encode, Opcode_ae_mulsrfq32sp24s_h_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsrfq32sp24s_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsrfq32sp24s_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsrfq32sp24s_l_Slot_ae_slot1_encode, Opcode_ae_mulsrfq32sp24s_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsrfq32sp24s_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsrfq32sp24s_h_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsrfq32sp24s_h_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsrfq32sp24s_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsrfq32sp24s_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mularfq32sp24s_h_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mularfq32sp24s_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mularfq32sp24s_l_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mularfq32sp24s_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mularfq32sp24s_h_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mularfq32sp24s_h_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mularfq32sp24s_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mularfq32sp24s_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulrfq32sp24s_h_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulrfq32sp24s_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulrfq32sp24s_l_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulrfq32sp24s_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulrfq32sp24s_h_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulrfq32sp24s_h_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulrfq32sp24s_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulrfq32sp24s_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfq32sp24s_h_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulsfq32sp24s_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfq32sp24s_l_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulsfq32sp24s_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfq32sp24s_h_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsfq32sp24s_h_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfq32sp24s_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsfq32sp24s_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafq32sp24s_h_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulafq32sp24s_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafq32sp24s_l_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulafq32sp24s_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafq32sp24s_h_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulafq32sp24s_h_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafq32sp24s_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulafq32sp24s_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfq32sp24s_h_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulfq32sp24s_h_Slot_ae_slot1_encode, Opcode_ae_mulfq32sp24s_h_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulfq32sp24s_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfq32sp24s_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulfq32sp24s_l_Slot_ae_slot1_encode, Opcode_ae_mulfq32sp24s_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulfq32sp24s_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfq32sp24s_h_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulfq32sp24s_h_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfq32sp24s_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulfq32sp24s_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32x16_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf32x16_l0_Slot_ae_slot1_encode, Opcode_ae_mulf32x16_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf32x16_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32x16_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mul32x16_l0_Slot_ae_slot1_encode, Opcode_ae_mul32x16_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mul32x16_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32x16_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulf32x16_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32x16_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mul32x16_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32x16_l1_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf32x16_l1_Slot_ae_slot1_encode, Opcode_ae_mulf32x16_l1_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf32x16_l1_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32x16_l1_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mul32x16_l1_Slot_ae_slot1_encode, Opcode_ae_mul32x16_l1_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mul32x16_l1_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32x16_l1_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulf32x16_l1_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32x16_l1_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mul32x16_l1_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32x16_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf32x16_l2_Slot_ae_slot1_encode, Opcode_ae_mulf32x16_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf32x16_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32x16_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mul32x16_l2_Slot_ae_slot1_encode, Opcode_ae_mul32x16_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mul32x16_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32x16_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulf32x16_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32x16_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mul32x16_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32x16_l3_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf32x16_l3_Slot_ae_slot1_encode, Opcode_ae_mulf32x16_l3_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf32x16_l3_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32x16_l3_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mul32x16_l3_Slot_ae_slot1_encode, Opcode_ae_mul32x16_l3_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mul32x16_l3_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32x16_l3_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulf32x16_l3_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32x16_l3_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mul32x16_l3_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32x16_h0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf32x16_h0_Slot_ae_slot1_encode, Opcode_ae_mulf32x16_h0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf32x16_h0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32x16_h0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mul32x16_h0_Slot_ae_slot1_encode, Opcode_ae_mul32x16_h0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mul32x16_h0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32x16_h0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulf32x16_h0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32x16_h0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mul32x16_h0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32x16_h1_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf32x16_h1_Slot_ae_slot1_encode, Opcode_ae_mulf32x16_h1_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf32x16_h1_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32x16_h1_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mul32x16_h1_Slot_ae_slot1_encode, Opcode_ae_mul32x16_h1_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mul32x16_h1_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32x16_h1_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulf32x16_h1_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32x16_h1_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mul32x16_h1_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32x16_h2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf32x16_h2_Slot_ae_slot1_encode, Opcode_ae_mulf32x16_h2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf32x16_h2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32x16_h2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mul32x16_h2_Slot_ae_slot1_encode, Opcode_ae_mul32x16_h2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mul32x16_h2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32x16_h2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulf32x16_h2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32x16_h2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mul32x16_h2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32x16_h3_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulf32x16_h3_Slot_ae_slot1_encode, Opcode_ae_mulf32x16_h3_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulf32x16_h3_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32x16_h3_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mul32x16_h3_Slot_ae_slot1_encode, Opcode_ae_mul32x16_h3_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mul32x16_h3_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf32x16_h3_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulf32x16_h3_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul32x16_h3_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mul32x16_h3_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32x16_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf32x16_l0_Slot_ae_slot1_encode, Opcode_ae_mulaf32x16_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf32x16_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32x16_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mula32x16_l0_Slot_ae_slot1_encode, Opcode_ae_mula32x16_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mula32x16_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32x16_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaf32x16_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32x16_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mula32x16_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32x16_l1_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf32x16_l1_Slot_ae_slot1_encode, Opcode_ae_mulaf32x16_l1_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf32x16_l1_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32x16_l1_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mula32x16_l1_Slot_ae_slot1_encode, Opcode_ae_mula32x16_l1_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mula32x16_l1_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32x16_l1_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaf32x16_l1_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32x16_l1_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mula32x16_l1_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32x16_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf32x16_l2_Slot_ae_slot1_encode, Opcode_ae_mulaf32x16_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf32x16_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32x16_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mula32x16_l2_Slot_ae_slot1_encode, Opcode_ae_mula32x16_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mula32x16_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32x16_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaf32x16_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32x16_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mula32x16_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32x16_l3_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf32x16_l3_Slot_ae_slot1_encode, Opcode_ae_mulaf32x16_l3_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf32x16_l3_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32x16_l3_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mula32x16_l3_Slot_ae_slot1_encode, Opcode_ae_mula32x16_l3_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mula32x16_l3_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32x16_l3_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaf32x16_l3_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32x16_l3_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mula32x16_l3_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32x16_h0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf32x16_h0_Slot_ae_slot1_encode, Opcode_ae_mulaf32x16_h0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf32x16_h0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32x16_h0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mula32x16_h0_Slot_ae_slot1_encode, Opcode_ae_mula32x16_h0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mula32x16_h0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32x16_h0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaf32x16_h0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32x16_h0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mula32x16_h0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32x16_h1_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf32x16_h1_Slot_ae_slot1_encode, Opcode_ae_mulaf32x16_h1_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf32x16_h1_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32x16_h1_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mula32x16_h1_Slot_ae_slot1_encode, Opcode_ae_mula32x16_h1_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mula32x16_h1_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32x16_h1_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaf32x16_h1_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32x16_h1_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mula32x16_h1_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32x16_h2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf32x16_h2_Slot_ae_slot1_encode, Opcode_ae_mulaf32x16_h2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf32x16_h2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32x16_h2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mula32x16_h2_Slot_ae_slot1_encode, Opcode_ae_mula32x16_h2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mula32x16_h2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32x16_h2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaf32x16_h2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32x16_h2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mula32x16_h2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32x16_h3_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaf32x16_h3_Slot_ae_slot1_encode, Opcode_ae_mulaf32x16_h3_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaf32x16_h3_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32x16_h3_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mula32x16_h3_Slot_ae_slot1_encode, Opcode_ae_mula32x16_h3_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mula32x16_h3_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf32x16_h3_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaf32x16_h3_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula32x16_h3_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mula32x16_h3_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32x16_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf32x16_l0_Slot_ae_slot1_encode, Opcode_ae_mulsf32x16_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf32x16_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32x16_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_muls32x16_l0_Slot_ae_slot1_encode, Opcode_ae_muls32x16_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_muls32x16_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32x16_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsf32x16_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32x16_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_muls32x16_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32x16_l1_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf32x16_l1_Slot_ae_slot1_encode, Opcode_ae_mulsf32x16_l1_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf32x16_l1_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32x16_l1_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_muls32x16_l1_Slot_ae_slot1_encode, Opcode_ae_muls32x16_l1_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_muls32x16_l1_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32x16_l1_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsf32x16_l1_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32x16_l1_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_muls32x16_l1_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32x16_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf32x16_l2_Slot_ae_slot1_encode, Opcode_ae_mulsf32x16_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf32x16_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32x16_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_muls32x16_l2_Slot_ae_slot1_encode, Opcode_ae_muls32x16_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_muls32x16_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32x16_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsf32x16_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32x16_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_muls32x16_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32x16_l3_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf32x16_l3_Slot_ae_slot1_encode, Opcode_ae_mulsf32x16_l3_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf32x16_l3_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32x16_l3_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_muls32x16_l3_Slot_ae_slot1_encode, Opcode_ae_muls32x16_l3_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_muls32x16_l3_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32x16_l3_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsf32x16_l3_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32x16_l3_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_muls32x16_l3_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32x16_h0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf32x16_h0_Slot_ae_slot1_encode, Opcode_ae_mulsf32x16_h0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf32x16_h0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32x16_h0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_muls32x16_h0_Slot_ae_slot1_encode, Opcode_ae_muls32x16_h0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_muls32x16_h0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32x16_h0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsf32x16_h0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32x16_h0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_muls32x16_h0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32x16_h1_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf32x16_h1_Slot_ae_slot1_encode, Opcode_ae_mulsf32x16_h1_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf32x16_h1_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32x16_h1_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_muls32x16_h1_Slot_ae_slot1_encode, Opcode_ae_muls32x16_h1_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_muls32x16_h1_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32x16_h1_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsf32x16_h1_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32x16_h1_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_muls32x16_h1_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32x16_h2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf32x16_h2_Slot_ae_slot1_encode, Opcode_ae_mulsf32x16_h2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf32x16_h2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32x16_h2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_muls32x16_h2_Slot_ae_slot1_encode, Opcode_ae_muls32x16_h2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_muls32x16_h2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32x16_h2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsf32x16_h2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32x16_h2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_muls32x16_h2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32x16_h3_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsf32x16_h3_Slot_ae_slot1_encode, Opcode_ae_mulsf32x16_h3_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsf32x16_h3_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32x16_h3_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_muls32x16_h3_Slot_ae_slot1_encode, Opcode_ae_muls32x16_h3_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_muls32x16_h3_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf32x16_h3_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsf32x16_h3_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls32x16_h3_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_muls32x16_h3_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd32x16_h3_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaafd32x16_h3_l2_Slot_ae_slot1_encode, Opcode_ae_mulaafd32x16_h3_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaafd32x16_h3_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaad32x16_h3_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaad32x16_h3_l2_Slot_ae_slot1_encode, Opcode_ae_mulaad32x16_h3_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaad32x16_h3_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd32x16_h3_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaafd32x16_h3_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaad32x16_h3_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaad32x16_h3_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd32x16_h1_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaafd32x16_h1_l0_Slot_ae_slot1_encode, Opcode_ae_mulaafd32x16_h1_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaafd32x16_h1_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaad32x16_h1_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaad32x16_h1_l0_Slot_ae_slot1_encode, Opcode_ae_mulaad32x16_h1_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaad32x16_h1_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd32x16_h1_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaafd32x16_h1_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaad32x16_h1_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaad32x16_h1_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulasfd32x16_h3_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulasfd32x16_h3_l2_Slot_ae_slot1_encode, Opcode_ae_mulasfd32x16_h3_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulasfd32x16_h3_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulasd32x16_h3_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulasd32x16_h3_l2_Slot_ae_slot1_encode, Opcode_ae_mulasd32x16_h3_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulasd32x16_h3_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulasfd32x16_h3_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulasfd32x16_h3_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulasd32x16_h3_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulasd32x16_h3_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulasfd32x16_h1_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulasfd32x16_h1_l0_Slot_ae_slot1_encode, Opcode_ae_mulasfd32x16_h1_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulasfd32x16_h1_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulasd32x16_h1_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulasd32x16_h1_l0_Slot_ae_slot1_encode, Opcode_ae_mulasd32x16_h1_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulasd32x16_h1_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulasfd32x16_h1_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulasfd32x16_h1_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulasd32x16_h1_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulasd32x16_h1_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsafd32x16_h3_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsafd32x16_h3_l2_Slot_ae_slot1_encode, Opcode_ae_mulsafd32x16_h3_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsafd32x16_h3_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsad32x16_h3_l2_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulsad32x16_h3_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsafd32x16_h3_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsafd32x16_h3_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsad32x16_h3_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsad32x16_h3_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsafd32x16_h1_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsafd32x16_h1_l0_Slot_ae_slot1_encode, Opcode_ae_mulsafd32x16_h1_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsafd32x16_h1_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsad32x16_h1_l0_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulsad32x16_h1_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsafd32x16_h1_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsafd32x16_h1_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsad32x16_h1_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsad32x16_h1_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssfd32x16_h3_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulssfd32x16_h3_l2_Slot_ae_slot1_encode, Opcode_ae_mulssfd32x16_h3_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulssfd32x16_h3_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssd32x16_h3_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulssd32x16_h3_l2_Slot_ae_slot1_encode, Opcode_ae_mulssd32x16_h3_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulssd32x16_h3_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssfd32x16_h3_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulssfd32x16_h3_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssd32x16_h3_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulssd32x16_h3_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssfd32x16_h1_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulssfd32x16_h1_l0_Slot_ae_slot1_encode, Opcode_ae_mulssfd32x16_h1_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulssfd32x16_h1_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssd32x16_h1_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulssd32x16_h1_l0_Slot_ae_slot1_encode, Opcode_ae_mulssd32x16_h1_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulssd32x16_h1_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssfd32x16_h1_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulssfd32x16_h1_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulssd32x16_h1_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulssd32x16_h1_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd32x16_h3_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzaafd32x16_h3_l2_Slot_ae_slot1_encode, Opcode_ae_mulzaafd32x16_h3_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzaafd32x16_h3_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaad32x16_h3_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzaad32x16_h3_l2_Slot_ae_slot1_encode, Opcode_ae_mulzaad32x16_h3_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzaad32x16_h3_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd32x16_h3_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzaafd32x16_h3_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaad32x16_h3_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzaad32x16_h3_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd32x16_h1_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzaafd32x16_h1_l0_Slot_ae_slot1_encode, Opcode_ae_mulzaafd32x16_h1_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzaafd32x16_h1_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaad32x16_h1_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzaad32x16_h1_l0_Slot_ae_slot1_encode, Opcode_ae_mulzaad32x16_h1_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzaad32x16_h1_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd32x16_h1_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzaafd32x16_h1_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaad32x16_h1_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzaad32x16_h1_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzasfd32x16_h3_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzasfd32x16_h3_l2_Slot_ae_slot1_encode, Opcode_ae_mulzasfd32x16_h3_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzasfd32x16_h3_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzasd32x16_h3_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzasd32x16_h3_l2_Slot_ae_slot1_encode, Opcode_ae_mulzasd32x16_h3_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzasd32x16_h3_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzasfd32x16_h3_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzasfd32x16_h3_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzasd32x16_h3_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzasd32x16_h3_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzasfd32x16_h1_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzasfd32x16_h1_l0_Slot_ae_slot1_encode, Opcode_ae_mulzasfd32x16_h1_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzasfd32x16_h1_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzasd32x16_h1_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzasd32x16_h1_l0_Slot_ae_slot1_encode, Opcode_ae_mulzasd32x16_h1_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzasd32x16_h1_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzasfd32x16_h1_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzasfd32x16_h1_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzasd32x16_h1_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzasd32x16_h1_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzsafd32x16_h3_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzsafd32x16_h3_l2_Slot_ae_slot1_encode, Opcode_ae_mulzsafd32x16_h3_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzsafd32x16_h3_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzsad32x16_h3_l2_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulzsad32x16_h3_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzsafd32x16_h3_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzsafd32x16_h3_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzsad32x16_h3_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzsad32x16_h3_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzsafd32x16_h1_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzsafd32x16_h1_l0_Slot_ae_slot1_encode, Opcode_ae_mulzsafd32x16_h1_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzsafd32x16_h1_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzsad32x16_h1_l0_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulzsad32x16_h1_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzsafd32x16_h1_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzsafd32x16_h1_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzsad32x16_h1_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzsad32x16_h1_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssfd32x16_h3_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzssfd32x16_h3_l2_Slot_ae_slot1_encode, Opcode_ae_mulzssfd32x16_h3_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzssfd32x16_h3_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssd32x16_h3_l2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzssd32x16_h3_l2_Slot_ae_slot1_encode, Opcode_ae_mulzssd32x16_h3_l2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzssd32x16_h3_l2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssfd32x16_h3_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzssfd32x16_h3_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssd32x16_h3_l2_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzssd32x16_h3_l2_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssfd32x16_h1_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzssfd32x16_h1_l0_Slot_ae_slot1_encode, Opcode_ae_mulzssfd32x16_h1_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzssfd32x16_h1_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssd32x16_h1_l0_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzssd32x16_h1_l0_Slot_ae_slot1_encode, Opcode_ae_mulzssd32x16_h1_l0_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzssd32x16_h1_l0_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssfd32x16_h1_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzssfd32x16_h1_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzssd32x16_h1_l0_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzssd32x16_h1_l0_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd32x16_h2_l3_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzaafd32x16_h2_l3_Slot_ae_slot1_encode, Opcode_ae_mulzaafd32x16_h2_l3_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzaafd32x16_h2_l3_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd32x16_h0_l1_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzaafd32x16_h0_l1_Slot_ae_slot1_encode, Opcode_ae_mulzaafd32x16_h0_l1_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzaafd32x16_h0_l1_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd32x16_h2_l3_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaafd32x16_h2_l3_Slot_ae_slot1_encode, Opcode_ae_mulaafd32x16_h2_l3_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaafd32x16_h2_l3_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd32x16_h0_l1_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaafd32x16_h0_l1_Slot_ae_slot1_encode, Opcode_ae_mulaafd32x16_h0_l1_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaafd32x16_h0_l1_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaad32x16_h2_l3_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzaad32x16_h2_l3_Slot_ae_slot1_encode, Opcode_ae_mulzaad32x16_h2_l3_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzaad32x16_h2_l3_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaad32x16_h0_l1_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulzaad32x16_h0_l1_Slot_ae_slot1_encode, Opcode_ae_mulzaad32x16_h0_l1_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulzaad32x16_h0_l1_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaad32x16_h2_l3_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaad32x16_h2_l3_Slot_ae_slot1_encode, Opcode_ae_mulaad32x16_h2_l3_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaad32x16_h2_l3_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaad32x16_h0_l1_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulaad32x16_h0_l1_Slot_ae_slot1_encode, Opcode_ae_mulaad32x16_h0_l1_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulaad32x16_h0_l1_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd32x16_h2_l3_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzaafd32x16_h2_l3_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaafd32x16_h0_l1_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzaafd32x16_h0_l1_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd32x16_h2_l3_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaafd32x16_h2_l3_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaafd32x16_h0_l1_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaafd32x16_h0_l1_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaad32x16_h2_l3_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzaad32x16_h2_l3_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulzaad32x16_h0_l1_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulzaad32x16_h0_l1_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaad32x16_h2_l3_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaad32x16_h2_l3_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaad32x16_h0_l1_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulaad32x16_h0_l1_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulp32x16x2_h_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulp32x16x2_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfp32x16x2rs_h_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulfp32x16x2rs_h_Slot_ae_slot1_encode, Opcode_ae_mulfp32x16x2rs_h_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulfp32x16x2rs_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfp32x16x2ras_h_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulfp32x16x2ras_h_Slot_ae_slot1_encode, Opcode_ae_mulfp32x16x2ras_h_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulfp32x16x2ras_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfp32x16x2rs_h_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulfp32x16x2rs_h_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfp32x16x2ras_h_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulfp32x16x2ras_h_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulp32x16x2_l_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulp32x16x2_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfp32x16x2rs_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulfp32x16x2rs_l_Slot_ae_slot1_encode, Opcode_ae_mulfp32x16x2rs_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulfp32x16x2rs_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfp32x16x2ras_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulfp32x16x2ras_l_Slot_ae_slot1_encode, Opcode_ae_mulfp32x16x2ras_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulfp32x16x2ras_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfp32x16x2rs_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulfp32x16x2rs_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfp32x16x2ras_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulfp32x16x2ras_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulap32x16x2_h_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulap32x16x2_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafp32x16x2rs_h_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulafp32x16x2rs_h_Slot_ae_slot1_encode, Opcode_ae_mulafp32x16x2rs_h_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulafp32x16x2rs_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafp32x16x2ras_h_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulafp32x16x2ras_h_Slot_ae_slot1_encode, Opcode_ae_mulafp32x16x2ras_h_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulafp32x16x2ras_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafp32x16x2rs_h_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulafp32x16x2rs_h_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafp32x16x2ras_h_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulafp32x16x2ras_h_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulap32x16x2_l_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulap32x16x2_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafp32x16x2rs_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulafp32x16x2rs_l_Slot_ae_slot1_encode, Opcode_ae_mulafp32x16x2rs_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulafp32x16x2rs_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafp32x16x2ras_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulafp32x16x2ras_l_Slot_ae_slot1_encode, Opcode_ae_mulafp32x16x2ras_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulafp32x16x2ras_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafp32x16x2rs_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulafp32x16x2rs_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafp32x16x2ras_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulafp32x16x2ras_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsp32x16x2_h_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulsp32x16x2_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfp32x16x2rs_h_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsfp32x16x2rs_h_Slot_ae_slot1_encode, Opcode_ae_mulsfp32x16x2rs_h_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsfp32x16x2rs_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfp32x16x2ras_h_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsfp32x16x2ras_h_Slot_ae_slot1_encode, Opcode_ae_mulsfp32x16x2ras_h_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsfp32x16x2ras_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfp32x16x2rs_h_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsfp32x16x2rs_h_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfp32x16x2ras_h_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsfp32x16x2ras_h_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsp32x16x2_l_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulsp32x16x2_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfp32x16x2rs_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsfp32x16x2rs_l_Slot_ae_slot1_encode, Opcode_ae_mulsfp32x16x2rs_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsfp32x16x2rs_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfp32x16x2ras_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsfp32x16x2ras_l_Slot_ae_slot1_encode, Opcode_ae_mulsfp32x16x2ras_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsfp32x16x2ras_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfp32x16x2rs_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsfp32x16x2rs_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfp32x16x2ras_l_s2_encode_fns[] = {
  0, 0, 0, Opcode_ae_mulsfp32x16x2ras_l_s2_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulp32x2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulp32x2_Slot_ae_slot1_encode, Opcode_ae_mulp32x2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulp32x2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfp32x2rs_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulfp32x2rs_Slot_ae_slot1_encode, Opcode_ae_mulfp32x2rs_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulfp32x2rs_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfp32x2ras_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulfp32x2ras_Slot_ae_slot1_encode, Opcode_ae_mulfp32x2ras_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulfp32x2ras_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulap32x2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulap32x2_Slot_ae_slot1_encode, Opcode_ae_mulap32x2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulap32x2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafp32x2rs_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulafp32x2rs_Slot_ae_slot1_encode, Opcode_ae_mulafp32x2rs_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulafp32x2rs_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafp32x2ras_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulafp32x2ras_Slot_ae_slot1_encode, Opcode_ae_mulafp32x2ras_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulafp32x2ras_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsp32x2_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsp32x2_Slot_ae_slot1_encode, Opcode_ae_mulsp32x2_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsp32x2_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfp32x2rs_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsfp32x2rs_Slot_ae_slot1_encode, Opcode_ae_mulsfp32x2rs_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsfp32x2rs_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsfp32x2ras_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulsfp32x2ras_Slot_ae_slot1_encode, Opcode_ae_mulsfp32x2ras_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulsfp32x2ras_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfp16x4s_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulfp16x4s_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfp16x4ras_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulfp16x4ras_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulc24_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulc24_Slot_ae_slot1_encode, Opcode_ae_mulc24_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulc24_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfc24ra_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulfc24ra_Slot_ae_slot1_encode, Opcode_ae_mulfc24ra_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulfc24ra_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulc32x16_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulc32x16_l_Slot_ae_slot1_encode, Opcode_ae_mulc32x16_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulc32x16_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfc32x16ras_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulfc32x16ras_l_Slot_ae_slot1_encode, Opcode_ae_mulfc32x16ras_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulfc32x16ras_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulc32x16_h_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulc32x16_h_Slot_ae_slot1_encode, Opcode_ae_mulc32x16_h_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulc32x16_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfc32x16ras_h_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulfc32x16ras_h_Slot_ae_slot1_encode, Opcode_ae_mulfc32x16ras_h_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulfc32x16ras_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulac24_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulac24_Slot_ae_slot1_encode, Opcode_ae_mulac24_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulac24_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafc24ra_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulafc24ra_Slot_ae_slot1_encode, Opcode_ae_mulafc24ra_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulafc24ra_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulac32x16_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulac32x16_l_Slot_ae_slot1_encode, Opcode_ae_mulac32x16_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulac32x16_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafc32x16ras_l_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulafc32x16ras_l_Slot_ae_slot1_encode, Opcode_ae_mulafc32x16ras_l_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulafc32x16ras_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulac32x16_h_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulac32x16_h_Slot_ae_slot1_encode, Opcode_ae_mulac32x16_h_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulac32x16_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafc32x16ras_h_encode_fns[] = {
  0, 0, 0, 0, Opcode_ae_mulafc32x16ras_h_Slot_ae_slot1_encode, Opcode_ae_mulafc32x16ras_h_Slot_ae_slot1_encode, 0, 0, 0, Opcode_ae_mulafc32x16ras_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulf16x4ss_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulf16x4ss_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulaf16x4ss_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulaf16x4ss_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulsf16x4ss_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulsf16x4ss_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mul16x4_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mul16x4_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mula16x4_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mula16x4_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_muls16x4_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_muls16x4_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfd24x2_fir_h_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulfd24x2_fir_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfd24x2_fir_l_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulfd24x2_fir_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfd32x16x2_fir_hh_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulfd32x16x2_fir_hh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfd32x16x2_fir_hl_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulfd32x16x2_fir_hl_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfd32x16x2_fir_lh_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulfd32x16x2_fir_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulfd32x16x2_fir_ll_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulfd32x16x2_fir_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafd24x2_fir_h_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulafd24x2_fir_h_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafd24x2_fir_l_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulafd24x2_fir_l_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafd32x16x2_fir_hh_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulafd32x16x2_fir_hh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafd32x16x2_fir_hl_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulafd32x16x2_fir_hl_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafd32x16x2_fir_lh_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulafd32x16x2_fir_lh_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_mulafd32x16x2_fir_ll_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_mulafd32x16x2_fir_ll_Slot_ae2_slot1_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_div64d32_h_encode_fns[] = {
  0, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_div64d32_h_Slot_ae_slot2_1_encode, 0, Opcode_ae_div64d32_h_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_div64d32_l_encode_fns[] = {
  Opcode_ae_div64d32_l_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, Opcode_ae_div64d32_l_Slot_ae_slot2_1_encode, 0, Opcode_ae_div64d32_l_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sha32_encode_fns[] = {
  Opcode_ae_sha32_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_vldl32t_encode_fns[] = {
  Opcode_ae_vldl32t_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_vldl16t_encode_fns[] = {
  Opcode_ae_vldl16t_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_vldl16c_encode_fns[] = {
  Opcode_ae_vldl16c_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_vldl16c_ip_encode_fns[] = {
  Opcode_ae_vldl16c_ip_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_vldl16c_ic_encode_fns[] = {
  Opcode_ae_vldl16c_ic_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_vldsht_encode_fns[] = {
  Opcode_ae_vldsht_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_lb_encode_fns[] = {
  Opcode_ae_lb_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_lbi_encode_fns[] = {
  Opcode_ae_lbi_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_lbk_encode_fns[] = {
  Opcode_ae_lbk_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_lbki_encode_fns[] = {
  Opcode_ae_lbki_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_lbs_encode_fns[] = {
  Opcode_ae_lbs_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_lbsi_encode_fns[] = {
  Opcode_ae_lbsi_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_db_encode_fns[] = {
  Opcode_ae_db_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_dbi_encode_fns[] = {
  Opcode_ae_dbi_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_db_ic_encode_fns[] = {
  Opcode_ae_db_ic_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_dbi_ic_encode_fns[] = {
  Opcode_ae_dbi_ic_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_db_ip_encode_fns[] = {
  Opcode_ae_db_ip_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_dbi_ip_encode_fns[] = {
  Opcode_ae_dbi_ip_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_vlel32t_encode_fns[] = {
  Opcode_ae_vlel32t_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_vlel16t_encode_fns[] = {
  Opcode_ae_vlel16t_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sb_encode_fns[] = {
  Opcode_ae_sb_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sbi_encode_fns[] = {
  Opcode_ae_sbi_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_vles16c_encode_fns[] = {
  Opcode_ae_vles16c_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sbf_encode_fns[] = {
  Opcode_ae_sbf_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sb_ic_encode_fns[] = {
  Opcode_ae_sb_ic_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sbi_ic_encode_fns[] = {
  Opcode_ae_sbi_ic_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_vles16c_ic_encode_fns[] = {
  Opcode_ae_vles16c_ic_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sbf_ic_encode_fns[] = {
  Opcode_ae_sbf_ic_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sb_ip_encode_fns[] = {
  Opcode_ae_sb_ip_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sbi_ip_encode_fns[] = {
  Opcode_ae_sbi_ip_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_vles16c_ip_encode_fns[] = {
  Opcode_ae_vles16c_ip_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sbf_ip_encode_fns[] = {
  Opcode_ae_sbf_ip_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ae_sext32_encode_fns[] = {
  Opcode_ae_sext32_Slot_inst_encode, 0, 0, Opcode_ae_sext32_Slot_ae_slot2_0_encode, 0, 0, 0, 0, 0, 0, Opcode_ae_sext32_Slot_ae2_slot0_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_lsi_encode_fns[] = {
  Opcode_lsi_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_lsip_encode_fns[] = {
  Opcode_lsip_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_lsx_encode_fns[] = {
  Opcode_lsx_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_lsxp_encode_fns[] = {
  Opcode_lsxp_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ssi_encode_fns[] = {
  Opcode_ssi_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ssip_encode_fns[] = {
  Opcode_ssip_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ssx_encode_fns[] = {
  Opcode_ssx_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ssxp_encode_fns[] = {
  Opcode_ssxp_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_abs_s_encode_fns[] = {
  Opcode_abs_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_neg_s_encode_fns[] = {
  Opcode_neg_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_mov_s_encode_fns[] = {
  Opcode_mov_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_moveqz_s_encode_fns[] = {
  Opcode_moveqz_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_movnez_s_encode_fns[] = {
  Opcode_movnez_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_movltz_s_encode_fns[] = {
  Opcode_movltz_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_movgez_s_encode_fns[] = {
  Opcode_movgez_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_movf_s_encode_fns[] = {
  Opcode_movf_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_movt_s_encode_fns[] = {
  Opcode_movt_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_wfr_encode_fns[] = {
  Opcode_wfr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rfr_encode_fns[] = {
  Opcode_rfr_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_round_s_encode_fns[] = {
  Opcode_round_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ceil_s_encode_fns[] = {
  Opcode_ceil_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_floor_s_encode_fns[] = {
  Opcode_floor_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_trunc_s_encode_fns[] = {
  Opcode_trunc_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_utrunc_s_encode_fns[] = {
  Opcode_utrunc_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_float_s_encode_fns[] = {
  Opcode_float_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ufloat_s_encode_fns[] = {
  Opcode_ufloat_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_un_s_encode_fns[] = {
  Opcode_un_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ult_s_encode_fns[] = {
  Opcode_ult_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ule_s_encode_fns[] = {
  Opcode_ule_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ueq_s_encode_fns[] = {
  Opcode_ueq_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_olt_s_encode_fns[] = {
  Opcode_olt_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_ole_s_encode_fns[] = {
  Opcode_ole_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_oeq_s_encode_fns[] = {
  Opcode_oeq_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_add_s_encode_fns[] = {
  Opcode_add_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_sub_s_encode_fns[] = {
  Opcode_sub_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_mul_s_encode_fns[] = {
  Opcode_mul_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_madd_s_encode_fns[] = {
  Opcode_madd_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_msub_s_encode_fns[] = {
  Opcode_msub_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_sqrt0_s_encode_fns[] = {
  Opcode_sqrt0_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_div0_s_encode_fns[] = {
  Opcode_div0_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_recip0_s_encode_fns[] = {
  Opcode_recip0_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_rsqrt0_s_encode_fns[] = {
  Opcode_rsqrt0_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_maddn_s_encode_fns[] = {
  Opcode_maddn_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_divn_s_encode_fns[] = {
  Opcode_divn_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_const_s_encode_fns[] = {
  Opcode_const_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_nexp01_s_encode_fns[] = {
  Opcode_nexp01_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_addexp_s_encode_fns[] = {
  Opcode_addexp_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_addexpm_s_encode_fns[] = {
  Opcode_addexpm_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_mkdadj_s_encode_fns[] = {
  Opcode_mkdadj_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static xtensa_opcode_encode_fn Opcode_mksadj_s_encode_fns[] = {
  Opcode_mksadj_s_Slot_inst_encode, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

int num_bypass_groups() {
    return 0;
}

int num_bypass_group_chunks() {
    return 0;
}

uint32 *bypass_entry(int i) {
    return 0;
}


/* Opcode table.  */

static xtensa_funcUnit_use Opcode_l32e_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_s32e_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_l32i_n_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_s32i_n_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_l16ui_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_l16si_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_l32i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_l32r_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_l8ui_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_s16i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_s32i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_s32nb_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_s8i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_lddr32_p_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_sddr32_p_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_lict_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_licw_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_sict_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_sicw_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_sdct_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ldct_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_l32ai_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_s32ri_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_s32c1i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16m_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16m_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16m_iu_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16m_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16m_xu_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16_xp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32f24_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32f24_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32f24_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32f24_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32f24_xp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32_xp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32m_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32m_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32m_iu_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32m_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32m_xu_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16x2m_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16x2m_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16x2m_iu_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16x2m_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16x2m_xu_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32x2f24_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32x2f24_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32x2f24_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32x2f24_rip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32x2f24_ric_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32x2f24_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32x2f24_xp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32x2_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32x2_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32x2_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32x2_rip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32x2_ric_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32x2_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l32x2_xp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16x4_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16x4_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16x4_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16x4_rip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16x4_ric_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16x4_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l16x4_xp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l64_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l64_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l64_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l64_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_l64_xp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16x2m_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16x2m_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16x2m_iu_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16x2m_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16x2m_xu_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32x2f24_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32x2f24_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32x2f24_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32x2f24_rip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32x2f24_ric_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32x2f24_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32x2f24_xp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32x2_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32x2_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32x2_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32x2_rip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32x2_ric_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32x2_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32x2_xp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16x4_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16x4_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16x4_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16x4_rip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16x4_ric_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16x4_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16x4_xp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16m_l_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16m_l_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16m_l_iu_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16m_l_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16m_l_xu_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32f24_l_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32f24_l_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32f24_l_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32f24_l_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32f24_l_xp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32_l_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32_l_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32_l_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32_l_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32_l_xp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16_0_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16_0_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16_0_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16_0_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s16_0_xp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s64_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s64_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s64_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s64_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s64_xp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32m_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32m_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32m_iu_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32m_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32m_xu_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_lalign64_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_salign64_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la64_pp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la24pos_pc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la24x2pos_pc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la32x2pos_pc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la16x4pos_pc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la24neg_pc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la24x2neg_pc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la32x2neg_pc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la16x4neg_pc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa64pos_fp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa64neg_fp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la32x2_ic_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la32x2_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la32x2_rip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la32x2_ric_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la16x4_ic_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la16x4_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la16x4_rip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la16x4_ric_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la32x2f24_ic_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la32x2f24_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la32x2f24_rip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la32x2f24_ric_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la24_ic_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la24_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la24_rip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la24_ric_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la24x2_ic_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la24x2_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la24x2_rip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_la24x2_ric_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa32x2_ic_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa32x2_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa32x2_rip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa32x2_ric_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa16x4_ic_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa16x4_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa16x4_rip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa16x4_ric_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa32x2f24_ic_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa32x2f24_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa32x2f24_rip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa32x2f24_ric_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa24_l_ic_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa24_l_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa24_l_rip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa24_l_ric_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa24x2_ic_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa24x2_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa24x2_rip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sa24x2_ric_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32ra64s_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32ra64s_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32ra64s_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32ra64s_xp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32ra64s_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s24ra64s_i_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s24ra64s_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s24ra64s_x_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s24ra64s_xp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s24ra64s_xc_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s32x2ra64s_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_s24x2ra64s_ip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_muls32f48p16s_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32s_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32f48p16s_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32r_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32f48p16s_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32s_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32f48p16s_lh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32r_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32f48p16s_hh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32s_hh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32_hh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32f48p16s_hh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32r_hh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32r_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulas32f48p16s_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32s_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulas32f48p16s_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32r_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulas32f48p16s_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32s_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulas32f48p16s_lh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32r_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulas32f48p16s_hh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32s_hh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32_hh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulas32f48p16s_hh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32r_hh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32r_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulss32f48p16s_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32s_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulss32f48p16s_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32r_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulss32f48p16s_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32s_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulss32f48p16s_lh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32r_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulss32f48p16s_hh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32s_hh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32_hh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulss32f48p16s_hh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32r_hh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32r_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32s_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32s_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32u_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32u_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32u_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf16ss_33_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf16ss_22_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf16ss_32_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf16ss_21_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf16ss_31_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf16ss_30_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf16ss_10_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf16ss_20_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf16ss_11_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf16ss_00_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf16ss_00_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf16ss_33_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf16ss_22_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf16ss_32_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf16ss_21_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf16ss_31_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf16ss_30_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf16ss_10_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf16ss_20_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf16ss_11_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf16ss_00_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf16ss_00_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf16ss_33_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf16ss_22_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf16ss_32_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf16ss_21_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf16ss_31_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf16ss_30_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf16ss_10_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf16ss_20_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf16ss_11_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf16ss_00_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf16ss_00_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd16ss_33_22_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd16ss_33_22_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd16ss_13_02_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd16ss_13_02_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd16ss_11_00_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd16ss_11_00_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssfd16ss_33_22_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssfd16ss_33_22_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssfd16ss_13_02_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssfd16ss_13_02_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssfd16ss_11_00_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssfd16ss_11_00_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd16ss_33_22_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd16ss_33_22_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd16ss_13_02_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd16ss_13_02_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd16ss_11_00_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd16ss_11_00_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssfd16ss_33_22_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssfd16ss_33_22_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssfd16ss_13_02_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssfd16ss_13_02_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssfd16ss_11_00_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssfd16ss_11_00_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf48q32sp16s_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf48q32sp16s_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf48q32sp16u_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf48q32sp16u_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulq32sp16s_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulq32sp16s_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulq32sp16u_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulq32sp16u_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf48q32sp16s_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf48q32sp16s_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf48q32sp16u_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf48q32sp16u_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaq32sp16s_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaq32sp16s_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaq32sp16u_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaq32sp16u_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf48q32sp16s_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf48q32sp16s_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf48q32sp16u_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf48q32sp16u_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsq32sp16s_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsq32sp16s_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsq32sp16u_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsq32sp16u_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfp24x2ra_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfp24x2r_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulp24x2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfp24x2ra_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfp24x2r_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulp24x2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafp24x2ra_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafp24x2r_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulap24x2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafp24x2ra_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafp24x2r_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulap24x2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfp24x2ra_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfp24x2r_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsp24x2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfp24x2ra_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfp24x2r_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsp24x2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd24_hh_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaad24_hh_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd24_hh_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaad24_hh_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd24_hl_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaad24_hl_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd24_hl_lh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaad24_hl_lh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzasfd24_hh_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzasd24_hh_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzasfd24_hh_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzasd24_hh_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzasfd24_hl_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzasd24_hl_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzasfd24_hl_lh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzasd24_hl_lh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzsafd24_hh_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzsad24_hh_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzsafd24_hh_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzsad24_hh_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssfd24_hh_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssd24_hh_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssfd24_hh_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssd24_hh_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssfd24_hl_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssd24_hl_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssfd24_hl_lh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssd24_hl_lh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd24_hh_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaad24_hh_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd24_hh_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaad24_hh_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd24_hl_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaad24_hl_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd24_hl_lh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaad24_hl_lh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulasfd24_hh_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulasd24_hh_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulasfd24_hh_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulasd24_hh_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulasfd24_hl_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulasd24_hl_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulasfd24_hl_lh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulasd24_hl_lh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsafd24_hh_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsad24_hh_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsafd24_hh_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsad24_hh_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssfd24_hh_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssd24_hh_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssfd24_hh_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssd24_hh_ll_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssfd24_hl_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssd24_hl_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssfd24_hl_lh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssd24_hl_lh_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsrfq32sp24s_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsrfq32sp24s_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsrfq32sp24s_h_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsrfq32sp24s_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mularfq32sp24s_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mularfq32sp24s_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mularfq32sp24s_h_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mularfq32sp24s_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulrfq32sp24s_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulrfq32sp24s_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulrfq32sp24s_h_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulrfq32sp24s_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfq32sp24s_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfq32sp24s_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfq32sp24s_h_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfq32sp24s_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafq32sp24s_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafq32sp24s_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafq32sp24s_h_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafq32sp24s_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfq32sp24s_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfq32sp24s_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfq32sp24s_h_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfq32sp24s_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32x16_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32x16_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32x16_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32x16_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32x16_l1_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32x16_l1_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32x16_l1_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32x16_l1_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32x16_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32x16_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32x16_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32x16_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32x16_l3_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32x16_l3_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32x16_l3_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32x16_l3_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32x16_h0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32x16_h0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32x16_h0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32x16_h0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32x16_h1_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32x16_h1_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32x16_h1_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32x16_h1_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32x16_h2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32x16_h2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32x16_h2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32x16_h2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32x16_h3_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32x16_h3_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf32x16_h3_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul32x16_h3_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32x16_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32x16_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32x16_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32x16_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32x16_l1_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32x16_l1_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32x16_l1_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32x16_l1_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32x16_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32x16_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32x16_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32x16_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32x16_l3_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32x16_l3_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32x16_l3_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32x16_l3_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32x16_h0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32x16_h0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32x16_h0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32x16_h0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32x16_h1_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32x16_h1_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32x16_h1_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32x16_h1_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32x16_h2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32x16_h2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32x16_h2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32x16_h2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32x16_h3_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32x16_h3_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf32x16_h3_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula32x16_h3_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32x16_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32x16_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32x16_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32x16_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32x16_l1_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32x16_l1_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32x16_l1_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32x16_l1_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32x16_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32x16_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32x16_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32x16_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32x16_l3_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32x16_l3_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32x16_l3_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32x16_l3_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32x16_h0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32x16_h0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32x16_h0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32x16_h0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32x16_h1_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32x16_h1_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32x16_h1_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32x16_h1_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32x16_h2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32x16_h2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32x16_h2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32x16_h2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32x16_h3_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32x16_h3_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf32x16_h3_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls32x16_h3_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd32x16_h3_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaad32x16_h3_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd32x16_h3_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaad32x16_h3_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd32x16_h1_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaad32x16_h1_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd32x16_h1_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaad32x16_h1_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulasfd32x16_h3_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulasd32x16_h3_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulasfd32x16_h3_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulasd32x16_h3_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulasfd32x16_h1_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulasd32x16_h1_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulasfd32x16_h1_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulasd32x16_h1_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsafd32x16_h3_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsad32x16_h3_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsafd32x16_h3_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsad32x16_h3_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsafd32x16_h1_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsad32x16_h1_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsafd32x16_h1_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsad32x16_h1_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssfd32x16_h3_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssd32x16_h3_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssfd32x16_h3_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssd32x16_h3_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssfd32x16_h1_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssd32x16_h1_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssfd32x16_h1_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulssd32x16_h1_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd32x16_h3_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaad32x16_h3_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd32x16_h3_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaad32x16_h3_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd32x16_h1_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaad32x16_h1_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd32x16_h1_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaad32x16_h1_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzasfd32x16_h3_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzasd32x16_h3_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzasfd32x16_h3_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzasd32x16_h3_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzasfd32x16_h1_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzasd32x16_h1_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzasfd32x16_h1_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzasd32x16_h1_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzsafd32x16_h3_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzsad32x16_h3_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzsafd32x16_h3_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzsad32x16_h3_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzsafd32x16_h1_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzsad32x16_h1_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzsafd32x16_h1_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzsad32x16_h1_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssfd32x16_h3_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssd32x16_h3_l2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssfd32x16_h3_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssd32x16_h3_l2_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssfd32x16_h1_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssd32x16_h1_l0_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssfd32x16_h1_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzssd32x16_h1_l0_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd32x16_h2_l3_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd32x16_h0_l1_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd32x16_h2_l3_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd32x16_h0_l1_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaad32x16_h2_l3_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaad32x16_h0_l1_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaad32x16_h2_l3_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaad32x16_h0_l1_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd32x16_h2_l3_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaafd32x16_h0_l1_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd32x16_h2_l3_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaafd32x16_h0_l1_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaad32x16_h2_l3_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulzaad32x16_h0_l1_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaad32x16_h2_l3_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaad32x16_h0_l1_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulp32x16x2_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfp32x16x2rs_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfp32x16x2ras_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfp32x16x2rs_h_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfp32x16x2ras_h_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulp32x16x2_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfp32x16x2rs_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfp32x16x2ras_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfp32x16x2rs_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfp32x16x2ras_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulap32x16x2_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafp32x16x2rs_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafp32x16x2ras_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafp32x16x2rs_h_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafp32x16x2ras_h_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulap32x16x2_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafp32x16x2rs_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafp32x16x2ras_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafp32x16x2rs_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafp32x16x2ras_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsp32x16x2_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfp32x16x2rs_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfp32x16x2ras_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfp32x16x2rs_h_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfp32x16x2ras_h_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsp32x16x2_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfp32x16x2rs_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfp32x16x2ras_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfp32x16x2rs_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfp32x16x2ras_l_s2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulp32x2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfp32x2rs_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfp32x2ras_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulap32x2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafp32x2rs_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafp32x2ras_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsp32x2_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfp32x2rs_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsfp32x2ras_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfp16x4s_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfp16x4ras_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulc24_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfc24ra_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulc32x16_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfc32x16ras_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulc32x16_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfc32x16ras_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulac24_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafc24ra_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulac32x16_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafc32x16ras_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulac32x16_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafc32x16ras_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulf16x4ss_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulaf16x4ss_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulsf16x4ss_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mul16x4_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mula16x4_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_muls16x4_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfd24x2_fir_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfd24x2_fir_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfd32x16x2_fir_hh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfd32x16x2_fir_hl_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfd32x16x2_fir_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulfd32x16x2_fir_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafd24x2_fir_h_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafd24x2_fir_l_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafd32x16x2_fir_hh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafd32x16x2_fir_hl_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafd32x16x2_fir_lh_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_mulafd32x16x2_fir_ll_funcUnit_uses[] = {
  { FUNCUNIT_ae_mulpp33x24_1, 3 },
  { FUNCUNIT_ae_mulpp33x24_2, 3 }
};

static xtensa_funcUnit_use Opcode_ae_vldl32t_funcUnit_uses[] = {
  { FUNCUNIT_ae_add32x27, 4 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_vldl16t_funcUnit_uses[] = {
  { FUNCUNIT_ae_add32x27, 4 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_vldl16c_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_shift32x5, 4 },
  { FUNCUNIT_ae_add32x27, 4 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_vldl16c_ip_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_shift32x5, 4 },
  { FUNCUNIT_ae_add32x27, 4 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_vldl16c_ic_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_shift32x5, 4 },
  { FUNCUNIT_ae_add32x27, 4 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_vldsht_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_shift32x5, 4 },
  { FUNCUNIT_ae_add32x27, 4 }
};

static xtensa_funcUnit_use Opcode_ae_lb_funcUnit_uses[] = {
  { FUNCUNIT_ae_leftshift32x5, 3 }
};

static xtensa_funcUnit_use Opcode_ae_lbi_funcUnit_uses[] = {
  { FUNCUNIT_ae_leftshift32x5, 3 }
};

static xtensa_funcUnit_use Opcode_ae_lbk_funcUnit_uses[] = {
  { FUNCUNIT_ae_leftshift32x5, 3 }
};

static xtensa_funcUnit_use Opcode_ae_lbki_funcUnit_uses[] = {
  { FUNCUNIT_ae_leftshift32x5, 3 }
};

static xtensa_funcUnit_use Opcode_ae_lbs_funcUnit_uses[] = {
  { FUNCUNIT_ae_leftshift32x5, 3 }
};

static xtensa_funcUnit_use Opcode_ae_lbsi_funcUnit_uses[] = {
  { FUNCUNIT_ae_leftshift32x5, 3 }
};

static xtensa_funcUnit_use Opcode_ae_db_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_dbi_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_db_ic_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_dbi_ic_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_db_ip_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_dbi_ip_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_vlel32t_funcUnit_uses[] = {
  { FUNCUNIT_ae_add32x27, 4 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_vlel16t_funcUnit_uses[] = {
  { FUNCUNIT_ae_add32x27, 4 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sb_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sbi_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_vles16c_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sbf_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sb_ic_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sbi_ic_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_vles16c_ic_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sbf_ic_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sb_ip_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sbi_ip_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_vles16c_ip_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ae_sbf_ip_funcUnit_uses[] = {
  { FUNCUNIT_ae_shift32x4, 3 },
  { FUNCUNIT_ae_leftshift32x5, 3 },
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_lsi_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_lsip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_lsx_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_lsxp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ssi_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ssip_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ssx_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_funcUnit_use Opcode_ssxp_funcUnit_uses[] = {
  { FUNCUNIT_XT_LOADSTORE_UNIT, 0 }
};

static xtensa_opcode_internal opcodes[] = {
  { "excw", ICLASS_xt_iclass_excw,
    0,
    Opcode_excw_encode_fns, 0, 0 },
  { "rfe", ICLASS_xt_iclass_rfe,
    XTENSA_OPCODE_IS_JUMP,
    Opcode_rfe_encode_fns, 0, 0 },
  { "rfde", ICLASS_xt_iclass_rfde,
    XTENSA_OPCODE_IS_JUMP,
    Opcode_rfde_encode_fns, 0, 0 },
  { "syscall", ICLASS_xt_iclass_syscall,
    0,
    Opcode_syscall_encode_fns, 0, 0 },
  { "call12", ICLASS_xt_iclass_call12,
    XTENSA_OPCODE_IS_CALL,
    Opcode_call12_encode_fns, 0, 0 },
  { "call8", ICLASS_xt_iclass_call8,
    XTENSA_OPCODE_IS_CALL,
    Opcode_call8_encode_fns, 0, 0 },
  { "call4", ICLASS_xt_iclass_call4,
    XTENSA_OPCODE_IS_CALL,
    Opcode_call4_encode_fns, 0, 0 },
  { "callx12", ICLASS_xt_iclass_callx12,
    XTENSA_OPCODE_IS_CALL,
    Opcode_callx12_encode_fns, 0, 0 },
  { "callx8", ICLASS_xt_iclass_callx8,
    XTENSA_OPCODE_IS_CALL,
    Opcode_callx8_encode_fns, 0, 0 },
  { "callx4", ICLASS_xt_iclass_callx4,
    XTENSA_OPCODE_IS_CALL,
    Opcode_callx4_encode_fns, 0, 0 },
  { "entry", ICLASS_xt_iclass_entry,
    0,
    Opcode_entry_encode_fns, 0, 0 },
  { "movsp", ICLASS_xt_iclass_movsp,
    0,
    Opcode_movsp_encode_fns, 0, 0 },
  { "rotw", ICLASS_xt_iclass_rotw,
    0,
    Opcode_rotw_encode_fns, 0, 0 },
  { "retw", ICLASS_xt_iclass_retw,
    XTENSA_OPCODE_IS_JUMP,
    Opcode_retw_encode_fns, 0, 0 },
  { "retw.n", ICLASS_xt_iclass_retw,
    XTENSA_OPCODE_IS_JUMP,
    Opcode_retw_n_encode_fns, 0, 0 },
  { "rfwo", ICLASS_xt_iclass_rfwou,
    XTENSA_OPCODE_IS_JUMP,
    Opcode_rfwo_encode_fns, 0, 0 },
  { "rfwu", ICLASS_xt_iclass_rfwou,
    XTENSA_OPCODE_IS_JUMP,
    Opcode_rfwu_encode_fns, 0, 0 },
  { "l32e", ICLASS_xt_iclass_l32e,
    0,
    Opcode_l32e_encode_fns, 1, Opcode_l32e_funcUnit_uses },
  { "s32e", ICLASS_xt_iclass_s32e,
    0,
    Opcode_s32e_encode_fns, 1, Opcode_s32e_funcUnit_uses },
  { "rsr.windowbase", ICLASS_xt_iclass_rsr_windowbase,
    0,
    Opcode_rsr_windowbase_encode_fns, 0, 0 },
  { "wsr.windowbase", ICLASS_xt_iclass_wsr_windowbase,
    0,
    Opcode_wsr_windowbase_encode_fns, 0, 0 },
  { "xsr.windowbase", ICLASS_xt_iclass_xsr_windowbase,
    0,
    Opcode_xsr_windowbase_encode_fns, 0, 0 },
  { "rsr.windowstart", ICLASS_xt_iclass_rsr_windowstart,
    0,
    Opcode_rsr_windowstart_encode_fns, 0, 0 },
  { "wsr.windowstart", ICLASS_xt_iclass_wsr_windowstart,
    0,
    Opcode_wsr_windowstart_encode_fns, 0, 0 },
  { "xsr.windowstart", ICLASS_xt_iclass_xsr_windowstart,
    0,
    Opcode_xsr_windowstart_encode_fns, 0, 0 },
  { "rfme", ICLASS_xt_iclass_rfme,
    XTENSA_OPCODE_IS_JUMP,
    Opcode_rfme_encode_fns, 0, 0 },
  { "rsr.mesr", ICLASS_xt_iclass_rsr_mesr,
    0,
    Opcode_rsr_mesr_encode_fns, 0, 0 },
  { "wsr.mesr", ICLASS_xt_iclass_wsr_mesr,
    0,
    Opcode_wsr_mesr_encode_fns, 0, 0 },
  { "xsr.mesr", ICLASS_xt_iclass_xsr_mesr,
    0,
    Opcode_xsr_mesr_encode_fns, 0, 0 },
  { "rsr.mecr", ICLASS_xt_iclass_rsr_mecr,
    0,
    Opcode_rsr_mecr_encode_fns, 0, 0 },
  { "wsr.mecr", ICLASS_xt_iclass_wsr_mecr,
    0,
    Opcode_wsr_mecr_encode_fns, 0, 0 },
  { "xsr.mecr", ICLASS_xt_iclass_xsr_mecr,
    0,
    Opcode_xsr_mecr_encode_fns, 0, 0 },
  { "rsr.mepc", ICLASS_xt_iclass_rsr_mepc,
    0,
    Opcode_rsr_mepc_encode_fns, 0, 0 },
  { "wsr.mepc", ICLASS_xt_iclass_wsr_mepc,
    0,
    Opcode_wsr_mepc_encode_fns, 0, 0 },
  { "xsr.mepc", ICLASS_xt_iclass_xsr_mepc,
    0,
    Opcode_xsr_mepc_encode_fns, 0, 0 },
  { "rsr.meps", ICLASS_xt_iclass_rsr_meps,
    0,
    Opcode_rsr_meps_encode_fns, 0, 0 },
  { "wsr.meps", ICLASS_xt_iclass_wsr_meps,
    0,
    Opcode_wsr_meps_encode_fns, 0, 0 },
  { "xsr.meps", ICLASS_xt_iclass_xsr_meps,
    0,
    Opcode_xsr_meps_encode_fns, 0, 0 },
  { "rsr.mesave", ICLASS_xt_iclass_rsr_mesave,
    0,
    Opcode_rsr_mesave_encode_fns, 0, 0 },
  { "wsr.mesave", ICLASS_xt_iclass_wsr_mesave,
    0,
    Opcode_wsr_mesave_encode_fns, 0, 0 },
  { "xsr.mesave", ICLASS_xt_iclass_xsr_mesave,
    0,
    Opcode_xsr_mesave_encode_fns, 0, 0 },
  { "rsr.mevaddr", ICLASS_xt_iclass_rsr_mevaddr,
    0,
    Opcode_rsr_mevaddr_encode_fns, 0, 0 },
  { "wsr.mevaddr", ICLASS_xt_iclass_wsr_mevaddr,
    0,
    Opcode_wsr_mevaddr_encode_fns, 0, 0 },
  { "xsr.mevaddr", ICLASS_xt_iclass_xsr_mevaddr,
    0,
    Opcode_xsr_mevaddr_encode_fns, 0, 0 },
  { "add.n", ICLASS_xt_iclass_add_n,
    0,
    Opcode_add_n_encode_fns, 0, 0 },
  { "addi.n", ICLASS_xt_iclass_addi_n,
    0,
    Opcode_addi_n_encode_fns, 0, 0 },
  { "beqz.n", ICLASS_xt_iclass_bz6,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_beqz_n_encode_fns, 0, 0 },
  { "bnez.n", ICLASS_xt_iclass_bz6,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bnez_n_encode_fns, 0, 0 },
  { "ill.n", ICLASS_xt_iclass_ill_n,
    0,
    Opcode_ill_n_encode_fns, 0, 0 },
  { "l32i.n", ICLASS_xt_iclass_loadi4,
    0,
    Opcode_l32i_n_encode_fns, 1, Opcode_l32i_n_funcUnit_uses },
  { "mov.n", ICLASS_xt_iclass_mov_n,
    0,
    Opcode_mov_n_encode_fns, 0, 0 },
  { "movi.n", ICLASS_xt_iclass_movi_n,
    0,
    Opcode_movi_n_encode_fns, 0, 0 },
  { "nop.n", ICLASS_xt_iclass_nopn,
    0,
    Opcode_nop_n_encode_fns, 0, 0 },
  { "ret.n", ICLASS_xt_iclass_retn,
    XTENSA_OPCODE_IS_JUMP,
    Opcode_ret_n_encode_fns, 0, 0 },
  { "s32i.n", ICLASS_xt_iclass_storei4,
    0,
    Opcode_s32i_n_encode_fns, 1, Opcode_s32i_n_funcUnit_uses },
  { "rur.threadptr", ICLASS_rur_threadptr,
    0,
    Opcode_rur_threadptr_encode_fns, 0, 0 },
  { "wur.threadptr", ICLASS_wur_threadptr,
    0,
    Opcode_wur_threadptr_encode_fns, 0, 0 },
  { "addi", ICLASS_xt_iclass_addi,
    0,
    Opcode_addi_encode_fns, 0, 0 },
  { "addmi", ICLASS_xt_iclass_addmi,
    0,
    Opcode_addmi_encode_fns, 0, 0 },
  { "add", ICLASS_xt_iclass_addsub,
    0,
    Opcode_add_encode_fns, 0, 0 },
  { "addx2", ICLASS_xt_iclass_addsub,
    0,
    Opcode_addx2_encode_fns, 0, 0 },
  { "addx4", ICLASS_xt_iclass_addsub,
    0,
    Opcode_addx4_encode_fns, 0, 0 },
  { "addx8", ICLASS_xt_iclass_addsub,
    0,
    Opcode_addx8_encode_fns, 0, 0 },
  { "sub", ICLASS_xt_iclass_addsub,
    0,
    Opcode_sub_encode_fns, 0, 0 },
  { "subx2", ICLASS_xt_iclass_addsub,
    0,
    Opcode_subx2_encode_fns, 0, 0 },
  { "subx4", ICLASS_xt_iclass_addsub,
    0,
    Opcode_subx4_encode_fns, 0, 0 },
  { "subx8", ICLASS_xt_iclass_addsub,
    0,
    Opcode_subx8_encode_fns, 0, 0 },
  { "and", ICLASS_xt_iclass_bit,
    0,
    Opcode_and_encode_fns, 0, 0 },
  { "or", ICLASS_xt_iclass_bit,
    0,
    Opcode_or_encode_fns, 0, 0 },
  { "xor", ICLASS_xt_iclass_bit,
    0,
    Opcode_xor_encode_fns, 0, 0 },
  { "beqi", ICLASS_xt_iclass_bsi8,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_beqi_encode_fns, 0, 0 },
  { "bgei", ICLASS_xt_iclass_bsi8,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bgei_encode_fns, 0, 0 },
  { "blti", ICLASS_xt_iclass_bsi8,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_blti_encode_fns, 0, 0 },
  { "bnei", ICLASS_xt_iclass_bsi8,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bnei_encode_fns, 0, 0 },
  { "bbci", ICLASS_xt_iclass_bsi8b,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bbci_encode_fns, 0, 0 },
  { "bbsi", ICLASS_xt_iclass_bsi8b,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bbsi_encode_fns, 0, 0 },
  { "bgeui", ICLASS_xt_iclass_bsi8u,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bgeui_encode_fns, 0, 0 },
  { "bltui", ICLASS_xt_iclass_bsi8u,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bltui_encode_fns, 0, 0 },
  { "ball", ICLASS_xt_iclass_bst8,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_ball_encode_fns, 0, 0 },
  { "bany", ICLASS_xt_iclass_bst8,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bany_encode_fns, 0, 0 },
  { "bbc", ICLASS_xt_iclass_bst8,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bbc_encode_fns, 0, 0 },
  { "bbs", ICLASS_xt_iclass_bst8,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bbs_encode_fns, 0, 0 },
  { "beq", ICLASS_xt_iclass_bst8,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_beq_encode_fns, 0, 0 },
  { "bge", ICLASS_xt_iclass_bst8,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bge_encode_fns, 0, 0 },
  { "bgeu", ICLASS_xt_iclass_bst8,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bgeu_encode_fns, 0, 0 },
  { "blt", ICLASS_xt_iclass_bst8,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_blt_encode_fns, 0, 0 },
  { "bltu", ICLASS_xt_iclass_bst8,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bltu_encode_fns, 0, 0 },
  { "bnall", ICLASS_xt_iclass_bst8,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bnall_encode_fns, 0, 0 },
  { "bne", ICLASS_xt_iclass_bst8,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bne_encode_fns, 0, 0 },
  { "bnone", ICLASS_xt_iclass_bst8,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bnone_encode_fns, 0, 0 },
  { "beqz", ICLASS_xt_iclass_bsz12,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_beqz_encode_fns, 0, 0 },
  { "bgez", ICLASS_xt_iclass_bsz12,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bgez_encode_fns, 0, 0 },
  { "bltz", ICLASS_xt_iclass_bsz12,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bltz_encode_fns, 0, 0 },
  { "bnez", ICLASS_xt_iclass_bsz12,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bnez_encode_fns, 0, 0 },
  { "call0", ICLASS_xt_iclass_call0,
    XTENSA_OPCODE_IS_CALL,
    Opcode_call0_encode_fns, 0, 0 },
  { "callx0", ICLASS_xt_iclass_callx0,
    XTENSA_OPCODE_IS_CALL,
    Opcode_callx0_encode_fns, 0, 0 },
  { "extui", ICLASS_xt_iclass_exti,
    0,
    Opcode_extui_encode_fns, 0, 0 },
  { "ill", ICLASS_xt_iclass_ill,
    0,
    Opcode_ill_encode_fns, 0, 0 },
  { "j", ICLASS_xt_iclass_jump,
    XTENSA_OPCODE_IS_JUMP,
    Opcode_j_encode_fns, 0, 0 },
  { "jx", ICLASS_xt_iclass_jumpx,
    XTENSA_OPCODE_IS_JUMP,
    Opcode_jx_encode_fns, 0, 0 },
  { "l16ui", ICLASS_xt_iclass_l16ui,
    0,
    Opcode_l16ui_encode_fns, 1, Opcode_l16ui_funcUnit_uses },
  { "l16si", ICLASS_xt_iclass_l16si,
    0,
    Opcode_l16si_encode_fns, 1, Opcode_l16si_funcUnit_uses },
  { "l32i", ICLASS_xt_iclass_l32i,
    0,
    Opcode_l32i_encode_fns, 1, Opcode_l32i_funcUnit_uses },
  { "l32r", ICLASS_xt_iclass_l32r,
    0,
    Opcode_l32r_encode_fns, 1, Opcode_l32r_funcUnit_uses },
  { "l8ui", ICLASS_xt_iclass_l8i,
    0,
    Opcode_l8ui_encode_fns, 1, Opcode_l8ui_funcUnit_uses },
  { "loop", ICLASS_xt_iclass_loop,
    XTENSA_OPCODE_IS_LOOP,
    Opcode_loop_encode_fns, 0, 0 },
  { "loopgtz", ICLASS_xt_iclass_loopz,
    XTENSA_OPCODE_IS_LOOP,
    Opcode_loopgtz_encode_fns, 0, 0 },
  { "loopnez", ICLASS_xt_iclass_loopz,
    XTENSA_OPCODE_IS_LOOP,
    Opcode_loopnez_encode_fns, 0, 0 },
  { "movi", ICLASS_xt_iclass_movi,
    0,
    Opcode_movi_encode_fns, 0, 0 },
  { "moveqz", ICLASS_xt_iclass_movz,
    0,
    Opcode_moveqz_encode_fns, 0, 0 },
  { "movgez", ICLASS_xt_iclass_movz,
    0,
    Opcode_movgez_encode_fns, 0, 0 },
  { "movltz", ICLASS_xt_iclass_movz,
    0,
    Opcode_movltz_encode_fns, 0, 0 },
  { "movnez", ICLASS_xt_iclass_movz,
    0,
    Opcode_movnez_encode_fns, 0, 0 },
  { "abs", ICLASS_xt_iclass_neg,
    0,
    Opcode_abs_encode_fns, 0, 0 },
  { "neg", ICLASS_xt_iclass_neg,
    0,
    Opcode_neg_encode_fns, 0, 0 },
  { "nop", ICLASS_xt_iclass_nop,
    0,
    Opcode_nop_encode_fns, 0, 0 },
  { "ret", ICLASS_xt_iclass_return,
    XTENSA_OPCODE_IS_JUMP,
    Opcode_ret_encode_fns, 0, 0 },
  { "simcall", ICLASS_xt_iclass_simcall,
    0,
    Opcode_simcall_encode_fns, 0, 0 },
  { "s16i", ICLASS_xt_iclass_s16i,
    0,
    Opcode_s16i_encode_fns, 1, Opcode_s16i_funcUnit_uses },
  { "s32i", ICLASS_xt_iclass_s32i,
    0,
    Opcode_s32i_encode_fns, 1, Opcode_s32i_funcUnit_uses },
  { "s32nb", ICLASS_xt_iclass_s32nb,
    0,
    Opcode_s32nb_encode_fns, 1, Opcode_s32nb_funcUnit_uses },
  { "s8i", ICLASS_xt_iclass_s8i,
    0,
    Opcode_s8i_encode_fns, 1, Opcode_s8i_funcUnit_uses },
  { "ssa8b", ICLASS_xt_iclass_sar,
    0,
    Opcode_ssa8b_encode_fns, 0, 0 },
  { "ssa8l", ICLASS_xt_iclass_sar,
    0,
    Opcode_ssa8l_encode_fns, 0, 0 },
  { "ssl", ICLASS_xt_iclass_sar,
    0,
    Opcode_ssl_encode_fns, 0, 0 },
  { "ssr", ICLASS_xt_iclass_sar,
    0,
    Opcode_ssr_encode_fns, 0, 0 },
  { "ssai", ICLASS_xt_iclass_sari,
    0,
    Opcode_ssai_encode_fns, 0, 0 },
  { "sll", ICLASS_xt_iclass_shifts,
    0,
    Opcode_sll_encode_fns, 0, 0 },
  { "src", ICLASS_xt_iclass_shiftst,
    0,
    Opcode_src_encode_fns, 0, 0 },
  { "sra", ICLASS_xt_iclass_shiftt,
    0,
    Opcode_sra_encode_fns, 0, 0 },
  { "srl", ICLASS_xt_iclass_shiftt,
    0,
    Opcode_srl_encode_fns, 0, 0 },
  { "slli", ICLASS_xt_iclass_slli,
    0,
    Opcode_slli_encode_fns, 0, 0 },
  { "srai", ICLASS_xt_iclass_srai,
    0,
    Opcode_srai_encode_fns, 0, 0 },
  { "srli", ICLASS_xt_iclass_srli,
    0,
    Opcode_srli_encode_fns, 0, 0 },
  { "memw", ICLASS_xt_iclass_memw,
    0,
    Opcode_memw_encode_fns, 0, 0 },
  { "extw", ICLASS_xt_iclass_extw,
    0,
    Opcode_extw_encode_fns, 0, 0 },
  { "isync", ICLASS_xt_iclass_isync,
    0,
    Opcode_isync_encode_fns, 0, 0 },
  { "dsync", ICLASS_xt_iclass_sync,
    0,
    Opcode_dsync_encode_fns, 0, 0 },
  { "esync", ICLASS_xt_iclass_sync,
    0,
    Opcode_esync_encode_fns, 0, 0 },
  { "rsync", ICLASS_xt_iclass_sync,
    0,
    Opcode_rsync_encode_fns, 0, 0 },
  { "rsil", ICLASS_xt_iclass_rsil,
    0,
    Opcode_rsil_encode_fns, 0, 0 },
  { "rsr.lend", ICLASS_xt_iclass_rsr_lend,
    0,
    Opcode_rsr_lend_encode_fns, 0, 0 },
  { "wsr.lend", ICLASS_xt_iclass_wsr_lend,
    0,
    Opcode_wsr_lend_encode_fns, 0, 0 },
  { "xsr.lend", ICLASS_xt_iclass_xsr_lend,
    0,
    Opcode_xsr_lend_encode_fns, 0, 0 },
  { "rsr.lcount", ICLASS_xt_iclass_rsr_lcount,
    0,
    Opcode_rsr_lcount_encode_fns, 0, 0 },
  { "wsr.lcount", ICLASS_xt_iclass_wsr_lcount,
    0,
    Opcode_wsr_lcount_encode_fns, 0, 0 },
  { "xsr.lcount", ICLASS_xt_iclass_xsr_lcount,
    0,
    Opcode_xsr_lcount_encode_fns, 0, 0 },
  { "rsr.lbeg", ICLASS_xt_iclass_rsr_lbeg,
    0,
    Opcode_rsr_lbeg_encode_fns, 0, 0 },
  { "wsr.lbeg", ICLASS_xt_iclass_wsr_lbeg,
    0,
    Opcode_wsr_lbeg_encode_fns, 0, 0 },
  { "xsr.lbeg", ICLASS_xt_iclass_xsr_lbeg,
    0,
    Opcode_xsr_lbeg_encode_fns, 0, 0 },
  { "rsr.sar", ICLASS_xt_iclass_rsr_sar,
    0,
    Opcode_rsr_sar_encode_fns, 0, 0 },
  { "wsr.sar", ICLASS_xt_iclass_wsr_sar,
    0,
    Opcode_wsr_sar_encode_fns, 0, 0 },
  { "xsr.sar", ICLASS_xt_iclass_xsr_sar,
    0,
    Opcode_xsr_sar_encode_fns, 0, 0 },
  { "rsr.memctl", ICLASS_xt_iclass_rsr_memctl,
    0,
    Opcode_rsr_memctl_encode_fns, 0, 0 },
  { "wsr.memctl", ICLASS_xt_iclass_wsr_memctl,
    0,
    Opcode_wsr_memctl_encode_fns, 0, 0 },
  { "xsr.memctl", ICLASS_xt_iclass_xsr_memctl,
    0,
    Opcode_xsr_memctl_encode_fns, 0, 0 },
  { "rsr.litbase", ICLASS_xt_iclass_rsr_litbase,
    0,
    Opcode_rsr_litbase_encode_fns, 0, 0 },
  { "wsr.litbase", ICLASS_xt_iclass_wsr_litbase,
    0,
    Opcode_wsr_litbase_encode_fns, 0, 0 },
  { "xsr.litbase", ICLASS_xt_iclass_xsr_litbase,
    0,
    Opcode_xsr_litbase_encode_fns, 0, 0 },
  { "rsr.configid0", ICLASS_xt_iclass_rsr_configid0,
    0,
    Opcode_rsr_configid0_encode_fns, 0, 0 },
  { "wsr.configid0", ICLASS_xt_iclass_wsr_configid0,
    0,
    Opcode_wsr_configid0_encode_fns, 0, 0 },
  { "rsr.configid1", ICLASS_xt_iclass_rsr_configid1,
    0,
    Opcode_rsr_configid1_encode_fns, 0, 0 },
  { "rsr.243", ICLASS_xt_iclass_rsr_243,
    0,
    Opcode_rsr_243_encode_fns, 0, 0 },
  { "rsr.ps", ICLASS_xt_iclass_rsr_ps,
    0,
    Opcode_rsr_ps_encode_fns, 0, 0 },
  { "wsr.ps", ICLASS_xt_iclass_wsr_ps,
    0,
    Opcode_wsr_ps_encode_fns, 0, 0 },
  { "xsr.ps", ICLASS_xt_iclass_xsr_ps,
    0,
    Opcode_xsr_ps_encode_fns, 0, 0 },
  { "rsr.epc1", ICLASS_xt_iclass_rsr_epc1,
    0,
    Opcode_rsr_epc1_encode_fns, 0, 0 },
  { "wsr.epc1", ICLASS_xt_iclass_wsr_epc1,
    0,
    Opcode_wsr_epc1_encode_fns, 0, 0 },
  { "xsr.epc1", ICLASS_xt_iclass_xsr_epc1,
    0,
    Opcode_xsr_epc1_encode_fns, 0, 0 },
  { "rsr.excsave1", ICLASS_xt_iclass_rsr_excsave1,
    0,
    Opcode_rsr_excsave1_encode_fns, 0, 0 },
  { "wsr.excsave1", ICLASS_xt_iclass_wsr_excsave1,
    0,
    Opcode_wsr_excsave1_encode_fns, 0, 0 },
  { "xsr.excsave1", ICLASS_xt_iclass_xsr_excsave1,
    0,
    Opcode_xsr_excsave1_encode_fns, 0, 0 },
  { "rsr.epc2", ICLASS_xt_iclass_rsr_epc2,
    0,
    Opcode_rsr_epc2_encode_fns, 0, 0 },
  { "wsr.epc2", ICLASS_xt_iclass_wsr_epc2,
    0,
    Opcode_wsr_epc2_encode_fns, 0, 0 },
  { "xsr.epc2", ICLASS_xt_iclass_xsr_epc2,
    0,
    Opcode_xsr_epc2_encode_fns, 0, 0 },
  { "rsr.excsave2", ICLASS_xt_iclass_rsr_excsave2,
    0,
    Opcode_rsr_excsave2_encode_fns, 0, 0 },
  { "wsr.excsave2", ICLASS_xt_iclass_wsr_excsave2,
    0,
    Opcode_wsr_excsave2_encode_fns, 0, 0 },
  { "xsr.excsave2", ICLASS_xt_iclass_xsr_excsave2,
    0,
    Opcode_xsr_excsave2_encode_fns, 0, 0 },
  { "rsr.epc3", ICLASS_xt_iclass_rsr_epc3,
    0,
    Opcode_rsr_epc3_encode_fns, 0, 0 },
  { "wsr.epc3", ICLASS_xt_iclass_wsr_epc3,
    0,
    Opcode_wsr_epc3_encode_fns, 0, 0 },
  { "xsr.epc3", ICLASS_xt_iclass_xsr_epc3,
    0,
    Opcode_xsr_epc3_encode_fns, 0, 0 },
  { "rsr.excsave3", ICLASS_xt_iclass_rsr_excsave3,
    0,
    Opcode_rsr_excsave3_encode_fns, 0, 0 },
  { "wsr.excsave3", ICLASS_xt_iclass_wsr_excsave3,
    0,
    Opcode_wsr_excsave3_encode_fns, 0, 0 },
  { "xsr.excsave3", ICLASS_xt_iclass_xsr_excsave3,
    0,
    Opcode_xsr_excsave3_encode_fns, 0, 0 },
  { "rsr.epc4", ICLASS_xt_iclass_rsr_epc4,
    0,
    Opcode_rsr_epc4_encode_fns, 0, 0 },
  { "wsr.epc4", ICLASS_xt_iclass_wsr_epc4,
    0,
    Opcode_wsr_epc4_encode_fns, 0, 0 },
  { "xsr.epc4", ICLASS_xt_iclass_xsr_epc4,
    0,
    Opcode_xsr_epc4_encode_fns, 0, 0 },
  { "rsr.excsave4", ICLASS_xt_iclass_rsr_excsave4,
    0,
    Opcode_rsr_excsave4_encode_fns, 0, 0 },
  { "wsr.excsave4", ICLASS_xt_iclass_wsr_excsave4,
    0,
    Opcode_wsr_excsave4_encode_fns, 0, 0 },
  { "xsr.excsave4", ICLASS_xt_iclass_xsr_excsave4,
    0,
    Opcode_xsr_excsave4_encode_fns, 0, 0 },
  { "rsr.epc5", ICLASS_xt_iclass_rsr_epc5,
    0,
    Opcode_rsr_epc5_encode_fns, 0, 0 },
  { "wsr.epc5", ICLASS_xt_iclass_wsr_epc5,
    0,
    Opcode_wsr_epc5_encode_fns, 0, 0 },
  { "xsr.epc5", ICLASS_xt_iclass_xsr_epc5,
    0,
    Opcode_xsr_epc5_encode_fns, 0, 0 },
  { "rsr.excsave5", ICLASS_xt_iclass_rsr_excsave5,
    0,
    Opcode_rsr_excsave5_encode_fns, 0, 0 },
  { "wsr.excsave5", ICLASS_xt_iclass_wsr_excsave5,
    0,
    Opcode_wsr_excsave5_encode_fns, 0, 0 },
  { "xsr.excsave5", ICLASS_xt_iclass_xsr_excsave5,
    0,
    Opcode_xsr_excsave5_encode_fns, 0, 0 },
  { "rsr.epc6", ICLASS_xt_iclass_rsr_epc6,
    0,
    Opcode_rsr_epc6_encode_fns, 0, 0 },
  { "wsr.epc6", ICLASS_xt_iclass_wsr_epc6,
    0,
    Opcode_wsr_epc6_encode_fns, 0, 0 },
  { "xsr.epc6", ICLASS_xt_iclass_xsr_epc6,
    0,
    Opcode_xsr_epc6_encode_fns, 0, 0 },
  { "rsr.excsave6", ICLASS_xt_iclass_rsr_excsave6,
    0,
    Opcode_rsr_excsave6_encode_fns, 0, 0 },
  { "wsr.excsave6", ICLASS_xt_iclass_wsr_excsave6,
    0,
    Opcode_wsr_excsave6_encode_fns, 0, 0 },
  { "xsr.excsave6", ICLASS_xt_iclass_xsr_excsave6,
    0,
    Opcode_xsr_excsave6_encode_fns, 0, 0 },
  { "rsr.epc7", ICLASS_xt_iclass_rsr_epc7,
    0,
    Opcode_rsr_epc7_encode_fns, 0, 0 },
  { "wsr.epc7", ICLASS_xt_iclass_wsr_epc7,
    0,
    Opcode_wsr_epc7_encode_fns, 0, 0 },
  { "xsr.epc7", ICLASS_xt_iclass_xsr_epc7,
    0,
    Opcode_xsr_epc7_encode_fns, 0, 0 },
  { "rsr.excsave7", ICLASS_xt_iclass_rsr_excsave7,
    0,
    Opcode_rsr_excsave7_encode_fns, 0, 0 },
  { "wsr.excsave7", ICLASS_xt_iclass_wsr_excsave7,
    0,
    Opcode_wsr_excsave7_encode_fns, 0, 0 },
  { "xsr.excsave7", ICLASS_xt_iclass_xsr_excsave7,
    0,
    Opcode_xsr_excsave7_encode_fns, 0, 0 },
  { "rsr.eps2", ICLASS_xt_iclass_rsr_eps2,
    0,
    Opcode_rsr_eps2_encode_fns, 0, 0 },
  { "wsr.eps2", ICLASS_xt_iclass_wsr_eps2,
    0,
    Opcode_wsr_eps2_encode_fns, 0, 0 },
  { "xsr.eps2", ICLASS_xt_iclass_xsr_eps2,
    0,
    Opcode_xsr_eps2_encode_fns, 0, 0 },
  { "rsr.eps3", ICLASS_xt_iclass_rsr_eps3,
    0,
    Opcode_rsr_eps3_encode_fns, 0, 0 },
  { "wsr.eps3", ICLASS_xt_iclass_wsr_eps3,
    0,
    Opcode_wsr_eps3_encode_fns, 0, 0 },
  { "xsr.eps3", ICLASS_xt_iclass_xsr_eps3,
    0,
    Opcode_xsr_eps3_encode_fns, 0, 0 },
  { "rsr.eps4", ICLASS_xt_iclass_rsr_eps4,
    0,
    Opcode_rsr_eps4_encode_fns, 0, 0 },
  { "wsr.eps4", ICLASS_xt_iclass_wsr_eps4,
    0,
    Opcode_wsr_eps4_encode_fns, 0, 0 },
  { "xsr.eps4", ICLASS_xt_iclass_xsr_eps4,
    0,
    Opcode_xsr_eps4_encode_fns, 0, 0 },
  { "rsr.eps5", ICLASS_xt_iclass_rsr_eps5,
    0,
    Opcode_rsr_eps5_encode_fns, 0, 0 },
  { "wsr.eps5", ICLASS_xt_iclass_wsr_eps5,
    0,
    Opcode_wsr_eps5_encode_fns, 0, 0 },
  { "xsr.eps5", ICLASS_xt_iclass_xsr_eps5,
    0,
    Opcode_xsr_eps5_encode_fns, 0, 0 },
  { "rsr.eps6", ICLASS_xt_iclass_rsr_eps6,
    0,
    Opcode_rsr_eps6_encode_fns, 0, 0 },
  { "wsr.eps6", ICLASS_xt_iclass_wsr_eps6,
    0,
    Opcode_wsr_eps6_encode_fns, 0, 0 },
  { "xsr.eps6", ICLASS_xt_iclass_xsr_eps6,
    0,
    Opcode_xsr_eps6_encode_fns, 0, 0 },
  { "rsr.eps7", ICLASS_xt_iclass_rsr_eps7,
    0,
    Opcode_rsr_eps7_encode_fns, 0, 0 },
  { "wsr.eps7", ICLASS_xt_iclass_wsr_eps7,
    0,
    Opcode_wsr_eps7_encode_fns, 0, 0 },
  { "xsr.eps7", ICLASS_xt_iclass_xsr_eps7,
    0,
    Opcode_xsr_eps7_encode_fns, 0, 0 },
  { "rsr.excvaddr", ICLASS_xt_iclass_rsr_excvaddr,
    0,
    Opcode_rsr_excvaddr_encode_fns, 0, 0 },
  { "wsr.excvaddr", ICLASS_xt_iclass_wsr_excvaddr,
    0,
    Opcode_wsr_excvaddr_encode_fns, 0, 0 },
  { "xsr.excvaddr", ICLASS_xt_iclass_xsr_excvaddr,
    0,
    Opcode_xsr_excvaddr_encode_fns, 0, 0 },
  { "rsr.depc", ICLASS_xt_iclass_rsr_depc,
    0,
    Opcode_rsr_depc_encode_fns, 0, 0 },
  { "wsr.depc", ICLASS_xt_iclass_wsr_depc,
    0,
    Opcode_wsr_depc_encode_fns, 0, 0 },
  { "xsr.depc", ICLASS_xt_iclass_xsr_depc,
    0,
    Opcode_xsr_depc_encode_fns, 0, 0 },
  { "rsr.exccause", ICLASS_xt_iclass_rsr_exccause,
    0,
    Opcode_rsr_exccause_encode_fns, 0, 0 },
  { "wsr.exccause", ICLASS_xt_iclass_wsr_exccause,
    0,
    Opcode_wsr_exccause_encode_fns, 0, 0 },
  { "xsr.exccause", ICLASS_xt_iclass_xsr_exccause,
    0,
    Opcode_xsr_exccause_encode_fns, 0, 0 },
  { "rsr.prid", ICLASS_xt_iclass_rsr_prid,
    0,
    Opcode_rsr_prid_encode_fns, 0, 0 },
  { "rsr.vecbase", ICLASS_xt_iclass_rsr_vecbase,
    0,
    Opcode_rsr_vecbase_encode_fns, 0, 0 },
  { "wsr.vecbase", ICLASS_xt_iclass_wsr_vecbase,
    0,
    Opcode_wsr_vecbase_encode_fns, 0, 0 },
  { "xsr.vecbase", ICLASS_xt_iclass_xsr_vecbase,
    0,
    Opcode_xsr_vecbase_encode_fns, 0, 0 },
  { "mul16s", ICLASS_xt_mul16,
    0,
    Opcode_mul16s_encode_fns, 0, 0 },
  { "mul16u", ICLASS_xt_mul16,
    0,
    Opcode_mul16u_encode_fns, 0, 0 },
  { "mull", ICLASS_xt_mul32,
    0,
    Opcode_mull_encode_fns, 0, 0 },
  { "mulsh", ICLASS_xt_mul32h,
    0,
    Opcode_mulsh_encode_fns, 0, 0 },
  { "muluh", ICLASS_xt_mul32h,
    0,
    Opcode_muluh_encode_fns, 0, 0 },
  { "rfi", ICLASS_xt_iclass_rfi,
    XTENSA_OPCODE_IS_JUMP,
    Opcode_rfi_encode_fns, 0, 0 },
  { "waiti", ICLASS_xt_iclass_wait,
    0,
    Opcode_waiti_encode_fns, 0, 0 },
  { "rsr.interrupt", ICLASS_xt_iclass_rsr_interrupt,
    0,
    Opcode_rsr_interrupt_encode_fns, 0, 0 },
  { "wsr.intset", ICLASS_xt_iclass_wsr_intset,
    0,
    Opcode_wsr_intset_encode_fns, 0, 0 },
  { "wsr.intclear", ICLASS_xt_iclass_wsr_intclear,
    0,
    Opcode_wsr_intclear_encode_fns, 0, 0 },
  { "rsr.intenable", ICLASS_xt_iclass_rsr_intenable,
    0,
    Opcode_rsr_intenable_encode_fns, 0, 0 },
  { "wsr.intenable", ICLASS_xt_iclass_wsr_intenable,
    0,
    Opcode_wsr_intenable_encode_fns, 0, 0 },
  { "xsr.intenable", ICLASS_xt_iclass_xsr_intenable,
    0,
    Opcode_xsr_intenable_encode_fns, 0, 0 },
  { "break", ICLASS_xt_iclass_break,
    0,
    Opcode_break_encode_fns, 0, 0 },
  { "break.n", ICLASS_xt_iclass_break_n,
    0,
    Opcode_break_n_encode_fns, 0, 0 },
  { "rsr.dbreaka0", ICLASS_xt_iclass_rsr_dbreaka0,
    0,
    Opcode_rsr_dbreaka0_encode_fns, 0, 0 },
  { "wsr.dbreaka0", ICLASS_xt_iclass_wsr_dbreaka0,
    0,
    Opcode_wsr_dbreaka0_encode_fns, 0, 0 },
  { "xsr.dbreaka0", ICLASS_xt_iclass_xsr_dbreaka0,
    0,
    Opcode_xsr_dbreaka0_encode_fns, 0, 0 },
  { "rsr.dbreakc0", ICLASS_xt_iclass_rsr_dbreakc0,
    0,
    Opcode_rsr_dbreakc0_encode_fns, 0, 0 },
  { "wsr.dbreakc0", ICLASS_xt_iclass_wsr_dbreakc0,
    0,
    Opcode_wsr_dbreakc0_encode_fns, 0, 0 },
  { "xsr.dbreakc0", ICLASS_xt_iclass_xsr_dbreakc0,
    0,
    Opcode_xsr_dbreakc0_encode_fns, 0, 0 },
  { "rsr.dbreaka1", ICLASS_xt_iclass_rsr_dbreaka1,
    0,
    Opcode_rsr_dbreaka1_encode_fns, 0, 0 },
  { "wsr.dbreaka1", ICLASS_xt_iclass_wsr_dbreaka1,
    0,
    Opcode_wsr_dbreaka1_encode_fns, 0, 0 },
  { "xsr.dbreaka1", ICLASS_xt_iclass_xsr_dbreaka1,
    0,
    Opcode_xsr_dbreaka1_encode_fns, 0, 0 },
  { "rsr.dbreakc1", ICLASS_xt_iclass_rsr_dbreakc1,
    0,
    Opcode_rsr_dbreakc1_encode_fns, 0, 0 },
  { "wsr.dbreakc1", ICLASS_xt_iclass_wsr_dbreakc1,
    0,
    Opcode_wsr_dbreakc1_encode_fns, 0, 0 },
  { "xsr.dbreakc1", ICLASS_xt_iclass_xsr_dbreakc1,
    0,
    Opcode_xsr_dbreakc1_encode_fns, 0, 0 },
  { "rsr.ibreaka0", ICLASS_xt_iclass_rsr_ibreaka0,
    0,
    Opcode_rsr_ibreaka0_encode_fns, 0, 0 },
  { "wsr.ibreaka0", ICLASS_xt_iclass_wsr_ibreaka0,
    0,
    Opcode_wsr_ibreaka0_encode_fns, 0, 0 },
  { "xsr.ibreaka0", ICLASS_xt_iclass_xsr_ibreaka0,
    0,
    Opcode_xsr_ibreaka0_encode_fns, 0, 0 },
  { "rsr.ibreaka1", ICLASS_xt_iclass_rsr_ibreaka1,
    0,
    Opcode_rsr_ibreaka1_encode_fns, 0, 0 },
  { "wsr.ibreaka1", ICLASS_xt_iclass_wsr_ibreaka1,
    0,
    Opcode_wsr_ibreaka1_encode_fns, 0, 0 },
  { "xsr.ibreaka1", ICLASS_xt_iclass_xsr_ibreaka1,
    0,
    Opcode_xsr_ibreaka1_encode_fns, 0, 0 },
  { "rsr.ibreakenable", ICLASS_xt_iclass_rsr_ibreakenable,
    0,
    Opcode_rsr_ibreakenable_encode_fns, 0, 0 },
  { "wsr.ibreakenable", ICLASS_xt_iclass_wsr_ibreakenable,
    0,
    Opcode_wsr_ibreakenable_encode_fns, 0, 0 },
  { "xsr.ibreakenable", ICLASS_xt_iclass_xsr_ibreakenable,
    0,
    Opcode_xsr_ibreakenable_encode_fns, 0, 0 },
  { "rsr.debugcause", ICLASS_xt_iclass_rsr_debugcause,
    0,
    Opcode_rsr_debugcause_encode_fns, 0, 0 },
  { "wsr.debugcause", ICLASS_xt_iclass_wsr_debugcause,
    0,
    Opcode_wsr_debugcause_encode_fns, 0, 0 },
  { "xsr.debugcause", ICLASS_xt_iclass_xsr_debugcause,
    0,
    Opcode_xsr_debugcause_encode_fns, 0, 0 },
  { "rsr.icount", ICLASS_xt_iclass_rsr_icount,
    0,
    Opcode_rsr_icount_encode_fns, 0, 0 },
  { "wsr.icount", ICLASS_xt_iclass_wsr_icount,
    0,
    Opcode_wsr_icount_encode_fns, 0, 0 },
  { "xsr.icount", ICLASS_xt_iclass_xsr_icount,
    0,
    Opcode_xsr_icount_encode_fns, 0, 0 },
  { "rsr.icountlevel", ICLASS_xt_iclass_rsr_icountlevel,
    0,
    Opcode_rsr_icountlevel_encode_fns, 0, 0 },
  { "wsr.icountlevel", ICLASS_xt_iclass_wsr_icountlevel,
    0,
    Opcode_wsr_icountlevel_encode_fns, 0, 0 },
  { "xsr.icountlevel", ICLASS_xt_iclass_xsr_icountlevel,
    0,
    Opcode_xsr_icountlevel_encode_fns, 0, 0 },
  { "rsr.ddr", ICLASS_xt_iclass_rsr_ddr,
    0,
    Opcode_rsr_ddr_encode_fns, 0, 0 },
  { "wsr.ddr", ICLASS_xt_iclass_wsr_ddr,
    0,
    Opcode_wsr_ddr_encode_fns, 0, 0 },
  { "xsr.ddr", ICLASS_xt_iclass_xsr_ddr,
    0,
    Opcode_xsr_ddr_encode_fns, 0, 0 },
  { "lddr32.p", ICLASS_xt_iclass_lddr32_p,
    0,
    Opcode_lddr32_p_encode_fns, 1, Opcode_lddr32_p_funcUnit_uses },
  { "sddr32.p", ICLASS_xt_iclass_sddr32_p,
    0,
    Opcode_sddr32_p_encode_fns, 1, Opcode_sddr32_p_funcUnit_uses },
  { "rfdo", ICLASS_xt_iclass_rfdo,
    XTENSA_OPCODE_IS_JUMP,
    Opcode_rfdo_encode_fns, 0, 0 },
  { "rfdd", ICLASS_xt_iclass_rfdd,
    XTENSA_OPCODE_IS_JUMP,
    Opcode_rfdd_encode_fns, 0, 0 },
  { "wsr.mmid", ICLASS_xt_iclass_wsr_mmid,
    0,
    Opcode_wsr_mmid_encode_fns, 0, 0 },
  { "andb", ICLASS_xt_iclass_bbool1,
    0,
    Opcode_andb_encode_fns, 0, 0 },
  { "andbc", ICLASS_xt_iclass_bbool1,
    0,
    Opcode_andbc_encode_fns, 0, 0 },
  { "orb", ICLASS_xt_iclass_bbool1,
    0,
    Opcode_orb_encode_fns, 0, 0 },
  { "orbc", ICLASS_xt_iclass_bbool1,
    0,
    Opcode_orbc_encode_fns, 0, 0 },
  { "xorb", ICLASS_xt_iclass_bbool1,
    0,
    Opcode_xorb_encode_fns, 0, 0 },
  { "all4", ICLASS_xt_iclass_bbool4,
    0,
    Opcode_all4_encode_fns, 0, 0 },
  { "any4", ICLASS_xt_iclass_bbool4,
    0,
    Opcode_any4_encode_fns, 0, 0 },
  { "all8", ICLASS_xt_iclass_bbool8,
    0,
    Opcode_all8_encode_fns, 0, 0 },
  { "any8", ICLASS_xt_iclass_bbool8,
    0,
    Opcode_any8_encode_fns, 0, 0 },
  { "bf", ICLASS_xt_iclass_bbranch,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bf_encode_fns, 0, 0 },
  { "bt", ICLASS_xt_iclass_bbranch,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bt_encode_fns, 0, 0 },
  { "movf", ICLASS_xt_iclass_bmove,
    0,
    Opcode_movf_encode_fns, 0, 0 },
  { "movt", ICLASS_xt_iclass_bmove,
    0,
    Opcode_movt_encode_fns, 0, 0 },
  { "rsr.br", ICLASS_xt_iclass_RSR_BR,
    0,
    Opcode_rsr_br_encode_fns, 0, 0 },
  { "wsr.br", ICLASS_xt_iclass_WSR_BR,
    0,
    Opcode_wsr_br_encode_fns, 0, 0 },
  { "xsr.br", ICLASS_xt_iclass_XSR_BR,
    0,
    Opcode_xsr_br_encode_fns, 0, 0 },
  { "rsr.ccount", ICLASS_xt_iclass_rsr_ccount,
    0,
    Opcode_rsr_ccount_encode_fns, 0, 0 },
  { "wsr.ccount", ICLASS_xt_iclass_wsr_ccount,
    0,
    Opcode_wsr_ccount_encode_fns, 0, 0 },
  { "xsr.ccount", ICLASS_xt_iclass_xsr_ccount,
    0,
    Opcode_xsr_ccount_encode_fns, 0, 0 },
  { "rsr.ccompare0", ICLASS_xt_iclass_rsr_ccompare0,
    0,
    Opcode_rsr_ccompare0_encode_fns, 0, 0 },
  { "wsr.ccompare0", ICLASS_xt_iclass_wsr_ccompare0,
    0,
    Opcode_wsr_ccompare0_encode_fns, 0, 0 },
  { "xsr.ccompare0", ICLASS_xt_iclass_xsr_ccompare0,
    0,
    Opcode_xsr_ccompare0_encode_fns, 0, 0 },
  { "rsr.ccompare1", ICLASS_xt_iclass_rsr_ccompare1,
    0,
    Opcode_rsr_ccompare1_encode_fns, 0, 0 },
  { "wsr.ccompare1", ICLASS_xt_iclass_wsr_ccompare1,
    0,
    Opcode_wsr_ccompare1_encode_fns, 0, 0 },
  { "xsr.ccompare1", ICLASS_xt_iclass_xsr_ccompare1,
    0,
    Opcode_xsr_ccompare1_encode_fns, 0, 0 },
  { "rsr.ccompare2", ICLASS_xt_iclass_rsr_ccompare2,
    0,
    Opcode_rsr_ccompare2_encode_fns, 0, 0 },
  { "wsr.ccompare2", ICLASS_xt_iclass_wsr_ccompare2,
    0,
    Opcode_wsr_ccompare2_encode_fns, 0, 0 },
  { "xsr.ccompare2", ICLASS_xt_iclass_xsr_ccompare2,
    0,
    Opcode_xsr_ccompare2_encode_fns, 0, 0 },
  { "ihi", ICLASS_xt_iclass_icache,
    0,
    Opcode_ihi_encode_fns, 0, 0 },
  { "ipf", ICLASS_xt_iclass_icache,
    0,
    Opcode_ipf_encode_fns, 0, 0 },
  { "ihu", ICLASS_xt_iclass_icache_lock,
    0,
    Opcode_ihu_encode_fns, 0, 0 },
  { "iiu", ICLASS_xt_iclass_icache_lock,
    0,
    Opcode_iiu_encode_fns, 0, 0 },
  { "ipfl", ICLASS_xt_iclass_icache_lock,
    0,
    Opcode_ipfl_encode_fns, 0, 0 },
  { "iii", ICLASS_xt_iclass_icache_inv,
    0,
    Opcode_iii_encode_fns, 0, 0 },
  { "lict", ICLASS_xt_iclass_licx,
    0,
    Opcode_lict_encode_fns, 1, Opcode_lict_funcUnit_uses },
  { "licw", ICLASS_xt_iclass_licx,
    0,
    Opcode_licw_encode_fns, 1, Opcode_licw_funcUnit_uses },
  { "sict", ICLASS_xt_iclass_sicx,
    0,
    Opcode_sict_encode_fns, 1, Opcode_sict_funcUnit_uses },
  { "sicw", ICLASS_xt_iclass_sicx,
    0,
    Opcode_sicw_encode_fns, 1, Opcode_sicw_funcUnit_uses },
  { "dhwb", ICLASS_xt_iclass_dcache,
    0,
    Opcode_dhwb_encode_fns, 0, 0 },
  { "dhwbi", ICLASS_xt_iclass_dcache,
    0,
    Opcode_dhwbi_encode_fns, 0, 0 },
  { "diwbui.p", ICLASS_xt_iclass_dcache_dyn,
    0,
    Opcode_diwbui_p_encode_fns, 0, 0 },
  { "diwb", ICLASS_xt_iclass_dcache_ind,
    0,
    Opcode_diwb_encode_fns, 0, 0 },
  { "diwbi", ICLASS_xt_iclass_dcache_ind,
    0,
    Opcode_diwbi_encode_fns, 0, 0 },
  { "dhi", ICLASS_xt_iclass_dcache_inv,
    0,
    Opcode_dhi_encode_fns, 0, 0 },
  { "dii", ICLASS_xt_iclass_dcache_inv,
    0,
    Opcode_dii_encode_fns, 0, 0 },
  { "dpfr", ICLASS_xt_iclass_dpf,
    0,
    Opcode_dpfr_encode_fns, 0, 0 },
  { "dpfro", ICLASS_xt_iclass_dpf,
    0,
    Opcode_dpfro_encode_fns, 0, 0 },
  { "dpfw", ICLASS_xt_iclass_dpf,
    0,
    Opcode_dpfw_encode_fns, 0, 0 },
  { "dpfwo", ICLASS_xt_iclass_dpf,
    0,
    Opcode_dpfwo_encode_fns, 0, 0 },
  { "dhu", ICLASS_xt_iclass_dcache_lock,
    0,
    Opcode_dhu_encode_fns, 0, 0 },
  { "diu", ICLASS_xt_iclass_dcache_lock,
    0,
    Opcode_diu_encode_fns, 0, 0 },
  { "dpfl", ICLASS_xt_iclass_dcache_lock,
    0,
    Opcode_dpfl_encode_fns, 0, 0 },
  { "sdct", ICLASS_xt_iclass_sdct,
    0,
    Opcode_sdct_encode_fns, 1, Opcode_sdct_funcUnit_uses },
  { "ldct", ICLASS_xt_iclass_ldct,
    0,
    Opcode_ldct_encode_fns, 1, Opcode_ldct_funcUnit_uses },
  { "rsr.prefctl", ICLASS_xt_iclass_rsr_prefctl,
    0,
    Opcode_rsr_prefctl_encode_fns, 0, 0 },
  { "wsr.prefctl", ICLASS_xt_iclass_wsr_prefctl,
    0,
    Opcode_wsr_prefctl_encode_fns, 0, 0 },
  { "xsr.prefctl", ICLASS_xt_iclass_xsr_prefctl,
    0,
    Opcode_xsr_prefctl_encode_fns, 0, 0 },
  { "idtlb", ICLASS_xt_iclass_idtlb,
    0,
    Opcode_idtlb_encode_fns, 0, 0 },
  { "pdtlb", ICLASS_xt_iclass_rdtlb,
    0,
    Opcode_pdtlb_encode_fns, 0, 0 },
  { "rdtlb0", ICLASS_xt_iclass_rdtlb,
    0,
    Opcode_rdtlb0_encode_fns, 0, 0 },
  { "rdtlb1", ICLASS_xt_iclass_rdtlb,
    0,
    Opcode_rdtlb1_encode_fns, 0, 0 },
  { "wdtlb", ICLASS_xt_iclass_wdtlb,
    0,
    Opcode_wdtlb_encode_fns, 0, 0 },
  { "iitlb", ICLASS_xt_iclass_iitlb,
    0,
    Opcode_iitlb_encode_fns, 0, 0 },
  { "pitlb", ICLASS_xt_iclass_ritlb,
    0,
    Opcode_pitlb_encode_fns, 0, 0 },
  { "ritlb0", ICLASS_xt_iclass_ritlb,
    0,
    Opcode_ritlb0_encode_fns, 0, 0 },
  { "ritlb1", ICLASS_xt_iclass_ritlb,
    0,
    Opcode_ritlb1_encode_fns, 0, 0 },
  { "witlb", ICLASS_xt_iclass_witlb,
    0,
    Opcode_witlb_encode_fns, 0, 0 },
  { "rsr.cpenable", ICLASS_xt_iclass_rsr_cpenable,
    0,
    Opcode_rsr_cpenable_encode_fns, 0, 0 },
  { "wsr.cpenable", ICLASS_xt_iclass_wsr_cpenable,
    0,
    Opcode_wsr_cpenable_encode_fns, 0, 0 },
  { "xsr.cpenable", ICLASS_xt_iclass_xsr_cpenable,
    0,
    Opcode_xsr_cpenable_encode_fns, 0, 0 },
  { "clamps", ICLASS_xt_iclass_clamp,
    0,
    Opcode_clamps_encode_fns, 0, 0 },
  { "max", ICLASS_xt_iclass_minmax,
    0,
    Opcode_max_encode_fns, 0, 0 },
  { "maxu", ICLASS_xt_iclass_minmax,
    0,
    Opcode_maxu_encode_fns, 0, 0 },
  { "min", ICLASS_xt_iclass_minmax,
    0,
    Opcode_min_encode_fns, 0, 0 },
  { "minu", ICLASS_xt_iclass_minmax,
    0,
    Opcode_minu_encode_fns, 0, 0 },
  { "nsa", ICLASS_xt_iclass_nsa,
    0,
    Opcode_nsa_encode_fns, 0, 0 },
  { "nsau", ICLASS_xt_iclass_nsa,
    0,
    Opcode_nsau_encode_fns, 0, 0 },
  { "sext", ICLASS_xt_iclass_sx,
    0,
    Opcode_sext_encode_fns, 0, 0 },
  { "l32ai", ICLASS_xt_iclass_l32ai,
    0,
    Opcode_l32ai_encode_fns, 1, Opcode_l32ai_funcUnit_uses },
  { "s32ri", ICLASS_xt_iclass_s32ri,
    0,
    Opcode_s32ri_encode_fns, 1, Opcode_s32ri_funcUnit_uses },
  { "s32c1i", ICLASS_xt_iclass_s32c1i,
    0,
    Opcode_s32c1i_encode_fns, 1, Opcode_s32c1i_funcUnit_uses },
  { "rsr.scompare1", ICLASS_xt_iclass_rsr_scompare1,
    0,
    Opcode_rsr_scompare1_encode_fns, 0, 0 },
  { "wsr.scompare1", ICLASS_xt_iclass_wsr_scompare1,
    0,
    Opcode_wsr_scompare1_encode_fns, 0, 0 },
  { "xsr.scompare1", ICLASS_xt_iclass_xsr_scompare1,
    0,
    Opcode_xsr_scompare1_encode_fns, 0, 0 },
  { "rsr.atomctl", ICLASS_xt_iclass_rsr_atomctl,
    0,
    Opcode_rsr_atomctl_encode_fns, 0, 0 },
  { "wsr.atomctl", ICLASS_xt_iclass_wsr_atomctl,
    0,
    Opcode_wsr_atomctl_encode_fns, 0, 0 },
  { "xsr.atomctl", ICLASS_xt_iclass_xsr_atomctl,
    0,
    Opcode_xsr_atomctl_encode_fns, 0, 0 },
  { "quos", ICLASS_xt_iclass_div,
    0,
    Opcode_quos_encode_fns, 0, 0 },
  { "quou", ICLASS_xt_iclass_div,
    0,
    Opcode_quou_encode_fns, 0, 0 },
  { "rems", ICLASS_xt_iclass_div,
    0,
    Opcode_rems_encode_fns, 0, 0 },
  { "remu", ICLASS_xt_iclass_div,
    0,
    Opcode_remu_encode_fns, 0, 0 },
  { "rer", ICLASS_xt_iclass_rer,
    0,
    Opcode_rer_encode_fns, 0, 0 },
  { "wer", ICLASS_xt_iclass_wer,
    0,
    Opcode_wer_encode_fns, 0, 0 },
  { "beqz.w18", ICLASS_xt_iclass_wb18_0,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_beqz_w18_encode_fns, 0, 0 },
  { "bgez.w18", ICLASS_xt_iclass_wb18_0,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bgez_w18_encode_fns, 0, 0 },
  { "bltz.w18", ICLASS_xt_iclass_wb18_0,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bltz_w18_encode_fns, 0, 0 },
  { "bnez.w18", ICLASS_xt_iclass_wb18_0,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bnez_w18_encode_fns, 0, 0 },
  { "beqi.w18", ICLASS_xt_iclass_wb18_1,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_beqi_w18_encode_fns, 0, 0 },
  { "bgei.w18", ICLASS_xt_iclass_wb18_1,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bgei_w18_encode_fns, 0, 0 },
  { "blti.w18", ICLASS_xt_iclass_wb18_1,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_blti_w18_encode_fns, 0, 0 },
  { "bnei.w18", ICLASS_xt_iclass_wb18_1,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bnei_w18_encode_fns, 0, 0 },
  { "bgeui.w18", ICLASS_xt_iclass_wb18_2,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bgeui_w18_encode_fns, 0, 0 },
  { "bltui.w18", ICLASS_xt_iclass_wb18_2,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bltui_w18_encode_fns, 0, 0 },
  { "bbci.w18", ICLASS_xt_iclass_wb18_3,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bbci_w18_encode_fns, 0, 0 },
  { "bbsi.w18", ICLASS_xt_iclass_wb18_3,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bbsi_w18_encode_fns, 0, 0 },
  { "ball.w18", ICLASS_xt_iclass_wb18_4,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_ball_w18_encode_fns, 0, 0 },
  { "bany.w18", ICLASS_xt_iclass_wb18_4,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bany_w18_encode_fns, 0, 0 },
  { "bbc.w18", ICLASS_xt_iclass_wb18_4,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bbc_w18_encode_fns, 0, 0 },
  { "bbs.w18", ICLASS_xt_iclass_wb18_4,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bbs_w18_encode_fns, 0, 0 },
  { "beq.w18", ICLASS_xt_iclass_wb18_4,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_beq_w18_encode_fns, 0, 0 },
  { "bgeu.w18", ICLASS_xt_iclass_wb18_4,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bgeu_w18_encode_fns, 0, 0 },
  { "bge.w18", ICLASS_xt_iclass_wb18_4,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bge_w18_encode_fns, 0, 0 },
  { "bltu.w18", ICLASS_xt_iclass_wb18_4,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bltu_w18_encode_fns, 0, 0 },
  { "blt.w18", ICLASS_xt_iclass_wb18_4,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_blt_w18_encode_fns, 0, 0 },
  { "bnall.w18", ICLASS_xt_iclass_wb18_4,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bnall_w18_encode_fns, 0, 0 },
  { "bne.w18", ICLASS_xt_iclass_wb18_4,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bne_w18_encode_fns, 0, 0 },
  { "bnone.w18", ICLASS_xt_iclass_wb18_4,
    XTENSA_OPCODE_IS_BRANCH,
    Opcode_bnone_w18_encode_fns, 0, 0 },
  { "rur.ae_ovf_sar", ICLASS_rur_ae_ovf_sar,
    0,
    Opcode_rur_ae_ovf_sar_encode_fns, 0, 0 },
  { "wur.ae_ovf_sar", ICLASS_wur_ae_ovf_sar,
    0,
    Opcode_wur_ae_ovf_sar_encode_fns, 0, 0 },
  { "rur.ae_bithead", ICLASS_rur_ae_bithead,
    0,
    Opcode_rur_ae_bithead_encode_fns, 0, 0 },
  { "wur.ae_bithead", ICLASS_wur_ae_bithead,
    0,
    Opcode_wur_ae_bithead_encode_fns, 0, 0 },
  { "rur.ae_ts_fts_bu_bp", ICLASS_rur_ae_ts_fts_bu_bp,
    0,
    Opcode_rur_ae_ts_fts_bu_bp_encode_fns, 0, 0 },
  { "wur.ae_ts_fts_bu_bp", ICLASS_wur_ae_ts_fts_bu_bp,
    0,
    Opcode_wur_ae_ts_fts_bu_bp_encode_fns, 0, 0 },
  { "rur.ae_cw_sd_no", ICLASS_rur_ae_cw_sd_no,
    0,
    Opcode_rur_ae_cw_sd_no_encode_fns, 0, 0 },
  { "wur.ae_cw_sd_no", ICLASS_wur_ae_cw_sd_no,
    0,
    Opcode_wur_ae_cw_sd_no_encode_fns, 0, 0 },
  { "rur.ae_cbegin0", ICLASS_rur_ae_cbegin0,
    0,
    Opcode_rur_ae_cbegin0_encode_fns, 0, 0 },
  { "wur.ae_cbegin0", ICLASS_wur_ae_cbegin0,
    0,
    Opcode_wur_ae_cbegin0_encode_fns, 0, 0 },
  { "rur.ae_cend0", ICLASS_rur_ae_cend0,
    0,
    Opcode_rur_ae_cend0_encode_fns, 0, 0 },
  { "wur.ae_cend0", ICLASS_wur_ae_cend0,
    0,
    Opcode_wur_ae_cend0_encode_fns, 0, 0 },
  { "rur.fcr", ICLASS_rur_fcr,
    0,
    Opcode_rur_fcr_encode_fns, 0, 0 },
  { "wur.fcr", ICLASS_wur_fcr,
    0,
    Opcode_wur_fcr_encode_fns, 0, 0 },
  { "rur.fsr", ICLASS_rur_fsr,
    0,
    Opcode_rur_fsr_encode_fns, 0, 0 },
  { "wur.fsr", ICLASS_wur_fsr,
    0,
    Opcode_wur_fsr_encode_fns, 0, 0 },
  { "rur.ae_overflow", ICLASS_RUR_AE_OVERFLOW,
    0,
    Opcode_rur_ae_overflow_encode_fns, 0, 0 },
  { "wur.ae_overflow", ICLASS_WUR_AE_OVERFLOW,
    0,
    Opcode_wur_ae_overflow_encode_fns, 0, 0 },
  { "rur.ae_sar", ICLASS_RUR_AE_SAR,
    0,
    Opcode_rur_ae_sar_encode_fns, 0, 0 },
  { "wur.ae_sar", ICLASS_WUR_AE_SAR,
    0,
    Opcode_wur_ae_sar_encode_fns, 0, 0 },
  { "rur.ae_bitptr", ICLASS_RUR_AE_BITPTR,
    0,
    Opcode_rur_ae_bitptr_encode_fns, 0, 0 },
  { "wur.ae_bitptr", ICLASS_WUR_AE_BITPTR,
    0,
    Opcode_wur_ae_bitptr_encode_fns, 0, 0 },
  { "rur.ae_bitsused", ICLASS_RUR_AE_BITSUSED,
    0,
    Opcode_rur_ae_bitsused_encode_fns, 0, 0 },
  { "wur.ae_bitsused", ICLASS_WUR_AE_BITSUSED,
    0,
    Opcode_wur_ae_bitsused_encode_fns, 0, 0 },
  { "rur.ae_tablesize", ICLASS_RUR_AE_TABLESIZE,
    0,
    Opcode_rur_ae_tablesize_encode_fns, 0, 0 },
  { "wur.ae_tablesize", ICLASS_WUR_AE_TABLESIZE,
    0,
    Opcode_wur_ae_tablesize_encode_fns, 0, 0 },
  { "rur.ae_first_ts", ICLASS_RUR_AE_FIRST_TS,
    0,
    Opcode_rur_ae_first_ts_encode_fns, 0, 0 },
  { "wur.ae_first_ts", ICLASS_WUR_AE_FIRST_TS,
    0,
    Opcode_wur_ae_first_ts_encode_fns, 0, 0 },
  { "rur.ae_nextoffset", ICLASS_RUR_AE_NEXTOFFSET,
    0,
    Opcode_rur_ae_nextoffset_encode_fns, 0, 0 },
  { "wur.ae_nextoffset", ICLASS_WUR_AE_NEXTOFFSET,
    0,
    Opcode_wur_ae_nextoffset_encode_fns, 0, 0 },
  { "rur.ae_searchdone", ICLASS_RUR_AE_SEARCHDONE,
    0,
    Opcode_rur_ae_searchdone_encode_fns, 0, 0 },
  { "wur.ae_searchdone", ICLASS_WUR_AE_SEARCHDONE,
    0,
    Opcode_wur_ae_searchdone_encode_fns, 0, 0 },
  { "rur.ae_cwrap", ICLASS_RUR_AE_CWRAP,
    0,
    Opcode_rur_ae_cwrap_encode_fns, 0, 0 },
  { "wur.ae_cwrap", ICLASS_WUR_AE_CWRAP,
    0,
    Opcode_wur_ae_cwrap_encode_fns, 0, 0 },
  { "ae_l16m.xc", ICLASS_AE_L16M_XC,
    0,
    Opcode_ae_l16m_xc_encode_fns, 1, Opcode_ae_l16m_xc_funcUnit_uses },
  { "ae_l16m.i", ICLASS_AE_L16M_I,
    0,
    Opcode_ae_l16m_i_encode_fns, 1, Opcode_ae_l16m_i_funcUnit_uses },
  { "ae_l16m.iu", ICLASS_AE_L16M_IU,
    0,
    Opcode_ae_l16m_iu_encode_fns, 1, Opcode_ae_l16m_iu_funcUnit_uses },
  { "ae_l16m.x", ICLASS_AE_L16M_X,
    0,
    Opcode_ae_l16m_x_encode_fns, 1, Opcode_ae_l16m_x_funcUnit_uses },
  { "ae_l16m.xu", ICLASS_AE_L16M_XU,
    0,
    Opcode_ae_l16m_xu_encode_fns, 1, Opcode_ae_l16m_xu_funcUnit_uses },
  { "ae_l16.xc", ICLASS_AE_L16_XC,
    0,
    Opcode_ae_l16_xc_encode_fns, 1, Opcode_ae_l16_xc_funcUnit_uses },
  { "ae_l16.i", ICLASS_AE_L16_I,
    0,
    Opcode_ae_l16_i_encode_fns, 1, Opcode_ae_l16_i_funcUnit_uses },
  { "ae_l16.ip", ICLASS_AE_L16_IP,
    0,
    Opcode_ae_l16_ip_encode_fns, 1, Opcode_ae_l16_ip_funcUnit_uses },
  { "ae_l16.x", ICLASS_AE_L16_X,
    0,
    Opcode_ae_l16_x_encode_fns, 1, Opcode_ae_l16_x_funcUnit_uses },
  { "ae_l16.xp", ICLASS_AE_L16_XP,
    0,
    Opcode_ae_l16_xp_encode_fns, 1, Opcode_ae_l16_xp_funcUnit_uses },
  { "ae_l32f24.xc", ICLASS_AE_L32F24_XC,
    0,
    Opcode_ae_l32f24_xc_encode_fns, 1, Opcode_ae_l32f24_xc_funcUnit_uses },
  { "ae_l32f24.i", ICLASS_AE_L32F24_I,
    0,
    Opcode_ae_l32f24_i_encode_fns, 1, Opcode_ae_l32f24_i_funcUnit_uses },
  { "ae_l32f24.ip", ICLASS_AE_L32F24_IP,
    0,
    Opcode_ae_l32f24_ip_encode_fns, 1, Opcode_ae_l32f24_ip_funcUnit_uses },
  { "ae_l32f24.x", ICLASS_AE_L32F24_X,
    0,
    Opcode_ae_l32f24_x_encode_fns, 1, Opcode_ae_l32f24_x_funcUnit_uses },
  { "ae_l32f24.xp", ICLASS_AE_L32F24_XP,
    0,
    Opcode_ae_l32f24_xp_encode_fns, 1, Opcode_ae_l32f24_xp_funcUnit_uses },
  { "ae_l32.xc", ICLASS_AE_L32_XC,
    0,
    Opcode_ae_l32_xc_encode_fns, 1, Opcode_ae_l32_xc_funcUnit_uses },
  { "ae_l32.i", ICLASS_AE_L32_I,
    0,
    Opcode_ae_l32_i_encode_fns, 1, Opcode_ae_l32_i_funcUnit_uses },
  { "ae_l32.ip", ICLASS_AE_L32_IP,
    0,
    Opcode_ae_l32_ip_encode_fns, 1, Opcode_ae_l32_ip_funcUnit_uses },
  { "ae_l32.x", ICLASS_AE_L32_X,
    0,
    Opcode_ae_l32_x_encode_fns, 1, Opcode_ae_l32_x_funcUnit_uses },
  { "ae_l32.xp", ICLASS_AE_L32_XP,
    0,
    Opcode_ae_l32_xp_encode_fns, 1, Opcode_ae_l32_xp_funcUnit_uses },
  { "ae_l32m.xc", ICLASS_AE_L32M_XC,
    0,
    Opcode_ae_l32m_xc_encode_fns, 1, Opcode_ae_l32m_xc_funcUnit_uses },
  { "ae_l32m.i", ICLASS_AE_L32M_I,
    0,
    Opcode_ae_l32m_i_encode_fns, 1, Opcode_ae_l32m_i_funcUnit_uses },
  { "ae_l32m.iu", ICLASS_AE_L32M_IU,
    0,
    Opcode_ae_l32m_iu_encode_fns, 1, Opcode_ae_l32m_iu_funcUnit_uses },
  { "ae_l32m.x", ICLASS_AE_L32M_X,
    0,
    Opcode_ae_l32m_x_encode_fns, 1, Opcode_ae_l32m_x_funcUnit_uses },
  { "ae_l32m.xu", ICLASS_AE_L32M_XU,
    0,
    Opcode_ae_l32m_xu_encode_fns, 1, Opcode_ae_l32m_xu_funcUnit_uses },
  { "ae_l16x2m.xc", ICLASS_AE_L16X2M_XC,
    0,
    Opcode_ae_l16x2m_xc_encode_fns, 1, Opcode_ae_l16x2m_xc_funcUnit_uses },
  { "ae_l16x2m.i", ICLASS_AE_L16X2M_I,
    0,
    Opcode_ae_l16x2m_i_encode_fns, 1, Opcode_ae_l16x2m_i_funcUnit_uses },
  { "ae_l16x2m.iu", ICLASS_AE_L16X2M_IU,
    0,
    Opcode_ae_l16x2m_iu_encode_fns, 1, Opcode_ae_l16x2m_iu_funcUnit_uses },
  { "ae_l16x2m.x", ICLASS_AE_L16X2M_X,
    0,
    Opcode_ae_l16x2m_x_encode_fns, 1, Opcode_ae_l16x2m_x_funcUnit_uses },
  { "ae_l16x2m.xu", ICLASS_AE_L16X2M_XU,
    0,
    Opcode_ae_l16x2m_xu_encode_fns, 1, Opcode_ae_l16x2m_xu_funcUnit_uses },
  { "ae_l32x2f24.xc", ICLASS_AE_L32X2F24_XC,
    0,
    Opcode_ae_l32x2f24_xc_encode_fns, 1, Opcode_ae_l32x2f24_xc_funcUnit_uses },
  { "ae_l32x2f24.i", ICLASS_AE_L32X2F24_I,
    0,
    Opcode_ae_l32x2f24_i_encode_fns, 1, Opcode_ae_l32x2f24_i_funcUnit_uses },
  { "ae_l32x2f24.ip", ICLASS_AE_L32X2F24_IP,
    0,
    Opcode_ae_l32x2f24_ip_encode_fns, 1, Opcode_ae_l32x2f24_ip_funcUnit_uses },
  { "ae_l32x2f24.rip", ICLASS_AE_L32X2F24_RIP,
    0,
    Opcode_ae_l32x2f24_rip_encode_fns, 1, Opcode_ae_l32x2f24_rip_funcUnit_uses },
  { "ae_l32x2f24.ric", ICLASS_AE_L32X2F24_RIC,
    0,
    Opcode_ae_l32x2f24_ric_encode_fns, 1, Opcode_ae_l32x2f24_ric_funcUnit_uses },
  { "ae_l32x2f24.x", ICLASS_AE_L32X2F24_X,
    0,
    Opcode_ae_l32x2f24_x_encode_fns, 1, Opcode_ae_l32x2f24_x_funcUnit_uses },
  { "ae_l32x2f24.xp", ICLASS_AE_L32X2F24_XP,
    0,
    Opcode_ae_l32x2f24_xp_encode_fns, 1, Opcode_ae_l32x2f24_xp_funcUnit_uses },
  { "ae_l32x2.xc", ICLASS_AE_L32X2_XC,
    0,
    Opcode_ae_l32x2_xc_encode_fns, 1, Opcode_ae_l32x2_xc_funcUnit_uses },
  { "ae_l32x2.i", ICLASS_AE_L32X2_I,
    0,
    Opcode_ae_l32x2_i_encode_fns, 1, Opcode_ae_l32x2_i_funcUnit_uses },
  { "ae_l32x2.ip", ICLASS_AE_L32X2_IP,
    0,
    Opcode_ae_l32x2_ip_encode_fns, 1, Opcode_ae_l32x2_ip_funcUnit_uses },
  { "ae_l32x2.rip", ICLASS_AE_L32X2_RIP,
    0,
    Opcode_ae_l32x2_rip_encode_fns, 1, Opcode_ae_l32x2_rip_funcUnit_uses },
  { "ae_l32x2.ric", ICLASS_AE_L32X2_RIC,
    0,
    Opcode_ae_l32x2_ric_encode_fns, 1, Opcode_ae_l32x2_ric_funcUnit_uses },
  { "ae_l32x2.x", ICLASS_AE_L32X2_X,
    0,
    Opcode_ae_l32x2_x_encode_fns, 1, Opcode_ae_l32x2_x_funcUnit_uses },
  { "ae_l32x2.xp", ICLASS_AE_L32X2_XP,
    0,
    Opcode_ae_l32x2_xp_encode_fns, 1, Opcode_ae_l32x2_xp_funcUnit_uses },
  { "ae_l16x4.xc", ICLASS_AE_L16X4_XC,
    0,
    Opcode_ae_l16x4_xc_encode_fns, 1, Opcode_ae_l16x4_xc_funcUnit_uses },
  { "ae_l16x4.i", ICLASS_AE_L16X4_I,
    0,
    Opcode_ae_l16x4_i_encode_fns, 1, Opcode_ae_l16x4_i_funcUnit_uses },
  { "ae_l16x4.ip", ICLASS_AE_L16X4_IP,
    0,
    Opcode_ae_l16x4_ip_encode_fns, 1, Opcode_ae_l16x4_ip_funcUnit_uses },
  { "ae_l16x4.rip", ICLASS_AE_L16X4_RIP,
    0,
    Opcode_ae_l16x4_rip_encode_fns, 1, Opcode_ae_l16x4_rip_funcUnit_uses },
  { "ae_l16x4.ric", ICLASS_AE_L16X4_RIC,
    0,
    Opcode_ae_l16x4_ric_encode_fns, 1, Opcode_ae_l16x4_ric_funcUnit_uses },
  { "ae_l16x4.x", ICLASS_AE_L16X4_X,
    0,
    Opcode_ae_l16x4_x_encode_fns, 1, Opcode_ae_l16x4_x_funcUnit_uses },
  { "ae_l16x4.xp", ICLASS_AE_L16X4_XP,
    0,
    Opcode_ae_l16x4_xp_encode_fns, 1, Opcode_ae_l16x4_xp_funcUnit_uses },
  { "ae_l64.xc", ICLASS_AE_L64_XC,
    0,
    Opcode_ae_l64_xc_encode_fns, 1, Opcode_ae_l64_xc_funcUnit_uses },
  { "ae_l64.i", ICLASS_AE_L64_I,
    0,
    Opcode_ae_l64_i_encode_fns, 1, Opcode_ae_l64_i_funcUnit_uses },
  { "ae_l64.ip", ICLASS_AE_L64_IP,
    0,
    Opcode_ae_l64_ip_encode_fns, 1, Opcode_ae_l64_ip_funcUnit_uses },
  { "ae_l64.x", ICLASS_AE_L64_X,
    0,
    Opcode_ae_l64_x_encode_fns, 1, Opcode_ae_l64_x_funcUnit_uses },
  { "ae_l64.xp", ICLASS_AE_L64_XP,
    0,
    Opcode_ae_l64_xp_encode_fns, 1, Opcode_ae_l64_xp_funcUnit_uses },
  { "ae_s16x2m.xc", ICLASS_AE_S16X2M_XC,
    0,
    Opcode_ae_s16x2m_xc_encode_fns, 1, Opcode_ae_s16x2m_xc_funcUnit_uses },
  { "ae_s16x2m.i", ICLASS_AE_S16X2M_I,
    0,
    Opcode_ae_s16x2m_i_encode_fns, 1, Opcode_ae_s16x2m_i_funcUnit_uses },
  { "ae_s16x2m.iu", ICLASS_AE_S16X2M_IU,
    0,
    Opcode_ae_s16x2m_iu_encode_fns, 1, Opcode_ae_s16x2m_iu_funcUnit_uses },
  { "ae_s16x2m.x", ICLASS_AE_S16X2M_X,
    0,
    Opcode_ae_s16x2m_x_encode_fns, 1, Opcode_ae_s16x2m_x_funcUnit_uses },
  { "ae_s16x2m.xu", ICLASS_AE_S16X2M_XU,
    0,
    Opcode_ae_s16x2m_xu_encode_fns, 1, Opcode_ae_s16x2m_xu_funcUnit_uses },
  { "ae_s32x2f24.xc", ICLASS_AE_S32X2F24_XC,
    0,
    Opcode_ae_s32x2f24_xc_encode_fns, 1, Opcode_ae_s32x2f24_xc_funcUnit_uses },
  { "ae_s32x2f24.i", ICLASS_AE_S32X2F24_I,
    0,
    Opcode_ae_s32x2f24_i_encode_fns, 1, Opcode_ae_s32x2f24_i_funcUnit_uses },
  { "ae_s32x2f24.ip", ICLASS_AE_S32X2F24_IP,
    0,
    Opcode_ae_s32x2f24_ip_encode_fns, 1, Opcode_ae_s32x2f24_ip_funcUnit_uses },
  { "ae_s32x2f24.rip", ICLASS_AE_S32X2F24_RIP,
    0,
    Opcode_ae_s32x2f24_rip_encode_fns, 1, Opcode_ae_s32x2f24_rip_funcUnit_uses },
  { "ae_s32x2f24.ric", ICLASS_AE_S32X2F24_RIC,
    0,
    Opcode_ae_s32x2f24_ric_encode_fns, 1, Opcode_ae_s32x2f24_ric_funcUnit_uses },
  { "ae_s32x2f24.x", ICLASS_AE_S32X2F24_X,
    0,
    Opcode_ae_s32x2f24_x_encode_fns, 1, Opcode_ae_s32x2f24_x_funcUnit_uses },
  { "ae_s32x2f24.xp", ICLASS_AE_S32X2F24_XP,
    0,
    Opcode_ae_s32x2f24_xp_encode_fns, 1, Opcode_ae_s32x2f24_xp_funcUnit_uses },
  { "ae_s32x2.xc", ICLASS_AE_S32X2_XC,
    0,
    Opcode_ae_s32x2_xc_encode_fns, 1, Opcode_ae_s32x2_xc_funcUnit_uses },
  { "ae_s32x2.i", ICLASS_AE_S32X2_I,
    0,
    Opcode_ae_s32x2_i_encode_fns, 1, Opcode_ae_s32x2_i_funcUnit_uses },
  { "ae_s32x2.ip", ICLASS_AE_S32X2_IP,
    0,
    Opcode_ae_s32x2_ip_encode_fns, 1, Opcode_ae_s32x2_ip_funcUnit_uses },
  { "ae_s32x2.rip", ICLASS_AE_S32X2_RIP,
    0,
    Opcode_ae_s32x2_rip_encode_fns, 1, Opcode_ae_s32x2_rip_funcUnit_uses },
  { "ae_s32x2.ric", ICLASS_AE_S32X2_RIC,
    0,
    Opcode_ae_s32x2_ric_encode_fns, 1, Opcode_ae_s32x2_ric_funcUnit_uses },
  { "ae_s32x2.x", ICLASS_AE_S32X2_X,
    0,
    Opcode_ae_s32x2_x_encode_fns, 1, Opcode_ae_s32x2_x_funcUnit_uses },
  { "ae_s32x2.xp", ICLASS_AE_S32X2_XP,
    0,
    Opcode_ae_s32x2_xp_encode_fns, 1, Opcode_ae_s32x2_xp_funcUnit_uses },
  { "ae_s16x4.xc", ICLASS_AE_S16X4_XC,
    0,
    Opcode_ae_s16x4_xc_encode_fns, 1, Opcode_ae_s16x4_xc_funcUnit_uses },
  { "ae_s16x4.i", ICLASS_AE_S16X4_I,
    0,
    Opcode_ae_s16x4_i_encode_fns, 1, Opcode_ae_s16x4_i_funcUnit_uses },
  { "ae_s16x4.ip", ICLASS_AE_S16X4_IP,
    0,
    Opcode_ae_s16x4_ip_encode_fns, 1, Opcode_ae_s16x4_ip_funcUnit_uses },
  { "ae_s16x4.rip", ICLASS_AE_S16X4_RIP,
    0,
    Opcode_ae_s16x4_rip_encode_fns, 1, Opcode_ae_s16x4_rip_funcUnit_uses },
  { "ae_s16x4.ric", ICLASS_AE_S16X4_RIC,
    0,
    Opcode_ae_s16x4_ric_encode_fns, 1, Opcode_ae_s16x4_ric_funcUnit_uses },
  { "ae_s16x4.x", ICLASS_AE_S16X4_X,
    0,
    Opcode_ae_s16x4_x_encode_fns, 1, Opcode_ae_s16x4_x_funcUnit_uses },
  { "ae_s16x4.xp", ICLASS_AE_S16X4_XP,
    0,
    Opcode_ae_s16x4_xp_encode_fns, 1, Opcode_ae_s16x4_xp_funcUnit_uses },
  { "ae_s16m.l.xc", ICLASS_AE_S16M_L_XC,
    0,
    Opcode_ae_s16m_l_xc_encode_fns, 1, Opcode_ae_s16m_l_xc_funcUnit_uses },
  { "ae_s16m.l.i", ICLASS_AE_S16M_L_I,
    0,
    Opcode_ae_s16m_l_i_encode_fns, 1, Opcode_ae_s16m_l_i_funcUnit_uses },
  { "ae_s16m.l.iu", ICLASS_AE_S16M_L_IU,
    0,
    Opcode_ae_s16m_l_iu_encode_fns, 1, Opcode_ae_s16m_l_iu_funcUnit_uses },
  { "ae_s16m.l.x", ICLASS_AE_S16M_L_X,
    0,
    Opcode_ae_s16m_l_x_encode_fns, 1, Opcode_ae_s16m_l_x_funcUnit_uses },
  { "ae_s16m.l.xu", ICLASS_AE_S16M_L_XU,
    0,
    Opcode_ae_s16m_l_xu_encode_fns, 1, Opcode_ae_s16m_l_xu_funcUnit_uses },
  { "ae_s32f24.l.xc", ICLASS_AE_S32F24_L_XC,
    0,
    Opcode_ae_s32f24_l_xc_encode_fns, 1, Opcode_ae_s32f24_l_xc_funcUnit_uses },
  { "ae_s32f24.l.i", ICLASS_AE_S32F24_L_I,
    0,
    Opcode_ae_s32f24_l_i_encode_fns, 1, Opcode_ae_s32f24_l_i_funcUnit_uses },
  { "ae_s32f24.l.ip", ICLASS_AE_S32F24_L_IP,
    0,
    Opcode_ae_s32f24_l_ip_encode_fns, 1, Opcode_ae_s32f24_l_ip_funcUnit_uses },
  { "ae_s32f24.l.x", ICLASS_AE_S32F24_L_X,
    0,
    Opcode_ae_s32f24_l_x_encode_fns, 1, Opcode_ae_s32f24_l_x_funcUnit_uses },
  { "ae_s32f24.l.xp", ICLASS_AE_S32F24_L_XP,
    0,
    Opcode_ae_s32f24_l_xp_encode_fns, 1, Opcode_ae_s32f24_l_xp_funcUnit_uses },
  { "ae_s32.l.xc", ICLASS_AE_S32_L_XC,
    0,
    Opcode_ae_s32_l_xc_encode_fns, 1, Opcode_ae_s32_l_xc_funcUnit_uses },
  { "ae_s32.l.i", ICLASS_AE_S32_L_I,
    0,
    Opcode_ae_s32_l_i_encode_fns, 1, Opcode_ae_s32_l_i_funcUnit_uses },
  { "ae_s32.l.ip", ICLASS_AE_S32_L_IP,
    0,
    Opcode_ae_s32_l_ip_encode_fns, 1, Opcode_ae_s32_l_ip_funcUnit_uses },
  { "ae_s32.l.x", ICLASS_AE_S32_L_X,
    0,
    Opcode_ae_s32_l_x_encode_fns, 1, Opcode_ae_s32_l_x_funcUnit_uses },
  { "ae_s32.l.xp", ICLASS_AE_S32_L_XP,
    0,
    Opcode_ae_s32_l_xp_encode_fns, 1, Opcode_ae_s32_l_xp_funcUnit_uses },
  { "ae_s16.0.xc", ICLASS_AE_S16_0_XC,
    0,
    Opcode_ae_s16_0_xc_encode_fns, 1, Opcode_ae_s16_0_xc_funcUnit_uses },
  { "ae_s16.0.i", ICLASS_AE_S16_0_I,
    0,
    Opcode_ae_s16_0_i_encode_fns, 1, Opcode_ae_s16_0_i_funcUnit_uses },
  { "ae_s16.0.ip", ICLASS_AE_S16_0_IP,
    0,
    Opcode_ae_s16_0_ip_encode_fns, 1, Opcode_ae_s16_0_ip_funcUnit_uses },
  { "ae_s16.0.x", ICLASS_AE_S16_0_X,
    0,
    Opcode_ae_s16_0_x_encode_fns, 1, Opcode_ae_s16_0_x_funcUnit_uses },
  { "ae_s16.0.xp", ICLASS_AE_S16_0_XP,
    0,
    Opcode_ae_s16_0_xp_encode_fns, 1, Opcode_ae_s16_0_xp_funcUnit_uses },
  { "ae_s64.xc", ICLASS_AE_S64_XC,
    0,
    Opcode_ae_s64_xc_encode_fns, 1, Opcode_ae_s64_xc_funcUnit_uses },
  { "ae_s64.i", ICLASS_AE_S64_I,
    0,
    Opcode_ae_s64_i_encode_fns, 1, Opcode_ae_s64_i_funcUnit_uses },
  { "ae_s64.ip", ICLASS_AE_S64_IP,
    0,
    Opcode_ae_s64_ip_encode_fns, 1, Opcode_ae_s64_ip_funcUnit_uses },
  { "ae_s64.x", ICLASS_AE_S64_X,
    0,
    Opcode_ae_s64_x_encode_fns, 1, Opcode_ae_s64_x_funcUnit_uses },
  { "ae_s64.xp", ICLASS_AE_S64_XP,
    0,
    Opcode_ae_s64_xp_encode_fns, 1, Opcode_ae_s64_xp_funcUnit_uses },
  { "ae_s32m.xc", ICLASS_AE_S32M_XC,
    0,
    Opcode_ae_s32m_xc_encode_fns, 1, Opcode_ae_s32m_xc_funcUnit_uses },
  { "ae_s32m.i", ICLASS_AE_S32M_I,
    0,
    Opcode_ae_s32m_i_encode_fns, 1, Opcode_ae_s32m_i_funcUnit_uses },
  { "ae_s32m.iu", ICLASS_AE_S32M_IU,
    0,
    Opcode_ae_s32m_iu_encode_fns, 1, Opcode_ae_s32m_iu_funcUnit_uses },
  { "ae_s32m.x", ICLASS_AE_S32M_X,
    0,
    Opcode_ae_s32m_x_encode_fns, 1, Opcode_ae_s32m_x_funcUnit_uses },
  { "ae_s32m.xu", ICLASS_AE_S32M_XU,
    0,
    Opcode_ae_s32m_xu_encode_fns, 1, Opcode_ae_s32m_xu_funcUnit_uses },
  { "ae_zalign64", ICLASS_AE_ZALIGN64,
    0,
    Opcode_ae_zalign64_encode_fns, 0, 0 },
  { "ae_lalign64.i", ICLASS_AE_LALIGN64_I,
    0,
    Opcode_ae_lalign64_i_encode_fns, 1, Opcode_ae_lalign64_i_funcUnit_uses },
  { "ae_salign64.i", ICLASS_AE_SALIGN64_I,
    0,
    Opcode_ae_salign64_i_encode_fns, 1, Opcode_ae_salign64_i_funcUnit_uses },
  { "ae_movalign", ICLASS_AE_MOVALIGN,
    0,
    Opcode_ae_movalign_encode_fns, 0, 0 },
  { "ae_la64.pp", ICLASS_AE_LA64_PP,
    0,
    Opcode_ae_la64_pp_encode_fns, 1, Opcode_ae_la64_pp_funcUnit_uses },
  { "ae_la24pos.pc", ICLASS_AE_LA24POS_PC,
    0,
    Opcode_ae_la24pos_pc_encode_fns, 1, Opcode_ae_la24pos_pc_funcUnit_uses },
  { "ae_la24x2pos.pc", ICLASS_AE_LA24X2POS_PC,
    0,
    Opcode_ae_la24x2pos_pc_encode_fns, 1, Opcode_ae_la24x2pos_pc_funcUnit_uses },
  { "ae_la32x2pos.pc", ICLASS_AE_LA32X2POS_PC,
    0,
    Opcode_ae_la32x2pos_pc_encode_fns, 1, Opcode_ae_la32x2pos_pc_funcUnit_uses },
  { "ae_la16x4pos.pc", ICLASS_AE_LA16X4POS_PC,
    0,
    Opcode_ae_la16x4pos_pc_encode_fns, 1, Opcode_ae_la16x4pos_pc_funcUnit_uses },
  { "ae_la24neg.pc", ICLASS_AE_LA24NEG_PC,
    0,
    Opcode_ae_la24neg_pc_encode_fns, 1, Opcode_ae_la24neg_pc_funcUnit_uses },
  { "ae_la24x2neg.pc", ICLASS_AE_LA24X2NEG_PC,
    0,
    Opcode_ae_la24x2neg_pc_encode_fns, 1, Opcode_ae_la24x2neg_pc_funcUnit_uses },
  { "ae_la32x2neg.pc", ICLASS_AE_LA32X2NEG_PC,
    0,
    Opcode_ae_la32x2neg_pc_encode_fns, 1, Opcode_ae_la32x2neg_pc_funcUnit_uses },
  { "ae_la16x4neg.pc", ICLASS_AE_LA16X4NEG_PC,
    0,
    Opcode_ae_la16x4neg_pc_encode_fns, 1, Opcode_ae_la16x4neg_pc_funcUnit_uses },
  { "ae_sa64pos.fp", ICLASS_AE_SA64POS_FP,
    0,
    Opcode_ae_sa64pos_fp_encode_fns, 1, Opcode_ae_sa64pos_fp_funcUnit_uses },
  { "ae_sa64neg.fp", ICLASS_AE_SA64NEG_FP,
    0,
    Opcode_ae_sa64neg_fp_encode_fns, 1, Opcode_ae_sa64neg_fp_funcUnit_uses },
  { "ae_la32x2.ic", ICLASS_AE_LA32X2_IC,
    0,
    Opcode_ae_la32x2_ic_encode_fns, 1, Opcode_ae_la32x2_ic_funcUnit_uses },
  { "ae_la32x2.ip", ICLASS_AE_LA32X2_IP,
    0,
    Opcode_ae_la32x2_ip_encode_fns, 1, Opcode_ae_la32x2_ip_funcUnit_uses },
  { "ae_la32x2.rip", ICLASS_AE_LA32X2_RIP,
    0,
    Opcode_ae_la32x2_rip_encode_fns, 1, Opcode_ae_la32x2_rip_funcUnit_uses },
  { "ae_la32x2.ric", ICLASS_AE_LA32X2_RIC,
    0,
    Opcode_ae_la32x2_ric_encode_fns, 1, Opcode_ae_la32x2_ric_funcUnit_uses },
  { "ae_la16x4.ic", ICLASS_AE_LA16X4_IC,
    0,
    Opcode_ae_la16x4_ic_encode_fns, 1, Opcode_ae_la16x4_ic_funcUnit_uses },
  { "ae_la16x4.ip", ICLASS_AE_LA16X4_IP,
    0,
    Opcode_ae_la16x4_ip_encode_fns, 1, Opcode_ae_la16x4_ip_funcUnit_uses },
  { "ae_la16x4.rip", ICLASS_AE_LA16X4_RIP,
    0,
    Opcode_ae_la16x4_rip_encode_fns, 1, Opcode_ae_la16x4_rip_funcUnit_uses },
  { "ae_la16x4.ric", ICLASS_AE_LA16X4_RIC,
    0,
    Opcode_ae_la16x4_ric_encode_fns, 1, Opcode_ae_la16x4_ric_funcUnit_uses },
  { "ae_la32x2f24.ic", ICLASS_AE_LA32X2F24_IC,
    0,
    Opcode_ae_la32x2f24_ic_encode_fns, 1, Opcode_ae_la32x2f24_ic_funcUnit_uses },
  { "ae_la32x2f24.ip", ICLASS_AE_LA32X2F24_IP,
    0,
    Opcode_ae_la32x2f24_ip_encode_fns, 1, Opcode_ae_la32x2f24_ip_funcUnit_uses },
  { "ae_la32x2f24.rip", ICLASS_AE_LA32X2F24_RIP,
    0,
    Opcode_ae_la32x2f24_rip_encode_fns, 1, Opcode_ae_la32x2f24_rip_funcUnit_uses },
  { "ae_la32x2f24.ric", ICLASS_AE_LA32X2F24_RIC,
    0,
    Opcode_ae_la32x2f24_ric_encode_fns, 1, Opcode_ae_la32x2f24_ric_funcUnit_uses },
  { "ae_la24.ic", ICLASS_AE_LA24_IC,
    0,
    Opcode_ae_la24_ic_encode_fns, 1, Opcode_ae_la24_ic_funcUnit_uses },
  { "ae_la24.ip", ICLASS_AE_LA24_IP,
    0,
    Opcode_ae_la24_ip_encode_fns, 1, Opcode_ae_la24_ip_funcUnit_uses },
  { "ae_la24.rip", ICLASS_AE_LA24_RIP,
    0,
    Opcode_ae_la24_rip_encode_fns, 1, Opcode_ae_la24_rip_funcUnit_uses },
  { "ae_la24.ric", ICLASS_AE_LA24_RIC,
    0,
    Opcode_ae_la24_ric_encode_fns, 1, Opcode_ae_la24_ric_funcUnit_uses },
  { "ae_la24x2.ic", ICLASS_AE_LA24X2_IC,
    0,
    Opcode_ae_la24x2_ic_encode_fns, 1, Opcode_ae_la24x2_ic_funcUnit_uses },
  { "ae_la24x2.ip", ICLASS_AE_LA24X2_IP,
    0,
    Opcode_ae_la24x2_ip_encode_fns, 1, Opcode_ae_la24x2_ip_funcUnit_uses },
  { "ae_la24x2.rip", ICLASS_AE_LA24X2_RIP,
    0,
    Opcode_ae_la24x2_rip_encode_fns, 1, Opcode_ae_la24x2_rip_funcUnit_uses },
  { "ae_la24x2.ric", ICLASS_AE_LA24X2_RIC,
    0,
    Opcode_ae_la24x2_ric_encode_fns, 1, Opcode_ae_la24x2_ric_funcUnit_uses },
  { "ae_sa32x2.ic", ICLASS_AE_SA32X2_IC,
    0,
    Opcode_ae_sa32x2_ic_encode_fns, 1, Opcode_ae_sa32x2_ic_funcUnit_uses },
  { "ae_sa32x2.ip", ICLASS_AE_SA32X2_IP,
    0,
    Opcode_ae_sa32x2_ip_encode_fns, 1, Opcode_ae_sa32x2_ip_funcUnit_uses },
  { "ae_sa32x2.rip", ICLASS_AE_SA32X2_RIP,
    0,
    Opcode_ae_sa32x2_rip_encode_fns, 1, Opcode_ae_sa32x2_rip_funcUnit_uses },
  { "ae_sa32x2.ric", ICLASS_AE_SA32X2_RIC,
    0,
    Opcode_ae_sa32x2_ric_encode_fns, 1, Opcode_ae_sa32x2_ric_funcUnit_uses },
  { "ae_sa16x4.ic", ICLASS_AE_SA16X4_IC,
    0,
    Opcode_ae_sa16x4_ic_encode_fns, 1, Opcode_ae_sa16x4_ic_funcUnit_uses },
  { "ae_sa16x4.ip", ICLASS_AE_SA16X4_IP,
    0,
    Opcode_ae_sa16x4_ip_encode_fns, 1, Opcode_ae_sa16x4_ip_funcUnit_uses },
  { "ae_sa16x4.rip", ICLASS_AE_SA16X4_RIP,
    0,
    Opcode_ae_sa16x4_rip_encode_fns, 1, Opcode_ae_sa16x4_rip_funcUnit_uses },
  { "ae_sa16x4.ric", ICLASS_AE_SA16X4_RIC,
    0,
    Opcode_ae_sa16x4_ric_encode_fns, 1, Opcode_ae_sa16x4_ric_funcUnit_uses },
  { "ae_sa32x2f24.ic", ICLASS_AE_SA32X2F24_IC,
    0,
    Opcode_ae_sa32x2f24_ic_encode_fns, 1, Opcode_ae_sa32x2f24_ic_funcUnit_uses },
  { "ae_sa32x2f24.ip", ICLASS_AE_SA32X2F24_IP,
    0,
    Opcode_ae_sa32x2f24_ip_encode_fns, 1, Opcode_ae_sa32x2f24_ip_funcUnit_uses },
  { "ae_sa32x2f24.rip", ICLASS_AE_SA32X2F24_RIP,
    0,
    Opcode_ae_sa32x2f24_rip_encode_fns, 1, Opcode_ae_sa32x2f24_rip_funcUnit_uses },
  { "ae_sa32x2f24.ric", ICLASS_AE_SA32X2F24_RIC,
    0,
    Opcode_ae_sa32x2f24_ric_encode_fns, 1, Opcode_ae_sa32x2f24_ric_funcUnit_uses },
  { "ae_sa24.l.ic", ICLASS_AE_SA24_L_IC,
    0,
    Opcode_ae_sa24_l_ic_encode_fns, 1, Opcode_ae_sa24_l_ic_funcUnit_uses },
  { "ae_sa24.l.ip", ICLASS_AE_SA24_L_IP,
    0,
    Opcode_ae_sa24_l_ip_encode_fns, 1, Opcode_ae_sa24_l_ip_funcUnit_uses },
  { "ae_sa24.l.rip", ICLASS_AE_SA24_L_RIP,
    0,
    Opcode_ae_sa24_l_rip_encode_fns, 1, Opcode_ae_sa24_l_rip_funcUnit_uses },
  { "ae_sa24.l.ric", ICLASS_AE_SA24_L_RIC,
    0,
    Opcode_ae_sa24_l_ric_encode_fns, 1, Opcode_ae_sa24_l_ric_funcUnit_uses },
  { "ae_sa24x2.ic", ICLASS_AE_SA24X2_IC,
    0,
    Opcode_ae_sa24x2_ic_encode_fns, 1, Opcode_ae_sa24x2_ic_funcUnit_uses },
  { "ae_sa24x2.ip", ICLASS_AE_SA24X2_IP,
    0,
    Opcode_ae_sa24x2_ip_encode_fns, 1, Opcode_ae_sa24x2_ip_funcUnit_uses },
  { "ae_sa24x2.rip", ICLASS_AE_SA24X2_RIP,
    0,
    Opcode_ae_sa24x2_rip_encode_fns, 1, Opcode_ae_sa24x2_rip_funcUnit_uses },
  { "ae_sa24x2.ric", ICLASS_AE_SA24X2_RIC,
    0,
    Opcode_ae_sa24x2_ric_encode_fns, 1, Opcode_ae_sa24x2_ric_funcUnit_uses },
  { "ae_s32ra64s.i", ICLASS_AE_S32RA64S_I,
    0,
    Opcode_ae_s32ra64s_i_encode_fns, 1, Opcode_ae_s32ra64s_i_funcUnit_uses },
  { "ae_s32ra64s.ip", ICLASS_AE_S32RA64S_IP,
    0,
    Opcode_ae_s32ra64s_ip_encode_fns, 1, Opcode_ae_s32ra64s_ip_funcUnit_uses },
  { "ae_s32ra64s.x", ICLASS_AE_S32RA64S_X,
    0,
    Opcode_ae_s32ra64s_x_encode_fns, 1, Opcode_ae_s32ra64s_x_funcUnit_uses },
  { "ae_s32ra64s.xp", ICLASS_AE_S32RA64S_XP,
    0,
    Opcode_ae_s32ra64s_xp_encode_fns, 1, Opcode_ae_s32ra64s_xp_funcUnit_uses },
  { "ae_s32ra64s.xc", ICLASS_AE_S32RA64S_XC,
    0,
    Opcode_ae_s32ra64s_xc_encode_fns, 1, Opcode_ae_s32ra64s_xc_funcUnit_uses },
  { "ae_s24ra64s.i", ICLASS_AE_S24RA64S_I,
    0,
    Opcode_ae_s24ra64s_i_encode_fns, 1, Opcode_ae_s24ra64s_i_funcUnit_uses },
  { "ae_s24ra64s.ip", ICLASS_AE_S24RA64S_IP,
    0,
    Opcode_ae_s24ra64s_ip_encode_fns, 1, Opcode_ae_s24ra64s_ip_funcUnit_uses },
  { "ae_s24ra64s.x", ICLASS_AE_S24RA64S_X,
    0,
    Opcode_ae_s24ra64s_x_encode_fns, 1, Opcode_ae_s24ra64s_x_funcUnit_uses },
  { "ae_s24ra64s.xp", ICLASS_AE_S24RA64S_XP,
    0,
    Opcode_ae_s24ra64s_xp_encode_fns, 1, Opcode_ae_s24ra64s_xp_funcUnit_uses },
  { "ae_s24ra64s.xc", ICLASS_AE_S24RA64S_XC,
    0,
    Opcode_ae_s24ra64s_xc_encode_fns, 1, Opcode_ae_s24ra64s_xc_funcUnit_uses },
  { "ae_s32x2ra64s.ip", ICLASS_AE_S32X2RA64S_IP,
    0,
    Opcode_ae_s32x2ra64s_ip_encode_fns, 1, Opcode_ae_s32x2ra64s_ip_funcUnit_uses },
  { "ae_s24x2ra64s.ip", ICLASS_AE_S24X2RA64S_IP,
    0,
    Opcode_ae_s24x2ra64s_ip_encode_fns, 1, Opcode_ae_s24x2ra64s_ip_funcUnit_uses },
  { "ae_addbrba32", ICLASS_AE_ADDBRBA32,
    0,
    Opcode_ae_addbrba32_encode_fns, 0, 0 },
  { "ae_sel16i", ICLASS_AE_SEL16I,
    0,
    Opcode_ae_sel16i_encode_fns, 0, 0 },
  { "ae_sel16i.n", ICLASS_AE_SEL16I_N,
    0,
    Opcode_ae_sel16i_n_encode_fns, 0, 0 },
  { "ae_shortswap", ICLASS_AE_SHORTSWAP,
    0,
    Opcode_ae_shortswap_encode_fns, 0, 0 },
  { "ae_movt16x4", ICLASS_AE_MOVT16X4,
    0,
    Opcode_ae_movt16x4_encode_fns, 0, 0 },
  { "ae_movf16x4", ICLASS_AE_MOVF16X4,
    0,
    Opcode_ae_movf16x4_encode_fns, 0, 0 },
  { "ae_movt32x2", ICLASS_AE_MOVT32X2,
    0,
    Opcode_ae_movt32x2_encode_fns, 0, 0 },
  { "ae_movf32x2", ICLASS_AE_MOVF32X2,
    0,
    Opcode_ae_movf32x2_encode_fns, 0, 0 },
  { "ae_movda32x2", ICLASS_AE_MOVDA32X2,
    0,
    Opcode_ae_movda32x2_encode_fns, 0, 0 },
  { "ae_movda32", ICLASS_AE_MOVDA32,
    0,
    Opcode_ae_movda32_encode_fns, 0, 0 },
  { "ae_movda16x2", ICLASS_AE_MOVDA16X2,
    0,
    Opcode_ae_movda16x2_encode_fns, 0, 0 },
  { "ae_movda16", ICLASS_AE_MOVDA16,
    0,
    Opcode_ae_movda16_encode_fns, 0, 0 },
  { "ae_movi", ICLASS_AE_MOVI,
    0,
    Opcode_ae_movi_encode_fns, 0, 0 },
  { "ae_truncp24a32x2", ICLASS_AE_TRUNCP24A32X2,
    0,
    Opcode_ae_truncp24a32x2_encode_fns, 0, 0 },
  { "ae_sat16x4", ICLASS_AE_SAT16X4,
    0,
    Opcode_ae_sat16x4_encode_fns, 0, 0 },
  { "ae_cvt32x2f16.32", ICLASS_AE_CVT32X2F16_32,
    0,
    Opcode_ae_cvt32x2f16_32_encode_fns, 0, 0 },
  { "ae_cvt32x2f16.10", ICLASS_AE_CVT32X2F16_10,
    0,
    Opcode_ae_cvt32x2f16_10_encode_fns, 0, 0 },
  { "ae_sext32x2d16.32", ICLASS_AE_SEXT32X2D16_32,
    0,
    Opcode_ae_sext32x2d16_32_encode_fns, 0, 0 },
  { "ae_sext32x2d16.10", ICLASS_AE_SEXT32X2D16_10,
    0,
    Opcode_ae_sext32x2d16_10_encode_fns, 0, 0 },
  { "ae_cvta32f24s.l", ICLASS_AE_CVTA32F24S_L,
    0,
    Opcode_ae_cvta32f24s_l_encode_fns, 0, 0 },
  { "ae_cvta32f24s.h", ICLASS_AE_CVTA32F24S_H,
    0,
    Opcode_ae_cvta32f24s_h_encode_fns, 0, 0 },
  { "ae_cvtp24a16x2.ll", ICLASS_AE_CVTP24A16X2_LL,
    0,
    Opcode_ae_cvtp24a16x2_ll_encode_fns, 0, 0 },
  { "ae_cvtp24a16x2.lh", ICLASS_AE_CVTP24A16X2_LH,
    0,
    Opcode_ae_cvtp24a16x2_lh_encode_fns, 0, 0 },
  { "ae_cvtp24a16x2.hl", ICLASS_AE_CVTP24A16X2_HL,
    0,
    Opcode_ae_cvtp24a16x2_hl_encode_fns, 0, 0 },
  { "ae_cvtp24a16x2.hh", ICLASS_AE_CVTP24A16X2_HH,
    0,
    Opcode_ae_cvtp24a16x2_hh_encode_fns, 0, 0 },
  { "ae_truncp24q48x2", ICLASS_AE_TRUNCP24Q48X2,
    0,
    Opcode_ae_truncp24q48x2_encode_fns, 0, 0 },
  { "ae_trunca32x2f64s", ICLASS_AE_TRUNCA32X2F64S,
    0,
    Opcode_ae_trunca32x2f64s_encode_fns, 0, 0 },
  { "ae_trunci32x2f64s", ICLASS_AE_TRUNCI32X2F64S,
    0,
    Opcode_ae_trunci32x2f64s_encode_fns, 0, 0 },
  { "ae_trunca32f64s.l", ICLASS_AE_TRUNCA32F64S_L,
    0,
    Opcode_ae_trunca32f64s_l_encode_fns, 0, 0 },
  { "ae_trunci32f64s.l", ICLASS_AE_TRUNCI32F64S_L,
    0,
    Opcode_ae_trunci32f64s_l_encode_fns, 0, 0 },
  { "ae_truncp16", ICLASS_AE_TRUNCP16,
    0,
    Opcode_ae_truncp16_encode_fns, 0, 0 },
  { "ae_round32x2f64ssym", ICLASS_AE_ROUND32X2F64SSYM,
    0,
    Opcode_ae_round32x2f64ssym_encode_fns, 0, 0 },
  { "ae_round32x2f64sasym", ICLASS_AE_ROUND32X2F64SASYM,
    0,
    Opcode_ae_round32x2f64sasym_encode_fns, 0, 0 },
  { "ae_round32x2f48ssym", ICLASS_AE_ROUND32X2F48SSYM,
    0,
    Opcode_ae_round32x2f48ssym_encode_fns, 0, 0 },
  { "ae_round32x2f48sasym", ICLASS_AE_ROUND32X2F48SASYM,
    0,
    Opcode_ae_round32x2f48sasym_encode_fns, 0, 0 },
  { "ae_round16x4f32ssym", ICLASS_AE_ROUND16X4F32SSYM,
    0,
    Opcode_ae_round16x4f32ssym_encode_fns, 0, 0 },
  { "ae_round16x4f32sasym", ICLASS_AE_ROUND16X4F32SASYM,
    0,
    Opcode_ae_round16x4f32sasym_encode_fns, 0, 0 },
  { "ae_round24x2f48ssym", ICLASS_AE_ROUND24X2F48SSYM,
    0,
    Opcode_ae_round24x2f48ssym_encode_fns, 0, 0 },
  { "ae_round24x2f48sasym", ICLASS_AE_ROUND24X2F48SASYM,
    0,
    Opcode_ae_round24x2f48sasym_encode_fns, 0, 0 },
  { "ae_roundsp16q48x2sym", ICLASS_AE_ROUNDSP16Q48X2SYM,
    0,
    Opcode_ae_roundsp16q48x2sym_encode_fns, 0, 0 },
  { "ae_roundsp16q48x2asym", ICLASS_AE_ROUNDSP16Q48X2ASYM,
    0,
    Opcode_ae_roundsp16q48x2asym_encode_fns, 0, 0 },
  { "ae_minabs32s", ICLASS_AE_MINABS32S,
    0,
    Opcode_ae_minabs32s_encode_fns, 0, 0 },
  { "ae_maxabs32s", ICLASS_AE_MAXABS32S,
    0,
    Opcode_ae_maxabs32s_encode_fns, 0, 0 },
  { "ae_roundsp16f24sym", ICLASS_AE_ROUNDSP16F24SYM,
    0,
    Opcode_ae_roundsp16f24sym_encode_fns, 0, 0 },
  { "ae_roundsp16f24asym", ICLASS_AE_ROUNDSP16F24ASYM,
    0,
    Opcode_ae_roundsp16f24asym_encode_fns, 0, 0 },
  { "ae_mov", ICLASS_AE_MOV,
    0,
    Opcode_ae_mov_encode_fns, 0, 0 },
  { "ae_movt64", ICLASS_AE_MOVT64,
    0,
    Opcode_ae_movt64_encode_fns, 0, 0 },
  { "ae_movf64", ICLASS_AE_MOVF64,
    0,
    Opcode_ae_movf64_encode_fns, 0, 0 },
  { "ae_cvtq56a32s", ICLASS_AE_CVTQ56A32S,
    0,
    Opcode_ae_cvtq56a32s_encode_fns, 0, 0 },
  { "ae_cvt48a32", ICLASS_AE_CVT48A32,
    0,
    Opcode_ae_cvt48a32_encode_fns, 0, 0 },
  { "ae_cvt64a32", ICLASS_AE_CVT64A32,
    0,
    Opcode_ae_cvt64a32_encode_fns, 0, 0 },
  { "ae_cvtq56p32s.l", ICLASS_AE_CVTQ56P32S_L,
    0,
    Opcode_ae_cvtq56p32s_l_encode_fns, 0, 0 },
  { "ae_cvtq56p32s.h", ICLASS_AE_CVTQ56P32S_H,
    0,
    Opcode_ae_cvtq56p32s_h_encode_fns, 0, 0 },
  { "ae_cvt64f32.h", ICLASS_AE_CVT64F32_H,
    0,
    Opcode_ae_cvt64f32_h_encode_fns, 0, 0 },
  { "ae_sat48s", ICLASS_AE_SAT48S,
    0,
    Opcode_ae_sat48s_encode_fns, 0, 0 },
  { "ae_satq56s", ICLASS_AE_SATQ56S,
    0,
    Opcode_ae_satq56s_encode_fns, 0, 0 },
  { "ae_sat24s", ICLASS_AE_SAT24S,
    0,
    Opcode_ae_sat24s_encode_fns, 0, 0 },
  { "ae_truncq32", ICLASS_AE_TRUNCQ32,
    0,
    Opcode_ae_truncq32_encode_fns, 0, 0 },
  { "ae_minabs64s", ICLASS_AE_MINABS64S,
    0,
    Opcode_ae_minabs64s_encode_fns, 0, 0 },
  { "ae_maxabs64s", ICLASS_AE_MAXABS64S,
    0,
    Opcode_ae_maxabs64s_encode_fns, 0, 0 },
  { "ae_roundsq32f48sym", ICLASS_AE_ROUNDSQ32F48SYM,
    0,
    Opcode_ae_roundsq32f48sym_encode_fns, 0, 0 },
  { "ae_roundsq32f48asym", ICLASS_AE_ROUNDSQ32F48ASYM,
    0,
    Opcode_ae_roundsq32f48asym_encode_fns, 0, 0 },
  { "ae_trunca32q48", ICLASS_AE_TRUNCA32Q48,
    0,
    Opcode_ae_trunca32q48_encode_fns, 0, 0 },
  { "ae_movad32.l", ICLASS_AE_MOVAD32_L,
    0,
    Opcode_ae_movad32_l_encode_fns, 0, 0 },
  { "ae_movad32.h", ICLASS_AE_MOVAD32_H,
    0,
    Opcode_ae_movad32_h_encode_fns, 0, 0 },
  { "ae_movad16.3", ICLASS_AE_MOVAD16_3,
    0,
    Opcode_ae_movad16_3_encode_fns, 0, 0 },
  { "ae_movad16.2", ICLASS_AE_MOVAD16_2,
    0,
    Opcode_ae_movad16_2_encode_fns, 0, 0 },
  { "ae_movad16.1", ICLASS_AE_MOVAD16_1,
    0,
    Opcode_ae_movad16_1_encode_fns, 0, 0 },
  { "ae_movad16.0", ICLASS_AE_MOVAD16_0,
    0,
    Opcode_ae_movad16_0_encode_fns, 0, 0 },
  { "ae_sra64_32", ICLASS_AE_SRA64_32,
    0,
    Opcode_ae_sra64_32_encode_fns, 0, 0 },
  { "ae_pksr32", ICLASS_AE_PKSR32,
    0,
    Opcode_ae_pksr32_encode_fns, 0, 0 },
  { "ae_pksr24", ICLASS_AE_PKSR24,
    0,
    Opcode_ae_pksr24_encode_fns, 0, 0 },
  { "ae_trunca16p24s.l", ICLASS_AE_TRUNCA16P24S_L,
    0,
    Opcode_ae_trunca16p24s_l_encode_fns, 0, 0 },
  { "ae_trunca16p24s.h", ICLASS_AE_TRUNCA16P24S_H,
    0,
    Opcode_ae_trunca16p24s_h_encode_fns, 0, 0 },
  { "ae_add32", ICLASS_AE_ADD32,
    0,
    Opcode_ae_add32_encode_fns, 0, 0 },
  { "ae_sub32", ICLASS_AE_SUB32,
    0,
    Opcode_ae_sub32_encode_fns, 0, 0 },
  { "ae_addsub32", ICLASS_AE_ADDSUB32,
    0,
    Opcode_ae_addsub32_encode_fns, 0, 0 },
  { "ae_subadd32", ICLASS_AE_SUBADD32,
    0,
    Opcode_ae_subadd32_encode_fns, 0, 0 },
  { "ae_add16", ICLASS_AE_ADD16,
    0,
    Opcode_ae_add16_encode_fns, 0, 0 },
  { "ae_sub16", ICLASS_AE_SUB16,
    0,
    Opcode_ae_sub16_encode_fns, 0, 0 },
  { "ae_add32_hl_lh", ICLASS_AE_ADD32_HL_LH,
    0,
    Opcode_ae_add32_hl_lh_encode_fns, 0, 0 },
  { "ae_neg32", ICLASS_AE_NEG32,
    0,
    Opcode_ae_neg32_encode_fns, 0, 0 },
  { "ae_abs32", ICLASS_AE_ABS32,
    0,
    Opcode_ae_abs32_encode_fns, 0, 0 },
  { "ae_add24s", ICLASS_AE_ADD24S,
    0,
    Opcode_ae_add24s_encode_fns, 0, 0 },
  { "ae_sub24s", ICLASS_AE_SUB24S,
    0,
    Opcode_ae_sub24s_encode_fns, 0, 0 },
  { "ae_add32s", ICLASS_AE_ADD32S,
    0,
    Opcode_ae_add32s_encode_fns, 0, 0 },
  { "ae_sub32s", ICLASS_AE_SUB32S,
    0,
    Opcode_ae_sub32s_encode_fns, 0, 0 },
  { "ae_addsub32s", ICLASS_AE_ADDSUB32S,
    0,
    Opcode_ae_addsub32s_encode_fns, 0, 0 },
  { "ae_subadd32s", ICLASS_AE_SUBADD32S,
    0,
    Opcode_ae_subadd32s_encode_fns, 0, 0 },
  { "ae_add16s", ICLASS_AE_ADD16S,
    0,
    Opcode_ae_add16s_encode_fns, 0, 0 },
  { "ae_sub16s", ICLASS_AE_SUB16S,
    0,
    Opcode_ae_sub16s_encode_fns, 0, 0 },
  { "ae_neg24s", ICLASS_AE_NEG24S,
    0,
    Opcode_ae_neg24s_encode_fns, 0, 0 },
  { "ae_abs24s", ICLASS_AE_ABS24S,
    0,
    Opcode_ae_abs24s_encode_fns, 0, 0 },
  { "ae_neg32s", ICLASS_AE_NEG32S,
    0,
    Opcode_ae_neg32s_encode_fns, 0, 0 },
  { "ae_abs32s", ICLASS_AE_ABS32S,
    0,
    Opcode_ae_abs32s_encode_fns, 0, 0 },
  { "ae_neg16s", ICLASS_AE_NEG16S,
    0,
    Opcode_ae_neg16s_encode_fns, 0, 0 },
  { "ae_abs16s", ICLASS_AE_ABS16S,
    0,
    Opcode_ae_abs16s_encode_fns, 0, 0 },
  { "ae_lt16", ICLASS_AE_LT16,
    0,
    Opcode_ae_lt16_encode_fns, 0, 0 },
  { "ae_le16", ICLASS_AE_LE16,
    0,
    Opcode_ae_le16_encode_fns, 0, 0 },
  { "ae_eq16", ICLASS_AE_EQ16,
    0,
    Opcode_ae_eq16_encode_fns, 0, 0 },
  { "ae_lt32", ICLASS_AE_LT32,
    0,
    Opcode_ae_lt32_encode_fns, 0, 0 },
  { "ae_le32", ICLASS_AE_LE32,
    0,
    Opcode_ae_le32_encode_fns, 0, 0 },
  { "ae_eq32", ICLASS_AE_EQ32,
    0,
    Opcode_ae_eq32_encode_fns, 0, 0 },
  { "ae_min32", ICLASS_AE_MIN32,
    0,
    Opcode_ae_min32_encode_fns, 0, 0 },
  { "ae_max32", ICLASS_AE_MAX32,
    0,
    Opcode_ae_max32_encode_fns, 0, 0 },
  { "ae_add64", ICLASS_AE_ADD64,
    0,
    Opcode_ae_add64_encode_fns, 0, 0 },
  { "ae_sub64", ICLASS_AE_SUB64,
    0,
    Opcode_ae_sub64_encode_fns, 0, 0 },
  { "ae_neg64", ICLASS_AE_NEG64,
    0,
    Opcode_ae_neg64_encode_fns, 0, 0 },
  { "ae_abs64", ICLASS_AE_ABS64,
    0,
    Opcode_ae_abs64_encode_fns, 0, 0 },
  { "ae_addsq56s", ICLASS_AE_ADDSQ56S,
    0,
    Opcode_ae_addsq56s_encode_fns, 0, 0 },
  { "ae_subsq56s", ICLASS_AE_SUBSQ56S,
    0,
    Opcode_ae_subsq56s_encode_fns, 0, 0 },
  { "ae_add64s", ICLASS_AE_ADD64S,
    0,
    Opcode_ae_add64s_encode_fns, 0, 0 },
  { "ae_sub64s", ICLASS_AE_SUB64S,
    0,
    Opcode_ae_sub64s_encode_fns, 0, 0 },
  { "ae_negsq56s", ICLASS_AE_NEGSQ56S,
    0,
    Opcode_ae_negsq56s_encode_fns, 0, 0 },
  { "ae_abssq56s", ICLASS_AE_ABSSQ56S,
    0,
    Opcode_ae_abssq56s_encode_fns, 0, 0 },
  { "ae_neg64s", ICLASS_AE_NEG64S,
    0,
    Opcode_ae_neg64s_encode_fns, 0, 0 },
  { "ae_abs64s", ICLASS_AE_ABS64S,
    0,
    Opcode_ae_abs64s_encode_fns, 0, 0 },
  { "ae_and", ICLASS_AE_AND,
    0,
    Opcode_ae_and_encode_fns, 0, 0 },
  { "ae_nand", ICLASS_AE_NAND,
    0,
    Opcode_ae_nand_encode_fns, 0, 0 },
  { "ae_or", ICLASS_AE_OR,
    0,
    Opcode_ae_or_encode_fns, 0, 0 },
  { "ae_xor", ICLASS_AE_XOR,
    0,
    Opcode_ae_xor_encode_fns, 0, 0 },
  { "ae_slai24", ICLASS_AE_SLAI24,
    0,
    Opcode_ae_slai24_encode_fns, 0, 0 },
  { "ae_srli24", ICLASS_AE_SRLI24,
    0,
    Opcode_ae_srli24_encode_fns, 0, 0 },
  { "ae_srai24", ICLASS_AE_SRAI24,
    0,
    Opcode_ae_srai24_encode_fns, 0, 0 },
  { "ae_slas24", ICLASS_AE_SLAS24,
    0,
    Opcode_ae_slas24_encode_fns, 0, 0 },
  { "ae_srls24", ICLASS_AE_SRLS24,
    0,
    Opcode_ae_srls24_encode_fns, 0, 0 },
  { "ae_sras24", ICLASS_AE_SRAS24,
    0,
    Opcode_ae_sras24_encode_fns, 0, 0 },
  { "ae_srai16", ICLASS_AE_SRAI16,
    0,
    Opcode_ae_srai16_encode_fns, 0, 0 },
  { "ae_srai16r", ICLASS_AE_SRAI16R,
    0,
    Opcode_ae_srai16r_encode_fns, 0, 0 },
  { "ae_slai32", ICLASS_AE_SLAI32,
    0,
    Opcode_ae_slai32_encode_fns, 0, 0 },
  { "ae_srli32", ICLASS_AE_SRLI32,
    0,
    Opcode_ae_srli32_encode_fns, 0, 0 },
  { "ae_srai32", ICLASS_AE_SRAI32,
    0,
    Opcode_ae_srai32_encode_fns, 0, 0 },
  { "ae_srai32r", ICLASS_AE_SRAI32R,
    0,
    Opcode_ae_srai32r_encode_fns, 0, 0 },
  { "ae_slas32", ICLASS_AE_SLAS32,
    0,
    Opcode_ae_slas32_encode_fns, 0, 0 },
  { "ae_srls32", ICLASS_AE_SRLS32,
    0,
    Opcode_ae_srls32_encode_fns, 0, 0 },
  { "ae_sras32", ICLASS_AE_SRAS32,
    0,
    Opcode_ae_sras32_encode_fns, 0, 0 },
  { "ae_slaa32", ICLASS_AE_SLAA32,
    0,
    Opcode_ae_slaa32_encode_fns, 0, 0 },
  { "ae_srla32", ICLASS_AE_SRLA32,
    0,
    Opcode_ae_srla32_encode_fns, 0, 0 },
  { "ae_sraa32", ICLASS_AE_SRAA32,
    0,
    Opcode_ae_sraa32_encode_fns, 0, 0 },
  { "ae_slai16s", ICLASS_AE_SLAI16S,
    0,
    Opcode_ae_slai16s_encode_fns, 0, 0 },
  { "ae_slaa16s", ICLASS_AE_SLAA16S,
    0,
    Opcode_ae_slaa16s_encode_fns, 0, 0 },
  { "ae_sraa16s", ICLASS_AE_SRAA16S,
    0,
    Opcode_ae_sraa16s_encode_fns, 0, 0 },
  { "ae_sraa16rs", ICLASS_AE_SRAA16RS,
    0,
    Opcode_ae_sraa16rs_encode_fns, 0, 0 },
  { "ae_slai24s", ICLASS_AE_SLAI24S,
    0,
    Opcode_ae_slai24s_encode_fns, 0, 0 },
  { "ae_slas24s", ICLASS_AE_SLAS24S,
    0,
    Opcode_ae_slas24s_encode_fns, 0, 0 },
  { "ae_slai32s", ICLASS_AE_SLAI32S,
    0,
    Opcode_ae_slai32s_encode_fns, 0, 0 },
  { "ae_slas32s", ICLASS_AE_SLAS32S,
    0,
    Opcode_ae_slas32s_encode_fns, 0, 0 },
  { "ae_slaa32s", ICLASS_AE_SLAA32S,
    0,
    Opcode_ae_slaa32s_encode_fns, 0, 0 },
  { "ae_sraa32s", ICLASS_AE_SRAA32S,
    0,
    Opcode_ae_sraa32s_encode_fns, 0, 0 },
  { "ae_sraa32rs", ICLASS_AE_SRAA32RS,
    0,
    Opcode_ae_sraa32rs_encode_fns, 0, 0 },
  { "ae_slasq56", ICLASS_AE_SLASQ56,
    0,
    Opcode_ae_slasq56_encode_fns, 0, 0 },
  { "ae_srlsq56", ICLASS_AE_SRLSQ56,
    0,
    Opcode_ae_srlsq56_encode_fns, 0, 0 },
  { "ae_srasq56", ICLASS_AE_SRASQ56,
    0,
    Opcode_ae_srasq56_encode_fns, 0, 0 },
  { "ae_slaaq56", ICLASS_AE_SLAAQ56,
    0,
    Opcode_ae_slaaq56_encode_fns, 0, 0 },
  { "ae_srlaq56", ICLASS_AE_SRLAQ56,
    0,
    Opcode_ae_srlaq56_encode_fns, 0, 0 },
  { "ae_sraaq56", ICLASS_AE_SRAAQ56,
    0,
    Opcode_ae_sraaq56_encode_fns, 0, 0 },
  { "ae_slai64", ICLASS_AE_SLAI64,
    0,
    Opcode_ae_slai64_encode_fns, 0, 0 },
  { "ae_srli64", ICLASS_AE_SRLI64,
    0,
    Opcode_ae_srli64_encode_fns, 0, 0 },
  { "ae_srai64", ICLASS_AE_SRAI64,
    0,
    Opcode_ae_srai64_encode_fns, 0, 0 },
  { "ae_slas64", ICLASS_AE_SLAS64,
    0,
    Opcode_ae_slas64_encode_fns, 0, 0 },
  { "ae_srls64", ICLASS_AE_SRLS64,
    0,
    Opcode_ae_srls64_encode_fns, 0, 0 },
  { "ae_sras64", ICLASS_AE_SRAS64,
    0,
    Opcode_ae_sras64_encode_fns, 0, 0 },
  { "ae_slaa64", ICLASS_AE_SLAA64,
    0,
    Opcode_ae_slaa64_encode_fns, 0, 0 },
  { "ae_srla64", ICLASS_AE_SRLA64,
    0,
    Opcode_ae_srla64_encode_fns, 0, 0 },
  { "ae_sraa64", ICLASS_AE_SRAA64,
    0,
    Opcode_ae_sraa64_encode_fns, 0, 0 },
  { "ae_slaisq56s", ICLASS_AE_SLAISQ56S,
    0,
    Opcode_ae_slaisq56s_encode_fns, 0, 0 },
  { "ae_slassq56s", ICLASS_AE_SLASSQ56S,
    0,
    Opcode_ae_slassq56s_encode_fns, 0, 0 },
  { "ae_slaasq56s", ICLASS_AE_SLAASQ56S,
    0,
    Opcode_ae_slaasq56s_encode_fns, 0, 0 },
  { "ae_slai64s", ICLASS_AE_SLAI64S,
    0,
    Opcode_ae_slai64s_encode_fns, 0, 0 },
  { "ae_slas64s", ICLASS_AE_SLAS64S,
    0,
    Opcode_ae_slas64s_encode_fns, 0, 0 },
  { "ae_slaa64s", ICLASS_AE_SLAA64S,
    0,
    Opcode_ae_slaa64s_encode_fns, 0, 0 },
  { "ae_lt64", ICLASS_AE_LT64,
    0,
    Opcode_ae_lt64_encode_fns, 0, 0 },
  { "ae_le64", ICLASS_AE_LE64,
    0,
    Opcode_ae_le64_encode_fns, 0, 0 },
  { "ae_eq64", ICLASS_AE_EQ64,
    0,
    Opcode_ae_eq64_encode_fns, 0, 0 },
  { "ae_max64", ICLASS_AE_MAX64,
    0,
    Opcode_ae_max64_encode_fns, 0, 0 },
  { "ae_min64", ICLASS_AE_MIN64,
    0,
    Opcode_ae_min64_encode_fns, 0, 0 },
  { "ae_nsa64", ICLASS_AE_NSA64,
    0,
    Opcode_ae_nsa64_encode_fns, 0, 0 },
  { "ae_nsaz16.0", ICLASS_AE_NSAZ16_0,
    0,
    Opcode_ae_nsaz16_0_encode_fns, 0, 0 },
  { "ae_nsaz32.l", ICLASS_AE_NSAZ32_L,
    0,
    Opcode_ae_nsaz32_l_encode_fns, 0, 0 },
  { "ae_muls32f48p16s.ll", ICLASS_AE_MULS32F48P16S_LL,
    0,
    Opcode_ae_muls32f48p16s_ll_encode_fns, 1, Opcode_ae_muls32f48p16s_ll_funcUnit_uses },
  { "ae_mulf32s.ll", ICLASS_AE_MULF32S_LL,
    0,
    Opcode_ae_mulf32s_ll_encode_fns, 1, Opcode_ae_mulf32s_ll_funcUnit_uses },
  { "ae_mul32.ll", ICLASS_AE_MUL32_LL,
    0,
    Opcode_ae_mul32_ll_encode_fns, 1, Opcode_ae_mul32_ll_funcUnit_uses },
  { "ae_muls32f48p16s.ll_s2", ICLASS_AE_MULS32F48P16S_LL_S2,
    0,
    Opcode_ae_muls32f48p16s_ll_s2_encode_fns, 1, Opcode_ae_muls32f48p16s_ll_s2_funcUnit_uses },
  { "ae_mulf32r.ll", ICLASS_AE_MULF32R_LL,
    0,
    Opcode_ae_mulf32r_ll_encode_fns, 1, Opcode_ae_mulf32r_ll_funcUnit_uses },
  { "ae_muls32f48p16s.lh", ICLASS_AE_MULS32F48P16S_LH,
    0,
    Opcode_ae_muls32f48p16s_lh_encode_fns, 1, Opcode_ae_muls32f48p16s_lh_funcUnit_uses },
  { "ae_mulf32s.lh", ICLASS_AE_MULF32S_LH,
    0,
    Opcode_ae_mulf32s_lh_encode_fns, 1, Opcode_ae_mulf32s_lh_funcUnit_uses },
  { "ae_mul32.lh", ICLASS_AE_MUL32_LH,
    0,
    Opcode_ae_mul32_lh_encode_fns, 1, Opcode_ae_mul32_lh_funcUnit_uses },
  { "ae_muls32f48p16s.lh_s2", ICLASS_AE_MULS32F48P16S_LH_S2,
    0,
    Opcode_ae_muls32f48p16s_lh_s2_encode_fns, 1, Opcode_ae_muls32f48p16s_lh_s2_funcUnit_uses },
  { "ae_mulf32r.lh", ICLASS_AE_MULF32R_LH,
    0,
    Opcode_ae_mulf32r_lh_encode_fns, 1, Opcode_ae_mulf32r_lh_funcUnit_uses },
  { "ae_muls32f48p16s.hh", ICLASS_AE_MULS32F48P16S_HH,
    0,
    Opcode_ae_muls32f48p16s_hh_encode_fns, 1, Opcode_ae_muls32f48p16s_hh_funcUnit_uses },
  { "ae_mulf32s.hh", ICLASS_AE_MULF32S_HH,
    0,
    Opcode_ae_mulf32s_hh_encode_fns, 1, Opcode_ae_mulf32s_hh_funcUnit_uses },
  { "ae_mul32.hh", ICLASS_AE_MUL32_HH,
    0,
    Opcode_ae_mul32_hh_encode_fns, 1, Opcode_ae_mul32_hh_funcUnit_uses },
  { "ae_muls32f48p16s.hh_s2", ICLASS_AE_MULS32F48P16S_HH_S2,
    0,
    Opcode_ae_muls32f48p16s_hh_s2_encode_fns, 1, Opcode_ae_muls32f48p16s_hh_s2_funcUnit_uses },
  { "ae_mulf32r.hh", ICLASS_AE_MULF32R_HH,
    0,
    Opcode_ae_mulf32r_hh_encode_fns, 1, Opcode_ae_mulf32r_hh_funcUnit_uses },
  { "ae_mulf32r.ll_s2", ICLASS_AE_MULF32R_LL_S2,
    0,
    Opcode_ae_mulf32r_ll_s2_encode_fns, 1, Opcode_ae_mulf32r_ll_s2_funcUnit_uses },
  { "ae_mulas32f48p16s.ll", ICLASS_AE_MULAS32F48P16S_LL,
    0,
    Opcode_ae_mulas32f48p16s_ll_encode_fns, 1, Opcode_ae_mulas32f48p16s_ll_funcUnit_uses },
  { "ae_mulaf32s.ll", ICLASS_AE_MULAF32S_LL,
    0,
    Opcode_ae_mulaf32s_ll_encode_fns, 1, Opcode_ae_mulaf32s_ll_funcUnit_uses },
  { "ae_mula32.ll", ICLASS_AE_MULA32_LL,
    0,
    Opcode_ae_mula32_ll_encode_fns, 1, Opcode_ae_mula32_ll_funcUnit_uses },
  { "ae_mulas32f48p16s.ll_s2", ICLASS_AE_MULAS32F48P16S_LL_S2,
    0,
    Opcode_ae_mulas32f48p16s_ll_s2_encode_fns, 1, Opcode_ae_mulas32f48p16s_ll_s2_funcUnit_uses },
  { "ae_mulaf32r.ll", ICLASS_AE_MULAF32R_LL,
    0,
    Opcode_ae_mulaf32r_ll_encode_fns, 1, Opcode_ae_mulaf32r_ll_funcUnit_uses },
  { "ae_mulas32f48p16s.lh", ICLASS_AE_MULAS32F48P16S_LH,
    0,
    Opcode_ae_mulas32f48p16s_lh_encode_fns, 1, Opcode_ae_mulas32f48p16s_lh_funcUnit_uses },
  { "ae_mulaf32s.lh", ICLASS_AE_MULAF32S_LH,
    0,
    Opcode_ae_mulaf32s_lh_encode_fns, 1, Opcode_ae_mulaf32s_lh_funcUnit_uses },
  { "ae_mula32.lh", ICLASS_AE_MULA32_LH,
    0,
    Opcode_ae_mula32_lh_encode_fns, 1, Opcode_ae_mula32_lh_funcUnit_uses },
  { "ae_mulas32f48p16s.lh_s2", ICLASS_AE_MULAS32F48P16S_LH_S2,
    0,
    Opcode_ae_mulas32f48p16s_lh_s2_encode_fns, 1, Opcode_ae_mulas32f48p16s_lh_s2_funcUnit_uses },
  { "ae_mulaf32r.lh", ICLASS_AE_MULAF32R_LH,
    0,
    Opcode_ae_mulaf32r_lh_encode_fns, 1, Opcode_ae_mulaf32r_lh_funcUnit_uses },
  { "ae_mulas32f48p16s.hh", ICLASS_AE_MULAS32F48P16S_HH,
    0,
    Opcode_ae_mulas32f48p16s_hh_encode_fns, 1, Opcode_ae_mulas32f48p16s_hh_funcUnit_uses },
  { "ae_mulaf32s.hh", ICLASS_AE_MULAF32S_HH,
    0,
    Opcode_ae_mulaf32s_hh_encode_fns, 1, Opcode_ae_mulaf32s_hh_funcUnit_uses },
  { "ae_mula32.hh", ICLASS_AE_MULA32_HH,
    0,
    Opcode_ae_mula32_hh_encode_fns, 1, Opcode_ae_mula32_hh_funcUnit_uses },
  { "ae_mulas32f48p16s.hh_s2", ICLASS_AE_MULAS32F48P16S_HH_S2,
    0,
    Opcode_ae_mulas32f48p16s_hh_s2_encode_fns, 1, Opcode_ae_mulas32f48p16s_hh_s2_funcUnit_uses },
  { "ae_mulaf32r.hh", ICLASS_AE_MULAF32R_HH,
    0,
    Opcode_ae_mulaf32r_hh_encode_fns, 1, Opcode_ae_mulaf32r_hh_funcUnit_uses },
  { "ae_mulaf32r.ll_s2", ICLASS_AE_MULAF32R_LL_S2,
    0,
    Opcode_ae_mulaf32r_ll_s2_encode_fns, 1, Opcode_ae_mulaf32r_ll_s2_funcUnit_uses },
  { "ae_mulss32f48p16s.ll", ICLASS_AE_MULSS32F48P16S_LL,
    0,
    Opcode_ae_mulss32f48p16s_ll_encode_fns, 1, Opcode_ae_mulss32f48p16s_ll_funcUnit_uses },
  { "ae_mulsf32s.ll", ICLASS_AE_MULSF32S_LL,
    0,
    Opcode_ae_mulsf32s_ll_encode_fns, 1, Opcode_ae_mulsf32s_ll_funcUnit_uses },
  { "ae_muls32.ll", ICLASS_AE_MULS32_LL,
    0,
    Opcode_ae_muls32_ll_encode_fns, 1, Opcode_ae_muls32_ll_funcUnit_uses },
  { "ae_mulss32f48p16s.ll_s2", ICLASS_AE_MULSS32F48P16S_LL_S2,
    0,
    Opcode_ae_mulss32f48p16s_ll_s2_encode_fns, 1, Opcode_ae_mulss32f48p16s_ll_s2_funcUnit_uses },
  { "ae_mulsf32r.ll", ICLASS_AE_MULSF32R_LL,
    0,
    Opcode_ae_mulsf32r_ll_encode_fns, 1, Opcode_ae_mulsf32r_ll_funcUnit_uses },
  { "ae_mulss32f48p16s.lh", ICLASS_AE_MULSS32F48P16S_LH,
    0,
    Opcode_ae_mulss32f48p16s_lh_encode_fns, 1, Opcode_ae_mulss32f48p16s_lh_funcUnit_uses },
  { "ae_mulsf32s.lh", ICLASS_AE_MULSF32S_LH,
    0,
    Opcode_ae_mulsf32s_lh_encode_fns, 1, Opcode_ae_mulsf32s_lh_funcUnit_uses },
  { "ae_muls32.lh", ICLASS_AE_MULS32_LH,
    0,
    Opcode_ae_muls32_lh_encode_fns, 1, Opcode_ae_muls32_lh_funcUnit_uses },
  { "ae_mulss32f48p16s.lh_s2", ICLASS_AE_MULSS32F48P16S_LH_S2,
    0,
    Opcode_ae_mulss32f48p16s_lh_s2_encode_fns, 1, Opcode_ae_mulss32f48p16s_lh_s2_funcUnit_uses },
  { "ae_mulsf32r.lh", ICLASS_AE_MULSF32R_LH,
    0,
    Opcode_ae_mulsf32r_lh_encode_fns, 1, Opcode_ae_mulsf32r_lh_funcUnit_uses },
  { "ae_mulss32f48p16s.hh", ICLASS_AE_MULSS32F48P16S_HH,
    0,
    Opcode_ae_mulss32f48p16s_hh_encode_fns, 1, Opcode_ae_mulss32f48p16s_hh_funcUnit_uses },
  { "ae_mulsf32s.hh", ICLASS_AE_MULSF32S_HH,
    0,
    Opcode_ae_mulsf32s_hh_encode_fns, 1, Opcode_ae_mulsf32s_hh_funcUnit_uses },
  { "ae_muls32.hh", ICLASS_AE_MULS32_HH,
    0,
    Opcode_ae_muls32_hh_encode_fns, 1, Opcode_ae_muls32_hh_funcUnit_uses },
  { "ae_mulss32f48p16s.hh_s2", ICLASS_AE_MULSS32F48P16S_HH_S2,
    0,
    Opcode_ae_mulss32f48p16s_hh_s2_encode_fns, 1, Opcode_ae_mulss32f48p16s_hh_s2_funcUnit_uses },
  { "ae_mulsf32r.hh", ICLASS_AE_MULSF32R_HH,
    0,
    Opcode_ae_mulsf32r_hh_encode_fns, 1, Opcode_ae_mulsf32r_hh_funcUnit_uses },
  { "ae_mulsf32r.ll_s2", ICLASS_AE_MULSF32R_LL_S2,
    0,
    Opcode_ae_mulsf32r_ll_s2_encode_fns, 1, Opcode_ae_mulsf32r_ll_s2_funcUnit_uses },
  { "ae_mulf32s.ll_s2", ICLASS_AE_MULF32S_LL_S2,
    0,
    Opcode_ae_mulf32s_ll_s2_encode_fns, 1, Opcode_ae_mulf32s_ll_s2_funcUnit_uses },
  { "ae_mulaf32s.ll_s2", ICLASS_AE_MULAF32S_LL_S2,
    0,
    Opcode_ae_mulaf32s_ll_s2_encode_fns, 1, Opcode_ae_mulaf32s_ll_s2_funcUnit_uses },
  { "ae_mul32.ll_s2", ICLASS_AE_MUL32_LL_S2,
    0,
    Opcode_ae_mul32_ll_s2_encode_fns, 1, Opcode_ae_mul32_ll_s2_funcUnit_uses },
  { "ae_mula32.ll_s2", ICLASS_AE_MULA32_LL_S2,
    0,
    Opcode_ae_mula32_ll_s2_encode_fns, 1, Opcode_ae_mula32_ll_s2_funcUnit_uses },
  { "ae_mul32u.ll", ICLASS_AE_MUL32U_LL,
    0,
    Opcode_ae_mul32u_ll_encode_fns, 1, Opcode_ae_mul32u_ll_funcUnit_uses },
  { "ae_mula32u.ll", ICLASS_AE_MULA32U_LL,
    0,
    Opcode_ae_mula32u_ll_encode_fns, 1, Opcode_ae_mula32u_ll_funcUnit_uses },
  { "ae_muls32u.ll", ICLASS_AE_MULS32U_LL,
    0,
    Opcode_ae_muls32u_ll_encode_fns, 1, Opcode_ae_muls32u_ll_funcUnit_uses },
  { "ae_mulf16ss.33", ICLASS_AE_MULF16SS_33,
    0,
    Opcode_ae_mulf16ss_33_encode_fns, 1, Opcode_ae_mulf16ss_33_funcUnit_uses },
  { "ae_mulf16ss.22", ICLASS_AE_MULF16SS_22,
    0,
    Opcode_ae_mulf16ss_22_encode_fns, 1, Opcode_ae_mulf16ss_22_funcUnit_uses },
  { "ae_mulf16ss.32", ICLASS_AE_MULF16SS_32,
    0,
    Opcode_ae_mulf16ss_32_encode_fns, 1, Opcode_ae_mulf16ss_32_funcUnit_uses },
  { "ae_mulf16ss.21", ICLASS_AE_MULF16SS_21,
    0,
    Opcode_ae_mulf16ss_21_encode_fns, 1, Opcode_ae_mulf16ss_21_funcUnit_uses },
  { "ae_mulf16ss.31", ICLASS_AE_MULF16SS_31,
    0,
    Opcode_ae_mulf16ss_31_encode_fns, 1, Opcode_ae_mulf16ss_31_funcUnit_uses },
  { "ae_mulf16ss.30", ICLASS_AE_MULF16SS_30,
    0,
    Opcode_ae_mulf16ss_30_encode_fns, 1, Opcode_ae_mulf16ss_30_funcUnit_uses },
  { "ae_mulf16ss.10", ICLASS_AE_MULF16SS_10,
    0,
    Opcode_ae_mulf16ss_10_encode_fns, 1, Opcode_ae_mulf16ss_10_funcUnit_uses },
  { "ae_mulf16ss.20", ICLASS_AE_MULF16SS_20,
    0,
    Opcode_ae_mulf16ss_20_encode_fns, 1, Opcode_ae_mulf16ss_20_funcUnit_uses },
  { "ae_mulf16ss.11", ICLASS_AE_MULF16SS_11,
    0,
    Opcode_ae_mulf16ss_11_encode_fns, 1, Opcode_ae_mulf16ss_11_funcUnit_uses },
  { "ae_mulf16ss.00", ICLASS_AE_MULF16SS_00,
    0,
    Opcode_ae_mulf16ss_00_encode_fns, 1, Opcode_ae_mulf16ss_00_funcUnit_uses },
  { "ae_mulf16ss.00_s2", ICLASS_AE_MULF16SS_00_S2,
    0,
    Opcode_ae_mulf16ss_00_s2_encode_fns, 1, Opcode_ae_mulf16ss_00_s2_funcUnit_uses },
  { "ae_mulsf16ss.33", ICLASS_AE_MULSF16SS_33,
    0,
    Opcode_ae_mulsf16ss_33_encode_fns, 1, Opcode_ae_mulsf16ss_33_funcUnit_uses },
  { "ae_mulsf16ss.22", ICLASS_AE_MULSF16SS_22,
    0,
    Opcode_ae_mulsf16ss_22_encode_fns, 1, Opcode_ae_mulsf16ss_22_funcUnit_uses },
  { "ae_mulsf16ss.32", ICLASS_AE_MULSF16SS_32,
    0,
    Opcode_ae_mulsf16ss_32_encode_fns, 1, Opcode_ae_mulsf16ss_32_funcUnit_uses },
  { "ae_mulsf16ss.21", ICLASS_AE_MULSF16SS_21,
    0,
    Opcode_ae_mulsf16ss_21_encode_fns, 1, Opcode_ae_mulsf16ss_21_funcUnit_uses },
  { "ae_mulsf16ss.31", ICLASS_AE_MULSF16SS_31,
    0,
    Opcode_ae_mulsf16ss_31_encode_fns, 1, Opcode_ae_mulsf16ss_31_funcUnit_uses },
  { "ae_mulsf16ss.30", ICLASS_AE_MULSF16SS_30,
    0,
    Opcode_ae_mulsf16ss_30_encode_fns, 1, Opcode_ae_mulsf16ss_30_funcUnit_uses },
  { "ae_mulsf16ss.10", ICLASS_AE_MULSF16SS_10,
    0,
    Opcode_ae_mulsf16ss_10_encode_fns, 1, Opcode_ae_mulsf16ss_10_funcUnit_uses },
  { "ae_mulsf16ss.20", ICLASS_AE_MULSF16SS_20,
    0,
    Opcode_ae_mulsf16ss_20_encode_fns, 1, Opcode_ae_mulsf16ss_20_funcUnit_uses },
  { "ae_mulsf16ss.11", ICLASS_AE_MULSF16SS_11,
    0,
    Opcode_ae_mulsf16ss_11_encode_fns, 1, Opcode_ae_mulsf16ss_11_funcUnit_uses },
  { "ae_mulsf16ss.00", ICLASS_AE_MULSF16SS_00,
    0,
    Opcode_ae_mulsf16ss_00_encode_fns, 1, Opcode_ae_mulsf16ss_00_funcUnit_uses },
  { "ae_mulsf16ss.00_s2", ICLASS_AE_MULSF16SS_00_S2,
    0,
    Opcode_ae_mulsf16ss_00_s2_encode_fns, 1, Opcode_ae_mulsf16ss_00_s2_funcUnit_uses },
  { "ae_mulaf16ss.33", ICLASS_AE_MULAF16SS_33,
    0,
    Opcode_ae_mulaf16ss_33_encode_fns, 1, Opcode_ae_mulaf16ss_33_funcUnit_uses },
  { "ae_mulaf16ss.22", ICLASS_AE_MULAF16SS_22,
    0,
    Opcode_ae_mulaf16ss_22_encode_fns, 1, Opcode_ae_mulaf16ss_22_funcUnit_uses },
  { "ae_mulaf16ss.32", ICLASS_AE_MULAF16SS_32,
    0,
    Opcode_ae_mulaf16ss_32_encode_fns, 1, Opcode_ae_mulaf16ss_32_funcUnit_uses },
  { "ae_mulaf16ss.21", ICLASS_AE_MULAF16SS_21,
    0,
    Opcode_ae_mulaf16ss_21_encode_fns, 1, Opcode_ae_mulaf16ss_21_funcUnit_uses },
  { "ae_mulaf16ss.31", ICLASS_AE_MULAF16SS_31,
    0,
    Opcode_ae_mulaf16ss_31_encode_fns, 1, Opcode_ae_mulaf16ss_31_funcUnit_uses },
  { "ae_mulaf16ss.30", ICLASS_AE_MULAF16SS_30,
    0,
    Opcode_ae_mulaf16ss_30_encode_fns, 1, Opcode_ae_mulaf16ss_30_funcUnit_uses },
  { "ae_mulaf16ss.10", ICLASS_AE_MULAF16SS_10,
    0,
    Opcode_ae_mulaf16ss_10_encode_fns, 1, Opcode_ae_mulaf16ss_10_funcUnit_uses },
  { "ae_mulaf16ss.20", ICLASS_AE_MULAF16SS_20,
    0,
    Opcode_ae_mulaf16ss_20_encode_fns, 1, Opcode_ae_mulaf16ss_20_funcUnit_uses },
  { "ae_mulaf16ss.11", ICLASS_AE_MULAF16SS_11,
    0,
    Opcode_ae_mulaf16ss_11_encode_fns, 1, Opcode_ae_mulaf16ss_11_funcUnit_uses },
  { "ae_mulaf16ss.00", ICLASS_AE_MULAF16SS_00,
    0,
    Opcode_ae_mulaf16ss_00_encode_fns, 1, Opcode_ae_mulaf16ss_00_funcUnit_uses },
  { "ae_mulaf16ss.00_s2", ICLASS_AE_MULAF16SS_00_S2,
    0,
    Opcode_ae_mulaf16ss_00_s2_encode_fns, 1, Opcode_ae_mulaf16ss_00_s2_funcUnit_uses },
  { "ae_mulaafd16ss.33_22", ICLASS_AE_MULAAFD16SS_33_22,
    0,
    Opcode_ae_mulaafd16ss_33_22_encode_fns, 1, Opcode_ae_mulaafd16ss_33_22_funcUnit_uses },
  { "ae_mulaafd16ss.33_22_s2", ICLASS_AE_MULAAFD16SS_33_22_S2,
    0,
    Opcode_ae_mulaafd16ss_33_22_s2_encode_fns, 1, Opcode_ae_mulaafd16ss_33_22_s2_funcUnit_uses },
  { "ae_mulaafd16ss.13_02", ICLASS_AE_MULAAFD16SS_13_02,
    0,
    Opcode_ae_mulaafd16ss_13_02_encode_fns, 1, Opcode_ae_mulaafd16ss_13_02_funcUnit_uses },
  { "ae_mulaafd16ss.13_02_s2", ICLASS_AE_MULAAFD16SS_13_02_S2,
    0,
    Opcode_ae_mulaafd16ss_13_02_s2_encode_fns, 1, Opcode_ae_mulaafd16ss_13_02_s2_funcUnit_uses },
  { "ae_mulaafd16ss.11_00", ICLASS_AE_MULAAFD16SS_11_00,
    0,
    Opcode_ae_mulaafd16ss_11_00_encode_fns, 1, Opcode_ae_mulaafd16ss_11_00_funcUnit_uses },
  { "ae_mulaafd16ss.11_00_s2", ICLASS_AE_MULAAFD16SS_11_00_S2,
    0,
    Opcode_ae_mulaafd16ss_11_00_s2_encode_fns, 1, Opcode_ae_mulaafd16ss_11_00_s2_funcUnit_uses },
  { "ae_mulssfd16ss.33_22", ICLASS_AE_MULSSFD16SS_33_22,
    0,
    Opcode_ae_mulssfd16ss_33_22_encode_fns, 1, Opcode_ae_mulssfd16ss_33_22_funcUnit_uses },
  { "ae_mulssfd16ss.33_22_s2", ICLASS_AE_MULSSFD16SS_33_22_S2,
    0,
    Opcode_ae_mulssfd16ss_33_22_s2_encode_fns, 1, Opcode_ae_mulssfd16ss_33_22_s2_funcUnit_uses },
  { "ae_mulssfd16ss.13_02", ICLASS_AE_MULSSFD16SS_13_02,
    0,
    Opcode_ae_mulssfd16ss_13_02_encode_fns, 1, Opcode_ae_mulssfd16ss_13_02_funcUnit_uses },
  { "ae_mulssfd16ss.13_02_s2", ICLASS_AE_MULSSFD16SS_13_02_S2,
    0,
    Opcode_ae_mulssfd16ss_13_02_s2_encode_fns, 1, Opcode_ae_mulssfd16ss_13_02_s2_funcUnit_uses },
  { "ae_mulssfd16ss.11_00", ICLASS_AE_MULSSFD16SS_11_00,
    0,
    Opcode_ae_mulssfd16ss_11_00_encode_fns, 1, Opcode_ae_mulssfd16ss_11_00_funcUnit_uses },
  { "ae_mulssfd16ss.11_00_s2", ICLASS_AE_MULSSFD16SS_11_00_S2,
    0,
    Opcode_ae_mulssfd16ss_11_00_s2_encode_fns, 1, Opcode_ae_mulssfd16ss_11_00_s2_funcUnit_uses },
  { "ae_mulzaafd16ss.33_22", ICLASS_AE_MULZAAFD16SS_33_22,
    0,
    Opcode_ae_mulzaafd16ss_33_22_encode_fns, 1, Opcode_ae_mulzaafd16ss_33_22_funcUnit_uses },
  { "ae_mulzaafd16ss.33_22_s2", ICLASS_AE_MULZAAFD16SS_33_22_S2,
    0,
    Opcode_ae_mulzaafd16ss_33_22_s2_encode_fns, 1, Opcode_ae_mulzaafd16ss_33_22_s2_funcUnit_uses },
  { "ae_mulzaafd16ss.13_02", ICLASS_AE_MULZAAFD16SS_13_02,
    0,
    Opcode_ae_mulzaafd16ss_13_02_encode_fns, 1, Opcode_ae_mulzaafd16ss_13_02_funcUnit_uses },
  { "ae_mulzaafd16ss.13_02_s2", ICLASS_AE_MULZAAFD16SS_13_02_S2,
    0,
    Opcode_ae_mulzaafd16ss_13_02_s2_encode_fns, 1, Opcode_ae_mulzaafd16ss_13_02_s2_funcUnit_uses },
  { "ae_mulzaafd16ss.11_00", ICLASS_AE_MULZAAFD16SS_11_00,
    0,
    Opcode_ae_mulzaafd16ss_11_00_encode_fns, 1, Opcode_ae_mulzaafd16ss_11_00_funcUnit_uses },
  { "ae_mulzaafd16ss.11_00_s2", ICLASS_AE_MULZAAFD16SS_11_00_S2,
    0,
    Opcode_ae_mulzaafd16ss_11_00_s2_encode_fns, 1, Opcode_ae_mulzaafd16ss_11_00_s2_funcUnit_uses },
  { "ae_mulzssfd16ss.33_22", ICLASS_AE_MULZSSFD16SS_33_22,
    0,
    Opcode_ae_mulzssfd16ss_33_22_encode_fns, 1, Opcode_ae_mulzssfd16ss_33_22_funcUnit_uses },
  { "ae_mulzssfd16ss.33_22_s2", ICLASS_AE_MULZSSFD16SS_33_22_S2,
    0,
    Opcode_ae_mulzssfd16ss_33_22_s2_encode_fns, 1, Opcode_ae_mulzssfd16ss_33_22_s2_funcUnit_uses },
  { "ae_mulzssfd16ss.13_02", ICLASS_AE_MULZSSFD16SS_13_02,
    0,
    Opcode_ae_mulzssfd16ss_13_02_encode_fns, 1, Opcode_ae_mulzssfd16ss_13_02_funcUnit_uses },
  { "ae_mulzssfd16ss.13_02_s2", ICLASS_AE_MULZSSFD16SS_13_02_S2,
    0,
    Opcode_ae_mulzssfd16ss_13_02_s2_encode_fns, 1, Opcode_ae_mulzssfd16ss_13_02_s2_funcUnit_uses },
  { "ae_mulzssfd16ss.11_00", ICLASS_AE_MULZSSFD16SS_11_00,
    0,
    Opcode_ae_mulzssfd16ss_11_00_encode_fns, 1, Opcode_ae_mulzssfd16ss_11_00_funcUnit_uses },
  { "ae_mulzssfd16ss.11_00_s2", ICLASS_AE_MULZSSFD16SS_11_00_S2,
    0,
    Opcode_ae_mulzssfd16ss_11_00_s2_encode_fns, 1, Opcode_ae_mulzssfd16ss_11_00_s2_funcUnit_uses },
  { "ae_mulf48q32sp16s.l", ICLASS_AE_MULF48Q32SP16S_L,
    0,
    Opcode_ae_mulf48q32sp16s_l_encode_fns, 1, Opcode_ae_mulf48q32sp16s_l_funcUnit_uses },
  { "ae_mulf48q32sp16s.l_s2", ICLASS_AE_MULF48Q32SP16S_L_S2,
    0,
    Opcode_ae_mulf48q32sp16s_l_s2_encode_fns, 1, Opcode_ae_mulf48q32sp16s_l_s2_funcUnit_uses },
  { "ae_mulf48q32sp16u.l", ICLASS_AE_MULF48Q32SP16U_L,
    0,
    Opcode_ae_mulf48q32sp16u_l_encode_fns, 1, Opcode_ae_mulf48q32sp16u_l_funcUnit_uses },
  { "ae_mulf48q32sp16u.l_s2", ICLASS_AE_MULF48Q32SP16U_L_S2,
    0,
    Opcode_ae_mulf48q32sp16u_l_s2_encode_fns, 1, Opcode_ae_mulf48q32sp16u_l_s2_funcUnit_uses },
  { "ae_mulq32sp16s.l", ICLASS_AE_MULQ32SP16S_L,
    0,
    Opcode_ae_mulq32sp16s_l_encode_fns, 1, Opcode_ae_mulq32sp16s_l_funcUnit_uses },
  { "ae_mulq32sp16s.l_s2", ICLASS_AE_MULQ32SP16S_L_S2,
    0,
    Opcode_ae_mulq32sp16s_l_s2_encode_fns, 1, Opcode_ae_mulq32sp16s_l_s2_funcUnit_uses },
  { "ae_mulq32sp16u.l", ICLASS_AE_MULQ32SP16U_L,
    0,
    Opcode_ae_mulq32sp16u_l_encode_fns, 1, Opcode_ae_mulq32sp16u_l_funcUnit_uses },
  { "ae_mulq32sp16u.l_s2", ICLASS_AE_MULQ32SP16U_L_S2,
    0,
    Opcode_ae_mulq32sp16u_l_s2_encode_fns, 1, Opcode_ae_mulq32sp16u_l_s2_funcUnit_uses },
  { "ae_mulaf48q32sp16s.l", ICLASS_AE_MULAF48Q32SP16S_L,
    0,
    Opcode_ae_mulaf48q32sp16s_l_encode_fns, 1, Opcode_ae_mulaf48q32sp16s_l_funcUnit_uses },
  { "ae_mulaf48q32sp16s.l_s2", ICLASS_AE_MULAF48Q32SP16S_L_S2,
    0,
    Opcode_ae_mulaf48q32sp16s_l_s2_encode_fns, 1, Opcode_ae_mulaf48q32sp16s_l_s2_funcUnit_uses },
  { "ae_mulaf48q32sp16u.l", ICLASS_AE_MULAF48Q32SP16U_L,
    0,
    Opcode_ae_mulaf48q32sp16u_l_encode_fns, 1, Opcode_ae_mulaf48q32sp16u_l_funcUnit_uses },
  { "ae_mulaf48q32sp16u.l_s2", ICLASS_AE_MULAF48Q32SP16U_L_S2,
    0,
    Opcode_ae_mulaf48q32sp16u_l_s2_encode_fns, 1, Opcode_ae_mulaf48q32sp16u_l_s2_funcUnit_uses },
  { "ae_mulaq32sp16s.l", ICLASS_AE_MULAQ32SP16S_L,
    0,
    Opcode_ae_mulaq32sp16s_l_encode_fns, 1, Opcode_ae_mulaq32sp16s_l_funcUnit_uses },
  { "ae_mulaq32sp16s.l_s2", ICLASS_AE_MULAQ32SP16S_L_S2,
    0,
    Opcode_ae_mulaq32sp16s_l_s2_encode_fns, 1, Opcode_ae_mulaq32sp16s_l_s2_funcUnit_uses },
  { "ae_mulaq32sp16u.l", ICLASS_AE_MULAQ32SP16U_L,
    0,
    Opcode_ae_mulaq32sp16u_l_encode_fns, 1, Opcode_ae_mulaq32sp16u_l_funcUnit_uses },
  { "ae_mulaq32sp16u.l_s2", ICLASS_AE_MULAQ32SP16U_L_S2,
    0,
    Opcode_ae_mulaq32sp16u_l_s2_encode_fns, 1, Opcode_ae_mulaq32sp16u_l_s2_funcUnit_uses },
  { "ae_mulsf48q32sp16s.l", ICLASS_AE_MULSF48Q32SP16S_L,
    0,
    Opcode_ae_mulsf48q32sp16s_l_encode_fns, 1, Opcode_ae_mulsf48q32sp16s_l_funcUnit_uses },
  { "ae_mulsf48q32sp16s.l_s2", ICLASS_AE_MULSF48Q32SP16S_L_S2,
    0,
    Opcode_ae_mulsf48q32sp16s_l_s2_encode_fns, 1, Opcode_ae_mulsf48q32sp16s_l_s2_funcUnit_uses },
  { "ae_mulsf48q32sp16u.l", ICLASS_AE_MULSF48Q32SP16U_L,
    0,
    Opcode_ae_mulsf48q32sp16u_l_encode_fns, 1, Opcode_ae_mulsf48q32sp16u_l_funcUnit_uses },
  { "ae_mulsf48q32sp16u.l_s2", ICLASS_AE_MULSF48Q32SP16U_L_S2,
    0,
    Opcode_ae_mulsf48q32sp16u_l_s2_encode_fns, 1, Opcode_ae_mulsf48q32sp16u_l_s2_funcUnit_uses },
  { "ae_mulsq32sp16s.l", ICLASS_AE_MULSQ32SP16S_L,
    0,
    Opcode_ae_mulsq32sp16s_l_encode_fns, 1, Opcode_ae_mulsq32sp16s_l_funcUnit_uses },
  { "ae_mulsq32sp16s.l_s2", ICLASS_AE_MULSQ32SP16S_L_S2,
    0,
    Opcode_ae_mulsq32sp16s_l_s2_encode_fns, 1, Opcode_ae_mulsq32sp16s_l_s2_funcUnit_uses },
  { "ae_mulsq32sp16u.l", ICLASS_AE_MULSQ32SP16U_L,
    0,
    Opcode_ae_mulsq32sp16u_l_encode_fns, 1, Opcode_ae_mulsq32sp16u_l_funcUnit_uses },
  { "ae_mulsq32sp16u.l_s2", ICLASS_AE_MULSQ32SP16U_L_S2,
    0,
    Opcode_ae_mulsq32sp16u_l_s2_encode_fns, 1, Opcode_ae_mulsq32sp16u_l_s2_funcUnit_uses },
  { "ae_mulfp24x2ra", ICLASS_AE_MULFP24X2RA,
    0,
    Opcode_ae_mulfp24x2ra_encode_fns, 1, Opcode_ae_mulfp24x2ra_funcUnit_uses },
  { "ae_mulfp24x2r", ICLASS_AE_MULFP24X2R,
    0,
    Opcode_ae_mulfp24x2r_encode_fns, 1, Opcode_ae_mulfp24x2r_funcUnit_uses },
  { "ae_mulp24x2", ICLASS_AE_MULP24X2,
    0,
    Opcode_ae_mulp24x2_encode_fns, 1, Opcode_ae_mulp24x2_funcUnit_uses },
  { "ae_mulfp24x2ra_s2", ICLASS_AE_MULFP24X2RA_S2,
    0,
    Opcode_ae_mulfp24x2ra_s2_encode_fns, 1, Opcode_ae_mulfp24x2ra_s2_funcUnit_uses },
  { "ae_mulfp24x2r_s2", ICLASS_AE_MULFP24X2R_S2,
    0,
    Opcode_ae_mulfp24x2r_s2_encode_fns, 1, Opcode_ae_mulfp24x2r_s2_funcUnit_uses },
  { "ae_mulp24x2_s2", ICLASS_AE_MULP24X2_S2,
    0,
    Opcode_ae_mulp24x2_s2_encode_fns, 1, Opcode_ae_mulp24x2_s2_funcUnit_uses },
  { "ae_mulafp24x2ra", ICLASS_AE_MULAFP24X2RA,
    0,
    Opcode_ae_mulafp24x2ra_encode_fns, 1, Opcode_ae_mulafp24x2ra_funcUnit_uses },
  { "ae_mulafp24x2r", ICLASS_AE_MULAFP24X2R,
    0,
    Opcode_ae_mulafp24x2r_encode_fns, 1, Opcode_ae_mulafp24x2r_funcUnit_uses },
  { "ae_mulap24x2", ICLASS_AE_MULAP24X2,
    0,
    Opcode_ae_mulap24x2_encode_fns, 1, Opcode_ae_mulap24x2_funcUnit_uses },
  { "ae_mulafp24x2ra_s2", ICLASS_AE_MULAFP24X2RA_S2,
    0,
    Opcode_ae_mulafp24x2ra_s2_encode_fns, 1, Opcode_ae_mulafp24x2ra_s2_funcUnit_uses },
  { "ae_mulafp24x2r_s2", ICLASS_AE_MULAFP24X2R_S2,
    0,
    Opcode_ae_mulafp24x2r_s2_encode_fns, 1, Opcode_ae_mulafp24x2r_s2_funcUnit_uses },
  { "ae_mulap24x2_s2", ICLASS_AE_MULAP24X2_S2,
    0,
    Opcode_ae_mulap24x2_s2_encode_fns, 1, Opcode_ae_mulap24x2_s2_funcUnit_uses },
  { "ae_mulsfp24x2ra", ICLASS_AE_MULSFP24X2RA,
    0,
    Opcode_ae_mulsfp24x2ra_encode_fns, 1, Opcode_ae_mulsfp24x2ra_funcUnit_uses },
  { "ae_mulsfp24x2r", ICLASS_AE_MULSFP24X2R,
    0,
    Opcode_ae_mulsfp24x2r_encode_fns, 1, Opcode_ae_mulsfp24x2r_funcUnit_uses },
  { "ae_mulsp24x2", ICLASS_AE_MULSP24X2,
    0,
    Opcode_ae_mulsp24x2_encode_fns, 1, Opcode_ae_mulsp24x2_funcUnit_uses },
  { "ae_mulsfp24x2ra_s2", ICLASS_AE_MULSFP24X2RA_S2,
    0,
    Opcode_ae_mulsfp24x2ra_s2_encode_fns, 1, Opcode_ae_mulsfp24x2ra_s2_funcUnit_uses },
  { "ae_mulsfp24x2r_s2", ICLASS_AE_MULSFP24X2R_S2,
    0,
    Opcode_ae_mulsfp24x2r_s2_encode_fns, 1, Opcode_ae_mulsfp24x2r_s2_funcUnit_uses },
  { "ae_mulsp24x2_s2", ICLASS_AE_MULSP24X2_S2,
    0,
    Opcode_ae_mulsp24x2_s2_encode_fns, 1, Opcode_ae_mulsp24x2_s2_funcUnit_uses },
  { "ae_mulzaafd24.hh.ll", ICLASS_AE_MULZAAFD24_HH_LL,
    0,
    Opcode_ae_mulzaafd24_hh_ll_encode_fns, 1, Opcode_ae_mulzaafd24_hh_ll_funcUnit_uses },
  { "ae_mulzaad24.hh.ll", ICLASS_AE_MULZAAD24_HH_LL,
    0,
    Opcode_ae_mulzaad24_hh_ll_encode_fns, 1, Opcode_ae_mulzaad24_hh_ll_funcUnit_uses },
  { "ae_mulzaafd24.hh.ll_s2", ICLASS_AE_MULZAAFD24_HH_LL_S2,
    0,
    Opcode_ae_mulzaafd24_hh_ll_s2_encode_fns, 1, Opcode_ae_mulzaafd24_hh_ll_s2_funcUnit_uses },
  { "ae_mulzaad24.hh.ll_s2", ICLASS_AE_MULZAAD24_HH_LL_S2,
    0,
    Opcode_ae_mulzaad24_hh_ll_s2_encode_fns, 1, Opcode_ae_mulzaad24_hh_ll_s2_funcUnit_uses },
  { "ae_mulzaafd24.hl.lh", ICLASS_AE_MULZAAFD24_HL_LH,
    0,
    Opcode_ae_mulzaafd24_hl_lh_encode_fns, 1, Opcode_ae_mulzaafd24_hl_lh_funcUnit_uses },
  { "ae_mulzaad24.hl.lh", ICLASS_AE_MULZAAD24_HL_LH,
    0,
    Opcode_ae_mulzaad24_hl_lh_encode_fns, 1, Opcode_ae_mulzaad24_hl_lh_funcUnit_uses },
  { "ae_mulzaafd24.hl.lh_s2", ICLASS_AE_MULZAAFD24_HL_LH_S2,
    0,
    Opcode_ae_mulzaafd24_hl_lh_s2_encode_fns, 1, Opcode_ae_mulzaafd24_hl_lh_s2_funcUnit_uses },
  { "ae_mulzaad24.hl.lh_s2", ICLASS_AE_MULZAAD24_HL_LH_S2,
    0,
    Opcode_ae_mulzaad24_hl_lh_s2_encode_fns, 1, Opcode_ae_mulzaad24_hl_lh_s2_funcUnit_uses },
  { "ae_mulzasfd24.hh.ll", ICLASS_AE_MULZASFD24_HH_LL,
    0,
    Opcode_ae_mulzasfd24_hh_ll_encode_fns, 1, Opcode_ae_mulzasfd24_hh_ll_funcUnit_uses },
  { "ae_mulzasd24.hh.ll", ICLASS_AE_MULZASD24_HH_LL,
    0,
    Opcode_ae_mulzasd24_hh_ll_encode_fns, 1, Opcode_ae_mulzasd24_hh_ll_funcUnit_uses },
  { "ae_mulzasfd24.hh.ll_s2", ICLASS_AE_MULZASFD24_HH_LL_S2,
    0,
    Opcode_ae_mulzasfd24_hh_ll_s2_encode_fns, 1, Opcode_ae_mulzasfd24_hh_ll_s2_funcUnit_uses },
  { "ae_mulzasd24.hh.ll_s2", ICLASS_AE_MULZASD24_HH_LL_S2,
    0,
    Opcode_ae_mulzasd24_hh_ll_s2_encode_fns, 1, Opcode_ae_mulzasd24_hh_ll_s2_funcUnit_uses },
  { "ae_mulzasfd24.hl.lh", ICLASS_AE_MULZASFD24_HL_LH,
    0,
    Opcode_ae_mulzasfd24_hl_lh_encode_fns, 1, Opcode_ae_mulzasfd24_hl_lh_funcUnit_uses },
  { "ae_mulzasd24.hl.lh", ICLASS_AE_MULZASD24_HL_LH,
    0,
    Opcode_ae_mulzasd24_hl_lh_encode_fns, 1, Opcode_ae_mulzasd24_hl_lh_funcUnit_uses },
  { "ae_mulzasfd24.hl.lh_s2", ICLASS_AE_MULZASFD24_HL_LH_S2,
    0,
    Opcode_ae_mulzasfd24_hl_lh_s2_encode_fns, 1, Opcode_ae_mulzasfd24_hl_lh_s2_funcUnit_uses },
  { "ae_mulzasd24.hl.lh_s2", ICLASS_AE_MULZASD24_HL_LH_S2,
    0,
    Opcode_ae_mulzasd24_hl_lh_s2_encode_fns, 1, Opcode_ae_mulzasd24_hl_lh_s2_funcUnit_uses },
  { "ae_mulzsafd24.hh.ll", ICLASS_AE_MULZSAFD24_HH_LL,
    0,
    Opcode_ae_mulzsafd24_hh_ll_encode_fns, 1, Opcode_ae_mulzsafd24_hh_ll_funcUnit_uses },
  { "ae_mulzsad24.hh.ll", ICLASS_AE_MULZSAD24_HH_LL,
    0,
    Opcode_ae_mulzsad24_hh_ll_encode_fns, 1, Opcode_ae_mulzsad24_hh_ll_funcUnit_uses },
  { "ae_mulzsafd24.hh.ll_s2", ICLASS_AE_MULZSAFD24_HH_LL_S2,
    0,
    Opcode_ae_mulzsafd24_hh_ll_s2_encode_fns, 1, Opcode_ae_mulzsafd24_hh_ll_s2_funcUnit_uses },
  { "ae_mulzsad24.hh.ll_s2", ICLASS_AE_MULZSAD24_HH_LL_S2,
    0,
    Opcode_ae_mulzsad24_hh_ll_s2_encode_fns, 1, Opcode_ae_mulzsad24_hh_ll_s2_funcUnit_uses },
  { "ae_mulzssfd24.hh.ll", ICLASS_AE_MULZSSFD24_HH_LL,
    0,
    Opcode_ae_mulzssfd24_hh_ll_encode_fns, 1, Opcode_ae_mulzssfd24_hh_ll_funcUnit_uses },
  { "ae_mulzssd24.hh.ll", ICLASS_AE_MULZSSD24_HH_LL,
    0,
    Opcode_ae_mulzssd24_hh_ll_encode_fns, 1, Opcode_ae_mulzssd24_hh_ll_funcUnit_uses },
  { "ae_mulzssfd24.hh.ll_s2", ICLASS_AE_MULZSSFD24_HH_LL_S2,
    0,
    Opcode_ae_mulzssfd24_hh_ll_s2_encode_fns, 1, Opcode_ae_mulzssfd24_hh_ll_s2_funcUnit_uses },
  { "ae_mulzssd24.hh.ll_s2", ICLASS_AE_MULZSSD24_HH_LL_S2,
    0,
    Opcode_ae_mulzssd24_hh_ll_s2_encode_fns, 1, Opcode_ae_mulzssd24_hh_ll_s2_funcUnit_uses },
  { "ae_mulzssfd24.hl.lh", ICLASS_AE_MULZSSFD24_HL_LH,
    0,
    Opcode_ae_mulzssfd24_hl_lh_encode_fns, 1, Opcode_ae_mulzssfd24_hl_lh_funcUnit_uses },
  { "ae_mulzssd24.hl.lh", ICLASS_AE_MULZSSD24_HL_LH,
    0,
    Opcode_ae_mulzssd24_hl_lh_encode_fns, 1, Opcode_ae_mulzssd24_hl_lh_funcUnit_uses },
  { "ae_mulzssfd24.hl.lh_s2", ICLASS_AE_MULZSSFD24_HL_LH_S2,
    0,
    Opcode_ae_mulzssfd24_hl_lh_s2_encode_fns, 1, Opcode_ae_mulzssfd24_hl_lh_s2_funcUnit_uses },
  { "ae_mulzssd24.hl.lh_s2", ICLASS_AE_MULZSSD24_HL_LH_S2,
    0,
    Opcode_ae_mulzssd24_hl_lh_s2_encode_fns, 1, Opcode_ae_mulzssd24_hl_lh_s2_funcUnit_uses },
  { "ae_mulaafd24.hh.ll", ICLASS_AE_MULAAFD24_HH_LL,
    0,
    Opcode_ae_mulaafd24_hh_ll_encode_fns, 1, Opcode_ae_mulaafd24_hh_ll_funcUnit_uses },
  { "ae_mulaad24.hh.ll", ICLASS_AE_MULAAD24_HH_LL,
    0,
    Opcode_ae_mulaad24_hh_ll_encode_fns, 1, Opcode_ae_mulaad24_hh_ll_funcUnit_uses },
  { "ae_mulaafd24.hh.ll_s2", ICLASS_AE_MULAAFD24_HH_LL_S2,
    0,
    Opcode_ae_mulaafd24_hh_ll_s2_encode_fns, 1, Opcode_ae_mulaafd24_hh_ll_s2_funcUnit_uses },
  { "ae_mulaad24.hh.ll_s2", ICLASS_AE_MULAAD24_HH_LL_S2,
    0,
    Opcode_ae_mulaad24_hh_ll_s2_encode_fns, 1, Opcode_ae_mulaad24_hh_ll_s2_funcUnit_uses },
  { "ae_mulaafd24.hl.lh", ICLASS_AE_MULAAFD24_HL_LH,
    0,
    Opcode_ae_mulaafd24_hl_lh_encode_fns, 1, Opcode_ae_mulaafd24_hl_lh_funcUnit_uses },
  { "ae_mulaad24.hl.lh", ICLASS_AE_MULAAD24_HL_LH,
    0,
    Opcode_ae_mulaad24_hl_lh_encode_fns, 1, Opcode_ae_mulaad24_hl_lh_funcUnit_uses },
  { "ae_mulaafd24.hl.lh_s2", ICLASS_AE_MULAAFD24_HL_LH_S2,
    0,
    Opcode_ae_mulaafd24_hl_lh_s2_encode_fns, 1, Opcode_ae_mulaafd24_hl_lh_s2_funcUnit_uses },
  { "ae_mulaad24.hl.lh_s2", ICLASS_AE_MULAAD24_HL_LH_S2,
    0,
    Opcode_ae_mulaad24_hl_lh_s2_encode_fns, 1, Opcode_ae_mulaad24_hl_lh_s2_funcUnit_uses },
  { "ae_mulasfd24.hh.ll", ICLASS_AE_MULASFD24_HH_LL,
    0,
    Opcode_ae_mulasfd24_hh_ll_encode_fns, 1, Opcode_ae_mulasfd24_hh_ll_funcUnit_uses },
  { "ae_mulasd24.hh.ll", ICLASS_AE_MULASD24_HH_LL,
    0,
    Opcode_ae_mulasd24_hh_ll_encode_fns, 1, Opcode_ae_mulasd24_hh_ll_funcUnit_uses },
  { "ae_mulasfd24.hh.ll_s2", ICLASS_AE_MULASFD24_HH_LL_S2,
    0,
    Opcode_ae_mulasfd24_hh_ll_s2_encode_fns, 1, Opcode_ae_mulasfd24_hh_ll_s2_funcUnit_uses },
  { "ae_mulasd24.hh.ll_s2", ICLASS_AE_MULASD24_HH_LL_S2,
    0,
    Opcode_ae_mulasd24_hh_ll_s2_encode_fns, 1, Opcode_ae_mulasd24_hh_ll_s2_funcUnit_uses },
  { "ae_mulasfd24.hl.lh", ICLASS_AE_MULASFD24_HL_LH,
    0,
    Opcode_ae_mulasfd24_hl_lh_encode_fns, 1, Opcode_ae_mulasfd24_hl_lh_funcUnit_uses },
  { "ae_mulasd24.hl.lh", ICLASS_AE_MULASD24_HL_LH,
    0,
    Opcode_ae_mulasd24_hl_lh_encode_fns, 1, Opcode_ae_mulasd24_hl_lh_funcUnit_uses },
  { "ae_mulasfd24.hl.lh_s2", ICLASS_AE_MULASFD24_HL_LH_S2,
    0,
    Opcode_ae_mulasfd24_hl_lh_s2_encode_fns, 1, Opcode_ae_mulasfd24_hl_lh_s2_funcUnit_uses },
  { "ae_mulasd24.hl.lh_s2", ICLASS_AE_MULASD24_HL_LH_S2,
    0,
    Opcode_ae_mulasd24_hl_lh_s2_encode_fns, 1, Opcode_ae_mulasd24_hl_lh_s2_funcUnit_uses },
  { "ae_mulsafd24.hh.ll", ICLASS_AE_MULSAFD24_HH_LL,
    0,
    Opcode_ae_mulsafd24_hh_ll_encode_fns, 1, Opcode_ae_mulsafd24_hh_ll_funcUnit_uses },
  { "ae_mulsad24.hh.ll", ICLASS_AE_MULSAD24_HH_LL,
    0,
    Opcode_ae_mulsad24_hh_ll_encode_fns, 1, Opcode_ae_mulsad24_hh_ll_funcUnit_uses },
  { "ae_mulsafd24.hh.ll_s2", ICLASS_AE_MULSAFD24_HH_LL_S2,
    0,
    Opcode_ae_mulsafd24_hh_ll_s2_encode_fns, 1, Opcode_ae_mulsafd24_hh_ll_s2_funcUnit_uses },
  { "ae_mulsad24.hh.ll_s2", ICLASS_AE_MULSAD24_HH_LL_S2,
    0,
    Opcode_ae_mulsad24_hh_ll_s2_encode_fns, 1, Opcode_ae_mulsad24_hh_ll_s2_funcUnit_uses },
  { "ae_mulssfd24.hh.ll", ICLASS_AE_MULSSFD24_HH_LL,
    0,
    Opcode_ae_mulssfd24_hh_ll_encode_fns, 1, Opcode_ae_mulssfd24_hh_ll_funcUnit_uses },
  { "ae_mulssd24.hh.ll", ICLASS_AE_MULSSD24_HH_LL,
    0,
    Opcode_ae_mulssd24_hh_ll_encode_fns, 1, Opcode_ae_mulssd24_hh_ll_funcUnit_uses },
  { "ae_mulssfd24.hh.ll_s2", ICLASS_AE_MULSSFD24_HH_LL_S2,
    0,
    Opcode_ae_mulssfd24_hh_ll_s2_encode_fns, 1, Opcode_ae_mulssfd24_hh_ll_s2_funcUnit_uses },
  { "ae_mulssd24.hh.ll_s2", ICLASS_AE_MULSSD24_HH_LL_S2,
    0,
    Opcode_ae_mulssd24_hh_ll_s2_encode_fns, 1, Opcode_ae_mulssd24_hh_ll_s2_funcUnit_uses },
  { "ae_mulssfd24.hl.lh", ICLASS_AE_MULSSFD24_HL_LH,
    0,
    Opcode_ae_mulssfd24_hl_lh_encode_fns, 1, Opcode_ae_mulssfd24_hl_lh_funcUnit_uses },
  { "ae_mulssd24.hl.lh", ICLASS_AE_MULSSD24_HL_LH,
    0,
    Opcode_ae_mulssd24_hl_lh_encode_fns, 1, Opcode_ae_mulssd24_hl_lh_funcUnit_uses },
  { "ae_mulssfd24.hl.lh_s2", ICLASS_AE_MULSSFD24_HL_LH_S2,
    0,
    Opcode_ae_mulssfd24_hl_lh_s2_encode_fns, 1, Opcode_ae_mulssfd24_hl_lh_s2_funcUnit_uses },
  { "ae_mulssd24.hl.lh_s2", ICLASS_AE_MULSSD24_HL_LH_S2,
    0,
    Opcode_ae_mulssd24_hl_lh_s2_encode_fns, 1, Opcode_ae_mulssd24_hl_lh_s2_funcUnit_uses },
  { "ae_mulsrfq32sp24s.h", ICLASS_AE_MULSRFQ32SP24S_H,
    0,
    Opcode_ae_mulsrfq32sp24s_h_encode_fns, 1, Opcode_ae_mulsrfq32sp24s_h_funcUnit_uses },
  { "ae_mulsrfq32sp24s.l", ICLASS_AE_MULSRFQ32SP24S_L,
    0,
    Opcode_ae_mulsrfq32sp24s_l_encode_fns, 1, Opcode_ae_mulsrfq32sp24s_l_funcUnit_uses },
  { "ae_mulsrfq32sp24s.h_s2", ICLASS_AE_MULSRFQ32SP24S_H_S2,
    0,
    Opcode_ae_mulsrfq32sp24s_h_s2_encode_fns, 1, Opcode_ae_mulsrfq32sp24s_h_s2_funcUnit_uses },
  { "ae_mulsrfq32sp24s.l_s2", ICLASS_AE_MULSRFQ32SP24S_L_S2,
    0,
    Opcode_ae_mulsrfq32sp24s_l_s2_encode_fns, 1, Opcode_ae_mulsrfq32sp24s_l_s2_funcUnit_uses },
  { "ae_mularfq32sp24s.h", ICLASS_AE_MULARFQ32SP24S_H,
    0,
    Opcode_ae_mularfq32sp24s_h_encode_fns, 1, Opcode_ae_mularfq32sp24s_h_funcUnit_uses },
  { "ae_mularfq32sp24s.l", ICLASS_AE_MULARFQ32SP24S_L,
    0,
    Opcode_ae_mularfq32sp24s_l_encode_fns, 1, Opcode_ae_mularfq32sp24s_l_funcUnit_uses },
  { "ae_mularfq32sp24s.h_s2", ICLASS_AE_MULARFQ32SP24S_H_S2,
    0,
    Opcode_ae_mularfq32sp24s_h_s2_encode_fns, 1, Opcode_ae_mularfq32sp24s_h_s2_funcUnit_uses },
  { "ae_mularfq32sp24s.l_s2", ICLASS_AE_MULARFQ32SP24S_L_S2,
    0,
    Opcode_ae_mularfq32sp24s_l_s2_encode_fns, 1, Opcode_ae_mularfq32sp24s_l_s2_funcUnit_uses },
  { "ae_mulrfq32sp24s.h", ICLASS_AE_MULRFQ32SP24S_H,
    0,
    Opcode_ae_mulrfq32sp24s_h_encode_fns, 1, Opcode_ae_mulrfq32sp24s_h_funcUnit_uses },
  { "ae_mulrfq32sp24s.l", ICLASS_AE_MULRFQ32SP24S_L,
    0,
    Opcode_ae_mulrfq32sp24s_l_encode_fns, 1, Opcode_ae_mulrfq32sp24s_l_funcUnit_uses },
  { "ae_mulrfq32sp24s.h_s2", ICLASS_AE_MULRFQ32SP24S_H_S2,
    0,
    Opcode_ae_mulrfq32sp24s_h_s2_encode_fns, 1, Opcode_ae_mulrfq32sp24s_h_s2_funcUnit_uses },
  { "ae_mulrfq32sp24s.l_s2", ICLASS_AE_MULRFQ32SP24S_L_S2,
    0,
    Opcode_ae_mulrfq32sp24s_l_s2_encode_fns, 1, Opcode_ae_mulrfq32sp24s_l_s2_funcUnit_uses },
  { "ae_mulsfq32sp24s.h", ICLASS_AE_MULSFQ32SP24S_H,
    0,
    Opcode_ae_mulsfq32sp24s_h_encode_fns, 1, Opcode_ae_mulsfq32sp24s_h_funcUnit_uses },
  { "ae_mulsfq32sp24s.l", ICLASS_AE_MULSFQ32SP24S_L,
    0,
    Opcode_ae_mulsfq32sp24s_l_encode_fns, 1, Opcode_ae_mulsfq32sp24s_l_funcUnit_uses },
  { "ae_mulsfq32sp24s.h_s2", ICLASS_AE_MULSFQ32SP24S_H_S2,
    0,
    Opcode_ae_mulsfq32sp24s_h_s2_encode_fns, 1, Opcode_ae_mulsfq32sp24s_h_s2_funcUnit_uses },
  { "ae_mulsfq32sp24s.l_s2", ICLASS_AE_MULSFQ32SP24S_L_S2,
    0,
    Opcode_ae_mulsfq32sp24s_l_s2_encode_fns, 1, Opcode_ae_mulsfq32sp24s_l_s2_funcUnit_uses },
  { "ae_mulafq32sp24s.h", ICLASS_AE_MULAFQ32SP24S_H,
    0,
    Opcode_ae_mulafq32sp24s_h_encode_fns, 1, Opcode_ae_mulafq32sp24s_h_funcUnit_uses },
  { "ae_mulafq32sp24s.l", ICLASS_AE_MULAFQ32SP24S_L,
    0,
    Opcode_ae_mulafq32sp24s_l_encode_fns, 1, Opcode_ae_mulafq32sp24s_l_funcUnit_uses },
  { "ae_mulafq32sp24s.h_s2", ICLASS_AE_MULAFQ32SP24S_H_S2,
    0,
    Opcode_ae_mulafq32sp24s_h_s2_encode_fns, 1, Opcode_ae_mulafq32sp24s_h_s2_funcUnit_uses },
  { "ae_mulafq32sp24s.l_s2", ICLASS_AE_MULAFQ32SP24S_L_S2,
    0,
    Opcode_ae_mulafq32sp24s_l_s2_encode_fns, 1, Opcode_ae_mulafq32sp24s_l_s2_funcUnit_uses },
  { "ae_mulfq32sp24s.h", ICLASS_AE_MULFQ32SP24S_H,
    0,
    Opcode_ae_mulfq32sp24s_h_encode_fns, 1, Opcode_ae_mulfq32sp24s_h_funcUnit_uses },
  { "ae_mulfq32sp24s.l", ICLASS_AE_MULFQ32SP24S_L,
    0,
    Opcode_ae_mulfq32sp24s_l_encode_fns, 1, Opcode_ae_mulfq32sp24s_l_funcUnit_uses },
  { "ae_mulfq32sp24s.h_s2", ICLASS_AE_MULFQ32SP24S_H_S2,
    0,
    Opcode_ae_mulfq32sp24s_h_s2_encode_fns, 1, Opcode_ae_mulfq32sp24s_h_s2_funcUnit_uses },
  { "ae_mulfq32sp24s.l_s2", ICLASS_AE_MULFQ32SP24S_L_S2,
    0,
    Opcode_ae_mulfq32sp24s_l_s2_encode_fns, 1, Opcode_ae_mulfq32sp24s_l_s2_funcUnit_uses },
  { "ae_mulf32x16.l0", ICLASS_AE_MULF32X16_L0,
    0,
    Opcode_ae_mulf32x16_l0_encode_fns, 1, Opcode_ae_mulf32x16_l0_funcUnit_uses },
  { "ae_mul32x16.l0", ICLASS_AE_MUL32X16_L0,
    0,
    Opcode_ae_mul32x16_l0_encode_fns, 1, Opcode_ae_mul32x16_l0_funcUnit_uses },
  { "ae_mulf32x16.l0_s2", ICLASS_AE_MULF32X16_L0_S2,
    0,
    Opcode_ae_mulf32x16_l0_s2_encode_fns, 1, Opcode_ae_mulf32x16_l0_s2_funcUnit_uses },
  { "ae_mul32x16.l0_s2", ICLASS_AE_MUL32X16_L0_S2,
    0,
    Opcode_ae_mul32x16_l0_s2_encode_fns, 1, Opcode_ae_mul32x16_l0_s2_funcUnit_uses },
  { "ae_mulf32x16.l1", ICLASS_AE_MULF32X16_L1,
    0,
    Opcode_ae_mulf32x16_l1_encode_fns, 1, Opcode_ae_mulf32x16_l1_funcUnit_uses },
  { "ae_mul32x16.l1", ICLASS_AE_MUL32X16_L1,
    0,
    Opcode_ae_mul32x16_l1_encode_fns, 1, Opcode_ae_mul32x16_l1_funcUnit_uses },
  { "ae_mulf32x16.l1_s2", ICLASS_AE_MULF32X16_L1_S2,
    0,
    Opcode_ae_mulf32x16_l1_s2_encode_fns, 1, Opcode_ae_mulf32x16_l1_s2_funcUnit_uses },
  { "ae_mul32x16.l1_s2", ICLASS_AE_MUL32X16_L1_S2,
    0,
    Opcode_ae_mul32x16_l1_s2_encode_fns, 1, Opcode_ae_mul32x16_l1_s2_funcUnit_uses },
  { "ae_mulf32x16.l2", ICLASS_AE_MULF32X16_L2,
    0,
    Opcode_ae_mulf32x16_l2_encode_fns, 1, Opcode_ae_mulf32x16_l2_funcUnit_uses },
  { "ae_mul32x16.l2", ICLASS_AE_MUL32X16_L2,
    0,
    Opcode_ae_mul32x16_l2_encode_fns, 1, Opcode_ae_mul32x16_l2_funcUnit_uses },
  { "ae_mulf32x16.l2_s2", ICLASS_AE_MULF32X16_L2_S2,
    0,
    Opcode_ae_mulf32x16_l2_s2_encode_fns, 1, Opcode_ae_mulf32x16_l2_s2_funcUnit_uses },
  { "ae_mul32x16.l2_s2", ICLASS_AE_MUL32X16_L2_S2,
    0,
    Opcode_ae_mul32x16_l2_s2_encode_fns, 1, Opcode_ae_mul32x16_l2_s2_funcUnit_uses },
  { "ae_mulf32x16.l3", ICLASS_AE_MULF32X16_L3,
    0,
    Opcode_ae_mulf32x16_l3_encode_fns, 1, Opcode_ae_mulf32x16_l3_funcUnit_uses },
  { "ae_mul32x16.l3", ICLASS_AE_MUL32X16_L3,
    0,
    Opcode_ae_mul32x16_l3_encode_fns, 1, Opcode_ae_mul32x16_l3_funcUnit_uses },
  { "ae_mulf32x16.l3_s2", ICLASS_AE_MULF32X16_L3_S2,
    0,
    Opcode_ae_mulf32x16_l3_s2_encode_fns, 1, Opcode_ae_mulf32x16_l3_s2_funcUnit_uses },
  { "ae_mul32x16.l3_s2", ICLASS_AE_MUL32X16_L3_S2,
    0,
    Opcode_ae_mul32x16_l3_s2_encode_fns, 1, Opcode_ae_mul32x16_l3_s2_funcUnit_uses },
  { "ae_mulf32x16.h0", ICLASS_AE_MULF32X16_H0,
    0,
    Opcode_ae_mulf32x16_h0_encode_fns, 1, Opcode_ae_mulf32x16_h0_funcUnit_uses },
  { "ae_mul32x16.h0", ICLASS_AE_MUL32X16_H0,
    0,
    Opcode_ae_mul32x16_h0_encode_fns, 1, Opcode_ae_mul32x16_h0_funcUnit_uses },
  { "ae_mulf32x16.h0_s2", ICLASS_AE_MULF32X16_H0_S2,
    0,
    Opcode_ae_mulf32x16_h0_s2_encode_fns, 1, Opcode_ae_mulf32x16_h0_s2_funcUnit_uses },
  { "ae_mul32x16.h0_s2", ICLASS_AE_MUL32X16_H0_S2,
    0,
    Opcode_ae_mul32x16_h0_s2_encode_fns, 1, Opcode_ae_mul32x16_h0_s2_funcUnit_uses },
  { "ae_mulf32x16.h1", ICLASS_AE_MULF32X16_H1,
    0,
    Opcode_ae_mulf32x16_h1_encode_fns, 1, Opcode_ae_mulf32x16_h1_funcUnit_uses },
  { "ae_mul32x16.h1", ICLASS_AE_MUL32X16_H1,
    0,
    Opcode_ae_mul32x16_h1_encode_fns, 1, Opcode_ae_mul32x16_h1_funcUnit_uses },
  { "ae_mulf32x16.h1_s2", ICLASS_AE_MULF32X16_H1_S2,
    0,
    Opcode_ae_mulf32x16_h1_s2_encode_fns, 1, Opcode_ae_mulf32x16_h1_s2_funcUnit_uses },
  { "ae_mul32x16.h1_s2", ICLASS_AE_MUL32X16_H1_S2,
    0,
    Opcode_ae_mul32x16_h1_s2_encode_fns, 1, Opcode_ae_mul32x16_h1_s2_funcUnit_uses },
  { "ae_mulf32x16.h2", ICLASS_AE_MULF32X16_H2,
    0,
    Opcode_ae_mulf32x16_h2_encode_fns, 1, Opcode_ae_mulf32x16_h2_funcUnit_uses },
  { "ae_mul32x16.h2", ICLASS_AE_MUL32X16_H2,
    0,
    Opcode_ae_mul32x16_h2_encode_fns, 1, Opcode_ae_mul32x16_h2_funcUnit_uses },
  { "ae_mulf32x16.h2_s2", ICLASS_AE_MULF32X16_H2_S2,
    0,
    Opcode_ae_mulf32x16_h2_s2_encode_fns, 1, Opcode_ae_mulf32x16_h2_s2_funcUnit_uses },
  { "ae_mul32x16.h2_s2", ICLASS_AE_MUL32X16_H2_S2,
    0,
    Opcode_ae_mul32x16_h2_s2_encode_fns, 1, Opcode_ae_mul32x16_h2_s2_funcUnit_uses },
  { "ae_mulf32x16.h3", ICLASS_AE_MULF32X16_H3,
    0,
    Opcode_ae_mulf32x16_h3_encode_fns, 1, Opcode_ae_mulf32x16_h3_funcUnit_uses },
  { "ae_mul32x16.h3", ICLASS_AE_MUL32X16_H3,
    0,
    Opcode_ae_mul32x16_h3_encode_fns, 1, Opcode_ae_mul32x16_h3_funcUnit_uses },
  { "ae_mulf32x16.h3_s2", ICLASS_AE_MULF32X16_H3_S2,
    0,
    Opcode_ae_mulf32x16_h3_s2_encode_fns, 1, Opcode_ae_mulf32x16_h3_s2_funcUnit_uses },
  { "ae_mul32x16.h3_s2", ICLASS_AE_MUL32X16_H3_S2,
    0,
    Opcode_ae_mul32x16_h3_s2_encode_fns, 1, Opcode_ae_mul32x16_h3_s2_funcUnit_uses },
  { "ae_mulaf32x16.l0", ICLASS_AE_MULAF32X16_L0,
    0,
    Opcode_ae_mulaf32x16_l0_encode_fns, 1, Opcode_ae_mulaf32x16_l0_funcUnit_uses },
  { "ae_mula32x16.l0", ICLASS_AE_MULA32X16_L0,
    0,
    Opcode_ae_mula32x16_l0_encode_fns, 1, Opcode_ae_mula32x16_l0_funcUnit_uses },
  { "ae_mulaf32x16.l0_s2", ICLASS_AE_MULAF32X16_L0_S2,
    0,
    Opcode_ae_mulaf32x16_l0_s2_encode_fns, 1, Opcode_ae_mulaf32x16_l0_s2_funcUnit_uses },
  { "ae_mula32x16.l0_s2", ICLASS_AE_MULA32X16_L0_S2,
    0,
    Opcode_ae_mula32x16_l0_s2_encode_fns, 1, Opcode_ae_mula32x16_l0_s2_funcUnit_uses },
  { "ae_mulaf32x16.l1", ICLASS_AE_MULAF32X16_L1,
    0,
    Opcode_ae_mulaf32x16_l1_encode_fns, 1, Opcode_ae_mulaf32x16_l1_funcUnit_uses },
  { "ae_mula32x16.l1", ICLASS_AE_MULA32X16_L1,
    0,
    Opcode_ae_mula32x16_l1_encode_fns, 1, Opcode_ae_mula32x16_l1_funcUnit_uses },
  { "ae_mulaf32x16.l1_s2", ICLASS_AE_MULAF32X16_L1_S2,
    0,
    Opcode_ae_mulaf32x16_l1_s2_encode_fns, 1, Opcode_ae_mulaf32x16_l1_s2_funcUnit_uses },
  { "ae_mula32x16.l1_s2", ICLASS_AE_MULA32X16_L1_S2,
    0,
    Opcode_ae_mula32x16_l1_s2_encode_fns, 1, Opcode_ae_mula32x16_l1_s2_funcUnit_uses },
  { "ae_mulaf32x16.l2", ICLASS_AE_MULAF32X16_L2,
    0,
    Opcode_ae_mulaf32x16_l2_encode_fns, 1, Opcode_ae_mulaf32x16_l2_funcUnit_uses },
  { "ae_mula32x16.l2", ICLASS_AE_MULA32X16_L2,
    0,
    Opcode_ae_mula32x16_l2_encode_fns, 1, Opcode_ae_mula32x16_l2_funcUnit_uses },
  { "ae_mulaf32x16.l2_s2", ICLASS_AE_MULAF32X16_L2_S2,
    0,
    Opcode_ae_mulaf32x16_l2_s2_encode_fns, 1, Opcode_ae_mulaf32x16_l2_s2_funcUnit_uses },
  { "ae_mula32x16.l2_s2", ICLASS_AE_MULA32X16_L2_S2,
    0,
    Opcode_ae_mula32x16_l2_s2_encode_fns, 1, Opcode_ae_mula32x16_l2_s2_funcUnit_uses },
  { "ae_mulaf32x16.l3", ICLASS_AE_MULAF32X16_L3,
    0,
    Opcode_ae_mulaf32x16_l3_encode_fns, 1, Opcode_ae_mulaf32x16_l3_funcUnit_uses },
  { "ae_mula32x16.l3", ICLASS_AE_MULA32X16_L3,
    0,
    Opcode_ae_mula32x16_l3_encode_fns, 1, Opcode_ae_mula32x16_l3_funcUnit_uses },
  { "ae_mulaf32x16.l3_s2", ICLASS_AE_MULAF32X16_L3_S2,
    0,
    Opcode_ae_mulaf32x16_l3_s2_encode_fns, 1, Opcode_ae_mulaf32x16_l3_s2_funcUnit_uses },
  { "ae_mula32x16.l3_s2", ICLASS_AE_MULA32X16_L3_S2,
    0,
    Opcode_ae_mula32x16_l3_s2_encode_fns, 1, Opcode_ae_mula32x16_l3_s2_funcUnit_uses },
  { "ae_mulaf32x16.h0", ICLASS_AE_MULAF32X16_H0,
    0,
    Opcode_ae_mulaf32x16_h0_encode_fns, 1, Opcode_ae_mulaf32x16_h0_funcUnit_uses },
  { "ae_mula32x16.h0", ICLASS_AE_MULA32X16_H0,
    0,
    Opcode_ae_mula32x16_h0_encode_fns, 1, Opcode_ae_mula32x16_h0_funcUnit_uses },
  { "ae_mulaf32x16.h0_s2", ICLASS_AE_MULAF32X16_H0_S2,
    0,
    Opcode_ae_mulaf32x16_h0_s2_encode_fns, 1, Opcode_ae_mulaf32x16_h0_s2_funcUnit_uses },
  { "ae_mula32x16.h0_s2", ICLASS_AE_MULA32X16_H0_S2,
    0,
    Opcode_ae_mula32x16_h0_s2_encode_fns, 1, Opcode_ae_mula32x16_h0_s2_funcUnit_uses },
  { "ae_mulaf32x16.h1", ICLASS_AE_MULAF32X16_H1,
    0,
    Opcode_ae_mulaf32x16_h1_encode_fns, 1, Opcode_ae_mulaf32x16_h1_funcUnit_uses },
  { "ae_mula32x16.h1", ICLASS_AE_MULA32X16_H1,
    0,
    Opcode_ae_mula32x16_h1_encode_fns, 1, Opcode_ae_mula32x16_h1_funcUnit_uses },
  { "ae_mulaf32x16.h1_s2", ICLASS_AE_MULAF32X16_H1_S2,
    0,
    Opcode_ae_mulaf32x16_h1_s2_encode_fns, 1, Opcode_ae_mulaf32x16_h1_s2_funcUnit_uses },
  { "ae_mula32x16.h1_s2", ICLASS_AE_MULA32X16_H1_S2,
    0,
    Opcode_ae_mula32x16_h1_s2_encode_fns, 1, Opcode_ae_mula32x16_h1_s2_funcUnit_uses },
  { "ae_mulaf32x16.h2", ICLASS_AE_MULAF32X16_H2,
    0,
    Opcode_ae_mulaf32x16_h2_encode_fns, 1, Opcode_ae_mulaf32x16_h2_funcUnit_uses },
  { "ae_mula32x16.h2", ICLASS_AE_MULA32X16_H2,
    0,
    Opcode_ae_mula32x16_h2_encode_fns, 1, Opcode_ae_mula32x16_h2_funcUnit_uses },
  { "ae_mulaf32x16.h2_s2", ICLASS_AE_MULAF32X16_H2_S2,
    0,
    Opcode_ae_mulaf32x16_h2_s2_encode_fns, 1, Opcode_ae_mulaf32x16_h2_s2_funcUnit_uses },
  { "ae_mula32x16.h2_s2", ICLASS_AE_MULA32X16_H2_S2,
    0,
    Opcode_ae_mula32x16_h2_s2_encode_fns, 1, Opcode_ae_mula32x16_h2_s2_funcUnit_uses },
  { "ae_mulaf32x16.h3", ICLASS_AE_MULAF32X16_H3,
    0,
    Opcode_ae_mulaf32x16_h3_encode_fns, 1, Opcode_ae_mulaf32x16_h3_funcUnit_uses },
  { "ae_mula32x16.h3", ICLASS_AE_MULA32X16_H3,
    0,
    Opcode_ae_mula32x16_h3_encode_fns, 1, Opcode_ae_mula32x16_h3_funcUnit_uses },
  { "ae_mulaf32x16.h3_s2", ICLASS_AE_MULAF32X16_H3_S2,
    0,
    Opcode_ae_mulaf32x16_h3_s2_encode_fns, 1, Opcode_ae_mulaf32x16_h3_s2_funcUnit_uses },
  { "ae_mula32x16.h3_s2", ICLASS_AE_MULA32X16_H3_S2,
    0,
    Opcode_ae_mula32x16_h3_s2_encode_fns, 1, Opcode_ae_mula32x16_h3_s2_funcUnit_uses },
  { "ae_mulsf32x16.l0", ICLASS_AE_MULSF32X16_L0,
    0,
    Opcode_ae_mulsf32x16_l0_encode_fns, 1, Opcode_ae_mulsf32x16_l0_funcUnit_uses },
  { "ae_muls32x16.l0", ICLASS_AE_MULS32X16_L0,
    0,
    Opcode_ae_muls32x16_l0_encode_fns, 1, Opcode_ae_muls32x16_l0_funcUnit_uses },
  { "ae_mulsf32x16.l0_s2", ICLASS_AE_MULSF32X16_L0_S2,
    0,
    Opcode_ae_mulsf32x16_l0_s2_encode_fns, 1, Opcode_ae_mulsf32x16_l0_s2_funcUnit_uses },
  { "ae_muls32x16.l0_s2", ICLASS_AE_MULS32X16_L0_S2,
    0,
    Opcode_ae_muls32x16_l0_s2_encode_fns, 1, Opcode_ae_muls32x16_l0_s2_funcUnit_uses },
  { "ae_mulsf32x16.l1", ICLASS_AE_MULSF32X16_L1,
    0,
    Opcode_ae_mulsf32x16_l1_encode_fns, 1, Opcode_ae_mulsf32x16_l1_funcUnit_uses },
  { "ae_muls32x16.l1", ICLASS_AE_MULS32X16_L1,
    0,
    Opcode_ae_muls32x16_l1_encode_fns, 1, Opcode_ae_muls32x16_l1_funcUnit_uses },
  { "ae_mulsf32x16.l1_s2", ICLASS_AE_MULSF32X16_L1_S2,
    0,
    Opcode_ae_mulsf32x16_l1_s2_encode_fns, 1, Opcode_ae_mulsf32x16_l1_s2_funcUnit_uses },
  { "ae_muls32x16.l1_s2", ICLASS_AE_MULS32X16_L1_S2,
    0,
    Opcode_ae_muls32x16_l1_s2_encode_fns, 1, Opcode_ae_muls32x16_l1_s2_funcUnit_uses },
  { "ae_mulsf32x16.l2", ICLASS_AE_MULSF32X16_L2,
    0,
    Opcode_ae_mulsf32x16_l2_encode_fns, 1, Opcode_ae_mulsf32x16_l2_funcUnit_uses },
  { "ae_muls32x16.l2", ICLASS_AE_MULS32X16_L2,
    0,
    Opcode_ae_muls32x16_l2_encode_fns, 1, Opcode_ae_muls32x16_l2_funcUnit_uses },
  { "ae_mulsf32x16.l2_s2", ICLASS_AE_MULSF32X16_L2_S2,
    0,
    Opcode_ae_mulsf32x16_l2_s2_encode_fns, 1, Opcode_ae_mulsf32x16_l2_s2_funcUnit_uses },
  { "ae_muls32x16.l2_s2", ICLASS_AE_MULS32X16_L2_S2,
    0,
    Opcode_ae_muls32x16_l2_s2_encode_fns, 1, Opcode_ae_muls32x16_l2_s2_funcUnit_uses },
  { "ae_mulsf32x16.l3", ICLASS_AE_MULSF32X16_L3,
    0,
    Opcode_ae_mulsf32x16_l3_encode_fns, 1, Opcode_ae_mulsf32x16_l3_funcUnit_uses },
  { "ae_muls32x16.l3", ICLASS_AE_MULS32X16_L3,
    0,
    Opcode_ae_muls32x16_l3_encode_fns, 1, Opcode_ae_muls32x16_l3_funcUnit_uses },
  { "ae_mulsf32x16.l3_s2", ICLASS_AE_MULSF32X16_L3_S2,
    0,
    Opcode_ae_mulsf32x16_l3_s2_encode_fns, 1, Opcode_ae_mulsf32x16_l3_s2_funcUnit_uses },
  { "ae_muls32x16.l3_s2", ICLASS_AE_MULS32X16_L3_S2,
    0,
    Opcode_ae_muls32x16_l3_s2_encode_fns, 1, Opcode_ae_muls32x16_l3_s2_funcUnit_uses },
  { "ae_mulsf32x16.h0", ICLASS_AE_MULSF32X16_H0,
    0,
    Opcode_ae_mulsf32x16_h0_encode_fns, 1, Opcode_ae_mulsf32x16_h0_funcUnit_uses },
  { "ae_muls32x16.h0", ICLASS_AE_MULS32X16_H0,
    0,
    Opcode_ae_muls32x16_h0_encode_fns, 1, Opcode_ae_muls32x16_h0_funcUnit_uses },
  { "ae_mulsf32x16.h0_s2", ICLASS_AE_MULSF32X16_H0_S2,
    0,
    Opcode_ae_mulsf32x16_h0_s2_encode_fns, 1, Opcode_ae_mulsf32x16_h0_s2_funcUnit_uses },
  { "ae_muls32x16.h0_s2", ICLASS_AE_MULS32X16_H0_S2,
    0,
    Opcode_ae_muls32x16_h0_s2_encode_fns, 1, Opcode_ae_muls32x16_h0_s2_funcUnit_uses },
  { "ae_mulsf32x16.h1", ICLASS_AE_MULSF32X16_H1,
    0,
    Opcode_ae_mulsf32x16_h1_encode_fns, 1, Opcode_ae_mulsf32x16_h1_funcUnit_uses },
  { "ae_muls32x16.h1", ICLASS_AE_MULS32X16_H1,
    0,
    Opcode_ae_muls32x16_h1_encode_fns, 1, Opcode_ae_muls32x16_h1_funcUnit_uses },
  { "ae_mulsf32x16.h1_s2", ICLASS_AE_MULSF32X16_H1_S2,
    0,
    Opcode_ae_mulsf32x16_h1_s2_encode_fns, 1, Opcode_ae_mulsf32x16_h1_s2_funcUnit_uses },
  { "ae_muls32x16.h1_s2", ICLASS_AE_MULS32X16_H1_S2,
    0,
    Opcode_ae_muls32x16_h1_s2_encode_fns, 1, Opcode_ae_muls32x16_h1_s2_funcUnit_uses },
  { "ae_mulsf32x16.h2", ICLASS_AE_MULSF32X16_H2,
    0,
    Opcode_ae_mulsf32x16_h2_encode_fns, 1, Opcode_ae_mulsf32x16_h2_funcUnit_uses },
  { "ae_muls32x16.h2", ICLASS_AE_MULS32X16_H2,
    0,
    Opcode_ae_muls32x16_h2_encode_fns, 1, Opcode_ae_muls32x16_h2_funcUnit_uses },
  { "ae_mulsf32x16.h2_s2", ICLASS_AE_MULSF32X16_H2_S2,
    0,
    Opcode_ae_mulsf32x16_h2_s2_encode_fns, 1, Opcode_ae_mulsf32x16_h2_s2_funcUnit_uses },
  { "ae_muls32x16.h2_s2", ICLASS_AE_MULS32X16_H2_S2,
    0,
    Opcode_ae_muls32x16_h2_s2_encode_fns, 1, Opcode_ae_muls32x16_h2_s2_funcUnit_uses },
  { "ae_mulsf32x16.h3", ICLASS_AE_MULSF32X16_H3,
    0,
    Opcode_ae_mulsf32x16_h3_encode_fns, 1, Opcode_ae_mulsf32x16_h3_funcUnit_uses },
  { "ae_muls32x16.h3", ICLASS_AE_MULS32X16_H3,
    0,
    Opcode_ae_muls32x16_h3_encode_fns, 1, Opcode_ae_muls32x16_h3_funcUnit_uses },
  { "ae_mulsf32x16.h3_s2", ICLASS_AE_MULSF32X16_H3_S2,
    0,
    Opcode_ae_mulsf32x16_h3_s2_encode_fns, 1, Opcode_ae_mulsf32x16_h3_s2_funcUnit_uses },
  { "ae_muls32x16.h3_s2", ICLASS_AE_MULS32X16_H3_S2,
    0,
    Opcode_ae_muls32x16_h3_s2_encode_fns, 1, Opcode_ae_muls32x16_h3_s2_funcUnit_uses },
  { "ae_mulaafd32x16.h3.l2", ICLASS_AE_MULAAFD32X16_H3_L2,
    0,
    Opcode_ae_mulaafd32x16_h3_l2_encode_fns, 1, Opcode_ae_mulaafd32x16_h3_l2_funcUnit_uses },
  { "ae_mulaad32x16.h3.l2", ICLASS_AE_MULAAD32X16_H3_L2,
    0,
    Opcode_ae_mulaad32x16_h3_l2_encode_fns, 1, Opcode_ae_mulaad32x16_h3_l2_funcUnit_uses },
  { "ae_mulaafd32x16.h3.l2_s2", ICLASS_AE_MULAAFD32X16_H3_L2_S2,
    0,
    Opcode_ae_mulaafd32x16_h3_l2_s2_encode_fns, 1, Opcode_ae_mulaafd32x16_h3_l2_s2_funcUnit_uses },
  { "ae_mulaad32x16.h3.l2_s2", ICLASS_AE_MULAAD32X16_H3_L2_S2,
    0,
    Opcode_ae_mulaad32x16_h3_l2_s2_encode_fns, 1, Opcode_ae_mulaad32x16_h3_l2_s2_funcUnit_uses },
  { "ae_mulaafd32x16.h1.l0", ICLASS_AE_MULAAFD32X16_H1_L0,
    0,
    Opcode_ae_mulaafd32x16_h1_l0_encode_fns, 1, Opcode_ae_mulaafd32x16_h1_l0_funcUnit_uses },
  { "ae_mulaad32x16.h1.l0", ICLASS_AE_MULAAD32X16_H1_L0,
    0,
    Opcode_ae_mulaad32x16_h1_l0_encode_fns, 1, Opcode_ae_mulaad32x16_h1_l0_funcUnit_uses },
  { "ae_mulaafd32x16.h1.l0_s2", ICLASS_AE_MULAAFD32X16_H1_L0_S2,
    0,
    Opcode_ae_mulaafd32x16_h1_l0_s2_encode_fns, 1, Opcode_ae_mulaafd32x16_h1_l0_s2_funcUnit_uses },
  { "ae_mulaad32x16.h1.l0_s2", ICLASS_AE_MULAAD32X16_H1_L0_S2,
    0,
    Opcode_ae_mulaad32x16_h1_l0_s2_encode_fns, 1, Opcode_ae_mulaad32x16_h1_l0_s2_funcUnit_uses },
  { "ae_mulasfd32x16.h3.l2", ICLASS_AE_MULASFD32X16_H3_L2,
    0,
    Opcode_ae_mulasfd32x16_h3_l2_encode_fns, 1, Opcode_ae_mulasfd32x16_h3_l2_funcUnit_uses },
  { "ae_mulasd32x16.h3.l2", ICLASS_AE_MULASD32X16_H3_L2,
    0,
    Opcode_ae_mulasd32x16_h3_l2_encode_fns, 1, Opcode_ae_mulasd32x16_h3_l2_funcUnit_uses },
  { "ae_mulasfd32x16.h3.l2_s2", ICLASS_AE_MULASFD32X16_H3_L2_S2,
    0,
    Opcode_ae_mulasfd32x16_h3_l2_s2_encode_fns, 1, Opcode_ae_mulasfd32x16_h3_l2_s2_funcUnit_uses },
  { "ae_mulasd32x16.h3.l2_s2", ICLASS_AE_MULASD32X16_H3_L2_S2,
    0,
    Opcode_ae_mulasd32x16_h3_l2_s2_encode_fns, 1, Opcode_ae_mulasd32x16_h3_l2_s2_funcUnit_uses },
  { "ae_mulasfd32x16.h1.l0", ICLASS_AE_MULASFD32X16_H1_L0,
    0,
    Opcode_ae_mulasfd32x16_h1_l0_encode_fns, 1, Opcode_ae_mulasfd32x16_h1_l0_funcUnit_uses },
  { "ae_mulasd32x16.h1.l0", ICLASS_AE_MULASD32X16_H1_L0,
    0,
    Opcode_ae_mulasd32x16_h1_l0_encode_fns, 1, Opcode_ae_mulasd32x16_h1_l0_funcUnit_uses },
  { "ae_mulasfd32x16.h1.l0_s2", ICLASS_AE_MULASFD32X16_H1_L0_S2,
    0,
    Opcode_ae_mulasfd32x16_h1_l0_s2_encode_fns, 1, Opcode_ae_mulasfd32x16_h1_l0_s2_funcUnit_uses },
  { "ae_mulasd32x16.h1.l0_s2", ICLASS_AE_MULASD32X16_H1_L0_S2,
    0,
    Opcode_ae_mulasd32x16_h1_l0_s2_encode_fns, 1, Opcode_ae_mulasd32x16_h1_l0_s2_funcUnit_uses },
  { "ae_mulsafd32x16.h3.l2", ICLASS_AE_MULSAFD32X16_H3_L2,
    0,
    Opcode_ae_mulsafd32x16_h3_l2_encode_fns, 1, Opcode_ae_mulsafd32x16_h3_l2_funcUnit_uses },
  { "ae_mulsad32x16.h3.l2", ICLASS_AE_MULSAD32X16_H3_L2,
    0,
    Opcode_ae_mulsad32x16_h3_l2_encode_fns, 1, Opcode_ae_mulsad32x16_h3_l2_funcUnit_uses },
  { "ae_mulsafd32x16.h3.l2_s2", ICLASS_AE_MULSAFD32X16_H3_L2_S2,
    0,
    Opcode_ae_mulsafd32x16_h3_l2_s2_encode_fns, 1, Opcode_ae_mulsafd32x16_h3_l2_s2_funcUnit_uses },
  { "ae_mulsad32x16.h3.l2_s2", ICLASS_AE_MULSAD32X16_H3_L2_S2,
    0,
    Opcode_ae_mulsad32x16_h3_l2_s2_encode_fns, 1, Opcode_ae_mulsad32x16_h3_l2_s2_funcUnit_uses },
  { "ae_mulsafd32x16.h1.l0", ICLASS_AE_MULSAFD32X16_H1_L0,
    0,
    Opcode_ae_mulsafd32x16_h1_l0_encode_fns, 1, Opcode_ae_mulsafd32x16_h1_l0_funcUnit_uses },
  { "ae_mulsad32x16.h1.l0", ICLASS_AE_MULSAD32X16_H1_L0,
    0,
    Opcode_ae_mulsad32x16_h1_l0_encode_fns, 1, Opcode_ae_mulsad32x16_h1_l0_funcUnit_uses },
  { "ae_mulsafd32x16.h1.l0_s2", ICLASS_AE_MULSAFD32X16_H1_L0_S2,
    0,
    Opcode_ae_mulsafd32x16_h1_l0_s2_encode_fns, 1, Opcode_ae_mulsafd32x16_h1_l0_s2_funcUnit_uses },
  { "ae_mulsad32x16.h1.l0_s2", ICLASS_AE_MULSAD32X16_H1_L0_S2,
    0,
    Opcode_ae_mulsad32x16_h1_l0_s2_encode_fns, 1, Opcode_ae_mulsad32x16_h1_l0_s2_funcUnit_uses },
  { "ae_mulssfd32x16.h3.l2", ICLASS_AE_MULSSFD32X16_H3_L2,
    0,
    Opcode_ae_mulssfd32x16_h3_l2_encode_fns, 1, Opcode_ae_mulssfd32x16_h3_l2_funcUnit_uses },
  { "ae_mulssd32x16.h3.l2", ICLASS_AE_MULSSD32X16_H3_L2,
    0,
    Opcode_ae_mulssd32x16_h3_l2_encode_fns, 1, Opcode_ae_mulssd32x16_h3_l2_funcUnit_uses },
  { "ae_mulssfd32x16.h3.l2_s2", ICLASS_AE_MULSSFD32X16_H3_L2_S2,
    0,
    Opcode_ae_mulssfd32x16_h3_l2_s2_encode_fns, 1, Opcode_ae_mulssfd32x16_h3_l2_s2_funcUnit_uses },
  { "ae_mulssd32x16.h3.l2_s2", ICLASS_AE_MULSSD32X16_H3_L2_S2,
    0,
    Opcode_ae_mulssd32x16_h3_l2_s2_encode_fns, 1, Opcode_ae_mulssd32x16_h3_l2_s2_funcUnit_uses },
  { "ae_mulssfd32x16.h1.l0", ICLASS_AE_MULSSFD32X16_H1_L0,
    0,
    Opcode_ae_mulssfd32x16_h1_l0_encode_fns, 1, Opcode_ae_mulssfd32x16_h1_l0_funcUnit_uses },
  { "ae_mulssd32x16.h1.l0", ICLASS_AE_MULSSD32X16_H1_L0,
    0,
    Opcode_ae_mulssd32x16_h1_l0_encode_fns, 1, Opcode_ae_mulssd32x16_h1_l0_funcUnit_uses },
  { "ae_mulssfd32x16.h1.l0_s2", ICLASS_AE_MULSSFD32X16_H1_L0_S2,
    0,
    Opcode_ae_mulssfd32x16_h1_l0_s2_encode_fns, 1, Opcode_ae_mulssfd32x16_h1_l0_s2_funcUnit_uses },
  { "ae_mulssd32x16.h1.l0_s2", ICLASS_AE_MULSSD32X16_H1_L0_S2,
    0,
    Opcode_ae_mulssd32x16_h1_l0_s2_encode_fns, 1, Opcode_ae_mulssd32x16_h1_l0_s2_funcUnit_uses },
  { "ae_mulzaafd32x16.h3.l2", ICLASS_AE_MULZAAFD32X16_H3_L2,
    0,
    Opcode_ae_mulzaafd32x16_h3_l2_encode_fns, 1, Opcode_ae_mulzaafd32x16_h3_l2_funcUnit_uses },
  { "ae_mulzaad32x16.h3.l2", ICLASS_AE_MULZAAD32X16_H3_L2,
    0,
    Opcode_ae_mulzaad32x16_h3_l2_encode_fns, 1, Opcode_ae_mulzaad32x16_h3_l2_funcUnit_uses },
  { "ae_mulzaafd32x16.h3.l2_s2", ICLASS_AE_MULZAAFD32X16_H3_L2_S2,
    0,
    Opcode_ae_mulzaafd32x16_h3_l2_s2_encode_fns, 1, Opcode_ae_mulzaafd32x16_h3_l2_s2_funcUnit_uses },
  { "ae_mulzaad32x16.h3.l2_s2", ICLASS_AE_MULZAAD32X16_H3_L2_S2,
    0,
    Opcode_ae_mulzaad32x16_h3_l2_s2_encode_fns, 1, Opcode_ae_mulzaad32x16_h3_l2_s2_funcUnit_uses },
  { "ae_mulzaafd32x16.h1.l0", ICLASS_AE_MULZAAFD32X16_H1_L0,
    0,
    Opcode_ae_mulzaafd32x16_h1_l0_encode_fns, 1, Opcode_ae_mulzaafd32x16_h1_l0_funcUnit_uses },
  { "ae_mulzaad32x16.h1.l0", ICLASS_AE_MULZAAD32X16_H1_L0,
    0,
    Opcode_ae_mulzaad32x16_h1_l0_encode_fns, 1, Opcode_ae_mulzaad32x16_h1_l0_funcUnit_uses },
  { "ae_mulzaafd32x16.h1.l0_s2", ICLASS_AE_MULZAAFD32X16_H1_L0_S2,
    0,
    Opcode_ae_mulzaafd32x16_h1_l0_s2_encode_fns, 1, Opcode_ae_mulzaafd32x16_h1_l0_s2_funcUnit_uses },
  { "ae_mulzaad32x16.h1.l0_s2", ICLASS_AE_MULZAAD32X16_H1_L0_S2,
    0,
    Opcode_ae_mulzaad32x16_h1_l0_s2_encode_fns, 1, Opcode_ae_mulzaad32x16_h1_l0_s2_funcUnit_uses },
  { "ae_mulzasfd32x16.h3.l2", ICLASS_AE_MULZASFD32X16_H3_L2,
    0,
    Opcode_ae_mulzasfd32x16_h3_l2_encode_fns, 1, Opcode_ae_mulzasfd32x16_h3_l2_funcUnit_uses },
  { "ae_mulzasd32x16.h3.l2", ICLASS_AE_MULZASD32X16_H3_L2,
    0,
    Opcode_ae_mulzasd32x16_h3_l2_encode_fns, 1, Opcode_ae_mulzasd32x16_h3_l2_funcUnit_uses },
  { "ae_mulzasfd32x16.h3.l2_s2", ICLASS_AE_MULZASFD32X16_H3_L2_S2,
    0,
    Opcode_ae_mulzasfd32x16_h3_l2_s2_encode_fns, 1, Opcode_ae_mulzasfd32x16_h3_l2_s2_funcUnit_uses },
  { "ae_mulzasd32x16.h3.l2_s2", ICLASS_AE_MULZASD32X16_H3_L2_S2,
    0,
    Opcode_ae_mulzasd32x16_h3_l2_s2_encode_fns, 1, Opcode_ae_mulzasd32x16_h3_l2_s2_funcUnit_uses },
  { "ae_mulzasfd32x16.h1.l0", ICLASS_AE_MULZASFD32X16_H1_L0,
    0,
    Opcode_ae_mulzasfd32x16_h1_l0_encode_fns, 1, Opcode_ae_mulzasfd32x16_h1_l0_funcUnit_uses },
  { "ae_mulzasd32x16.h1.l0", ICLASS_AE_MULZASD32X16_H1_L0,
    0,
    Opcode_ae_mulzasd32x16_h1_l0_encode_fns, 1, Opcode_ae_mulzasd32x16_h1_l0_funcUnit_uses },
  { "ae_mulzasfd32x16.h1.l0_s2", ICLASS_AE_MULZASFD32X16_H1_L0_S2,
    0,
    Opcode_ae_mulzasfd32x16_h1_l0_s2_encode_fns, 1, Opcode_ae_mulzasfd32x16_h1_l0_s2_funcUnit_uses },
  { "ae_mulzasd32x16.h1.l0_s2", ICLASS_AE_MULZASD32X16_H1_L0_S2,
    0,
    Opcode_ae_mulzasd32x16_h1_l0_s2_encode_fns, 1, Opcode_ae_mulzasd32x16_h1_l0_s2_funcUnit_uses },
  { "ae_mulzsafd32x16.h3.l2", ICLASS_AE_MULZSAFD32X16_H3_L2,
    0,
    Opcode_ae_mulzsafd32x16_h3_l2_encode_fns, 1, Opcode_ae_mulzsafd32x16_h3_l2_funcUnit_uses },
  { "ae_mulzsad32x16.h3.l2", ICLASS_AE_MULZSAD32X16_H3_L2,
    0,
    Opcode_ae_mulzsad32x16_h3_l2_encode_fns, 1, Opcode_ae_mulzsad32x16_h3_l2_funcUnit_uses },
  { "ae_mulzsafd32x16.h3.l2_s2", ICLASS_AE_MULZSAFD32X16_H3_L2_S2,
    0,
    Opcode_ae_mulzsafd32x16_h3_l2_s2_encode_fns, 1, Opcode_ae_mulzsafd32x16_h3_l2_s2_funcUnit_uses },
  { "ae_mulzsad32x16.h3.l2_s2", ICLASS_AE_MULZSAD32X16_H3_L2_S2,
    0,
    Opcode_ae_mulzsad32x16_h3_l2_s2_encode_fns, 1, Opcode_ae_mulzsad32x16_h3_l2_s2_funcUnit_uses },
  { "ae_mulzsafd32x16.h1.l0", ICLASS_AE_MULZSAFD32X16_H1_L0,
    0,
    Opcode_ae_mulzsafd32x16_h1_l0_encode_fns, 1, Opcode_ae_mulzsafd32x16_h1_l0_funcUnit_uses },
  { "ae_mulzsad32x16.h1.l0", ICLASS_AE_MULZSAD32X16_H1_L0,
    0,
    Opcode_ae_mulzsad32x16_h1_l0_encode_fns, 1, Opcode_ae_mulzsad32x16_h1_l0_funcUnit_uses },
  { "ae_mulzsafd32x16.h1.l0_s2", ICLASS_AE_MULZSAFD32X16_H1_L0_S2,
    0,
    Opcode_ae_mulzsafd32x16_h1_l0_s2_encode_fns, 1, Opcode_ae_mulzsafd32x16_h1_l0_s2_funcUnit_uses },
  { "ae_mulzsad32x16.h1.l0_s2", ICLASS_AE_MULZSAD32X16_H1_L0_S2,
    0,
    Opcode_ae_mulzsad32x16_h1_l0_s2_encode_fns, 1, Opcode_ae_mulzsad32x16_h1_l0_s2_funcUnit_uses },
  { "ae_mulzssfd32x16.h3.l2", ICLASS_AE_MULZSSFD32X16_H3_L2,
    0,
    Opcode_ae_mulzssfd32x16_h3_l2_encode_fns, 1, Opcode_ae_mulzssfd32x16_h3_l2_funcUnit_uses },
  { "ae_mulzssd32x16.h3.l2", ICLASS_AE_MULZSSD32X16_H3_L2,
    0,
    Opcode_ae_mulzssd32x16_h3_l2_encode_fns, 1, Opcode_ae_mulzssd32x16_h3_l2_funcUnit_uses },
  { "ae_mulzssfd32x16.h3.l2_s2", ICLASS_AE_MULZSSFD32X16_H3_L2_S2,
    0,
    Opcode_ae_mulzssfd32x16_h3_l2_s2_encode_fns, 1, Opcode_ae_mulzssfd32x16_h3_l2_s2_funcUnit_uses },
  { "ae_mulzssd32x16.h3.l2_s2", ICLASS_AE_MULZSSD32X16_H3_L2_S2,
    0,
    Opcode_ae_mulzssd32x16_h3_l2_s2_encode_fns, 1, Opcode_ae_mulzssd32x16_h3_l2_s2_funcUnit_uses },
  { "ae_mulzssfd32x16.h1.l0", ICLASS_AE_MULZSSFD32X16_H1_L0,
    0,
    Opcode_ae_mulzssfd32x16_h1_l0_encode_fns, 1, Opcode_ae_mulzssfd32x16_h1_l0_funcUnit_uses },
  { "ae_mulzssd32x16.h1.l0", ICLASS_AE_MULZSSD32X16_H1_L0,
    0,
    Opcode_ae_mulzssd32x16_h1_l0_encode_fns, 1, Opcode_ae_mulzssd32x16_h1_l0_funcUnit_uses },
  { "ae_mulzssfd32x16.h1.l0_s2", ICLASS_AE_MULZSSFD32X16_H1_L0_S2,
    0,
    Opcode_ae_mulzssfd32x16_h1_l0_s2_encode_fns, 1, Opcode_ae_mulzssfd32x16_h1_l0_s2_funcUnit_uses },
  { "ae_mulzssd32x16.h1.l0_s2", ICLASS_AE_MULZSSD32X16_H1_L0_S2,
    0,
    Opcode_ae_mulzssd32x16_h1_l0_s2_encode_fns, 1, Opcode_ae_mulzssd32x16_h1_l0_s2_funcUnit_uses },
  { "ae_mulzaafd32x16.h2.l3", ICLASS_AE_MULZAAFD32X16_H2_L3,
    0,
    Opcode_ae_mulzaafd32x16_h2_l3_encode_fns, 1, Opcode_ae_mulzaafd32x16_h2_l3_funcUnit_uses },
  { "ae_mulzaafd32x16.h0.l1", ICLASS_AE_MULZAAFD32X16_H0_L1,
    0,
    Opcode_ae_mulzaafd32x16_h0_l1_encode_fns, 1, Opcode_ae_mulzaafd32x16_h0_l1_funcUnit_uses },
  { "ae_mulaafd32x16.h2.l3", ICLASS_AE_MULAAFD32X16_H2_L3,
    0,
    Opcode_ae_mulaafd32x16_h2_l3_encode_fns, 1, Opcode_ae_mulaafd32x16_h2_l3_funcUnit_uses },
  { "ae_mulaafd32x16.h0.l1", ICLASS_AE_MULAAFD32X16_H0_L1,
    0,
    Opcode_ae_mulaafd32x16_h0_l1_encode_fns, 1, Opcode_ae_mulaafd32x16_h0_l1_funcUnit_uses },
  { "ae_mulzaad32x16.h2.l3", ICLASS_AE_MULZAAD32X16_H2_L3,
    0,
    Opcode_ae_mulzaad32x16_h2_l3_encode_fns, 1, Opcode_ae_mulzaad32x16_h2_l3_funcUnit_uses },
  { "ae_mulzaad32x16.h0.l1", ICLASS_AE_MULZAAD32X16_H0_L1,
    0,
    Opcode_ae_mulzaad32x16_h0_l1_encode_fns, 1, Opcode_ae_mulzaad32x16_h0_l1_funcUnit_uses },
  { "ae_mulaad32x16.h2.l3", ICLASS_AE_MULAAD32X16_H2_L3,
    0,
    Opcode_ae_mulaad32x16_h2_l3_encode_fns, 1, Opcode_ae_mulaad32x16_h2_l3_funcUnit_uses },
  { "ae_mulaad32x16.h0.l1", ICLASS_AE_MULAAD32X16_H0_L1,
    0,
    Opcode_ae_mulaad32x16_h0_l1_encode_fns, 1, Opcode_ae_mulaad32x16_h0_l1_funcUnit_uses },
  { "ae_mulzaafd32x16.h2.l3_s2", ICLASS_AE_MULZAAFD32X16_H2_L3_S2,
    0,
    Opcode_ae_mulzaafd32x16_h2_l3_s2_encode_fns, 1, Opcode_ae_mulzaafd32x16_h2_l3_s2_funcUnit_uses },
  { "ae_mulzaafd32x16.h0.l1_s2", ICLASS_AE_MULZAAFD32X16_H0_L1_S2,
    0,
    Opcode_ae_mulzaafd32x16_h0_l1_s2_encode_fns, 1, Opcode_ae_mulzaafd32x16_h0_l1_s2_funcUnit_uses },
  { "ae_mulaafd32x16.h2.l3_s2", ICLASS_AE_MULAAFD32X16_H2_L3_S2,
    0,
    Opcode_ae_mulaafd32x16_h2_l3_s2_encode_fns, 1, Opcode_ae_mulaafd32x16_h2_l3_s2_funcUnit_uses },
  { "ae_mulaafd32x16.h0.l1_s2", ICLASS_AE_MULAAFD32X16_H0_L1_S2,
    0,
    Opcode_ae_mulaafd32x16_h0_l1_s2_encode_fns, 1, Opcode_ae_mulaafd32x16_h0_l1_s2_funcUnit_uses },
  { "ae_mulzaad32x16.h2.l3_s2", ICLASS_AE_MULZAAD32X16_H2_L3_S2,
    0,
    Opcode_ae_mulzaad32x16_h2_l3_s2_encode_fns, 1, Opcode_ae_mulzaad32x16_h2_l3_s2_funcUnit_uses },
  { "ae_mulzaad32x16.h0.l1_s2", ICLASS_AE_MULZAAD32X16_H0_L1_S2,
    0,
    Opcode_ae_mulzaad32x16_h0_l1_s2_encode_fns, 1, Opcode_ae_mulzaad32x16_h0_l1_s2_funcUnit_uses },
  { "ae_mulaad32x16.h2.l3_s2", ICLASS_AE_MULAAD32X16_H2_L3_S2,
    0,
    Opcode_ae_mulaad32x16_h2_l3_s2_encode_fns, 1, Opcode_ae_mulaad32x16_h2_l3_s2_funcUnit_uses },
  { "ae_mulaad32x16.h0.l1_s2", ICLASS_AE_MULAAD32X16_H0_L1_S2,
    0,
    Opcode_ae_mulaad32x16_h0_l1_s2_encode_fns, 1, Opcode_ae_mulaad32x16_h0_l1_s2_funcUnit_uses },
  { "ae_mulp32x16x2.h", ICLASS_AE_MULP32X16X2_H,
    0,
    Opcode_ae_mulp32x16x2_h_encode_fns, 1, Opcode_ae_mulp32x16x2_h_funcUnit_uses },
  { "ae_mulfp32x16x2rs.h", ICLASS_AE_MULFP32X16X2RS_H,
    0,
    Opcode_ae_mulfp32x16x2rs_h_encode_fns, 1, Opcode_ae_mulfp32x16x2rs_h_funcUnit_uses },
  { "ae_mulfp32x16x2ras.h", ICLASS_AE_MULFP32X16X2RAS_H,
    0,
    Opcode_ae_mulfp32x16x2ras_h_encode_fns, 1, Opcode_ae_mulfp32x16x2ras_h_funcUnit_uses },
  { "ae_mulfp32x16x2rs.h_s2", ICLASS_AE_MULFP32X16X2RS_H_S2,
    0,
    Opcode_ae_mulfp32x16x2rs_h_s2_encode_fns, 1, Opcode_ae_mulfp32x16x2rs_h_s2_funcUnit_uses },
  { "ae_mulfp32x16x2ras.h_s2", ICLASS_AE_MULFP32X16X2RAS_H_S2,
    0,
    Opcode_ae_mulfp32x16x2ras_h_s2_encode_fns, 1, Opcode_ae_mulfp32x16x2ras_h_s2_funcUnit_uses },
  { "ae_mulp32x16x2.l", ICLASS_AE_MULP32X16X2_L,
    0,
    Opcode_ae_mulp32x16x2_l_encode_fns, 1, Opcode_ae_mulp32x16x2_l_funcUnit_uses },
  { "ae_mulfp32x16x2rs.l", ICLASS_AE_MULFP32X16X2RS_L,
    0,
    Opcode_ae_mulfp32x16x2rs_l_encode_fns, 1, Opcode_ae_mulfp32x16x2rs_l_funcUnit_uses },
  { "ae_mulfp32x16x2ras.l", ICLASS_AE_MULFP32X16X2RAS_L,
    0,
    Opcode_ae_mulfp32x16x2ras_l_encode_fns, 1, Opcode_ae_mulfp32x16x2ras_l_funcUnit_uses },
  { "ae_mulfp32x16x2rs.l_s2", ICLASS_AE_MULFP32X16X2RS_L_S2,
    0,
    Opcode_ae_mulfp32x16x2rs_l_s2_encode_fns, 1, Opcode_ae_mulfp32x16x2rs_l_s2_funcUnit_uses },
  { "ae_mulfp32x16x2ras.l_s2", ICLASS_AE_MULFP32X16X2RAS_L_S2,
    0,
    Opcode_ae_mulfp32x16x2ras_l_s2_encode_fns, 1, Opcode_ae_mulfp32x16x2ras_l_s2_funcUnit_uses },
  { "ae_mulap32x16x2.h", ICLASS_AE_MULAP32X16X2_H,
    0,
    Opcode_ae_mulap32x16x2_h_encode_fns, 1, Opcode_ae_mulap32x16x2_h_funcUnit_uses },
  { "ae_mulafp32x16x2rs.h", ICLASS_AE_MULAFP32X16X2RS_H,
    0,
    Opcode_ae_mulafp32x16x2rs_h_encode_fns, 1, Opcode_ae_mulafp32x16x2rs_h_funcUnit_uses },
  { "ae_mulafp32x16x2ras.h", ICLASS_AE_MULAFP32X16X2RAS_H,
    0,
    Opcode_ae_mulafp32x16x2ras_h_encode_fns, 1, Opcode_ae_mulafp32x16x2ras_h_funcUnit_uses },
  { "ae_mulafp32x16x2rs.h_s2", ICLASS_AE_MULAFP32X16X2RS_H_S2,
    0,
    Opcode_ae_mulafp32x16x2rs_h_s2_encode_fns, 1, Opcode_ae_mulafp32x16x2rs_h_s2_funcUnit_uses },
  { "ae_mulafp32x16x2ras.h_s2", ICLASS_AE_MULAFP32X16X2RAS_H_S2,
    0,
    Opcode_ae_mulafp32x16x2ras_h_s2_encode_fns, 1, Opcode_ae_mulafp32x16x2ras_h_s2_funcUnit_uses },
  { "ae_mulap32x16x2.l", ICLASS_AE_MULAP32X16X2_L,
    0,
    Opcode_ae_mulap32x16x2_l_encode_fns, 1, Opcode_ae_mulap32x16x2_l_funcUnit_uses },
  { "ae_mulafp32x16x2rs.l", ICLASS_AE_MULAFP32X16X2RS_L,
    0,
    Opcode_ae_mulafp32x16x2rs_l_encode_fns, 1, Opcode_ae_mulafp32x16x2rs_l_funcUnit_uses },
  { "ae_mulafp32x16x2ras.l", ICLASS_AE_MULAFP32X16X2RAS_L,
    0,
    Opcode_ae_mulafp32x16x2ras_l_encode_fns, 1, Opcode_ae_mulafp32x16x2ras_l_funcUnit_uses },
  { "ae_mulafp32x16x2rs.l_s2", ICLASS_AE_MULAFP32X16X2RS_L_S2,
    0,
    Opcode_ae_mulafp32x16x2rs_l_s2_encode_fns, 1, Opcode_ae_mulafp32x16x2rs_l_s2_funcUnit_uses },
  { "ae_mulafp32x16x2ras.l_s2", ICLASS_AE_MULAFP32X16X2RAS_L_S2,
    0,
    Opcode_ae_mulafp32x16x2ras_l_s2_encode_fns, 1, Opcode_ae_mulafp32x16x2ras_l_s2_funcUnit_uses },
  { "ae_mulsp32x16x2.h", ICLASS_AE_MULSP32X16X2_H,
    0,
    Opcode_ae_mulsp32x16x2_h_encode_fns, 1, Opcode_ae_mulsp32x16x2_h_funcUnit_uses },
  { "ae_mulsfp32x16x2rs.h", ICLASS_AE_MULSFP32X16X2RS_H,
    0,
    Opcode_ae_mulsfp32x16x2rs_h_encode_fns, 1, Opcode_ae_mulsfp32x16x2rs_h_funcUnit_uses },
  { "ae_mulsfp32x16x2ras.h", ICLASS_AE_MULSFP32X16X2RAS_H,
    0,
    Opcode_ae_mulsfp32x16x2ras_h_encode_fns, 1, Opcode_ae_mulsfp32x16x2ras_h_funcUnit_uses },
  { "ae_mulsfp32x16x2rs.h_s2", ICLASS_AE_MULSFP32X16X2RS_H_S2,
    0,
    Opcode_ae_mulsfp32x16x2rs_h_s2_encode_fns, 1, Opcode_ae_mulsfp32x16x2rs_h_s2_funcUnit_uses },
  { "ae_mulsfp32x16x2ras.h_s2", ICLASS_AE_MULSFP32X16X2RAS_H_S2,
    0,
    Opcode_ae_mulsfp32x16x2ras_h_s2_encode_fns, 1, Opcode_ae_mulsfp32x16x2ras_h_s2_funcUnit_uses },
  { "ae_mulsp32x16x2.l", ICLASS_AE_MULSP32X16X2_L,
    0,
    Opcode_ae_mulsp32x16x2_l_encode_fns, 1, Opcode_ae_mulsp32x16x2_l_funcUnit_uses },
  { "ae_mulsfp32x16x2rs.l", ICLASS_AE_MULSFP32X16X2RS_L,
    0,
    Opcode_ae_mulsfp32x16x2rs_l_encode_fns, 1, Opcode_ae_mulsfp32x16x2rs_l_funcUnit_uses },
  { "ae_mulsfp32x16x2ras.l", ICLASS_AE_MULSFP32X16X2RAS_L,
    0,
    Opcode_ae_mulsfp32x16x2ras_l_encode_fns, 1, Opcode_ae_mulsfp32x16x2ras_l_funcUnit_uses },
  { "ae_mulsfp32x16x2rs.l_s2", ICLASS_AE_MULSFP32X16X2RS_L_S2,
    0,
    Opcode_ae_mulsfp32x16x2rs_l_s2_encode_fns, 1, Opcode_ae_mulsfp32x16x2rs_l_s2_funcUnit_uses },
  { "ae_mulsfp32x16x2ras.l_s2", ICLASS_AE_MULSFP32X16X2RAS_L_S2,
    0,
    Opcode_ae_mulsfp32x16x2ras_l_s2_encode_fns, 1, Opcode_ae_mulsfp32x16x2ras_l_s2_funcUnit_uses },
  { "ae_mulp32x2", ICLASS_AE_MULP32X2,
    0,
    Opcode_ae_mulp32x2_encode_fns, 2, Opcode_ae_mulp32x2_funcUnit_uses },
  { "ae_mulfp32x2rs", ICLASS_AE_MULFP32X2RS,
    0,
    Opcode_ae_mulfp32x2rs_encode_fns, 2, Opcode_ae_mulfp32x2rs_funcUnit_uses },
  { "ae_mulfp32x2ras", ICLASS_AE_MULFP32X2RAS,
    0,
    Opcode_ae_mulfp32x2ras_encode_fns, 2, Opcode_ae_mulfp32x2ras_funcUnit_uses },
  { "ae_mulap32x2", ICLASS_AE_MULAP32X2,
    0,
    Opcode_ae_mulap32x2_encode_fns, 2, Opcode_ae_mulap32x2_funcUnit_uses },
  { "ae_mulafp32x2rs", ICLASS_AE_MULAFP32X2RS,
    0,
    Opcode_ae_mulafp32x2rs_encode_fns, 2, Opcode_ae_mulafp32x2rs_funcUnit_uses },
  { "ae_mulafp32x2ras", ICLASS_AE_MULAFP32X2RAS,
    0,
    Opcode_ae_mulafp32x2ras_encode_fns, 2, Opcode_ae_mulafp32x2ras_funcUnit_uses },
  { "ae_mulsp32x2", ICLASS_AE_MULSP32X2,
    0,
    Opcode_ae_mulsp32x2_encode_fns, 2, Opcode_ae_mulsp32x2_funcUnit_uses },
  { "ae_mulsfp32x2rs", ICLASS_AE_MULSFP32X2RS,
    0,
    Opcode_ae_mulsfp32x2rs_encode_fns, 2, Opcode_ae_mulsfp32x2rs_funcUnit_uses },
  { "ae_mulsfp32x2ras", ICLASS_AE_MULSFP32X2RAS,
    0,
    Opcode_ae_mulsfp32x2ras_encode_fns, 2, Opcode_ae_mulsfp32x2ras_funcUnit_uses },
  { "ae_mulfp16x4s", ICLASS_AE_MULFP16X4S,
    0,
    Opcode_ae_mulfp16x4s_encode_fns, 2, Opcode_ae_mulfp16x4s_funcUnit_uses },
  { "ae_mulfp16x4ras", ICLASS_AE_MULFP16X4RAS,
    0,
    Opcode_ae_mulfp16x4ras_encode_fns, 2, Opcode_ae_mulfp16x4ras_funcUnit_uses },
  { "ae_mulc24", ICLASS_AE_MULC24,
    0,
    Opcode_ae_mulc24_encode_fns, 2, Opcode_ae_mulc24_funcUnit_uses },
  { "ae_mulfc24ra", ICLASS_AE_MULFC24RA,
    0,
    Opcode_ae_mulfc24ra_encode_fns, 2, Opcode_ae_mulfc24ra_funcUnit_uses },
  { "ae_mulc32x16.l", ICLASS_AE_MULC32X16_L,
    0,
    Opcode_ae_mulc32x16_l_encode_fns, 2, Opcode_ae_mulc32x16_l_funcUnit_uses },
  { "ae_mulfc32x16ras.l", ICLASS_AE_MULFC32X16RAS_L,
    0,
    Opcode_ae_mulfc32x16ras_l_encode_fns, 2, Opcode_ae_mulfc32x16ras_l_funcUnit_uses },
  { "ae_mulc32x16.h", ICLASS_AE_MULC32X16_H,
    0,
    Opcode_ae_mulc32x16_h_encode_fns, 2, Opcode_ae_mulc32x16_h_funcUnit_uses },
  { "ae_mulfc32x16ras.h", ICLASS_AE_MULFC32X16RAS_H,
    0,
    Opcode_ae_mulfc32x16ras_h_encode_fns, 2, Opcode_ae_mulfc32x16ras_h_funcUnit_uses },
  { "ae_mulac24", ICLASS_AE_MULAC24,
    0,
    Opcode_ae_mulac24_encode_fns, 2, Opcode_ae_mulac24_funcUnit_uses },
  { "ae_mulafc24ra", ICLASS_AE_MULAFC24RA,
    0,
    Opcode_ae_mulafc24ra_encode_fns, 2, Opcode_ae_mulafc24ra_funcUnit_uses },
  { "ae_mulac32x16.l", ICLASS_AE_MULAC32X16_L,
    0,
    Opcode_ae_mulac32x16_l_encode_fns, 2, Opcode_ae_mulac32x16_l_funcUnit_uses },
  { "ae_mulafc32x16ras.l", ICLASS_AE_MULAFC32X16RAS_L,
    0,
    Opcode_ae_mulafc32x16ras_l_encode_fns, 2, Opcode_ae_mulafc32x16ras_l_funcUnit_uses },
  { "ae_mulac32x16.h", ICLASS_AE_MULAC32X16_H,
    0,
    Opcode_ae_mulac32x16_h_encode_fns, 2, Opcode_ae_mulac32x16_h_funcUnit_uses },
  { "ae_mulafc32x16ras.h", ICLASS_AE_MULAFC32X16RAS_H,
    0,
    Opcode_ae_mulafc32x16ras_h_encode_fns, 2, Opcode_ae_mulafc32x16ras_h_funcUnit_uses },
  { "ae_mulf16x4ss", ICLASS_AE_MULF16X4SS,
    0,
    Opcode_ae_mulf16x4ss_encode_fns, 2, Opcode_ae_mulf16x4ss_funcUnit_uses },
  { "ae_mulaf16x4ss", ICLASS_AE_MULAF16X4SS,
    0,
    Opcode_ae_mulaf16x4ss_encode_fns, 2, Opcode_ae_mulaf16x4ss_funcUnit_uses },
  { "ae_mulsf16x4ss", ICLASS_AE_MULSF16X4SS,
    0,
    Opcode_ae_mulsf16x4ss_encode_fns, 2, Opcode_ae_mulsf16x4ss_funcUnit_uses },
  { "ae_mul16x4", ICLASS_AE_MUL16X4,
    0,
    Opcode_ae_mul16x4_encode_fns, 2, Opcode_ae_mul16x4_funcUnit_uses },
  { "ae_mula16x4", ICLASS_AE_MULA16X4,
    0,
    Opcode_ae_mula16x4_encode_fns, 2, Opcode_ae_mula16x4_funcUnit_uses },
  { "ae_muls16x4", ICLASS_AE_MULS16X4,
    0,
    Opcode_ae_muls16x4_encode_fns, 2, Opcode_ae_muls16x4_funcUnit_uses },
  { "ae_mulfd24x2.fir.h", ICLASS_AE_MULFD24X2_FIR_H,
    0,
    Opcode_ae_mulfd24x2_fir_h_encode_fns, 2, Opcode_ae_mulfd24x2_fir_h_funcUnit_uses },
  { "ae_mulfd24x2.fir.l", ICLASS_AE_MULFD24X2_FIR_L,
    0,
    Opcode_ae_mulfd24x2_fir_l_encode_fns, 2, Opcode_ae_mulfd24x2_fir_l_funcUnit_uses },
  { "ae_mulfd32x16x2.fir.hh", ICLASS_AE_MULFD32X16X2_FIR_HH,
    0,
    Opcode_ae_mulfd32x16x2_fir_hh_encode_fns, 2, Opcode_ae_mulfd32x16x2_fir_hh_funcUnit_uses },
  { "ae_mulfd32x16x2.fir.hl", ICLASS_AE_MULFD32X16X2_FIR_HL,
    0,
    Opcode_ae_mulfd32x16x2_fir_hl_encode_fns, 2, Opcode_ae_mulfd32x16x2_fir_hl_funcUnit_uses },
  { "ae_mulfd32x16x2.fir.lh", ICLASS_AE_MULFD32X16X2_FIR_LH,
    0,
    Opcode_ae_mulfd32x16x2_fir_lh_encode_fns, 2, Opcode_ae_mulfd32x16x2_fir_lh_funcUnit_uses },
  { "ae_mulfd32x16x2.fir.ll", ICLASS_AE_MULFD32X16X2_FIR_LL,
    0,
    Opcode_ae_mulfd32x16x2_fir_ll_encode_fns, 2, Opcode_ae_mulfd32x16x2_fir_ll_funcUnit_uses },
  { "ae_mulafd24x2.fir.h", ICLASS_AE_MULAFD24X2_FIR_H,
    0,
    Opcode_ae_mulafd24x2_fir_h_encode_fns, 2, Opcode_ae_mulafd24x2_fir_h_funcUnit_uses },
  { "ae_mulafd24x2.fir.l", ICLASS_AE_MULAFD24X2_FIR_L,
    0,
    Opcode_ae_mulafd24x2_fir_l_encode_fns, 2, Opcode_ae_mulafd24x2_fir_l_funcUnit_uses },
  { "ae_mulafd32x16x2.fir.hh", ICLASS_AE_MULAFD32X16X2_FIR_HH,
    0,
    Opcode_ae_mulafd32x16x2_fir_hh_encode_fns, 2, Opcode_ae_mulafd32x16x2_fir_hh_funcUnit_uses },
  { "ae_mulafd32x16x2.fir.hl", ICLASS_AE_MULAFD32X16X2_FIR_HL,
    0,
    Opcode_ae_mulafd32x16x2_fir_hl_encode_fns, 2, Opcode_ae_mulafd32x16x2_fir_hl_funcUnit_uses },
  { "ae_mulafd32x16x2.fir.lh", ICLASS_AE_MULAFD32X16X2_FIR_LH,
    0,
    Opcode_ae_mulafd32x16x2_fir_lh_encode_fns, 2, Opcode_ae_mulafd32x16x2_fir_lh_funcUnit_uses },
  { "ae_mulafd32x16x2.fir.ll", ICLASS_AE_MULAFD32X16X2_FIR_LL,
    0,
    Opcode_ae_mulafd32x16x2_fir_ll_encode_fns, 2, Opcode_ae_mulafd32x16x2_fir_ll_funcUnit_uses },
  { "ae_div64d32.h", ICLASS_AE_DIV64D32_H,
    0,
    Opcode_ae_div64d32_h_encode_fns, 0, 0 },
  { "ae_div64d32.l", ICLASS_AE_DIV64D32_L,
    0,
    Opcode_ae_div64d32_l_encode_fns, 0, 0 },
  { "ae_sha32", ICLASS_AE_SHA32,
    0,
    Opcode_ae_sha32_encode_fns, 0, 0 },
  { "ae_vldl32t", ICLASS_AE_VLDL32T,
    0,
    Opcode_ae_vldl32t_encode_fns, 2, Opcode_ae_vldl32t_funcUnit_uses },
  { "ae_vldl16t", ICLASS_AE_VLDL16T,
    0,
    Opcode_ae_vldl16t_encode_fns, 2, Opcode_ae_vldl16t_funcUnit_uses },
  { "ae_vldl16c", ICLASS_AE_VLDL16C,
    0,
    Opcode_ae_vldl16c_encode_fns, 4, Opcode_ae_vldl16c_funcUnit_uses },
  { "ae_vldl16c.ip", ICLASS_AE_VLDL16C_IP,
    0,
    Opcode_ae_vldl16c_ip_encode_fns, 4, Opcode_ae_vldl16c_ip_funcUnit_uses },
  { "ae_vldl16c.ic", ICLASS_AE_VLDL16C_IC,
    0,
    Opcode_ae_vldl16c_ic_encode_fns, 4, Opcode_ae_vldl16c_ic_funcUnit_uses },
  { "ae_vldsht", ICLASS_AE_VLDSHT,
    0,
    Opcode_ae_vldsht_encode_fns, 3, Opcode_ae_vldsht_funcUnit_uses },
  { "ae_lb", ICLASS_AE_LB,
    0,
    Opcode_ae_lb_encode_fns, 1, Opcode_ae_lb_funcUnit_uses },
  { "ae_lbi", ICLASS_AE_LBI,
    0,
    Opcode_ae_lbi_encode_fns, 1, Opcode_ae_lbi_funcUnit_uses },
  { "ae_lbk", ICLASS_AE_LBK,
    0,
    Opcode_ae_lbk_encode_fns, 1, Opcode_ae_lbk_funcUnit_uses },
  { "ae_lbki", ICLASS_AE_LBKI,
    0,
    Opcode_ae_lbki_encode_fns, 1, Opcode_ae_lbki_funcUnit_uses },
  { "ae_lbs", ICLASS_AE_LBS,
    0,
    Opcode_ae_lbs_encode_fns, 1, Opcode_ae_lbs_funcUnit_uses },
  { "ae_lbsi", ICLASS_AE_LBSI,
    0,
    Opcode_ae_lbsi_encode_fns, 1, Opcode_ae_lbsi_funcUnit_uses },
  { "ae_db", ICLASS_AE_DB,
    0,
    Opcode_ae_db_encode_fns, 3, Opcode_ae_db_funcUnit_uses },
  { "ae_dbi", ICLASS_AE_DBI,
    0,
    Opcode_ae_dbi_encode_fns, 3, Opcode_ae_dbi_funcUnit_uses },
  { "ae_db.ic", ICLASS_AE_DB_IC,
    0,
    Opcode_ae_db_ic_encode_fns, 3, Opcode_ae_db_ic_funcUnit_uses },
  { "ae_dbi.ic", ICLASS_AE_DBI_IC,
    0,
    Opcode_ae_dbi_ic_encode_fns, 3, Opcode_ae_dbi_ic_funcUnit_uses },
  { "ae_db.ip", ICLASS_AE_DB_IP,
    0,
    Opcode_ae_db_ip_encode_fns, 3, Opcode_ae_db_ip_funcUnit_uses },
  { "ae_dbi.ip", ICLASS_AE_DBI_IP,
    0,
    Opcode_ae_dbi_ip_encode_fns, 3, Opcode_ae_dbi_ip_funcUnit_uses },
  { "ae_vlel32t", ICLASS_AE_VLEL32T,
    0,
    Opcode_ae_vlel32t_encode_fns, 2, Opcode_ae_vlel32t_funcUnit_uses },
  { "ae_vlel16t", ICLASS_AE_VLEL16T,
    0,
    Opcode_ae_vlel16t_encode_fns, 2, Opcode_ae_vlel16t_funcUnit_uses },
  { "ae_sb", ICLASS_AE_SB,
    0,
    Opcode_ae_sb_encode_fns, 3, Opcode_ae_sb_funcUnit_uses },
  { "ae_sbi", ICLASS_AE_SBI,
    0,
    Opcode_ae_sbi_encode_fns, 3, Opcode_ae_sbi_funcUnit_uses },
  { "ae_vles16c", ICLASS_AE_VLES16C,
    0,
    Opcode_ae_vles16c_encode_fns, 3, Opcode_ae_vles16c_funcUnit_uses },
  { "ae_sbf", ICLASS_AE_SBF,
    0,
    Opcode_ae_sbf_encode_fns, 3, Opcode_ae_sbf_funcUnit_uses },
  { "ae_sb.ic", ICLASS_AE_SB_IC,
    0,
    Opcode_ae_sb_ic_encode_fns, 3, Opcode_ae_sb_ic_funcUnit_uses },
  { "ae_sbi.ic", ICLASS_AE_SBI_IC,
    0,
    Opcode_ae_sbi_ic_encode_fns, 3, Opcode_ae_sbi_ic_funcUnit_uses },
  { "ae_vles16c.ic", ICLASS_AE_VLES16C_IC,
    0,
    Opcode_ae_vles16c_ic_encode_fns, 3, Opcode_ae_vles16c_ic_funcUnit_uses },
  { "ae_sbf.ic", ICLASS_AE_SBF_IC,
    0,
    Opcode_ae_sbf_ic_encode_fns, 3, Opcode_ae_sbf_ic_funcUnit_uses },
  { "ae_sb.ip", ICLASS_AE_SB_IP,
    0,
    Opcode_ae_sb_ip_encode_fns, 3, Opcode_ae_sb_ip_funcUnit_uses },
  { "ae_sbi.ip", ICLASS_AE_SBI_IP,
    0,
    Opcode_ae_sbi_ip_encode_fns, 3, Opcode_ae_sbi_ip_funcUnit_uses },
  { "ae_vles16c.ip", ICLASS_AE_VLES16C_IP,
    0,
    Opcode_ae_vles16c_ip_encode_fns, 3, Opcode_ae_vles16c_ip_funcUnit_uses },
  { "ae_sbf.ip", ICLASS_AE_SBF_IP,
    0,
    Opcode_ae_sbf_ip_encode_fns, 3, Opcode_ae_sbf_ip_funcUnit_uses },
  { "ae_sext32", ICLASS_AE_SEXT32,
    0,
    Opcode_ae_sext32_encode_fns, 0, 0 },
  { "lsi", ICLASS_LSI,
    0,
    Opcode_lsi_encode_fns, 1, Opcode_lsi_funcUnit_uses },
  { "lsip", ICLASS_LSIP,
    0,
    Opcode_lsip_encode_fns, 1, Opcode_lsip_funcUnit_uses },
  { "lsx", ICLASS_LSX,
    0,
    Opcode_lsx_encode_fns, 1, Opcode_lsx_funcUnit_uses },
  { "lsxp", ICLASS_LSXP,
    0,
    Opcode_lsxp_encode_fns, 1, Opcode_lsxp_funcUnit_uses },
  { "ssi", ICLASS_SSI,
    0,
    Opcode_ssi_encode_fns, 1, Opcode_ssi_funcUnit_uses },
  { "ssip", ICLASS_SSIP,
    0,
    Opcode_ssip_encode_fns, 1, Opcode_ssip_funcUnit_uses },
  { "ssx", ICLASS_SSX,
    0,
    Opcode_ssx_encode_fns, 1, Opcode_ssx_funcUnit_uses },
  { "ssxp", ICLASS_SSXP,
    0,
    Opcode_ssxp_encode_fns, 1, Opcode_ssxp_funcUnit_uses },
  { "abs.s", ICLASS_ABS_S,
    0,
    Opcode_abs_s_encode_fns, 0, 0 },
  { "neg.s", ICLASS_NEG_S,
    0,
    Opcode_neg_s_encode_fns, 0, 0 },
  { "mov.s", ICLASS_MOV_S,
    0,
    Opcode_mov_s_encode_fns, 0, 0 },
  { "moveqz.s", ICLASS_MOVEQZ_S,
    0,
    Opcode_moveqz_s_encode_fns, 0, 0 },
  { "movnez.s", ICLASS_MOVNEZ_S,
    0,
    Opcode_movnez_s_encode_fns, 0, 0 },
  { "movltz.s", ICLASS_MOVLTZ_S,
    0,
    Opcode_movltz_s_encode_fns, 0, 0 },
  { "movgez.s", ICLASS_MOVGEZ_S,
    0,
    Opcode_movgez_s_encode_fns, 0, 0 },
  { "movf.s", ICLASS_MOVF_S,
    0,
    Opcode_movf_s_encode_fns, 0, 0 },
  { "movt.s", ICLASS_MOVT_S,
    0,
    Opcode_movt_s_encode_fns, 0, 0 },
  { "wfr", ICLASS_WFR,
    0,
    Opcode_wfr_encode_fns, 0, 0 },
  { "rfr", ICLASS_RFR,
    0,
    Opcode_rfr_encode_fns, 0, 0 },
  { "round.s", ICLASS_ROUND_S,
    0,
    Opcode_round_s_encode_fns, 0, 0 },
  { "ceil.s", ICLASS_CEIL_S,
    0,
    Opcode_ceil_s_encode_fns, 0, 0 },
  { "floor.s", ICLASS_FLOOR_S,
    0,
    Opcode_floor_s_encode_fns, 0, 0 },
  { "trunc.s", ICLASS_TRUNC_S,
    0,
    Opcode_trunc_s_encode_fns, 0, 0 },
  { "utrunc.s", ICLASS_UTRUNC_S,
    0,
    Opcode_utrunc_s_encode_fns, 0, 0 },
  { "float.s", ICLASS_FLOAT_S,
    0,
    Opcode_float_s_encode_fns, 0, 0 },
  { "ufloat.s", ICLASS_UFLOAT_S,
    0,
    Opcode_ufloat_s_encode_fns, 0, 0 },
  { "un.s", ICLASS_UN_S,
    0,
    Opcode_un_s_encode_fns, 0, 0 },
  { "ult.s", ICLASS_ULT_S,
    0,
    Opcode_ult_s_encode_fns, 0, 0 },
  { "ule.s", ICLASS_ULE_S,
    0,
    Opcode_ule_s_encode_fns, 0, 0 },
  { "ueq.s", ICLASS_UEQ_S,
    0,
    Opcode_ueq_s_encode_fns, 0, 0 },
  { "olt.s", ICLASS_OLT_S,
    0,
    Opcode_olt_s_encode_fns, 0, 0 },
  { "ole.s", ICLASS_OLE_S,
    0,
    Opcode_ole_s_encode_fns, 0, 0 },
  { "oeq.s", ICLASS_OEQ_S,
    0,
    Opcode_oeq_s_encode_fns, 0, 0 },
  { "add.s", ICLASS_ADD_S,
    0,
    Opcode_add_s_encode_fns, 0, 0 },
  { "sub.s", ICLASS_SUB_S,
    0,
    Opcode_sub_s_encode_fns, 0, 0 },
  { "mul.s", ICLASS_MUL_S,
    0,
    Opcode_mul_s_encode_fns, 0, 0 },
  { "madd.s", ICLASS_MADD_S,
    0,
    Opcode_madd_s_encode_fns, 0, 0 },
  { "msub.s", ICLASS_MSUB_S,
    0,
    Opcode_msub_s_encode_fns, 0, 0 },
  { "sqrt0.s", ICLASS_SQRT0_S,
    0,
    Opcode_sqrt0_s_encode_fns, 0, 0 },
  { "div0.s", ICLASS_DIV0_S,
    0,
    Opcode_div0_s_encode_fns, 0, 0 },
  { "recip0.s", ICLASS_RECIP0_S,
    0,
    Opcode_recip0_s_encode_fns, 0, 0 },
  { "rsqrt0.s", ICLASS_RSQRT0_S,
    0,
    Opcode_rsqrt0_s_encode_fns, 0, 0 },
  { "maddn.s", ICLASS_MADDN_S,
    0,
    Opcode_maddn_s_encode_fns, 0, 0 },
  { "divn.s", ICLASS_DIVN_S,
    0,
    Opcode_divn_s_encode_fns, 0, 0 },
  { "const.s", ICLASS_CONST_S,
    0,
    Opcode_const_s_encode_fns, 0, 0 },
  { "nexp01.s", ICLASS_NEXP01_S,
    0,
    Opcode_nexp01_s_encode_fns, 0, 0 },
  { "addexp.s", ICLASS_ADDEXP_S,
    0,
    Opcode_addexp_s_encode_fns, 0, 0 },
  { "addexpm.s", ICLASS_ADDEXPM_S,
    0,
    Opcode_addexpm_s_encode_fns, 0, 0 },
  { "mkdadj.s", ICLASS_MKDADJ_S,
    0,
    Opcode_mkdadj_s_encode_fns, 0, 0 },
  { "mksadj.s", ICLASS_MKSADJ_S,
    0,
    Opcode_mksadj_s_encode_fns, 0, 0 }
};

enum xtensa_opcode_id {
  OPCODE_EXCW,
  OPCODE_RFE,
  OPCODE_RFDE,
  OPCODE_SYSCALL,
  OPCODE_CALL12,
  OPCODE_CALL8,
  OPCODE_CALL4,
  OPCODE_CALLX12,
  OPCODE_CALLX8,
  OPCODE_CALLX4,
  OPCODE_ENTRY,
  OPCODE_MOVSP,
  OPCODE_ROTW,
  OPCODE_RETW,
  OPCODE_RETW_N,
  OPCODE_RFWO,
  OPCODE_RFWU,
  OPCODE_L32E,
  OPCODE_S32E,
  OPCODE_RSR_WINDOWBASE,
  OPCODE_WSR_WINDOWBASE,
  OPCODE_XSR_WINDOWBASE,
  OPCODE_RSR_WINDOWSTART,
  OPCODE_WSR_WINDOWSTART,
  OPCODE_XSR_WINDOWSTART,
  OPCODE_RFME,
  OPCODE_RSR_MESR,
  OPCODE_WSR_MESR,
  OPCODE_XSR_MESR,
  OPCODE_RSR_MECR,
  OPCODE_WSR_MECR,
  OPCODE_XSR_MECR,
  OPCODE_RSR_MEPC,
  OPCODE_WSR_MEPC,
  OPCODE_XSR_MEPC,
  OPCODE_RSR_MEPS,
  OPCODE_WSR_MEPS,
  OPCODE_XSR_MEPS,
  OPCODE_RSR_MESAVE,
  OPCODE_WSR_MESAVE,
  OPCODE_XSR_MESAVE,
  OPCODE_RSR_MEVADDR,
  OPCODE_WSR_MEVADDR,
  OPCODE_XSR_MEVADDR,
  OPCODE_ADD_N,
  OPCODE_ADDI_N,
  OPCODE_BEQZ_N,
  OPCODE_BNEZ_N,
  OPCODE_ILL_N,
  OPCODE_L32I_N,
  OPCODE_MOV_N,
  OPCODE_MOVI_N,
  OPCODE_NOP_N,
  OPCODE_RET_N,
  OPCODE_S32I_N,
  OPCODE_RUR_THREADPTR,
  OPCODE_WUR_THREADPTR,
  OPCODE_ADDI,
  OPCODE_ADDMI,
  OPCODE_ADD,
  OPCODE_ADDX2,
  OPCODE_ADDX4,
  OPCODE_ADDX8,
  OPCODE_SUB,
  OPCODE_SUBX2,
  OPCODE_SUBX4,
  OPCODE_SUBX8,
  OPCODE_AND,
  OPCODE_OR,
  OPCODE_XOR,
  OPCODE_BEQI,
  OPCODE_BGEI,
  OPCODE_BLTI,
  OPCODE_BNEI,
  OPCODE_BBCI,
  OPCODE_BBSI,
  OPCODE_BGEUI,
  OPCODE_BLTUI,
  OPCODE_BALL,
  OPCODE_BANY,
  OPCODE_BBC,
  OPCODE_BBS,
  OPCODE_BEQ,
  OPCODE_BGE,
  OPCODE_BGEU,
  OPCODE_BLT,
  OPCODE_BLTU,
  OPCODE_BNALL,
  OPCODE_BNE,
  OPCODE_BNONE,
  OPCODE_BEQZ,
  OPCODE_BGEZ,
  OPCODE_BLTZ,
  OPCODE_BNEZ,
  OPCODE_CALL0,
  OPCODE_CALLX0,
  OPCODE_EXTUI,
  OPCODE_ILL,
  OPCODE_J,
  OPCODE_JX,
  OPCODE_L16UI,
  OPCODE_L16SI,
  OPCODE_L32I,
  OPCODE_L32R,
  OPCODE_L8UI,
  OPCODE_LOOP,
  OPCODE_LOOPGTZ,
  OPCODE_LOOPNEZ,
  OPCODE_MOVI,
  OPCODE_MOVEQZ,
  OPCODE_MOVGEZ,
  OPCODE_MOVLTZ,
  OPCODE_MOVNEZ,
  OPCODE_ABS,
  OPCODE_NEG,
  OPCODE_NOP,
  OPCODE_RET,
  OPCODE_SIMCALL,
  OPCODE_S16I,
  OPCODE_S32I,
  OPCODE_S32NB,
  OPCODE_S8I,
  OPCODE_SSA8B,
  OPCODE_SSA8L,
  OPCODE_SSL,
  OPCODE_SSR,
  OPCODE_SSAI,
  OPCODE_SLL,
  OPCODE_SRC,
  OPCODE_SRA,
  OPCODE_SRL,
  OPCODE_SLLI,
  OPCODE_SRAI,
  OPCODE_SRLI,
  OPCODE_MEMW,
  OPCODE_EXTW,
  OPCODE_ISYNC,
  OPCODE_DSYNC,
  OPCODE_ESYNC,
  OPCODE_RSYNC,
  OPCODE_RSIL,
  OPCODE_RSR_LEND,
  OPCODE_WSR_LEND,
  OPCODE_XSR_LEND,
  OPCODE_RSR_LCOUNT,
  OPCODE_WSR_LCOUNT,
  OPCODE_XSR_LCOUNT,
  OPCODE_RSR_LBEG,
  OPCODE_WSR_LBEG,
  OPCODE_XSR_LBEG,
  OPCODE_RSR_SAR,
  OPCODE_WSR_SAR,
  OPCODE_XSR_SAR,
  OPCODE_RSR_MEMCTL,
  OPCODE_WSR_MEMCTL,
  OPCODE_XSR_MEMCTL,
  OPCODE_RSR_LITBASE,
  OPCODE_WSR_LITBASE,
  OPCODE_XSR_LITBASE,
  OPCODE_RSR_CONFIGID0,
  OPCODE_WSR_CONFIGID0,
  OPCODE_RSR_CONFIGID1,
  OPCODE_RSR_243,
  OPCODE_RSR_PS,
  OPCODE_WSR_PS,
  OPCODE_XSR_PS,
  OPCODE_RSR_EPC1,
  OPCODE_WSR_EPC1,
  OPCODE_XSR_EPC1,
  OPCODE_RSR_EXCSAVE1,
  OPCODE_WSR_EXCSAVE1,
  OPCODE_XSR_EXCSAVE1,
  OPCODE_RSR_EPC2,
  OPCODE_WSR_EPC2,
  OPCODE_XSR_EPC2,
  OPCODE_RSR_EXCSAVE2,
  OPCODE_WSR_EXCSAVE2,
  OPCODE_XSR_EXCSAVE2,
  OPCODE_RSR_EPC3,
  OPCODE_WSR_EPC3,
  OPCODE_XSR_EPC3,
  OPCODE_RSR_EXCSAVE3,
  OPCODE_WSR_EXCSAVE3,
  OPCODE_XSR_EXCSAVE3,
  OPCODE_RSR_EPC4,
  OPCODE_WSR_EPC4,
  OPCODE_XSR_EPC4,
  OPCODE_RSR_EXCSAVE4,
  OPCODE_WSR_EXCSAVE4,
  OPCODE_XSR_EXCSAVE4,
  OPCODE_RSR_EPC5,
  OPCODE_WSR_EPC5,
  OPCODE_XSR_EPC5,
  OPCODE_RSR_EXCSAVE5,
  OPCODE_WSR_EXCSAVE5,
  OPCODE_XSR_EXCSAVE5,
  OPCODE_RSR_EPC6,
  OPCODE_WSR_EPC6,
  OPCODE_XSR_EPC6,
  OPCODE_RSR_EXCSAVE6,
  OPCODE_WSR_EXCSAVE6,
  OPCODE_XSR_EXCSAVE6,
  OPCODE_RSR_EPC7,
  OPCODE_WSR_EPC7,
  OPCODE_XSR_EPC7,
  OPCODE_RSR_EXCSAVE7,
  OPCODE_WSR_EXCSAVE7,
  OPCODE_XSR_EXCSAVE7,
  OPCODE_RSR_EPS2,
  OPCODE_WSR_EPS2,
  OPCODE_XSR_EPS2,
  OPCODE_RSR_EPS3,
  OPCODE_WSR_EPS3,
  OPCODE_XSR_EPS3,
  OPCODE_RSR_EPS4,
  OPCODE_WSR_EPS4,
  OPCODE_XSR_EPS4,
  OPCODE_RSR_EPS5,
  OPCODE_WSR_EPS5,
  OPCODE_XSR_EPS5,
  OPCODE_RSR_EPS6,
  OPCODE_WSR_EPS6,
  OPCODE_XSR_EPS6,
  OPCODE_RSR_EPS7,
  OPCODE_WSR_EPS7,
  OPCODE_XSR_EPS7,
  OPCODE_RSR_EXCVADDR,
  OPCODE_WSR_EXCVADDR,
  OPCODE_XSR_EXCVADDR,
  OPCODE_RSR_DEPC,
  OPCODE_WSR_DEPC,
  OPCODE_XSR_DEPC,
  OPCODE_RSR_EXCCAUSE,
  OPCODE_WSR_EXCCAUSE,
  OPCODE_XSR_EXCCAUSE,
  OPCODE_RSR_PRID,
  OPCODE_RSR_VECBASE,
  OPCODE_WSR_VECBASE,
  OPCODE_XSR_VECBASE,
  OPCODE_MUL16S,
  OPCODE_MUL16U,
  OPCODE_MULL,
  OPCODE_MULSH,
  OPCODE_MULUH,
  OPCODE_RFI,
  OPCODE_WAITI,
  OPCODE_RSR_INTERRUPT,
  OPCODE_WSR_INTSET,
  OPCODE_WSR_INTCLEAR,
  OPCODE_RSR_INTENABLE,
  OPCODE_WSR_INTENABLE,
  OPCODE_XSR_INTENABLE,
  OPCODE_BREAK,
  OPCODE_BREAK_N,
  OPCODE_RSR_DBREAKA0,
  OPCODE_WSR_DBREAKA0,
  OPCODE_XSR_DBREAKA0,
  OPCODE_RSR_DBREAKC0,
  OPCODE_WSR_DBREAKC0,
  OPCODE_XSR_DBREAKC0,
  OPCODE_RSR_DBREAKA1,
  OPCODE_WSR_DBREAKA1,
  OPCODE_XSR_DBREAKA1,
  OPCODE_RSR_DBREAKC1,
  OPCODE_WSR_DBREAKC1,
  OPCODE_XSR_DBREAKC1,
  OPCODE_RSR_IBREAKA0,
  OPCODE_WSR_IBREAKA0,
  OPCODE_XSR_IBREAKA0,
  OPCODE_RSR_IBREAKA1,
  OPCODE_WSR_IBREAKA1,
  OPCODE_XSR_IBREAKA1,
  OPCODE_RSR_IBREAKENABLE,
  OPCODE_WSR_IBREAKENABLE,
  OPCODE_XSR_IBREAKENABLE,
  OPCODE_RSR_DEBUGCAUSE,
  OPCODE_WSR_DEBUGCAUSE,
  OPCODE_XSR_DEBUGCAUSE,
  OPCODE_RSR_ICOUNT,
  OPCODE_WSR_ICOUNT,
  OPCODE_XSR_ICOUNT,
  OPCODE_RSR_ICOUNTLEVEL,
  OPCODE_WSR_ICOUNTLEVEL,
  OPCODE_XSR_ICOUNTLEVEL,
  OPCODE_RSR_DDR,
  OPCODE_WSR_DDR,
  OPCODE_XSR_DDR,
  OPCODE_LDDR32_P,
  OPCODE_SDDR32_P,
  OPCODE_RFDO,
  OPCODE_RFDD,
  OPCODE_WSR_MMID,
  OPCODE_ANDB,
  OPCODE_ANDBC,
  OPCODE_ORB,
  OPCODE_ORBC,
  OPCODE_XORB,
  OPCODE_ALL4,
  OPCODE_ANY4,
  OPCODE_ALL8,
  OPCODE_ANY8,
  OPCODE_BF,
  OPCODE_BT,
  OPCODE_MOVF,
  OPCODE_MOVT,
  OPCODE_RSR_BR,
  OPCODE_WSR_BR,
  OPCODE_XSR_BR,
  OPCODE_RSR_CCOUNT,
  OPCODE_WSR_CCOUNT,
  OPCODE_XSR_CCOUNT,
  OPCODE_RSR_CCOMPARE0,
  OPCODE_WSR_CCOMPARE0,
  OPCODE_XSR_CCOMPARE0,
  OPCODE_RSR_CCOMPARE1,
  OPCODE_WSR_CCOMPARE1,
  OPCODE_XSR_CCOMPARE1,
  OPCODE_RSR_CCOMPARE2,
  OPCODE_WSR_CCOMPARE2,
  OPCODE_XSR_CCOMPARE2,
  OPCODE_IHI,
  OPCODE_IPF,
  OPCODE_IHU,
  OPCODE_IIU,
  OPCODE_IPFL,
  OPCODE_III,
  OPCODE_LICT,
  OPCODE_LICW,
  OPCODE_SICT,
  OPCODE_SICW,
  OPCODE_DHWB,
  OPCODE_DHWBI,
  OPCODE_DIWBUI_P,
  OPCODE_DIWB,
  OPCODE_DIWBI,
  OPCODE_DHI,
  OPCODE_DII,
  OPCODE_DPFR,
  OPCODE_DPFRO,
  OPCODE_DPFW,
  OPCODE_DPFWO,
  OPCODE_DHU,
  OPCODE_DIU,
  OPCODE_DPFL,
  OPCODE_SDCT,
  OPCODE_LDCT,
  OPCODE_RSR_PREFCTL,
  OPCODE_WSR_PREFCTL,
  OPCODE_XSR_PREFCTL,
  OPCODE_IDTLB,
  OPCODE_PDTLB,
  OPCODE_RDTLB0,
  OPCODE_RDTLB1,
  OPCODE_WDTLB,
  OPCODE_IITLB,
  OPCODE_PITLB,
  OPCODE_RITLB0,
  OPCODE_RITLB1,
  OPCODE_WITLB,
  OPCODE_RSR_CPENABLE,
  OPCODE_WSR_CPENABLE,
  OPCODE_XSR_CPENABLE,
  OPCODE_CLAMPS,
  OPCODE_MAX,
  OPCODE_MAXU,
  OPCODE_MIN,
  OPCODE_MINU,
  OPCODE_NSA,
  OPCODE_NSAU,
  OPCODE_SEXT,
  OPCODE_L32AI,
  OPCODE_S32RI,
  OPCODE_S32C1I,
  OPCODE_RSR_SCOMPARE1,
  OPCODE_WSR_SCOMPARE1,
  OPCODE_XSR_SCOMPARE1,
  OPCODE_RSR_ATOMCTL,
  OPCODE_WSR_ATOMCTL,
  OPCODE_XSR_ATOMCTL,
  OPCODE_QUOS,
  OPCODE_QUOU,
  OPCODE_REMS,
  OPCODE_REMU,
  OPCODE_RER,
  OPCODE_WER,
  OPCODE_BEQZ_W18,
  OPCODE_BGEZ_W18,
  OPCODE_BLTZ_W18,
  OPCODE_BNEZ_W18,
  OPCODE_BEQI_W18,
  OPCODE_BGEI_W18,
  OPCODE_BLTI_W18,
  OPCODE_BNEI_W18,
  OPCODE_BGEUI_W18,
  OPCODE_BLTUI_W18,
  OPCODE_BBCI_W18,
  OPCODE_BBSI_W18,
  OPCODE_BALL_W18,
  OPCODE_BANY_W18,
  OPCODE_BBC_W18,
  OPCODE_BBS_W18,
  OPCODE_BEQ_W18,
  OPCODE_BGEU_W18,
  OPCODE_BGE_W18,
  OPCODE_BLTU_W18,
  OPCODE_BLT_W18,
  OPCODE_BNALL_W18,
  OPCODE_BNE_W18,
  OPCODE_BNONE_W18,
  OPCODE_RUR_AE_OVF_SAR,
  OPCODE_WUR_AE_OVF_SAR,
  OPCODE_RUR_AE_BITHEAD,
  OPCODE_WUR_AE_BITHEAD,
  OPCODE_RUR_AE_TS_FTS_BU_BP,
  OPCODE_WUR_AE_TS_FTS_BU_BP,
  OPCODE_RUR_AE_CW_SD_NO,
  OPCODE_WUR_AE_CW_SD_NO,
  OPCODE_RUR_AE_CBEGIN0,
  OPCODE_WUR_AE_CBEGIN0,
  OPCODE_RUR_AE_CEND0,
  OPCODE_WUR_AE_CEND0,
  OPCODE_RUR_FCR,
  OPCODE_WUR_FCR,
  OPCODE_RUR_FSR,
  OPCODE_WUR_FSR,
  OPCODE_RUR_AE_OVERFLOW,
  OPCODE_WUR_AE_OVERFLOW,
  OPCODE_RUR_AE_SAR,
  OPCODE_WUR_AE_SAR,
  OPCODE_RUR_AE_BITPTR,
  OPCODE_WUR_AE_BITPTR,
  OPCODE_RUR_AE_BITSUSED,
  OPCODE_WUR_AE_BITSUSED,
  OPCODE_RUR_AE_TABLESIZE,
  OPCODE_WUR_AE_TABLESIZE,
  OPCODE_RUR_AE_FIRST_TS,
  OPCODE_WUR_AE_FIRST_TS,
  OPCODE_RUR_AE_NEXTOFFSET,
  OPCODE_WUR_AE_NEXTOFFSET,
  OPCODE_RUR_AE_SEARCHDONE,
  OPCODE_WUR_AE_SEARCHDONE,
  OPCODE_RUR_AE_CWRAP,
  OPCODE_WUR_AE_CWRAP,
  OPCODE_AE_L16M_XC,
  OPCODE_AE_L16M_I,
  OPCODE_AE_L16M_IU,
  OPCODE_AE_L16M_X,
  OPCODE_AE_L16M_XU,
  OPCODE_AE_L16_XC,
  OPCODE_AE_L16_I,
  OPCODE_AE_L16_IP,
  OPCODE_AE_L16_X,
  OPCODE_AE_L16_XP,
  OPCODE_AE_L32F24_XC,
  OPCODE_AE_L32F24_I,
  OPCODE_AE_L32F24_IP,
  OPCODE_AE_L32F24_X,
  OPCODE_AE_L32F24_XP,
  OPCODE_AE_L32_XC,
  OPCODE_AE_L32_I,
  OPCODE_AE_L32_IP,
  OPCODE_AE_L32_X,
  OPCODE_AE_L32_XP,
  OPCODE_AE_L32M_XC,
  OPCODE_AE_L32M_I,
  OPCODE_AE_L32M_IU,
  OPCODE_AE_L32M_X,
  OPCODE_AE_L32M_XU,
  OPCODE_AE_L16X2M_XC,
  OPCODE_AE_L16X2M_I,
  OPCODE_AE_L16X2M_IU,
  OPCODE_AE_L16X2M_X,
  OPCODE_AE_L16X2M_XU,
  OPCODE_AE_L32X2F24_XC,
  OPCODE_AE_L32X2F24_I,
  OPCODE_AE_L32X2F24_IP,
  OPCODE_AE_L32X2F24_RIP,
  OPCODE_AE_L32X2F24_RIC,
  OPCODE_AE_L32X2F24_X,
  OPCODE_AE_L32X2F24_XP,
  OPCODE_AE_L32X2_XC,
  OPCODE_AE_L32X2_I,
  OPCODE_AE_L32X2_IP,
  OPCODE_AE_L32X2_RIP,
  OPCODE_AE_L32X2_RIC,
  OPCODE_AE_L32X2_X,
  OPCODE_AE_L32X2_XP,
  OPCODE_AE_L16X4_XC,
  OPCODE_AE_L16X4_I,
  OPCODE_AE_L16X4_IP,
  OPCODE_AE_L16X4_RIP,
  OPCODE_AE_L16X4_RIC,
  OPCODE_AE_L16X4_X,
  OPCODE_AE_L16X4_XP,
  OPCODE_AE_L64_XC,
  OPCODE_AE_L64_I,
  OPCODE_AE_L64_IP,
  OPCODE_AE_L64_X,
  OPCODE_AE_L64_XP,
  OPCODE_AE_S16X2M_XC,
  OPCODE_AE_S16X2M_I,
  OPCODE_AE_S16X2M_IU,
  OPCODE_AE_S16X2M_X,
  OPCODE_AE_S16X2M_XU,
  OPCODE_AE_S32X2F24_XC,
  OPCODE_AE_S32X2F24_I,
  OPCODE_AE_S32X2F24_IP,
  OPCODE_AE_S32X2F24_RIP,
  OPCODE_AE_S32X2F24_RIC,
  OPCODE_AE_S32X2F24_X,
  OPCODE_AE_S32X2F24_XP,
  OPCODE_AE_S32X2_XC,
  OPCODE_AE_S32X2_I,
  OPCODE_AE_S32X2_IP,
  OPCODE_AE_S32X2_RIP,
  OPCODE_AE_S32X2_RIC,
  OPCODE_AE_S32X2_X,
  OPCODE_AE_S32X2_XP,
  OPCODE_AE_S16X4_XC,
  OPCODE_AE_S16X4_I,
  OPCODE_AE_S16X4_IP,
  OPCODE_AE_S16X4_RIP,
  OPCODE_AE_S16X4_RIC,
  OPCODE_AE_S16X4_X,
  OPCODE_AE_S16X4_XP,
  OPCODE_AE_S16M_L_XC,
  OPCODE_AE_S16M_L_I,
  OPCODE_AE_S16M_L_IU,
  OPCODE_AE_S16M_L_X,
  OPCODE_AE_S16M_L_XU,
  OPCODE_AE_S32F24_L_XC,
  OPCODE_AE_S32F24_L_I,
  OPCODE_AE_S32F24_L_IP,
  OPCODE_AE_S32F24_L_X,
  OPCODE_AE_S32F24_L_XP,
  OPCODE_AE_S32_L_XC,
  OPCODE_AE_S32_L_I,
  OPCODE_AE_S32_L_IP,
  OPCODE_AE_S32_L_X,
  OPCODE_AE_S32_L_XP,
  OPCODE_AE_S16_0_XC,
  OPCODE_AE_S16_0_I,
  OPCODE_AE_S16_0_IP,
  OPCODE_AE_S16_0_X,
  OPCODE_AE_S16_0_XP,
  OPCODE_AE_S64_XC,
  OPCODE_AE_S64_I,
  OPCODE_AE_S64_IP,
  OPCODE_AE_S64_X,
  OPCODE_AE_S64_XP,
  OPCODE_AE_S32M_XC,
  OPCODE_AE_S32M_I,
  OPCODE_AE_S32M_IU,
  OPCODE_AE_S32M_X,
  OPCODE_AE_S32M_XU,
  OPCODE_AE_ZALIGN64,
  OPCODE_AE_LALIGN64_I,
  OPCODE_AE_SALIGN64_I,
  OPCODE_AE_MOVALIGN,
  OPCODE_AE_LA64_PP,
  OPCODE_AE_LA24POS_PC,
  OPCODE_AE_LA24X2POS_PC,
  OPCODE_AE_LA32X2POS_PC,
  OPCODE_AE_LA16X4POS_PC,
  OPCODE_AE_LA24NEG_PC,
  OPCODE_AE_LA24X2NEG_PC,
  OPCODE_AE_LA32X2NEG_PC,
  OPCODE_AE_LA16X4NEG_PC,
  OPCODE_AE_SA64POS_FP,
  OPCODE_AE_SA64NEG_FP,
  OPCODE_AE_LA32X2_IC,
  OPCODE_AE_LA32X2_IP,
  OPCODE_AE_LA32X2_RIP,
  OPCODE_AE_LA32X2_RIC,
  OPCODE_AE_LA16X4_IC,
  OPCODE_AE_LA16X4_IP,
  OPCODE_AE_LA16X4_RIP,
  OPCODE_AE_LA16X4_RIC,
  OPCODE_AE_LA32X2F24_IC,
  OPCODE_AE_LA32X2F24_IP,
  OPCODE_AE_LA32X2F24_RIP,
  OPCODE_AE_LA32X2F24_RIC,
  OPCODE_AE_LA24_IC,
  OPCODE_AE_LA24_IP,
  OPCODE_AE_LA24_RIP,
  OPCODE_AE_LA24_RIC,
  OPCODE_AE_LA24X2_IC,
  OPCODE_AE_LA24X2_IP,
  OPCODE_AE_LA24X2_RIP,
  OPCODE_AE_LA24X2_RIC,
  OPCODE_AE_SA32X2_IC,
  OPCODE_AE_SA32X2_IP,
  OPCODE_AE_SA32X2_RIP,
  OPCODE_AE_SA32X2_RIC,
  OPCODE_AE_SA16X4_IC,
  OPCODE_AE_SA16X4_IP,
  OPCODE_AE_SA16X4_RIP,
  OPCODE_AE_SA16X4_RIC,
  OPCODE_AE_SA32X2F24_IC,
  OPCODE_AE_SA32X2F24_IP,
  OPCODE_AE_SA32X2F24_RIP,
  OPCODE_AE_SA32X2F24_RIC,
  OPCODE_AE_SA24_L_IC,
  OPCODE_AE_SA24_L_IP,
  OPCODE_AE_SA24_L_RIP,
  OPCODE_AE_SA24_L_RIC,
  OPCODE_AE_SA24X2_IC,
  OPCODE_AE_SA24X2_IP,
  OPCODE_AE_SA24X2_RIP,
  OPCODE_AE_SA24X2_RIC,
  OPCODE_AE_S32RA64S_I,
  OPCODE_AE_S32RA64S_IP,
  OPCODE_AE_S32RA64S_X,
  OPCODE_AE_S32RA64S_XP,
  OPCODE_AE_S32RA64S_XC,
  OPCODE_AE_S24RA64S_I,
  OPCODE_AE_S24RA64S_IP,
  OPCODE_AE_S24RA64S_X,
  OPCODE_AE_S24RA64S_XP,
  OPCODE_AE_S24RA64S_XC,
  OPCODE_AE_S32X2RA64S_IP,
  OPCODE_AE_S24X2RA64S_IP,
  OPCODE_AE_ADDBRBA32,
  OPCODE_AE_SEL16I,
  OPCODE_AE_SEL16I_N,
  OPCODE_AE_SHORTSWAP,
  OPCODE_AE_MOVT16X4,
  OPCODE_AE_MOVF16X4,
  OPCODE_AE_MOVT32X2,
  OPCODE_AE_MOVF32X2,
  OPCODE_AE_MOVDA32X2,
  OPCODE_AE_MOVDA32,
  OPCODE_AE_MOVDA16X2,
  OPCODE_AE_MOVDA16,
  OPCODE_AE_MOVI,
  OPCODE_AE_TRUNCP24A32X2,
  OPCODE_AE_SAT16X4,
  OPCODE_AE_CVT32X2F16_32,
  OPCODE_AE_CVT32X2F16_10,
  OPCODE_AE_SEXT32X2D16_32,
  OPCODE_AE_SEXT32X2D16_10,
  OPCODE_AE_CVTA32F24S_L,
  OPCODE_AE_CVTA32F24S_H,
  OPCODE_AE_CVTP24A16X2_LL,
  OPCODE_AE_CVTP24A16X2_LH,
  OPCODE_AE_CVTP24A16X2_HL,
  OPCODE_AE_CVTP24A16X2_HH,
  OPCODE_AE_TRUNCP24Q48X2,
  OPCODE_AE_TRUNCA32X2F64S,
  OPCODE_AE_TRUNCI32X2F64S,
  OPCODE_AE_TRUNCA32F64S_L,
  OPCODE_AE_TRUNCI32F64S_L,
  OPCODE_AE_TRUNCP16,
  OPCODE_AE_ROUND32X2F64SSYM,
  OPCODE_AE_ROUND32X2F64SASYM,
  OPCODE_AE_ROUND32X2F48SSYM,
  OPCODE_AE_ROUND32X2F48SASYM,
  OPCODE_AE_ROUND16X4F32SSYM,
  OPCODE_AE_ROUND16X4F32SASYM,
  OPCODE_AE_ROUND24X2F48SSYM,
  OPCODE_AE_ROUND24X2F48SASYM,
  OPCODE_AE_ROUNDSP16Q48X2SYM,
  OPCODE_AE_ROUNDSP16Q48X2ASYM,
  OPCODE_AE_MINABS32S,
  OPCODE_AE_MAXABS32S,
  OPCODE_AE_ROUNDSP16F24SYM,
  OPCODE_AE_ROUNDSP16F24ASYM,
  OPCODE_AE_MOV,
  OPCODE_AE_MOVT64,
  OPCODE_AE_MOVF64,
  OPCODE_AE_CVTQ56A32S,
  OPCODE_AE_CVT48A32,
  OPCODE_AE_CVT64A32,
  OPCODE_AE_CVTQ56P32S_L,
  OPCODE_AE_CVTQ56P32S_H,
  OPCODE_AE_CVT64F32_H,
  OPCODE_AE_SAT48S,
  OPCODE_AE_SATQ56S,
  OPCODE_AE_SAT24S,
  OPCODE_AE_TRUNCQ32,
  OPCODE_AE_MINABS64S,
  OPCODE_AE_MAXABS64S,
  OPCODE_AE_ROUNDSQ32F48SYM,
  OPCODE_AE_ROUNDSQ32F48ASYM,
  OPCODE_AE_TRUNCA32Q48,
  OPCODE_AE_MOVAD32_L,
  OPCODE_AE_MOVAD32_H,
  OPCODE_AE_MOVAD16_3,
  OPCODE_AE_MOVAD16_2,
  OPCODE_AE_MOVAD16_1,
  OPCODE_AE_MOVAD16_0,
  OPCODE_AE_SRA64_32,
  OPCODE_AE_PKSR32,
  OPCODE_AE_PKSR24,
  OPCODE_AE_TRUNCA16P24S_L,
  OPCODE_AE_TRUNCA16P24S_H,
  OPCODE_AE_ADD32,
  OPCODE_AE_SUB32,
  OPCODE_AE_ADDSUB32,
  OPCODE_AE_SUBADD32,
  OPCODE_AE_ADD16,
  OPCODE_AE_SUB16,
  OPCODE_AE_ADD32_HL_LH,
  OPCODE_AE_NEG32,
  OPCODE_AE_ABS32,
  OPCODE_AE_ADD24S,
  OPCODE_AE_SUB24S,
  OPCODE_AE_ADD32S,
  OPCODE_AE_SUB32S,
  OPCODE_AE_ADDSUB32S,
  OPCODE_AE_SUBADD32S,
  OPCODE_AE_ADD16S,
  OPCODE_AE_SUB16S,
  OPCODE_AE_NEG24S,
  OPCODE_AE_ABS24S,
  OPCODE_AE_NEG32S,
  OPCODE_AE_ABS32S,
  OPCODE_AE_NEG16S,
  OPCODE_AE_ABS16S,
  OPCODE_AE_LT16,
  OPCODE_AE_LE16,
  OPCODE_AE_EQ16,
  OPCODE_AE_LT32,
  OPCODE_AE_LE32,
  OPCODE_AE_EQ32,
  OPCODE_AE_MIN32,
  OPCODE_AE_MAX32,
  OPCODE_AE_ADD64,
  OPCODE_AE_SUB64,
  OPCODE_AE_NEG64,
  OPCODE_AE_ABS64,
  OPCODE_AE_ADDSQ56S,
  OPCODE_AE_SUBSQ56S,
  OPCODE_AE_ADD64S,
  OPCODE_AE_SUB64S,
  OPCODE_AE_NEGSQ56S,
  OPCODE_AE_ABSSQ56S,
  OPCODE_AE_NEG64S,
  OPCODE_AE_ABS64S,
  OPCODE_AE_AND,
  OPCODE_AE_NAND,
  OPCODE_AE_OR,
  OPCODE_AE_XOR,
  OPCODE_AE_SLAI24,
  OPCODE_AE_SRLI24,
  OPCODE_AE_SRAI24,
  OPCODE_AE_SLAS24,
  OPCODE_AE_SRLS24,
  OPCODE_AE_SRAS24,
  OPCODE_AE_SRAI16,
  OPCODE_AE_SRAI16R,
  OPCODE_AE_SLAI32,
  OPCODE_AE_SRLI32,
  OPCODE_AE_SRAI32,
  OPCODE_AE_SRAI32R,
  OPCODE_AE_SLAS32,
  OPCODE_AE_SRLS32,
  OPCODE_AE_SRAS32,
  OPCODE_AE_SLAA32,
  OPCODE_AE_SRLA32,
  OPCODE_AE_SRAA32,
  OPCODE_AE_SLAI16S,
  OPCODE_AE_SLAA16S,
  OPCODE_AE_SRAA16S,
  OPCODE_AE_SRAA16RS,
  OPCODE_AE_SLAI24S,
  OPCODE_AE_SLAS24S,
  OPCODE_AE_SLAI32S,
  OPCODE_AE_SLAS32S,
  OPCODE_AE_SLAA32S,
  OPCODE_AE_SRAA32S,
  OPCODE_AE_SRAA32RS,
  OPCODE_AE_SLASQ56,
  OPCODE_AE_SRLSQ56,
  OPCODE_AE_SRASQ56,
  OPCODE_AE_SLAAQ56,
  OPCODE_AE_SRLAQ56,
  OPCODE_AE_SRAAQ56,
  OPCODE_AE_SLAI64,
  OPCODE_AE_SRLI64,
  OPCODE_AE_SRAI64,
  OPCODE_AE_SLAS64,
  OPCODE_AE_SRLS64,
  OPCODE_AE_SRAS64,
  OPCODE_AE_SLAA64,
  OPCODE_AE_SRLA64,
  OPCODE_AE_SRAA64,
  OPCODE_AE_SLAISQ56S,
  OPCODE_AE_SLASSQ56S,
  OPCODE_AE_SLAASQ56S,
  OPCODE_AE_SLAI64S,
  OPCODE_AE_SLAS64S,
  OPCODE_AE_SLAA64S,
  OPCODE_AE_LT64,
  OPCODE_AE_LE64,
  OPCODE_AE_EQ64,
  OPCODE_AE_MAX64,
  OPCODE_AE_MIN64,
  OPCODE_AE_NSA64,
  OPCODE_AE_NSAZ16_0,
  OPCODE_AE_NSAZ32_L,
  OPCODE_AE_MULS32F48P16S_LL,
  OPCODE_AE_MULF32S_LL,
  OPCODE_AE_MUL32_LL,
  OPCODE_AE_MULS32F48P16S_LL_S2,
  OPCODE_AE_MULF32R_LL,
  OPCODE_AE_MULS32F48P16S_LH,
  OPCODE_AE_MULF32S_LH,
  OPCODE_AE_MUL32_LH,
  OPCODE_AE_MULS32F48P16S_LH_S2,
  OPCODE_AE_MULF32R_LH,
  OPCODE_AE_MULS32F48P16S_HH,
  OPCODE_AE_MULF32S_HH,
  OPCODE_AE_MUL32_HH,
  OPCODE_AE_MULS32F48P16S_HH_S2,
  OPCODE_AE_MULF32R_HH,
  OPCODE_AE_MULF32R_LL_S2,
  OPCODE_AE_MULAS32F48P16S_LL,
  OPCODE_AE_MULAF32S_LL,
  OPCODE_AE_MULA32_LL,
  OPCODE_AE_MULAS32F48P16S_LL_S2,
  OPCODE_AE_MULAF32R_LL,
  OPCODE_AE_MULAS32F48P16S_LH,
  OPCODE_AE_MULAF32S_LH,
  OPCODE_AE_MULA32_LH,
  OPCODE_AE_MULAS32F48P16S_LH_S2,
  OPCODE_AE_MULAF32R_LH,
  OPCODE_AE_MULAS32F48P16S_HH,
  OPCODE_AE_MULAF32S_HH,
  OPCODE_AE_MULA32_HH,
  OPCODE_AE_MULAS32F48P16S_HH_S2,
  OPCODE_AE_MULAF32R_HH,
  OPCODE_AE_MULAF32R_LL_S2,
  OPCODE_AE_MULSS32F48P16S_LL,
  OPCODE_AE_MULSF32S_LL,
  OPCODE_AE_MULS32_LL,
  OPCODE_AE_MULSS32F48P16S_LL_S2,
  OPCODE_AE_MULSF32R_LL,
  OPCODE_AE_MULSS32F48P16S_LH,
  OPCODE_AE_MULSF32S_LH,
  OPCODE_AE_MULS32_LH,
  OPCODE_AE_MULSS32F48P16S_LH_S2,
  OPCODE_AE_MULSF32R_LH,
  OPCODE_AE_MULSS32F48P16S_HH,
  OPCODE_AE_MULSF32S_HH,
  OPCODE_AE_MULS32_HH,
  OPCODE_AE_MULSS32F48P16S_HH_S2,
  OPCODE_AE_MULSF32R_HH,
  OPCODE_AE_MULSF32R_LL_S2,
  OPCODE_AE_MULF32S_LL_S2,
  OPCODE_AE_MULAF32S_LL_S2,
  OPCODE_AE_MUL32_LL_S2,
  OPCODE_AE_MULA32_LL_S2,
  OPCODE_AE_MUL32U_LL,
  OPCODE_AE_MULA32U_LL,
  OPCODE_AE_MULS32U_LL,
  OPCODE_AE_MULF16SS_33,
  OPCODE_AE_MULF16SS_22,
  OPCODE_AE_MULF16SS_32,
  OPCODE_AE_MULF16SS_21,
  OPCODE_AE_MULF16SS_31,
  OPCODE_AE_MULF16SS_30,
  OPCODE_AE_MULF16SS_10,
  OPCODE_AE_MULF16SS_20,
  OPCODE_AE_MULF16SS_11,
  OPCODE_AE_MULF16SS_00,
  OPCODE_AE_MULF16SS_00_S2,
  OPCODE_AE_MULSF16SS_33,
  OPCODE_AE_MULSF16SS_22,
  OPCODE_AE_MULSF16SS_32,
  OPCODE_AE_MULSF16SS_21,
  OPCODE_AE_MULSF16SS_31,
  OPCODE_AE_MULSF16SS_30,
  OPCODE_AE_MULSF16SS_10,
  OPCODE_AE_MULSF16SS_20,
  OPCODE_AE_MULSF16SS_11,
  OPCODE_AE_MULSF16SS_00,
  OPCODE_AE_MULSF16SS_00_S2,
  OPCODE_AE_MULAF16SS_33,
  OPCODE_AE_MULAF16SS_22,
  OPCODE_AE_MULAF16SS_32,
  OPCODE_AE_MULAF16SS_21,
  OPCODE_AE_MULAF16SS_31,
  OPCODE_AE_MULAF16SS_30,
  OPCODE_AE_MULAF16SS_10,
  OPCODE_AE_MULAF16SS_20,
  OPCODE_AE_MULAF16SS_11,
  OPCODE_AE_MULAF16SS_00,
  OPCODE_AE_MULAF16SS_00_S2,
  OPCODE_AE_MULAAFD16SS_33_22,
  OPCODE_AE_MULAAFD16SS_33_22_S2,
  OPCODE_AE_MULAAFD16SS_13_02,
  OPCODE_AE_MULAAFD16SS_13_02_S2,
  OPCODE_AE_MULAAFD16SS_11_00,
  OPCODE_AE_MULAAFD16SS_11_00_S2,
  OPCODE_AE_MULSSFD16SS_33_22,
  OPCODE_AE_MULSSFD16SS_33_22_S2,
  OPCODE_AE_MULSSFD16SS_13_02,
  OPCODE_AE_MULSSFD16SS_13_02_S2,
  OPCODE_AE_MULSSFD16SS_11_00,
  OPCODE_AE_MULSSFD16SS_11_00_S2,
  OPCODE_AE_MULZAAFD16SS_33_22,
  OPCODE_AE_MULZAAFD16SS_33_22_S2,
  OPCODE_AE_MULZAAFD16SS_13_02,
  OPCODE_AE_MULZAAFD16SS_13_02_S2,
  OPCODE_AE_MULZAAFD16SS_11_00,
  OPCODE_AE_MULZAAFD16SS_11_00_S2,
  OPCODE_AE_MULZSSFD16SS_33_22,
  OPCODE_AE_MULZSSFD16SS_33_22_S2,
  OPCODE_AE_MULZSSFD16SS_13_02,
  OPCODE_AE_MULZSSFD16SS_13_02_S2,
  OPCODE_AE_MULZSSFD16SS_11_00,
  OPCODE_AE_MULZSSFD16SS_11_00_S2,
  OPCODE_AE_MULF48Q32SP16S_L,
  OPCODE_AE_MULF48Q32SP16S_L_S2,
  OPCODE_AE_MULF48Q32SP16U_L,
  OPCODE_AE_MULF48Q32SP16U_L_S2,
  OPCODE_AE_MULQ32SP16S_L,
  OPCODE_AE_MULQ32SP16S_L_S2,
  OPCODE_AE_MULQ32SP16U_L,
  OPCODE_AE_MULQ32SP16U_L_S2,
  OPCODE_AE_MULAF48Q32SP16S_L,
  OPCODE_AE_MULAF48Q32SP16S_L_S2,
  OPCODE_AE_MULAF48Q32SP16U_L,
  OPCODE_AE_MULAF48Q32SP16U_L_S2,
  OPCODE_AE_MULAQ32SP16S_L,
  OPCODE_AE_MULAQ32SP16S_L_S2,
  OPCODE_AE_MULAQ32SP16U_L,
  OPCODE_AE_MULAQ32SP16U_L_S2,
  OPCODE_AE_MULSF48Q32SP16S_L,
  OPCODE_AE_MULSF48Q32SP16S_L_S2,
  OPCODE_AE_MULSF48Q32SP16U_L,
  OPCODE_AE_MULSF48Q32SP16U_L_S2,
  OPCODE_AE_MULSQ32SP16S_L,
  OPCODE_AE_MULSQ32SP16S_L_S2,
  OPCODE_AE_MULSQ32SP16U_L,
  OPCODE_AE_MULSQ32SP16U_L_S2,
  OPCODE_AE_MULFP24X2RA,
  OPCODE_AE_MULFP24X2R,
  OPCODE_AE_MULP24X2,
  OPCODE_AE_MULFP24X2RA_S2,
  OPCODE_AE_MULFP24X2R_S2,
  OPCODE_AE_MULP24X2_S2,
  OPCODE_AE_MULAFP24X2RA,
  OPCODE_AE_MULAFP24X2R,
  OPCODE_AE_MULAP24X2,
  OPCODE_AE_MULAFP24X2RA_S2,
  OPCODE_AE_MULAFP24X2R_S2,
  OPCODE_AE_MULAP24X2_S2,
  OPCODE_AE_MULSFP24X2RA,
  OPCODE_AE_MULSFP24X2R,
  OPCODE_AE_MULSP24X2,
  OPCODE_AE_MULSFP24X2RA_S2,
  OPCODE_AE_MULSFP24X2R_S2,
  OPCODE_AE_MULSP24X2_S2,
  OPCODE_AE_MULZAAFD24_HH_LL,
  OPCODE_AE_MULZAAD24_HH_LL,
  OPCODE_AE_MULZAAFD24_HH_LL_S2,
  OPCODE_AE_MULZAAD24_HH_LL_S2,
  OPCODE_AE_MULZAAFD24_HL_LH,
  OPCODE_AE_MULZAAD24_HL_LH,
  OPCODE_AE_MULZAAFD24_HL_LH_S2,
  OPCODE_AE_MULZAAD24_HL_LH_S2,
  OPCODE_AE_MULZASFD24_HH_LL,
  OPCODE_AE_MULZASD24_HH_LL,
  OPCODE_AE_MULZASFD24_HH_LL_S2,
  OPCODE_AE_MULZASD24_HH_LL_S2,
  OPCODE_AE_MULZASFD24_HL_LH,
  OPCODE_AE_MULZASD24_HL_LH,
  OPCODE_AE_MULZASFD24_HL_LH_S2,
  OPCODE_AE_MULZASD24_HL_LH_S2,
  OPCODE_AE_MULZSAFD24_HH_LL,
  OPCODE_AE_MULZSAD24_HH_LL,
  OPCODE_AE_MULZSAFD24_HH_LL_S2,
  OPCODE_AE_MULZSAD24_HH_LL_S2,
  OPCODE_AE_MULZSSFD24_HH_LL,
  OPCODE_AE_MULZSSD24_HH_LL,
  OPCODE_AE_MULZSSFD24_HH_LL_S2,
  OPCODE_AE_MULZSSD24_HH_LL_S2,
  OPCODE_AE_MULZSSFD24_HL_LH,
  OPCODE_AE_MULZSSD24_HL_LH,
  OPCODE_AE_MULZSSFD24_HL_LH_S2,
  OPCODE_AE_MULZSSD24_HL_LH_S2,
  OPCODE_AE_MULAAFD24_HH_LL,
  OPCODE_AE_MULAAD24_HH_LL,
  OPCODE_AE_MULAAFD24_HH_LL_S2,
  OPCODE_AE_MULAAD24_HH_LL_S2,
  OPCODE_AE_MULAAFD24_HL_LH,
  OPCODE_AE_MULAAD24_HL_LH,
  OPCODE_AE_MULAAFD24_HL_LH_S2,
  OPCODE_AE_MULAAD24_HL_LH_S2,
  OPCODE_AE_MULASFD24_HH_LL,
  OPCODE_AE_MULASD24_HH_LL,
  OPCODE_AE_MULASFD24_HH_LL_S2,
  OPCODE_AE_MULASD24_HH_LL_S2,
  OPCODE_AE_MULASFD24_HL_LH,
  OPCODE_AE_MULASD24_HL_LH,
  OPCODE_AE_MULASFD24_HL_LH_S2,
  OPCODE_AE_MULASD24_HL_LH_S2,
  OPCODE_AE_MULSAFD24_HH_LL,
  OPCODE_AE_MULSAD24_HH_LL,
  OPCODE_AE_MULSAFD24_HH_LL_S2,
  OPCODE_AE_MULSAD24_HH_LL_S2,
  OPCODE_AE_MULSSFD24_HH_LL,
  OPCODE_AE_MULSSD24_HH_LL,
  OPCODE_AE_MULSSFD24_HH_LL_S2,
  OPCODE_AE_MULSSD24_HH_LL_S2,
  OPCODE_AE_MULSSFD24_HL_LH,
  OPCODE_AE_MULSSD24_HL_LH,
  OPCODE_AE_MULSSFD24_HL_LH_S2,
  OPCODE_AE_MULSSD24_HL_LH_S2,
  OPCODE_AE_MULSRFQ32SP24S_H,
  OPCODE_AE_MULSRFQ32SP24S_L,
  OPCODE_AE_MULSRFQ32SP24S_H_S2,
  OPCODE_AE_MULSRFQ32SP24S_L_S2,
  OPCODE_AE_MULARFQ32SP24S_H,
  OPCODE_AE_MULARFQ32SP24S_L,
  OPCODE_AE_MULARFQ32SP24S_H_S2,
  OPCODE_AE_MULARFQ32SP24S_L_S2,
  OPCODE_AE_MULRFQ32SP24S_H,
  OPCODE_AE_MULRFQ32SP24S_L,
  OPCODE_AE_MULRFQ32SP24S_H_S2,
  OPCODE_AE_MULRFQ32SP24S_L_S2,
  OPCODE_AE_MULSFQ32SP24S_H,
  OPCODE_AE_MULSFQ32SP24S_L,
  OPCODE_AE_MULSFQ32SP24S_H_S2,
  OPCODE_AE_MULSFQ32SP24S_L_S2,
  OPCODE_AE_MULAFQ32SP24S_H,
  OPCODE_AE_MULAFQ32SP24S_L,
  OPCODE_AE_MULAFQ32SP24S_H_S2,
  OPCODE_AE_MULAFQ32SP24S_L_S2,
  OPCODE_AE_MULFQ32SP24S_H,
  OPCODE_AE_MULFQ32SP24S_L,
  OPCODE_AE_MULFQ32SP24S_H_S2,
  OPCODE_AE_MULFQ32SP24S_L_S2,
  OPCODE_AE_MULF32X16_L0,
  OPCODE_AE_MUL32X16_L0,
  OPCODE_AE_MULF32X16_L0_S2,
  OPCODE_AE_MUL32X16_L0_S2,
  OPCODE_AE_MULF32X16_L1,
  OPCODE_AE_MUL32X16_L1,
  OPCODE_AE_MULF32X16_L1_S2,
  OPCODE_AE_MUL32X16_L1_S2,
  OPCODE_AE_MULF32X16_L2,
  OPCODE_AE_MUL32X16_L2,
  OPCODE_AE_MULF32X16_L2_S2,
  OPCODE_AE_MUL32X16_L2_S2,
  OPCODE_AE_MULF32X16_L3,
  OPCODE_AE_MUL32X16_L3,
  OPCODE_AE_MULF32X16_L3_S2,
  OPCODE_AE_MUL32X16_L3_S2,
  OPCODE_AE_MULF32X16_H0,
  OPCODE_AE_MUL32X16_H0,
  OPCODE_AE_MULF32X16_H0_S2,
  OPCODE_AE_MUL32X16_H0_S2,
  OPCODE_AE_MULF32X16_H1,
  OPCODE_AE_MUL32X16_H1,
  OPCODE_AE_MULF32X16_H1_S2,
  OPCODE_AE_MUL32X16_H1_S2,
  OPCODE_AE_MULF32X16_H2,
  OPCODE_AE_MUL32X16_H2,
  OPCODE_AE_MULF32X16_H2_S2,
  OPCODE_AE_MUL32X16_H2_S2,
  OPCODE_AE_MULF32X16_H3,
  OPCODE_AE_MUL32X16_H3,
  OPCODE_AE_MULF32X16_H3_S2,
  OPCODE_AE_MUL32X16_H3_S2,
  OPCODE_AE_MULAF32X16_L0,
  OPCODE_AE_MULA32X16_L0,
  OPCODE_AE_MULAF32X16_L0_S2,
  OPCODE_AE_MULA32X16_L0_S2,
  OPCODE_AE_MULAF32X16_L1,
  OPCODE_AE_MULA32X16_L1,
  OPCODE_AE_MULAF32X16_L1_S2,
  OPCODE_AE_MULA32X16_L1_S2,
  OPCODE_AE_MULAF32X16_L2,
  OPCODE_AE_MULA32X16_L2,
  OPCODE_AE_MULAF32X16_L2_S2,
  OPCODE_AE_MULA32X16_L2_S2,
  OPCODE_AE_MULAF32X16_L3,
  OPCODE_AE_MULA32X16_L3,
  OPCODE_AE_MULAF32X16_L3_S2,
  OPCODE_AE_MULA32X16_L3_S2,
  OPCODE_AE_MULAF32X16_H0,
  OPCODE_AE_MULA32X16_H0,
  OPCODE_AE_MULAF32X16_H0_S2,
  OPCODE_AE_MULA32X16_H0_S2,
  OPCODE_AE_MULAF32X16_H1,
  OPCODE_AE_MULA32X16_H1,
  OPCODE_AE_MULAF32X16_H1_S2,
  OPCODE_AE_MULA32X16_H1_S2,
  OPCODE_AE_MULAF32X16_H2,
  OPCODE_AE_MULA32X16_H2,
  OPCODE_AE_MULAF32X16_H2_S2,
  OPCODE_AE_MULA32X16_H2_S2,
  OPCODE_AE_MULAF32X16_H3,
  OPCODE_AE_MULA32X16_H3,
  OPCODE_AE_MULAF32X16_H3_S2,
  OPCODE_AE_MULA32X16_H3_S2,
  OPCODE_AE_MULSF32X16_L0,
  OPCODE_AE_MULS32X16_L0,
  OPCODE_AE_MULSF32X16_L0_S2,
  OPCODE_AE_MULS32X16_L0_S2,
  OPCODE_AE_MULSF32X16_L1,
  OPCODE_AE_MULS32X16_L1,
  OPCODE_AE_MULSF32X16_L1_S2,
  OPCODE_AE_MULS32X16_L1_S2,
  OPCODE_AE_MULSF32X16_L2,
  OPCODE_AE_MULS32X16_L2,
  OPCODE_AE_MULSF32X16_L2_S2,
  OPCODE_AE_MULS32X16_L2_S2,
  OPCODE_AE_MULSF32X16_L3,
  OPCODE_AE_MULS32X16_L3,
  OPCODE_AE_MULSF32X16_L3_S2,
  OPCODE_AE_MULS32X16_L3_S2,
  OPCODE_AE_MULSF32X16_H0,
  OPCODE_AE_MULS32X16_H0,
  OPCODE_AE_MULSF32X16_H0_S2,
  OPCODE_AE_MULS32X16_H0_S2,
  OPCODE_AE_MULSF32X16_H1,
  OPCODE_AE_MULS32X16_H1,
  OPCODE_AE_MULSF32X16_H1_S2,
  OPCODE_AE_MULS32X16_H1_S2,
  OPCODE_AE_MULSF32X16_H2,
  OPCODE_AE_MULS32X16_H2,
  OPCODE_AE_MULSF32X16_H2_S2,
  OPCODE_AE_MULS32X16_H2_S2,
  OPCODE_AE_MULSF32X16_H3,
  OPCODE_AE_MULS32X16_H3,
  OPCODE_AE_MULSF32X16_H3_S2,
  OPCODE_AE_MULS32X16_H3_S2,
  OPCODE_AE_MULAAFD32X16_H3_L2,
  OPCODE_AE_MULAAD32X16_H3_L2,
  OPCODE_AE_MULAAFD32X16_H3_L2_S2,
  OPCODE_AE_MULAAD32X16_H3_L2_S2,
  OPCODE_AE_MULAAFD32X16_H1_L0,
  OPCODE_AE_MULAAD32X16_H1_L0,
  OPCODE_AE_MULAAFD32X16_H1_L0_S2,
  OPCODE_AE_MULAAD32X16_H1_L0_S2,
  OPCODE_AE_MULASFD32X16_H3_L2,
  OPCODE_AE_MULASD32X16_H3_L2,
  OPCODE_AE_MULASFD32X16_H3_L2_S2,
  OPCODE_AE_MULASD32X16_H3_L2_S2,
  OPCODE_AE_MULASFD32X16_H1_L0,
  OPCODE_AE_MULASD32X16_H1_L0,
  OPCODE_AE_MULASFD32X16_H1_L0_S2,
  OPCODE_AE_MULASD32X16_H1_L0_S2,
  OPCODE_AE_MULSAFD32X16_H3_L2,
  OPCODE_AE_MULSAD32X16_H3_L2,
  OPCODE_AE_MULSAFD32X16_H3_L2_S2,
  OPCODE_AE_MULSAD32X16_H3_L2_S2,
  OPCODE_AE_MULSAFD32X16_H1_L0,
  OPCODE_AE_MULSAD32X16_H1_L0,
  OPCODE_AE_MULSAFD32X16_H1_L0_S2,
  OPCODE_AE_MULSAD32X16_H1_L0_S2,
  OPCODE_AE_MULSSFD32X16_H3_L2,
  OPCODE_AE_MULSSD32X16_H3_L2,
  OPCODE_AE_MULSSFD32X16_H3_L2_S2,
  OPCODE_AE_MULSSD32X16_H3_L2_S2,
  OPCODE_AE_MULSSFD32X16_H1_L0,
  OPCODE_AE_MULSSD32X16_H1_L0,
  OPCODE_AE_MULSSFD32X16_H1_L0_S2,
  OPCODE_AE_MULSSD32X16_H1_L0_S2,
  OPCODE_AE_MULZAAFD32X16_H3_L2,
  OPCODE_AE_MULZAAD32X16_H3_L2,
  OPCODE_AE_MULZAAFD32X16_H3_L2_S2,
  OPCODE_AE_MULZAAD32X16_H3_L2_S2,
  OPCODE_AE_MULZAAFD32X16_H1_L0,
  OPCODE_AE_MULZAAD32X16_H1_L0,
  OPCODE_AE_MULZAAFD32X16_H1_L0_S2,
  OPCODE_AE_MULZAAD32X16_H1_L0_S2,
  OPCODE_AE_MULZASFD32X16_H3_L2,
  OPCODE_AE_MULZASD32X16_H3_L2,
  OPCODE_AE_MULZASFD32X16_H3_L2_S2,
  OPCODE_AE_MULZASD32X16_H3_L2_S2,
  OPCODE_AE_MULZASFD32X16_H1_L0,
  OPCODE_AE_MULZASD32X16_H1_L0,
  OPCODE_AE_MULZASFD32X16_H1_L0_S2,
  OPCODE_AE_MULZASD32X16_H1_L0_S2,
  OPCODE_AE_MULZSAFD32X16_H3_L2,
  OPCODE_AE_MULZSAD32X16_H3_L2,
  OPCODE_AE_MULZSAFD32X16_H3_L2_S2,
  OPCODE_AE_MULZSAD32X16_H3_L2_S2,
  OPCODE_AE_MULZSAFD32X16_H1_L0,
  OPCODE_AE_MULZSAD32X16_H1_L0,
  OPCODE_AE_MULZSAFD32X16_H1_L0_S2,
  OPCODE_AE_MULZSAD32X16_H1_L0_S2,
  OPCODE_AE_MULZSSFD32X16_H3_L2,
  OPCODE_AE_MULZSSD32X16_H3_L2,
  OPCODE_AE_MULZSSFD32X16_H3_L2_S2,
  OPCODE_AE_MULZSSD32X16_H3_L2_S2,
  OPCODE_AE_MULZSSFD32X16_H1_L0,
  OPCODE_AE_MULZSSD32X16_H1_L0,
  OPCODE_AE_MULZSSFD32X16_H1_L0_S2,
  OPCODE_AE_MULZSSD32X16_H1_L0_S2,
  OPCODE_AE_MULZAAFD32X16_H2_L3,
  OPCODE_AE_MULZAAFD32X16_H0_L1,
  OPCODE_AE_MULAAFD32X16_H2_L3,
  OPCODE_AE_MULAAFD32X16_H0_L1,
  OPCODE_AE_MULZAAD32X16_H2_L3,
  OPCODE_AE_MULZAAD32X16_H0_L1,
  OPCODE_AE_MULAAD32X16_H2_L3,
  OPCODE_AE_MULAAD32X16_H0_L1,
  OPCODE_AE_MULZAAFD32X16_H2_L3_S2,
  OPCODE_AE_MULZAAFD32X16_H0_L1_S2,
  OPCODE_AE_MULAAFD32X16_H2_L3_S2,
  OPCODE_AE_MULAAFD32X16_H0_L1_S2,
  OPCODE_AE_MULZAAD32X16_H2_L3_S2,
  OPCODE_AE_MULZAAD32X16_H0_L1_S2,
  OPCODE_AE_MULAAD32X16_H2_L3_S2,
  OPCODE_AE_MULAAD32X16_H0_L1_S2,
  OPCODE_AE_MULP32X16X2_H,
  OPCODE_AE_MULFP32X16X2RS_H,
  OPCODE_AE_MULFP32X16X2RAS_H,
  OPCODE_AE_MULFP32X16X2RS_H_S2,
  OPCODE_AE_MULFP32X16X2RAS_H_S2,
  OPCODE_AE_MULP32X16X2_L,
  OPCODE_AE_MULFP32X16X2RS_L,
  OPCODE_AE_MULFP32X16X2RAS_L,
  OPCODE_AE_MULFP32X16X2RS_L_S2,
  OPCODE_AE_MULFP32X16X2RAS_L_S2,
  OPCODE_AE_MULAP32X16X2_H,
  OPCODE_AE_MULAFP32X16X2RS_H,
  OPCODE_AE_MULAFP32X16X2RAS_H,
  OPCODE_AE_MULAFP32X16X2RS_H_S2,
  OPCODE_AE_MULAFP32X16X2RAS_H_S2,
  OPCODE_AE_MULAP32X16X2_L,
  OPCODE_AE_MULAFP32X16X2RS_L,
  OPCODE_AE_MULAFP32X16X2RAS_L,
  OPCODE_AE_MULAFP32X16X2RS_L_S2,
  OPCODE_AE_MULAFP32X16X2RAS_L_S2,
  OPCODE_AE_MULSP32X16X2_H,
  OPCODE_AE_MULSFP32X16X2RS_H,
  OPCODE_AE_MULSFP32X16X2RAS_H,
  OPCODE_AE_MULSFP32X16X2RS_H_S2,
  OPCODE_AE_MULSFP32X16X2RAS_H_S2,
  OPCODE_AE_MULSP32X16X2_L,
  OPCODE_AE_MULSFP32X16X2RS_L,
  OPCODE_AE_MULSFP32X16X2RAS_L,
  OPCODE_AE_MULSFP32X16X2RS_L_S2,
  OPCODE_AE_MULSFP32X16X2RAS_L_S2,
  OPCODE_AE_MULP32X2,
  OPCODE_AE_MULFP32X2RS,
  OPCODE_AE_MULFP32X2RAS,
  OPCODE_AE_MULAP32X2,
  OPCODE_AE_MULAFP32X2RS,
  OPCODE_AE_MULAFP32X2RAS,
  OPCODE_AE_MULSP32X2,
  OPCODE_AE_MULSFP32X2RS,
  OPCODE_AE_MULSFP32X2RAS,
  OPCODE_AE_MULFP16X4S,
  OPCODE_AE_MULFP16X4RAS,
  OPCODE_AE_MULC24,
  OPCODE_AE_MULFC24RA,
  OPCODE_AE_MULC32X16_L,
  OPCODE_AE_MULFC32X16RAS_L,
  OPCODE_AE_MULC32X16_H,
  OPCODE_AE_MULFC32X16RAS_H,
  OPCODE_AE_MULAC24,
  OPCODE_AE_MULAFC24RA,
  OPCODE_AE_MULAC32X16_L,
  OPCODE_AE_MULAFC32X16RAS_L,
  OPCODE_AE_MULAC32X16_H,
  OPCODE_AE_MULAFC32X16RAS_H,
  OPCODE_AE_MULF16X4SS,
  OPCODE_AE_MULAF16X4SS,
  OPCODE_AE_MULSF16X4SS,
  OPCODE_AE_MUL16X4,
  OPCODE_AE_MULA16X4,
  OPCODE_AE_MULS16X4,
  OPCODE_AE_MULFD24X2_FIR_H,
  OPCODE_AE_MULFD24X2_FIR_L,
  OPCODE_AE_MULFD32X16X2_FIR_HH,
  OPCODE_AE_MULFD32X16X2_FIR_HL,
  OPCODE_AE_MULFD32X16X2_FIR_LH,
  OPCODE_AE_MULFD32X16X2_FIR_LL,
  OPCODE_AE_MULAFD24X2_FIR_H,
  OPCODE_AE_MULAFD24X2_FIR_L,
  OPCODE_AE_MULAFD32X16X2_FIR_HH,
  OPCODE_AE_MULAFD32X16X2_FIR_HL,
  OPCODE_AE_MULAFD32X16X2_FIR_LH,
  OPCODE_AE_MULAFD32X16X2_FIR_LL,
  OPCODE_AE_DIV64D32_H,
  OPCODE_AE_DIV64D32_L,
  OPCODE_AE_SHA32,
  OPCODE_AE_VLDL32T,
  OPCODE_AE_VLDL16T,
  OPCODE_AE_VLDL16C,
  OPCODE_AE_VLDL16C_IP,
  OPCODE_AE_VLDL16C_IC,
  OPCODE_AE_VLDSHT,
  OPCODE_AE_LB,
  OPCODE_AE_LBI,
  OPCODE_AE_LBK,
  OPCODE_AE_LBKI,
  OPCODE_AE_LBS,
  OPCODE_AE_LBSI,
  OPCODE_AE_DB,
  OPCODE_AE_DBI,
  OPCODE_AE_DB_IC,
  OPCODE_AE_DBI_IC,
  OPCODE_AE_DB_IP,
  OPCODE_AE_DBI_IP,
  OPCODE_AE_VLEL32T,
  OPCODE_AE_VLEL16T,
  OPCODE_AE_SB,
  OPCODE_AE_SBI,
  OPCODE_AE_VLES16C,
  OPCODE_AE_SBF,
  OPCODE_AE_SB_IC,
  OPCODE_AE_SBI_IC,
  OPCODE_AE_VLES16C_IC,
  OPCODE_AE_SBF_IC,
  OPCODE_AE_SB_IP,
  OPCODE_AE_SBI_IP,
  OPCODE_AE_VLES16C_IP,
  OPCODE_AE_SBF_IP,
  OPCODE_AE_SEXT32,
  OPCODE_LSI,
  OPCODE_LSIP,
  OPCODE_LSX,
  OPCODE_LSXP,
  OPCODE_SSI,
  OPCODE_SSIP,
  OPCODE_SSX,
  OPCODE_SSXP,
  OPCODE_ABS_S,
  OPCODE_NEG_S,
  OPCODE_MOV_S,
  OPCODE_MOVEQZ_S,
  OPCODE_MOVNEZ_S,
  OPCODE_MOVLTZ_S,
  OPCODE_MOVGEZ_S,
  OPCODE_MOVF_S,
  OPCODE_MOVT_S,
  OPCODE_WFR,
  OPCODE_RFR,
  OPCODE_ROUND_S,
  OPCODE_CEIL_S,
  OPCODE_FLOOR_S,
  OPCODE_TRUNC_S,
  OPCODE_UTRUNC_S,
  OPCODE_FLOAT_S,
  OPCODE_UFLOAT_S,
  OPCODE_UN_S,
  OPCODE_ULT_S,
  OPCODE_ULE_S,
  OPCODE_UEQ_S,
  OPCODE_OLT_S,
  OPCODE_OLE_S,
  OPCODE_OEQ_S,
  OPCODE_ADD_S,
  OPCODE_SUB_S,
  OPCODE_MUL_S,
  OPCODE_MADD_S,
  OPCODE_MSUB_S,
  OPCODE_SQRT0_S,
  OPCODE_DIV0_S,
  OPCODE_RECIP0_S,
  OPCODE_RSQRT0_S,
  OPCODE_MADDN_S,
  OPCODE_DIVN_S,
  OPCODE_CONST_S,
  OPCODE_NEXP01_S,
  OPCODE_ADDEXP_S,
  OPCODE_ADDEXPM_S,
  OPCODE_MKDADJ_S,
  OPCODE_MKSADJ_S
};


/* Slot-specific opcode decode functions.  */

static int
Slot_inst_decode (const xtensa_insnbuf insn)
{
  if (Field_op0_Slot_inst_get (insn) == 0)
    {
      if (Field_op1_Slot_inst_get (insn) == 0)
	{
	  if (Field_op2_Slot_inst_get (insn) == 0)
	    {
	      if (Field_r_Slot_inst_get (insn) == 0)
		{
		  if (Field_m_Slot_inst_get (insn) == 0 &&
		      Field_s_Slot_inst_get (insn) == 0 &&
		      Field_n_Slot_inst_get (insn) == 0)
		    return OPCODE_ILL;
		  if (Field_m_Slot_inst_get (insn) == 2)
		    {
		      if (Field_n_Slot_inst_get (insn) == 0)
			return OPCODE_RET;
		      if (Field_n_Slot_inst_get (insn) == 1)
			return OPCODE_RETW;
		      if (Field_n_Slot_inst_get (insn) == 2)
			return OPCODE_JX;
		    }
		  if (Field_m_Slot_inst_get (insn) == 3)
		    {
		      if (Field_n_Slot_inst_get (insn) == 0)
			return OPCODE_CALLX0;
		      if (Field_n_Slot_inst_get (insn) == 1)
			return OPCODE_CALLX4;
		      if (Field_n_Slot_inst_get (insn) == 2)
			return OPCODE_CALLX8;
		      if (Field_n_Slot_inst_get (insn) == 3)
			return OPCODE_CALLX12;
		    }
		}
	      if (Field_r_Slot_inst_get (insn) == 1)
		return OPCODE_MOVSP;
	      if (Field_r_Slot_inst_get (insn) == 2)
		{
		  if (Field_s_Slot_inst_get (insn) == 0)
		    {
		      if (Field_t_Slot_inst_get (insn) == 0)
			return OPCODE_ISYNC;
		      if (Field_t_Slot_inst_get (insn) == 1)
			return OPCODE_RSYNC;
		      if (Field_t_Slot_inst_get (insn) == 2)
			return OPCODE_ESYNC;
		      if (Field_t_Slot_inst_get (insn) == 3)
			return OPCODE_DSYNC;
		      if (Field_t_Slot_inst_get (insn) == 8)
			return OPCODE_EXCW;
		      if (Field_t_Slot_inst_get (insn) == 12)
			return OPCODE_MEMW;
		      if (Field_t_Slot_inst_get (insn) == 13)
			return OPCODE_EXTW;
		      if (Field_t_Slot_inst_get (insn) == 15)
			return OPCODE_NOP;
		    }
		}
	      if (Field_r_Slot_inst_get (insn) == 3)
		{
		  if (Field_t_Slot_inst_get (insn) == 0)
		    {
		      if (Field_s_Slot_inst_get (insn) == 0)
			return OPCODE_RFE;
		      if (Field_s_Slot_inst_get (insn) == 2)
			return OPCODE_RFDE;
		      if (Field_s_Slot_inst_get (insn) == 4)
			return OPCODE_RFWO;
		      if (Field_s_Slot_inst_get (insn) == 5)
			return OPCODE_RFWU;
		    }
		  if (Field_t_Slot_inst_get (insn) == 1)
		    return OPCODE_RFI;
		  if (Field_t_Slot_inst_get (insn) == 2 &&
		      Field_s_Slot_inst_get (insn) == 0)
		    return OPCODE_RFME;
		}
	      if (Field_r_Slot_inst_get (insn) == 4)
		return OPCODE_BREAK;
	      if (Field_r_Slot_inst_get (insn) == 5)
		{
		  if (Field_s_Slot_inst_get (insn) == 0 &&
		      Field_t_Slot_inst_get (insn) == 0)
		    return OPCODE_SYSCALL;
		  if (Field_s_Slot_inst_get (insn) == 1 &&
		      Field_t_Slot_inst_get (insn) == 0)
		    return OPCODE_SIMCALL;
		}
	      if (Field_r_Slot_inst_get (insn) == 6)
		return OPCODE_RSIL;
	      if (Field_r_Slot_inst_get (insn) == 7 &&
		  Field_t_Slot_inst_get (insn) == 0)
		return OPCODE_WAITI;
	      if (Field_r_Slot_inst_get (insn) == 7)
		{
		  if (Field_t_Slot_inst_get (insn) == 14)
		    return OPCODE_LDDR32_P;
		  if (Field_t_Slot_inst_get (insn) == 15)
		    return OPCODE_SDDR32_P;
		}
	      if (Field_r_Slot_inst_get (insn) == 8)
		return OPCODE_ANY4;
	      if (Field_r_Slot_inst_get (insn) == 9)
		return OPCODE_ALL4;
	      if (Field_r_Slot_inst_get (insn) == 10)
		return OPCODE_ANY8;
	      if (Field_r_Slot_inst_get (insn) == 11)
		return OPCODE_ALL8;
	    }
	  if (Field_op2_Slot_inst_get (insn) == 1)
	    return OPCODE_AND;
	  if (Field_op2_Slot_inst_get (insn) == 2)
	    return OPCODE_OR;
	  if (Field_op2_Slot_inst_get (insn) == 3)
	    return OPCODE_XOR;
	  if (Field_op2_Slot_inst_get (insn) == 4)
	    {
	      if (Field_r_Slot_inst_get (insn) == 0 &&
		  Field_t_Slot_inst_get (insn) == 0)
		return OPCODE_SSR;
	      if (Field_r_Slot_inst_get (insn) == 1 &&
		  Field_t_Slot_inst_get (insn) == 0)
		return OPCODE_SSL;
	      if (Field_r_Slot_inst_get (insn) == 2 &&
		  Field_t_Slot_inst_get (insn) == 0)
		return OPCODE_SSA8L;
	      if (Field_r_Slot_inst_get (insn) == 3 &&
		  Field_t_Slot_inst_get (insn) == 0)
		return OPCODE_SSA8B;
	      if (Field_r_Slot_inst_get (insn) == 4 &&
		  Field_thi3_Slot_inst_get (insn) == 0)
		return OPCODE_SSAI;
	      if (Field_r_Slot_inst_get (insn) == 6)
		return OPCODE_RER;
	      if (Field_r_Slot_inst_get (insn) == 7)
		return OPCODE_WER;
	      if (Field_r_Slot_inst_get (insn) == 8 &&
		  Field_s_Slot_inst_get (insn) == 0)
		return OPCODE_ROTW;
	      if (Field_r_Slot_inst_get (insn) == 14)
		return OPCODE_NSA;
	      if (Field_r_Slot_inst_get (insn) == 15)
		return OPCODE_NSAU;
	    }
	  if (Field_op2_Slot_inst_get (insn) == 5)
	    {
	      if (Field_r_Slot_inst_get (insn) == 3)
		return OPCODE_RITLB0;
	      if (Field_r_Slot_inst_get (insn) == 4 &&
		  Field_t_Slot_inst_get (insn) == 0)
		return OPCODE_IITLB;
	      if (Field_r_Slot_inst_get (insn) == 5)
		return OPCODE_PITLB;
	      if (Field_r_Slot_inst_get (insn) == 6)
		return OPCODE_WITLB;
	      if (Field_r_Slot_inst_get (insn) == 7)
		return OPCODE_RITLB1;
	      if (Field_r_Slot_inst_get (insn) == 11)
		return OPCODE_RDTLB0;
	      if (Field_r_Slot_inst_get (insn) == 12 &&
		  Field_t_Slot_inst_get (insn) == 0)
		return OPCODE_IDTLB;
	      if (Field_r_Slot_inst_get (insn) == 13)
		return OPCODE_PDTLB;
	      if (Field_r_Slot_inst_get (insn) == 14)
		return OPCODE_WDTLB;
	      if (Field_r_Slot_inst_get (insn) == 15)
		return OPCODE_RDTLB1;
	    }
	  if (Field_op2_Slot_inst_get (insn) == 6)
	    {
	      if (Field_s_Slot_inst_get (insn) == 0)
		return OPCODE_NEG;
	      if (Field_s_Slot_inst_get (insn) == 1)
		return OPCODE_ABS;
	    }
	  if (Field_op2_Slot_inst_get (insn) == 8)
	    return OPCODE_ADD;
	  if (Field_op2_Slot_inst_get (insn) == 9)
	    return OPCODE_ADDX2;
	  if (Field_op2_Slot_inst_get (insn) == 10)
	    return OPCODE_ADDX4;
	  if (Field_op2_Slot_inst_get (insn) == 11)
	    return OPCODE_ADDX8;
	  if (Field_op2_Slot_inst_get (insn) == 12)
	    return OPCODE_SUB;
	  if (Field_op2_Slot_inst_get (insn) == 13)
	    return OPCODE_SUBX2;
	  if (Field_op2_Slot_inst_get (insn) == 14)
	    return OPCODE_SUBX4;
	  if (Field_op2_Slot_inst_get (insn) == 15)
	    return OPCODE_SUBX8;
	}
      if (Field_op1_Slot_inst_get (insn) == 1)
	{
	  if ((Field_op2_Slot_inst_get (insn) == 0 ||
	       Field_op2_Slot_inst_get (insn) == 1))
	    return OPCODE_SLLI;
	  if ((Field_op2_Slot_inst_get (insn) == 2 ||
	       Field_op2_Slot_inst_get (insn) == 3))
	    return OPCODE_SRAI;
	  if (Field_op2_Slot_inst_get (insn) == 4)
	    return OPCODE_SRLI;
	  if (Field_op2_Slot_inst_get (insn) == 6)
	    {
	      if (Field_sr_Slot_inst_get (insn) == 0)
		return OPCODE_XSR_LBEG;
	      if (Field_sr_Slot_inst_get (insn) == 1)
		return OPCODE_XSR_LEND;
	      if (Field_sr_Slot_inst_get (insn) == 2)
		return OPCODE_XSR_LCOUNT;
	      if (Field_sr_Slot_inst_get (insn) == 3)
		return OPCODE_XSR_SAR;
	      if (Field_sr_Slot_inst_get (insn) == 4)
		return OPCODE_XSR_BR;
	      if (Field_sr_Slot_inst_get (insn) == 5)
		return OPCODE_XSR_LITBASE;
	      if (Field_sr_Slot_inst_get (insn) == 12)
		return OPCODE_XSR_SCOMPARE1;
	      if (Field_sr_Slot_inst_get (insn) == 40)
		return OPCODE_XSR_PREFCTL;
	      if (Field_sr_Slot_inst_get (insn) == 72)
		return OPCODE_XSR_WINDOWBASE;
	      if (Field_sr_Slot_inst_get (insn) == 73)
		return OPCODE_XSR_WINDOWSTART;
	      if (Field_sr_Slot_inst_get (insn) == 96)
		return OPCODE_XSR_IBREAKENABLE;
	      if (Field_sr_Slot_inst_get (insn) == 97)
		return OPCODE_XSR_MEMCTL;
	      if (Field_sr_Slot_inst_get (insn) == 99)
		return OPCODE_XSR_ATOMCTL;
	      if (Field_sr_Slot_inst_get (insn) == 104)
		return OPCODE_XSR_DDR;
	      if (Field_sr_Slot_inst_get (insn) == 106)
		return OPCODE_XSR_MEPC;
	      if (Field_sr_Slot_inst_get (insn) == 107)
		return OPCODE_XSR_MEPS;
	      if (Field_sr_Slot_inst_get (insn) == 108)
		return OPCODE_XSR_MESAVE;
	      if (Field_sr_Slot_inst_get (insn) == 109)
		return OPCODE_XSR_MESR;
	      if (Field_sr_Slot_inst_get (insn) == 110)
		return OPCODE_XSR_MECR;
	      if (Field_sr_Slot_inst_get (insn) == 111)
		return OPCODE_XSR_MEVADDR;
	      if (Field_sr_Slot_inst_get (insn) == 128)
		return OPCODE_XSR_IBREAKA0;
	      if (Field_sr_Slot_inst_get (insn) == 129)
		return OPCODE_XSR_IBREAKA1;
	      if (Field_sr_Slot_inst_get (insn) == 144)
		return OPCODE_XSR_DBREAKA0;
	      if (Field_sr_Slot_inst_get (insn) == 145)
		return OPCODE_XSR_DBREAKA1;
	      if (Field_sr_Slot_inst_get (insn) == 160)
		return OPCODE_XSR_DBREAKC0;
	      if (Field_sr_Slot_inst_get (insn) == 161)
		return OPCODE_XSR_DBREAKC1;
	      if (Field_sr_Slot_inst_get (insn) == 177)
		return OPCODE_XSR_EPC1;
	      if (Field_sr_Slot_inst_get (insn) == 178)
		return OPCODE_XSR_EPC2;
	      if (Field_sr_Slot_inst_get (insn) == 179)
		return OPCODE_XSR_EPC3;
	      if (Field_sr_Slot_inst_get (insn) == 180)
		return OPCODE_XSR_EPC4;
	      if (Field_sr_Slot_inst_get (insn) == 181)
		return OPCODE_XSR_EPC5;
	      if (Field_sr_Slot_inst_get (insn) == 182)
		return OPCODE_XSR_EPC6;
	      if (Field_sr_Slot_inst_get (insn) == 183)
		return OPCODE_XSR_EPC7;
	      if (Field_sr_Slot_inst_get (insn) == 192)
		return OPCODE_XSR_DEPC;
	      if (Field_sr_Slot_inst_get (insn) == 194)
		return OPCODE_XSR_EPS2;
	      if (Field_sr_Slot_inst_get (insn) == 195)
		return OPCODE_XSR_EPS3;
	      if (Field_sr_Slot_inst_get (insn) == 196)
		return OPCODE_XSR_EPS4;
	      if (Field_sr_Slot_inst_get (insn) == 197)
		return OPCODE_XSR_EPS5;
	      if (Field_sr_Slot_inst_get (insn) == 198)
		return OPCODE_XSR_EPS6;
	      if (Field_sr_Slot_inst_get (insn) == 199)
		return OPCODE_XSR_EPS7;
	      if (Field_sr_Slot_inst_get (insn) == 209)
		return OPCODE_XSR_EXCSAVE1;
	      if (Field_sr_Slot_inst_get (insn) == 210)
		return OPCODE_XSR_EXCSAVE2;
	      if (Field_sr_Slot_inst_get (insn) == 211)
		return OPCODE_XSR_EXCSAVE3;
	      if (Field_sr_Slot_inst_get (insn) == 212)
		return OPCODE_XSR_EXCSAVE4;
	      if (Field_sr_Slot_inst_get (insn) == 213)
		return OPCODE_XSR_EXCSAVE5;
	      if (Field_sr_Slot_inst_get (insn) == 214)
		return OPCODE_XSR_EXCSAVE6;
	      if (Field_sr_Slot_inst_get (insn) == 215)
		return OPCODE_XSR_EXCSAVE7;
	      if (Field_sr_Slot_inst_get (insn) == 224)
		return OPCODE_XSR_CPENABLE;
	      if (Field_sr_Slot_inst_get (insn) == 228)
		return OPCODE_XSR_INTENABLE;
	      if (Field_sr_Slot_inst_get (insn) == 230)
		return OPCODE_XSR_PS;
	      if (Field_sr_Slot_inst_get (insn) == 231)
		return OPCODE_XSR_VECBASE;
	      if (Field_sr_Slot_inst_get (insn) == 232)
		return OPCODE_XSR_EXCCAUSE;
	      if (Field_sr_Slot_inst_get (insn) == 233)
		return OPCODE_XSR_DEBUGCAUSE;
	      if (Field_sr_Slot_inst_get (insn) == 234)
		return OPCODE_XSR_CCOUNT;
	      if (Field_sr_Slot_inst_get (insn) == 236)
		return OPCODE_XSR_ICOUNT;
	      if (Field_sr_Slot_inst_get (insn) == 237)
		return OPCODE_XSR_ICOUNTLEVEL;
	      if (Field_sr_Slot_inst_get (insn) == 238)
		return OPCODE_XSR_EXCVADDR;
	      if (Field_sr_Slot_inst_get (insn) == 240)
		return OPCODE_XSR_CCOMPARE0;
	      if (Field_sr_Slot_inst_get (insn) == 241)
		return OPCODE_XSR_CCOMPARE1;
	      if (Field_sr_Slot_inst_get (insn) == 242)
		return OPCODE_XSR_CCOMPARE2;
	    }
	  if (Field_op2_Slot_inst_get (insn) == 8)
	    return OPCODE_SRC;
	  if (Field_op2_Slot_inst_get (insn) == 9 &&
	      Field_s_Slot_inst_get (insn) == 0)
	    return OPCODE_SRL;
	  if (Field_op2_Slot_inst_get (insn) == 10 &&
	      Field_t_Slot_inst_get (insn) == 0)
	    return OPCODE_SLL;
	  if (Field_op2_Slot_inst_get (insn) == 11 &&
	      Field_s_Slot_inst_get (insn) == 0)
	    return OPCODE_SRA;
	  if (Field_op2_Slot_inst_get (insn) == 12)
	    return OPCODE_MUL16U;
	  if (Field_op2_Slot_inst_get (insn) == 13)
	    return OPCODE_MUL16S;
	  if (Field_op2_Slot_inst_get (insn) == 15)
	    {
	      if (Field_r_Slot_inst_get (insn) == 0)
		return OPCODE_LICT;
	      if (Field_r_Slot_inst_get (insn) == 1)
		return OPCODE_SICT;
	      if (Field_r_Slot_inst_get (insn) == 2)
		return OPCODE_LICW;
	      if (Field_r_Slot_inst_get (insn) == 3)
		return OPCODE_SICW;
	      if (Field_r_Slot_inst_get (insn) == 8)
		return OPCODE_LDCT;
	      if (Field_r_Slot_inst_get (insn) == 9)
		return OPCODE_SDCT;
	      if (Field_r_Slot_inst_get (insn) == 14 &&
		  Field_t_Slot_inst_get (insn) == 0)
		return OPCODE_RFDO;
	      if (Field_r_Slot_inst_get (insn) == 14 &&
		  Field_t_Slot_inst_get (insn) == 1)
		return OPCODE_RFDD;
	    }
	}
      if (Field_op1_Slot_inst_get (insn) == 2)
	{
	  if (Field_op2_Slot_inst_get (insn) == 0)
	    return OPCODE_ANDB;
	  if (Field_op2_Slot_inst_get (insn) == 1)
	    return OPCODE_ANDBC;
	  if (Field_op2_Slot_inst_get (insn) == 2)
	    return OPCODE_ORB;
	  if (Field_op2_Slot_inst_get (insn) == 3)
	    return OPCODE_ORBC;
	  if (Field_op2_Slot_inst_get (insn) == 4)
	    return OPCODE_XORB;
	  if (Field_op2_Slot_inst_get (insn) == 8)
	    return OPCODE_MULL;
	  if (Field_op2_Slot_inst_get (insn) == 10)
	    return OPCODE_MULUH;
	  if (Field_op2_Slot_inst_get (insn) == 11)
	    return OPCODE_MULSH;
	  if (Field_op2_Slot_inst_get (insn) == 12)
	    return OPCODE_QUOU;
	  if (Field_op2_Slot_inst_get (insn) == 13)
	    return OPCODE_QUOS;
	  if (Field_op2_Slot_inst_get (insn) == 14)
	    return OPCODE_REMU;
	  if (Field_op2_Slot_inst_get (insn) == 15)
	    return OPCODE_REMS;
	}
      if (Field_op1_Slot_inst_get (insn) == 3)
	{
	  if (Field_op2_Slot_inst_get (insn) == 0)
	    {
	      if (Field_sr_Slot_inst_get (insn) == 0)
		return OPCODE_RSR_LBEG;
	      if (Field_sr_Slot_inst_get (insn) == 1)
		return OPCODE_RSR_LEND;
	      if (Field_sr_Slot_inst_get (insn) == 2)
		return OPCODE_RSR_LCOUNT;
	      if (Field_sr_Slot_inst_get (insn) == 3)
		return OPCODE_RSR_SAR;
	      if (Field_sr_Slot_inst_get (insn) == 4)
		return OPCODE_RSR_BR;
	      if (Field_sr_Slot_inst_get (insn) == 5)
		return OPCODE_RSR_LITBASE;
	      if (Field_sr_Slot_inst_get (insn) == 12)
		return OPCODE_RSR_SCOMPARE1;
	      if (Field_sr_Slot_inst_get (insn) == 40)
		return OPCODE_RSR_PREFCTL;
	      if (Field_sr_Slot_inst_get (insn) == 72)
		return OPCODE_RSR_WINDOWBASE;
	      if (Field_sr_Slot_inst_get (insn) == 73)
		return OPCODE_RSR_WINDOWSTART;
	      if (Field_sr_Slot_inst_get (insn) == 96)
		return OPCODE_RSR_IBREAKENABLE;
	      if (Field_sr_Slot_inst_get (insn) == 97)
		return OPCODE_RSR_MEMCTL;
	      if (Field_sr_Slot_inst_get (insn) == 99)
		return OPCODE_RSR_ATOMCTL;
	      if (Field_sr_Slot_inst_get (insn) == 104)
		return OPCODE_RSR_DDR;
	      if (Field_sr_Slot_inst_get (insn) == 106)
		return OPCODE_RSR_MEPC;
	      if (Field_sr_Slot_inst_get (insn) == 107)
		return OPCODE_RSR_MEPS;
	      if (Field_sr_Slot_inst_get (insn) == 108)
		return OPCODE_RSR_MESAVE;
	      if (Field_sr_Slot_inst_get (insn) == 109)
		return OPCODE_RSR_MESR;
	      if (Field_sr_Slot_inst_get (insn) == 110)
		return OPCODE_RSR_MECR;
	      if (Field_sr_Slot_inst_get (insn) == 111)
		return OPCODE_RSR_MEVADDR;
	      if (Field_sr_Slot_inst_get (insn) == 128)
		return OPCODE_RSR_IBREAKA0;
	      if (Field_sr_Slot_inst_get (insn) == 129)
		return OPCODE_RSR_IBREAKA1;
	      if (Field_sr_Slot_inst_get (insn) == 144)
		return OPCODE_RSR_DBREAKA0;
	      if (Field_sr_Slot_inst_get (insn) == 145)
		return OPCODE_RSR_DBREAKA1;
	      if (Field_sr_Slot_inst_get (insn) == 160)
		return OPCODE_RSR_DBREAKC0;
	      if (Field_sr_Slot_inst_get (insn) == 161)
		return OPCODE_RSR_DBREAKC1;
	      if (Field_sr_Slot_inst_get (insn) == 176)
		return OPCODE_RSR_CONFIGID0;
	      if (Field_sr_Slot_inst_get (insn) == 177)
		return OPCODE_RSR_EPC1;
	      if (Field_sr_Slot_inst_get (insn) == 178)
		return OPCODE_RSR_EPC2;
	      if (Field_sr_Slot_inst_get (insn) == 179)
		return OPCODE_RSR_EPC3;
	      if (Field_sr_Slot_inst_get (insn) == 180)
		return OPCODE_RSR_EPC4;
	      if (Field_sr_Slot_inst_get (insn) == 181)
		return OPCODE_RSR_EPC5;
	      if (Field_sr_Slot_inst_get (insn) == 182)
		return OPCODE_RSR_EPC6;
	      if (Field_sr_Slot_inst_get (insn) == 183)
		return OPCODE_RSR_EPC7;
	      if (Field_sr_Slot_inst_get (insn) == 192)
		return OPCODE_RSR_DEPC;
	      if (Field_sr_Slot_inst_get (insn) == 194)
		return OPCODE_RSR_EPS2;
	      if (Field_sr_Slot_inst_get (insn) == 195)
		return OPCODE_RSR_EPS3;
	      if (Field_sr_Slot_inst_get (insn) == 196)
		return OPCODE_RSR_EPS4;
	      if (Field_sr_Slot_inst_get (insn) == 197)
		return OPCODE_RSR_EPS5;
	      if (Field_sr_Slot_inst_get (insn) == 198)
		return OPCODE_RSR_EPS6;
	      if (Field_sr_Slot_inst_get (insn) == 199)
		return OPCODE_RSR_EPS7;
	      if (Field_sr_Slot_inst_get (insn) == 208)
		return OPCODE_RSR_CONFIGID1;
	      if (Field_sr_Slot_inst_get (insn) == 209)
		return OPCODE_RSR_EXCSAVE1;
	      if (Field_sr_Slot_inst_get (insn) == 210)
		return OPCODE_RSR_EXCSAVE2;
	      if (Field_sr_Slot_inst_get (insn) == 211)
		return OPCODE_RSR_EXCSAVE3;
	      if (Field_sr_Slot_inst_get (insn) == 212)
		return OPCODE_RSR_EXCSAVE4;
	      if (Field_sr_Slot_inst_get (insn) == 213)
		return OPCODE_RSR_EXCSAVE5;
	      if (Field_sr_Slot_inst_get (insn) == 214)
		return OPCODE_RSR_EXCSAVE6;
	      if (Field_sr_Slot_inst_get (insn) == 215)
		return OPCODE_RSR_EXCSAVE7;
	      if (Field_sr_Slot_inst_get (insn) == 224)
		return OPCODE_RSR_CPENABLE;
	      if (Field_sr_Slot_inst_get (insn) == 226)
		return OPCODE_RSR_INTERRUPT;
	      if (Field_sr_Slot_inst_get (insn) == 228)
		return OPCODE_RSR_INTENABLE;
	      if (Field_sr_Slot_inst_get (insn) == 230)
		return OPCODE_RSR_PS;
	      if (Field_sr_Slot_inst_get (insn) == 231)
		return OPCODE_RSR_VECBASE;
	      if (Field_sr_Slot_inst_get (insn) == 232)
		return OPCODE_RSR_EXCCAUSE;
	      if (Field_sr_Slot_inst_get (insn) == 233)
		return OPCODE_RSR_DEBUGCAUSE;
	      if (Field_sr_Slot_inst_get (insn) == 234)
		return OPCODE_RSR_CCOUNT;
	      if (Field_sr_Slot_inst_get (insn) == 235)
		return OPCODE_RSR_PRID;
	      if (Field_sr_Slot_inst_get (insn) == 236)
		return OPCODE_RSR_ICOUNT;
	      if (Field_sr_Slot_inst_get (insn) == 237)
		return OPCODE_RSR_ICOUNTLEVEL;
	      if (Field_sr_Slot_inst_get (insn) == 238)
		return OPCODE_RSR_EXCVADDR;
	      if (Field_sr_Slot_inst_get (insn) == 240)
		return OPCODE_RSR_CCOMPARE0;
	      if (Field_sr_Slot_inst_get (insn) == 241)
		return OPCODE_RSR_CCOMPARE1;
	      if (Field_sr_Slot_inst_get (insn) == 242)
		return OPCODE_RSR_CCOMPARE2;
	      if (Field_sr_Slot_inst_get (insn) == 243)
		return OPCODE_RSR_243;
	    }
	  if (Field_op2_Slot_inst_get (insn) == 1)
	    {
	      if (Field_sr_Slot_inst_get (insn) == 0)
		return OPCODE_WSR_LBEG;
	      if (Field_sr_Slot_inst_get (insn) == 1)
		return OPCODE_WSR_LEND;
	      if (Field_sr_Slot_inst_get (insn) == 2)
		return OPCODE_WSR_LCOUNT;
	      if (Field_sr_Slot_inst_get (insn) == 3)
		return OPCODE_WSR_SAR;
	      if (Field_sr_Slot_inst_get (insn) == 4)
		return OPCODE_WSR_BR;
	      if (Field_sr_Slot_inst_get (insn) == 5)
		return OPCODE_WSR_LITBASE;
	      if (Field_sr_Slot_inst_get (insn) == 12)
		return OPCODE_WSR_SCOMPARE1;
	      if (Field_sr_Slot_inst_get (insn) == 40)
		return OPCODE_WSR_PREFCTL;
	      if (Field_sr_Slot_inst_get (insn) == 72)
		return OPCODE_WSR_WINDOWBASE;
	      if (Field_sr_Slot_inst_get (insn) == 73)
		return OPCODE_WSR_WINDOWSTART;
	      if (Field_sr_Slot_inst_get (insn) == 89)
		return OPCODE_WSR_MMID;
	      if (Field_sr_Slot_inst_get (insn) == 96)
		return OPCODE_WSR_IBREAKENABLE;
	      if (Field_sr_Slot_inst_get (insn) == 97)
		return OPCODE_WSR_MEMCTL;
	      if (Field_sr_Slot_inst_get (insn) == 99)
		return OPCODE_WSR_ATOMCTL;
	      if (Field_sr_Slot_inst_get (insn) == 104)
		return OPCODE_WSR_DDR;
	      if (Field_sr_Slot_inst_get (insn) == 106)
		return OPCODE_WSR_MEPC;
	      if (Field_sr_Slot_inst_get (insn) == 107)
		return OPCODE_WSR_MEPS;
	      if (Field_sr_Slot_inst_get (insn) == 108)
		return OPCODE_WSR_MESAVE;
	      if (Field_sr_Slot_inst_get (insn) == 109)
		return OPCODE_WSR_MESR;
	      if (Field_sr_Slot_inst_get (insn) == 110)
		return OPCODE_WSR_MECR;
	      if (Field_sr_Slot_inst_get (insn) == 111)
		return OPCODE_WSR_MEVADDR;
	      if (Field_sr_Slot_inst_get (insn) == 128)
		return OPCODE_WSR_IBREAKA0;
	      if (Field_sr_Slot_inst_get (insn) == 129)
		return OPCODE_WSR_IBREAKA1;
	      if (Field_sr_Slot_inst_get (insn) == 144)
		return OPCODE_WSR_DBREAKA0;
	      if (Field_sr_Slot_inst_get (insn) == 145)
		return OPCODE_WSR_DBREAKA1;
	      if (Field_sr_Slot_inst_get (insn) == 160)
		return OPCODE_WSR_DBREAKC0;
	      if (Field_sr_Slot_inst_get (insn) == 161)
		return OPCODE_WSR_DBREAKC1;
	      if (Field_sr_Slot_inst_get (insn) == 176)
		return OPCODE_WSR_CONFIGID0;
	      if (Field_sr_Slot_inst_get (insn) == 177)
		return OPCODE_WSR_EPC1;
	      if (Field_sr_Slot_inst_get (insn) == 178)
		return OPCODE_WSR_EPC2;
	      if (Field_sr_Slot_inst_get (insn) == 179)
		return OPCODE_WSR_EPC3;
	      if (Field_sr_Slot_inst_get (insn) == 180)
		return OPCODE_WSR_EPC4;
	      if (Field_sr_Slot_inst_get (insn) == 181)
		return OPCODE_WSR_EPC5;
	      if (Field_sr_Slot_inst_get (insn) == 182)
		return OPCODE_WSR_EPC6;
	      if (Field_sr_Slot_inst_get (insn) == 183)
		return OPCODE_WSR_EPC7;
	      if (Field_sr_Slot_inst_get (insn) == 192)
		return OPCODE_WSR_DEPC;
	      if (Field_sr_Slot_inst_get (insn) == 194)
		return OPCODE_WSR_EPS2;
	      if (Field_sr_Slot_inst_get (insn) == 195)
		return OPCODE_WSR_EPS3;
	      if (Field_sr_Slot_inst_get (insn) == 196)
		return OPCODE_WSR_EPS4;
	      if (Field_sr_Slot_inst_get (insn) == 197)
		return OPCODE_WSR_EPS5;
	      if (Field_sr_Slot_inst_get (insn) == 198)
		return OPCODE_WSR_EPS6;
	      if (Field_sr_Slot_inst_get (insn) == 199)
		return OPCODE_WSR_EPS7;
	      if (Field_sr_Slot_inst_get (insn) == 209)
		return OPCODE_WSR_EXCSAVE1;
	      if (Field_sr_Slot_inst_get (insn) == 210)
		return OPCODE_WSR_EXCSAVE2;
	      if (Field_sr_Slot_inst_get (insn) == 211)
		return OPCODE_WSR_EXCSAVE3;
	      if (Field_sr_Slot_inst_get (insn) == 212)
		return OPCODE_WSR_EXCSAVE4;
	      if (Field_sr_Slot_inst_get (insn) == 213)
		return OPCODE_WSR_EXCSAVE5;
	      if (Field_sr_Slot_inst_get (insn) == 214)
		return OPCODE_WSR_EXCSAVE6;
	      if (Field_sr_Slot_inst_get (insn) == 215)
		return OPCODE_WSR_EXCSAVE7;
	      if (Field_sr_Slot_inst_get (insn) == 224)
		return OPCODE_WSR_CPENABLE;
	      if (Field_sr_Slot_inst_get (insn) == 226)
		return OPCODE_WSR_INTSET;
	      if (Field_sr_Slot_inst_get (insn) == 227)
		return OPCODE_WSR_INTCLEAR;
	      if (Field_sr_Slot_inst_get (insn) == 228)
		return OPCODE_WSR_INTENABLE;
	      if (Field_sr_Slot_inst_get (insn) == 230)
		return OPCODE_WSR_PS;
	      if (Field_sr_Slot_inst_get (insn) == 231)
		return OPCODE_WSR_VECBASE;
	      if (Field_sr_Slot_inst_get (insn) == 232)
		return OPCODE_WSR_EXCCAUSE;
	      if (Field_sr_Slot_inst_get (insn) == 233)
		return OPCODE_WSR_DEBUGCAUSE;
	      if (Field_sr_Slot_inst_get (insn) == 234)
		return OPCODE_WSR_CCOUNT;
	      if (Field_sr_Slot_inst_get (insn) == 236)
		return OPCODE_WSR_ICOUNT;
	      if (Field_sr_Slot_inst_get (insn) == 237)
		return OPCODE_WSR_ICOUNTLEVEL;
	      if (Field_sr_Slot_inst_get (insn) == 238)
		return OPCODE_WSR_EXCVADDR;
	      if (Field_sr_Slot_inst_get (insn) == 240)
		return OPCODE_WSR_CCOMPARE0;
	      if (Field_sr_Slot_inst_get (insn) == 241)
		return OPCODE_WSR_CCOMPARE1;
	      if (Field_sr_Slot_inst_get (insn) == 242)
		return OPCODE_WSR_CCOMPARE2;
	    }
	  if (Field_op2_Slot_inst_get (insn) == 2)
	    return OPCODE_SEXT;
	  if (Field_op2_Slot_inst_get (insn) == 3)
	    return OPCODE_CLAMPS;
	  if (Field_op2_Slot_inst_get (insn) == 4)
	    return OPCODE_MIN;
	  if (Field_op2_Slot_inst_get (insn) == 5)
	    return OPCODE_MAX;
	  if (Field_op2_Slot_inst_get (insn) == 6)
	    return OPCODE_MINU;
	  if (Field_op2_Slot_inst_get (insn) == 7)
	    return OPCODE_MAXU;
	  if (Field_op2_Slot_inst_get (insn) == 8)
	    return OPCODE_MOVEQZ;
	  if (Field_op2_Slot_inst_get (insn) == 9)
	    return OPCODE_MOVNEZ;
	  if (Field_op2_Slot_inst_get (insn) == 10)
	    return OPCODE_MOVLTZ;
	  if (Field_op2_Slot_inst_get (insn) == 11)
	    return OPCODE_MOVGEZ;
	  if (Field_op2_Slot_inst_get (insn) == 12)
	    return OPCODE_MOVF;
	  if (Field_op2_Slot_inst_get (insn) == 13)
	    return OPCODE_MOVT;
	  if (Field_op2_Slot_inst_get (insn) == 14)
	    {
	      if (Field_st_Slot_inst_get (insn) == 231)
		return OPCODE_RUR_THREADPTR;
	      if (Field_st_Slot_inst_get (insn) == 232)
		return OPCODE_RUR_FCR;
	      if (Field_st_Slot_inst_get (insn) == 233)
		return OPCODE_RUR_FSR;
	      if (Field_st_Slot_inst_get (insn) == 240)
		return OPCODE_RUR_AE_OVF_SAR;
	      if (Field_st_Slot_inst_get (insn) == 241)
		return OPCODE_RUR_AE_BITHEAD;
	      if (Field_st_Slot_inst_get (insn) == 242)
		return OPCODE_RUR_AE_TS_FTS_BU_BP;
	      if (Field_st_Slot_inst_get (insn) == 243)
		return OPCODE_RUR_AE_CW_SD_NO;
	      if (Field_st_Slot_inst_get (insn) == 246)
		return OPCODE_RUR_AE_CBEGIN0;
	      if (Field_st_Slot_inst_get (insn) == 247)
		return OPCODE_RUR_AE_CEND0;
	    }
	  if (Field_op2_Slot_inst_get (insn) == 15)
	    {
	      if (Field_sr_Slot_inst_get (insn) == 231)
		return OPCODE_WUR_THREADPTR;
	      if (Field_sr_Slot_inst_get (insn) == 232)
		return OPCODE_WUR_FCR;
	      if (Field_sr_Slot_inst_get (insn) == 233)
		return OPCODE_WUR_FSR;
	      if (Field_sr_Slot_inst_get (insn) == 240)
		return OPCODE_WUR_AE_OVF_SAR;
	      if (Field_sr_Slot_inst_get (insn) == 241)
		return OPCODE_WUR_AE_BITHEAD;
	      if (Field_sr_Slot_inst_get (insn) == 242)
		return OPCODE_WUR_AE_TS_FTS_BU_BP;
	      if (Field_sr_Slot_inst_get (insn) == 243)
		return OPCODE_WUR_AE_CW_SD_NO;
	      if (Field_sr_Slot_inst_get (insn) == 246)
		return OPCODE_WUR_AE_CBEGIN0;
	      if (Field_sr_Slot_inst_get (insn) == 247)
		return OPCODE_WUR_AE_CEND0;
	    }
	}
      if ((Field_op1_Slot_inst_get (insn) == 4 ||
	   Field_op1_Slot_inst_get (insn) == 5))
	return OPCODE_EXTUI;
      if (Field_op1_Slot_inst_get (insn) == 8)
	{
	  if (Field_op2_Slot_inst_get (insn) == 0)
	    return OPCODE_LSX;
	  if (Field_op2_Slot_inst_get (insn) == 1)
	    return OPCODE_LSXP;
	  if (Field_op2_Slot_inst_get (insn) == 4)
	    return OPCODE_SSX;
	  if (Field_op2_Slot_inst_get (insn) == 5)
	    return OPCODE_SSXP;
	}
      if (Field_op1_Slot_inst_get (insn) == 9)
	{
	  if (Field_op2_Slot_inst_get (insn) == 0)
	    return OPCODE_L32E;
	  if (Field_op2_Slot_inst_get (insn) == 4)
	    return OPCODE_S32E;
	  if (Field_op2_Slot_inst_get (insn) == 5)
	    return OPCODE_S32NB;
	}
      if (Field_op1_Slot_inst_get (insn) == 10)
	{
	  if (Field_op2_Slot_inst_get (insn) == 0)
	    return OPCODE_ADD_S;
	  if (Field_op2_Slot_inst_get (insn) == 1)
	    return OPCODE_SUB_S;
	  if (Field_op2_Slot_inst_get (insn) == 2)
	    return OPCODE_MUL_S;
	  if (Field_op2_Slot_inst_get (insn) == 4)
	    return OPCODE_MADD_S;
	  if (Field_op2_Slot_inst_get (insn) == 5)
	    return OPCODE_MSUB_S;
	  if (Field_op2_Slot_inst_get (insn) == 6)
	    return OPCODE_MADDN_S;
	  if (Field_op2_Slot_inst_get (insn) == 7)
	    return OPCODE_DIVN_S;
	  if (Field_op2_Slot_inst_get (insn) == 8)
	    return OPCODE_ROUND_S;
	  if (Field_op2_Slot_inst_get (insn) == 9)
	    return OPCODE_TRUNC_S;
	  if (Field_op2_Slot_inst_get (insn) == 10)
	    return OPCODE_FLOOR_S;
	  if (Field_op2_Slot_inst_get (insn) == 11)
	    return OPCODE_CEIL_S;
	  if (Field_op2_Slot_inst_get (insn) == 12)
	    return OPCODE_FLOAT_S;
	  if (Field_op2_Slot_inst_get (insn) == 13)
	    return OPCODE_UFLOAT_S;
	  if (Field_op2_Slot_inst_get (insn) == 14)
	    return OPCODE_UTRUNC_S;
	  if (Field_op2_Slot_inst_get (insn) == 15)
	    {
	      if (Field_t_Slot_inst_get (insn) == 0)
		return OPCODE_MOV_S;
	      if (Field_t_Slot_inst_get (insn) == 1)
		return OPCODE_ABS_S;
	      if (Field_t_Slot_inst_get (insn) == 3)
		return OPCODE_CONST_S;
	      if (Field_t_Slot_inst_get (insn) == 4)
		return OPCODE_RFR;
	      if (Field_t_Slot_inst_get (insn) == 5)
		return OPCODE_WFR;
	      if (Field_t_Slot_inst_get (insn) == 6)
		return OPCODE_NEG_S;
	      if (Field_t_Slot_inst_get (insn) == 7)
		return OPCODE_DIV0_S;
	      if (Field_t_Slot_inst_get (insn) == 8)
		return OPCODE_RECIP0_S;
	      if (Field_t_Slot_inst_get (insn) == 9)
		return OPCODE_SQRT0_S;
	      if (Field_t_Slot_inst_get (insn) == 10)
		return OPCODE_RSQRT0_S;
	      if (Field_t_Slot_inst_get (insn) == 11)
		return OPCODE_NEXP01_S;
	      if (Field_t_Slot_inst_get (insn) == 12)
		return OPCODE_MKSADJ_S;
	      if (Field_t_Slot_inst_get (insn) == 13)
		return OPCODE_MKDADJ_S;
	      if (Field_t_Slot_inst_get (insn) == 14)
		return OPCODE_ADDEXP_S;
	      if (Field_t_Slot_inst_get (insn) == 15)
		return OPCODE_ADDEXPM_S;
	    }
	}
      if (Field_op1_Slot_inst_get (insn) == 11)
	{
	  if (Field_op2_Slot_inst_get (insn) == 1)
	    return OPCODE_UN_S;
	  if (Field_op2_Slot_inst_get (insn) == 2)
	    return OPCODE_OEQ_S;
	  if (Field_op2_Slot_inst_get (insn) == 3)
	    return OPCODE_UEQ_S;
	  if (Field_op2_Slot_inst_get (insn) == 4)
	    return OPCODE_OLT_S;
	  if (Field_op2_Slot_inst_get (insn) == 5)
	    return OPCODE_ULT_S;
	  if (Field_op2_Slot_inst_get (insn) == 6)
	    return OPCODE_OLE_S;
	  if (Field_op2_Slot_inst_get (insn) == 7)
	    return OPCODE_ULE_S;
	  if (Field_op2_Slot_inst_get (insn) == 8)
	    return OPCODE_MOVEQZ_S;
	  if (Field_op2_Slot_inst_get (insn) == 9)
	    return OPCODE_MOVNEZ_S;
	  if (Field_op2_Slot_inst_get (insn) == 10)
	    return OPCODE_MOVLTZ_S;
	  if (Field_op2_Slot_inst_get (insn) == 11)
	    return OPCODE_MOVGEZ_S;
	  if (Field_op2_Slot_inst_get (insn) == 12)
	    return OPCODE_MOVF_S;
	  if (Field_op2_Slot_inst_get (insn) == 13)
	    return OPCODE_MOVT_S;
	}
    }
  if (Field_op0_Slot_inst_get (insn) == 1)
    return OPCODE_L32R;
  if (Field_op0_Slot_inst_get (insn) == 2)
    {
      if (Field_r_Slot_inst_get (insn) == 0)
	return OPCODE_L8UI;
      if (Field_r_Slot_inst_get (insn) == 1)
	return OPCODE_L16UI;
      if (Field_r_Slot_inst_get (insn) == 2)
	return OPCODE_L32I;
      if (Field_r_Slot_inst_get (insn) == 4)
	return OPCODE_S8I;
      if (Field_r_Slot_inst_get (insn) == 5)
	return OPCODE_S16I;
      if (Field_r_Slot_inst_get (insn) == 6)
	return OPCODE_S32I;
      if (Field_r_Slot_inst_get (insn) == 7)
	{
	  if (Field_t_Slot_inst_get (insn) == 0)
	    return OPCODE_DPFR;
	  if (Field_t_Slot_inst_get (insn) == 1)
	    return OPCODE_DPFW;
	  if (Field_t_Slot_inst_get (insn) == 2)
	    return OPCODE_DPFRO;
	  if (Field_t_Slot_inst_get (insn) == 3)
	    return OPCODE_DPFWO;
	  if (Field_t_Slot_inst_get (insn) == 4)
	    return OPCODE_DHWB;
	  if (Field_t_Slot_inst_get (insn) == 5)
	    return OPCODE_DHWBI;
	  if (Field_t_Slot_inst_get (insn) == 6)
	    return OPCODE_DHI;
	  if (Field_t_Slot_inst_get (insn) == 7)
	    return OPCODE_DII;
	  if (Field_t_Slot_inst_get (insn) == 8)
	    {
	      if (Field_op1_Slot_inst_get (insn) == 0)
		return OPCODE_DPFL;
	      if (Field_op1_Slot_inst_get (insn) == 2)
		return OPCODE_DHU;
	      if (Field_op1_Slot_inst_get (insn) == 3)
		return OPCODE_DIU;
	      if (Field_op1_Slot_inst_get (insn) == 4)
		return OPCODE_DIWB;
	      if (Field_op1_Slot_inst_get (insn) == 5)
		return OPCODE_DIWBI;
	      if (Field_op1_Slot_inst_get (insn) == 15 &&
		  Field_op2_Slot_inst_get (insn) == 0)
		return OPCODE_DIWBUI_P;
	    }
	  if (Field_t_Slot_inst_get (insn) == 12)
	    return OPCODE_IPF;
	  if (Field_t_Slot_inst_get (insn) == 13)
	    {
	      if (Field_op1_Slot_inst_get (insn) == 0)
		return OPCODE_IPFL;
	      if (Field_op1_Slot_inst_get (insn) == 2)
		return OPCODE_IHU;
	      if (Field_op1_Slot_inst_get (insn) == 3)
		return OPCODE_IIU;
	    }
	  if (Field_t_Slot_inst_get (insn) == 14)
	    return OPCODE_IHI;
	  if (Field_t_Slot_inst_get (insn) == 15)
	    return OPCODE_III;
	}
      if (Field_r_Slot_inst_get (insn) == 9)
	return OPCODE_L16SI;
      if (Field_r_Slot_inst_get (insn) == 10)
	return OPCODE_MOVI;
      if (Field_r_Slot_inst_get (insn) == 11)
	return OPCODE_L32AI;
      if (Field_r_Slot_inst_get (insn) == 12)
	return OPCODE_ADDI;
      if (Field_r_Slot_inst_get (insn) == 13)
	return OPCODE_ADDMI;
      if (Field_r_Slot_inst_get (insn) == 14)
	return OPCODE_S32C1I;
      if (Field_r_Slot_inst_get (insn) == 15)
	return OPCODE_S32RI;
    }
  if (Field_op0_Slot_inst_get (insn) == 3)
    {
      if (Field_r_Slot_inst_get (insn) == 0)
	return OPCODE_LSI;
      if (Field_r_Slot_inst_get (insn) == 4)
	return OPCODE_SSI;
      if (Field_r_Slot_inst_get (insn) == 8)
	return OPCODE_LSIP;
      if (Field_r_Slot_inst_get (insn) == 12)
	return OPCODE_SSIP;
    }
  if (Field_op0_Slot_inst_get (insn) == 4)
    {
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 1)
	return OPCODE_AE_S64_I;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 2)
	return OPCODE_AE_S64_IP;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 13 &&
	  Field_inst_7_6_Slot_inst_get (insn) == 2)
	return OPCODE_AE_LA32X2_IC;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 13 &&
	  Field_inst_7_6_Slot_inst_get (insn) == 3)
	return OPCODE_AE_LA32X2_IP;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 12 &&
	  Field_inst_7_6_Slot_inst_get (insn) == 0)
	return OPCODE_AE_LA32X2F24_IC;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 12 &&
	  Field_inst_7_6_Slot_inst_get (insn) == 1)
	return OPCODE_AE_LA32X2F24_IP;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 13 &&
	  Field_inst_7_6_Slot_inst_get (insn) == 0)
	return OPCODE_AE_LA24X2_IC;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 13 &&
	  Field_inst_7_6_Slot_inst_get (insn) == 1)
	return OPCODE_AE_LA24X2_IP;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 12 &&
	  Field_inst_7_6_Slot_inst_get (insn) == 3)
	return OPCODE_AE_SA32X2_IP;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 12 &&
	  Field_inst_7_6_Slot_inst_get (insn) == 2)
	return OPCODE_AE_SA16X4_IP;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 4)
	return OPCODE_AE_S32RA64S_XP;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 0)
	return OPCODE_AE_S32X2RA64S_IP;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 3)
	return OPCODE_AE_S24X2RA64S_IP;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 7)
	return OPCODE_AE_SRAA32;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 5)
	return OPCODE_AE_SLAA32S;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 6)
	return OPCODE_AE_SLAASQ56S;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 14)
	return OPCODE_AE_VLDL32T;
      if (Field_op2_Slot_inst_get (insn) == 0 &&
	  Field_op1_Slot_inst_get (insn) == 15)
	return OPCODE_AE_VLDL16T;
      if (Field_op2_Slot_inst_get (insn) == 1 &&
	  Field_op1_Slot_inst_get (insn) == 5)
	return OPCODE_AE_MOVDA32X2;
      if (Field_op2_Slot_inst_get (insn) == 1 &&
	  Field_op1_Slot_inst_get (insn) == 4)
	return OPCODE_AE_MOVDA16X2;
      if (Field_op2_Slot_inst_get (insn) == 1 &&
	  Field_op1_Slot_inst_get (insn) == 12 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 1)
	return OPCODE_AE_SEXT32X2D16_32;
      if (Field_op2_Slot_inst_get (insn) == 1 &&
	  Field_op1_Slot_inst_get (insn) == 3)
	return OPCODE_AE_CVTP24A16X2_LL;
      if (Field_op2_Slot_inst_get (insn) == 1 &&
	  Field_op1_Slot_inst_get (insn) == 2)
	return OPCODE_AE_CVTP24A16X2_LH;
      if (Field_op2_Slot_inst_get (insn) == 1 &&
	  Field_op1_Slot_inst_get (insn) == 1)
	return OPCODE_AE_CVTP24A16X2_HL;
      if (Field_op2_Slot_inst_get (insn) == 1 &&
	  Field_op1_Slot_inst_get (insn) == 0)
	return OPCODE_AE_CVTP24A16X2_HH;
      if (Field_op2_Slot_inst_get (insn) == 1 &&
	  Field_op1_Slot_inst_get (insn) == 13)
	return OPCODE_AE_TRUNCP24Q48X2;
      if (Field_op2_Slot_inst_get (insn) == 1 &&
	  Field_op1_Slot_inst_get (insn) == 12 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 0)
	return OPCODE_AE_TRUNCP16;
      if (Field_op2_Slot_inst_get (insn) == 1 &&
	  Field_op1_Slot_inst_get (insn) == 12 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 2)
	return OPCODE_AE_TRUNCQ32;
      if (Field_op2_Slot_inst_get (insn) == 1 &&
	  Field_op1_Slot_inst_get (insn) == 6)
	return OPCODE_AE_OR;
      if (Field_op2_Slot_inst_get (insn) == 1 &&
	  Field_op1_Slot_inst_get (insn) == 14)
	return OPCODE_AE_XOR;
      if (Field_op2_Slot_inst_get (insn) == 1 &&
	  Field_op1_Slot_inst_get (insn) == 7)
	return OPCODE_AE_SEXT32;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 12 &&
	  Field_inst_7_Slot_inst_get (insn) == 1)
	return OPCODE_AE_L32X2F24_IP;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 8 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 3 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 1 &&
	  Field_inst_5_4_Slot_inst_get (insn) == 0)
	return OPCODE_AE_ZALIGN64;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 8 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 3 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 0)
	return OPCODE_AE_MOVALIGN;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 11 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 10)
	return OPCODE_AE_SAT48S;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 11 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 9)
	return OPCODE_AE_ROUNDSQ32F48SYM;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 11 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 8)
	return OPCODE_AE_ROUNDSQ32F48ASYM;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 5 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 3)
	return OPCODE_AE_TRUNCA32Q48;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 5 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 12)
	return OPCODE_AE_MOVAD32_L;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 5 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 11)
	return OPCODE_AE_MOVAD32_H;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 5 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 10)
	return OPCODE_AE_MOVAD16_3;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 5 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 9)
	return OPCODE_AE_MOVAD16_2;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 5 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 8)
	return OPCODE_AE_MOVAD16_0;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_9_8_Slot_inst_get (insn) == 2)
	return OPCODE_AE_PKSR32;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 6 &&
	  Field_inst_9_8_Slot_inst_get (insn) == 2)
	return OPCODE_AE_PKSR24;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 5 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 2)
	return OPCODE_AE_TRUNCA16P24S_L;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 5 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 1)
	return OPCODE_AE_TRUNCA16P24S_H;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 11 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 1)
	return OPCODE_AE_ABS24S;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 11 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 7)
	return OPCODE_AE_NEG32S;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 11 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 3)
	return OPCODE_AE_ABS32S;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 11 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 6)
	return OPCODE_AE_NEG16S;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 11 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 2)
	return OPCODE_AE_ABS16S;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 11 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 5)
	return OPCODE_AE_NEG64;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 8)
	return OPCODE_AE_ABS64;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 4 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 11)
	return OPCODE_AE_SLAS24;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 4 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 14)
	return OPCODE_AE_SRAS24;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 0)
	return OPCODE_AE_SLAA32;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 3)
	return OPCODE_AE_SLAA16S;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 4 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 12)
	return OPCODE_AE_SLASQ56;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 4 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 15)
	return OPCODE_AE_SRASQ56;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 1)
	return OPCODE_AE_SLAAQ56;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 2)
	return OPCODE_AE_SLAA64;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 4 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 13)
	return OPCODE_AE_SLAS64S;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 5 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 13)
	return OPCODE_AE_NSA64;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 5 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 14)
	return OPCODE_AE_NSAZ16_0;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 5 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 15)
	return OPCODE_AE_NSAZ32_L;
      if (Field_op2_Slot_inst_get (insn) == 2 &&
	  Field_op1_Slot_inst_get (insn) == 11 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 4)
	return OPCODE_AE_DIV64D32_L;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 13 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 2)
	return OPCODE_AE_L32X2F24_RIP;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 14 &&
	  Field_inst_7_Slot_inst_get (insn) == 1)
	return OPCODE_AE_L32X2_IP;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 13 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 1)
	return OPCODE_AE_L32X2_RIP;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_7_6_Slot_inst_get (insn) == 2)
	return OPCODE_AE_LA16X4_IC;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_7_6_Slot_inst_get (insn) == 3)
	return OPCODE_AE_LA16X4_IP;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 5 &&
	  Field_inst_7_6_Slot_inst_get (insn) == 2)
	return OPCODE_AE_LA16X4_RIP;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 15 &&
	  Field_inst_7_6_Slot_inst_get (insn) == 3)
	return OPCODE_AE_SA32X2F24_IP;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 11 &&
	  Field_inst_4_Slot_inst_get (insn) == 1)
	return OPCODE_AE_MOVT32X2;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 10 &&
	  Field_inst_4_Slot_inst_get (insn) == 1)
	return OPCODE_AE_MOVF32X2;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 12 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 3)
	return OPCODE_AE_MOVDA32;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 12 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 2)
	return OPCODE_AE_MOVDA16;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 13 &&
	  Field_inst_7_6_Slot_inst_get (insn) == 2)
	return OPCODE_AE_MOVI;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 14 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 1)
	return OPCODE_AE_MOV;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 12 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 1)
	return OPCODE_AE_CVT48A32;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 14 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 3)
	return OPCODE_AE_CVTQ56P32S_L;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 14 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 2)
	return OPCODE_AE_CVTQ56P32S_H;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 0)
	return OPCODE_AE_ADD32;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 2)
	return OPCODE_AE_ADD24S;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 3)
	return OPCODE_AE_ADD16S;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 1)
	return OPCODE_AE_ADD64;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 6 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 8)
	return OPCODE_AE_SHA32;
      if (Field_op2_Slot_inst_get (insn) == 3 &&
	  Field_op1_Slot_inst_get (insn) == 4 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 1 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 0)
	return OPCODE_AE_VLDSHT;
      if (Field_op2_Slot_inst_get (insn) == 4 &&
	  Field_op1_Slot_inst_get (insn) == 7)
	return OPCODE_AE_ROUND32X2F64SASYM;
      if (Field_op2_Slot_inst_get (insn) == 4 &&
	  Field_op1_Slot_inst_get (insn) == 2)
	return OPCODE_AE_ROUND16X4F32SASYM;
      if (Field_op2_Slot_inst_get (insn) == 4 &&
	  Field_op1_Slot_inst_get (insn) == 5)
	return OPCODE_AE_ROUND24X2F48SSYM;
      if (Field_op2_Slot_inst_get (insn) == 4 &&
	  Field_op1_Slot_inst_get (insn) == 4)
	return OPCODE_AE_ROUND24X2F48SASYM;
      if (Field_op2_Slot_inst_get (insn) == 4 &&
	  Field_op1_Slot_inst_get (insn) == 3)
	return OPCODE_AE_ROUNDSP16Q48X2ASYM;
      if (Field_op2_Slot_inst_get (insn) == 4 &&
	  Field_op1_Slot_inst_get (insn) == 12)
	return OPCODE_AE_SUB32;
      if (Field_op2_Slot_inst_get (insn) == 4 &&
	  Field_op1_Slot_inst_get (insn) == 0)
	return OPCODE_AE_ADD32S;
      if (Field_op2_Slot_inst_get (insn) == 4 &&
	  Field_op1_Slot_inst_get (insn) == 15)
	return OPCODE_AE_SUB32S;
      if (Field_op2_Slot_inst_get (insn) == 4 &&
	  Field_op1_Slot_inst_get (insn) == 14)
	return OPCODE_AE_SUB16S;
      if (Field_op2_Slot_inst_get (insn) == 4 &&
	  Field_op1_Slot_inst_get (insn) == 13)
	return OPCODE_AE_SUB64;
      if (Field_op2_Slot_inst_get (insn) == 4 &&
	  Field_op1_Slot_inst_get (insn) == 1)
	return OPCODE_AE_AND;
      if (Field_op2_Slot_inst_get (insn) == 5 &&
	  Field_op1_Slot_inst_get (insn) == 4 &&
	  Field_inst_12_Slot_inst_get (insn) == 1)
	return OPCODE_AE_LT32;
      if (Field_op2_Slot_inst_get (insn) == 5 &&
	  Field_op1_Slot_inst_get (insn) == 4 &&
	  Field_inst_12_Slot_inst_get (insn) == 0)
	return OPCODE_AE_EQ32;
      if (Field_op2_Slot_inst_get (insn) == 5 &&
	  Field_op1_Slot_inst_get (insn) == 3)
	return OPCODE_AE_MIN32;
      if (Field_op2_Slot_inst_get (insn) == 5 &&
	  Field_op1_Slot_inst_get (insn) == 2)
	return OPCODE_AE_MAX32;
      if (Field_op2_Slot_inst_get (insn) == 5 &&
	  Field_op1_Slot_inst_get (insn) == 1)
	return OPCODE_AE_LT64;
      if (Field_op2_Slot_inst_get (insn) == 5 &&
	  Field_op1_Slot_inst_get (insn) == 0)
	return OPCODE_AE_LE64;
      if (Field_op2_Slot_inst_get (insn) == 5 &&
	  Field_op1_Slot_inst_get (insn) == 6)
	return OPCODE_AE_SBI_IC;
      if (Field_op2_Slot_inst_get (insn) == 5 &&
	  Field_op1_Slot_inst_get (insn) == 7)
	return OPCODE_AE_SBI_IP;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 14 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 10)
	return OPCODE_RUR_AE_OVERFLOW;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 14 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 11)
	return OPCODE_WUR_AE_OVERFLOW;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 14 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 12)
	return OPCODE_RUR_AE_SAR;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 14 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 13)
	return OPCODE_WUR_AE_SAR;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 14 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 14)
	return OPCODE_RUR_AE_BITPTR;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 14 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 15)
	return OPCODE_WUR_AE_BITPTR;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 15 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 0)
	return OPCODE_RUR_AE_BITSUSED;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 15 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 1)
	return OPCODE_WUR_AE_BITSUSED;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 15 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 2)
	return OPCODE_RUR_AE_TABLESIZE;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 15 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 3)
	return OPCODE_WUR_AE_TABLESIZE;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 15 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 4)
	return OPCODE_RUR_AE_FIRST_TS;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 15 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 5)
	return OPCODE_WUR_AE_FIRST_TS;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 15 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 6)
	return OPCODE_RUR_AE_NEXTOFFSET;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 15 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 7)
	return OPCODE_WUR_AE_NEXTOFFSET;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 15 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 8)
	return OPCODE_RUR_AE_SEARCHDONE;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 15 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 9)
	return OPCODE_WUR_AE_SEARCHDONE;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 15 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 10)
	return OPCODE_RUR_AE_CWRAP;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 15 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 11)
	return OPCODE_WUR_AE_CWRAP;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 2 &&
	  Field_inst_7_Slot_inst_get (insn) == 1)
	return OPCODE_AE_S32X2F24_IP;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 2 &&
	  Field_inst_7_Slot_inst_get (insn) == 0)
	return OPCODE_AE_S32X2_IP;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 0)
	return OPCODE_AE_MOVT64;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 1)
	return OPCODE_AE_SRLAQ56;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 9 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 2)
	return OPCODE_AE_LB;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 9 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 3)
	return OPCODE_AE_LBI;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 9 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 6)
	return OPCODE_AE_LBS;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 9 &&
	  Field_inst_11_8_Slot_inst_get (insn) == 7)
	return OPCODE_AE_LBSI;
      if (Field_op2_Slot_inst_get (insn) == 6 &&
	  Field_op1_Slot_inst_get (insn) == 3)
	return OPCODE_AE_SBI;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_7_6_Slot_inst_get (insn) == 3 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 2)
	return OPCODE_AE_LA64_PP;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_7_6_Slot_inst_get (insn) == 3 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 1)
	return OPCODE_AE_LA32X2POS_PC;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_7_6_Slot_inst_get (insn) == 3 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 3)
	return OPCODE_AE_SA64POS_FP;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 14 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 6)
	return OPCODE_AE_VLDL16C;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 14 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 8)
	return OPCODE_AE_VLDL16C_IP;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 14 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 7)
	return OPCODE_AE_VLDL16C_IC;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 4)
	return OPCODE_AE_DB;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 5)
	return OPCODE_AE_DBI;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 6)
	return OPCODE_AE_DB_IC;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 7)
	return OPCODE_AE_DBI_IC;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 8)
	return OPCODE_AE_DB_IP;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 9)
	return OPCODE_AE_DBI_IP;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 10)
	return OPCODE_AE_SB;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 14 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 0)
	return OPCODE_AE_VLES16C;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 14 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 1)
	return OPCODE_AE_SBF;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 11)
	return OPCODE_AE_SB_IC;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 14 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 2)
	return OPCODE_AE_VLES16C_IC;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 14 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 3)
	return OPCODE_AE_SBF_IC;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 12)
	return OPCODE_AE_SB_IP;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 14 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 4)
	return OPCODE_AE_VLES16C_IP;
      if (Field_op2_Slot_inst_get (insn) == 7 &&
	  Field_op1_Slot_inst_get (insn) == 7 &&
	  Field_inst_15_12_Slot_inst_get (insn) == 14 &&
	  Field_inst_7_4_Slot_inst_get (insn) == 5)
	return OPCODE_AE_SBF_IP;
      if (Field_op2_Slot_inst_get (insn) == 8 &&
	  Field_op1_Slot_inst_get (insn) == 0 &&
	  Field_inst_7_Slot_inst_get (insn) == 1)
	return OPCODE_AE_S16X4_IP;
      if (Field_op2_Slot_inst_get (insn) == 8 &&
	  Field_op1_Slot_inst_get (insn) == 2)
	return OPCODE_AE_SRAA32S;
      if (Field_op2_Slot_inst_get (insn) == 8 &&
	  Field_inst_19_18_Slot_inst_get (insn) == 2)
	return OPCODE_AE_SLAI64;
      if (Field_op2_Slot_inst_get (insn) == 8 &&
	  Field_inst_19_18_Slot_inst_get (insn) == 3)
	return OPCODE_AE_SRAI64;
      if (Field_op2_Slot_inst_get (insn) == 8 &&
	  Field_op1_Slot_inst_get (insn) == 1)
	return OPCODE_AE_SRAA64;
      if (Field_op2_Slot_inst_get (insn) == 8 &&
	  Field_inst_19_18_Slot_inst_get (insn) == 1)
	return OPCODE_AE_SLAISQ56S;
      if (Field_op2_Slot_inst_get (insn) == 8 &&
	  Field_op1_Slot_inst_get (insn) == 3)
	return OPCODE_AE_LBK;
      if (Field_op2_Slot_inst_get (insn) == 9 &&
	  Field_op1_Slot_inst_get (insn) == 0 &&
	  Field_inst_7_Slot_inst_get (insn) == 1)
	return OPCODE_AE_L16X4_IP;
      if (Field_op2_Slot_inst_get (insn) == 9 &&
	  Field_inst_19_17_Slot_inst_get (insn) == 2)
	return OPCODE_AE_SLAI24;
      if (Field_op2_Slot_inst_get (insn) == 9 &&
	  Field_inst_19_17_Slot_inst_get (insn) == 6)
	return OPCODE_AE_SRAI24;
      if (Field_op2_Slot_inst_get (insn) == 9 &&
	  Field_inst_19_17_Slot_inst_get (insn) == 3)
	return OPCODE_AE_SLAI32;
      if (Field_op2_Slot_inst_get (insn) == 9 &&
	  Field_inst_19_17_Slot_inst_get (insn) == 1)
	return OPCODE_AE_SRLI32;
      if (Field_op2_Slot_inst_get (insn) == 9 &&
	  Field_inst_19_17_Slot_inst_get (insn) == 7)
	return OPCODE_AE_SRAI32;
      if (Field_op2_Slot_inst_get (insn) == 9 &&
	  Field_inst_19_17_Slot_inst_get (insn) == 4)
	return OPCODE_AE_SLAI24S;
      if (Field_op2_Slot_inst_get (insn) == 9 &&
	  Field_inst_19_17_Slot_inst_get (insn) == 5)
	return OPCODE_AE_SLAI32S;
      if (Field_op2_Slot_inst_get (insn) == 9 &&
	  Field_op1_Slot_inst_get (insn) == 1)
	return OPCODE_AE_SRAAQ56;
      if (Field_op2_Slot_inst_get (insn) == 10)
	return OPCODE_AE_SEL16I;
      if (Field_op2_Slot_inst_get (insn) == 11 &&
	  Field_op1_Slot_inst_get (insn) == 1)
	return OPCODE_AE_L16M_I;
      if (Field_op2_Slot_inst_get (insn) == 11 &&
	  Field_op1_Slot_inst_get (insn) == 2)
	return OPCODE_AE_L16M_IU;
      if (Field_op2_Slot_inst_get (insn) == 11 &&
	  Field_op1_Slot_inst_get (insn) == 3)
	return OPCODE_AE_L16M_XU;
      if (Field_op2_Slot_inst_get (insn) == 11 &&
	  Field_op1_Slot_inst_get (insn) == 0)
	return OPCODE_AE_L16_I;
      if (Field_op2_Slot_inst_get (insn) == 11 &&
	  Field_op1_Slot_inst_get (insn) == 4)
	return OPCODE_AE_L16_IP;
      if (Field_op2_Slot_inst_get (insn) == 11 &&
	  Field_op1_Slot_inst_get (insn) == 5)
	return OPCODE_AE_L32F24_XC;
      if (Field_op2_Slot_inst_get (insn) == 11 &&
	  Field_op1_Slot_inst_get (insn) == 6)
	return OPCODE_AE_L32F24_I;
      if (Field_op2_Slot_inst_get (insn) == 11 &&
	  Field_op1_Slot_inst_get (insn) == 7)
	return OPCODE_AE_L32F24_IP;
      if (Field_op2_Slot_inst_get (insn) == 11 &&
	  Field_op1_Slot_inst_get (insn) == 12)
	return OPCODE_AE_L32_XC;
      if (Field_op2_Slot_inst_get (insn) == 11 &&
	  Field_op1_Slot_inst_get (insn) == 13)
	return OPCODE_AE_L32_I;
      if (Field_op2_Slot_inst_get (insn) == 11 &&
	  Field_op1_Slot_inst_get (insn) == 14)
	return OPCODE_AE_L32_IP;
      if (Field_op2_Slot_inst_get (insn) == 11 &&
	  Field_op1_Slot_inst_get (insn) == 15)
	return OPCODE_AE_L32_X;
      if (Field_op2_Slot_inst_get (insn) == 11 &&
	  Field_op1_Slot_inst_get (insn) == 8)
	return OPCODE_AE_L16X2M_I;
      if (Field_op2_Slot_inst_get (insn) == 11 &&
	  Field_op1_Slot_inst_get (insn) == 9)
	return OPCODE_AE_L16X2M_IU;
      if (Field_op2_Slot_inst_get (insn) == 11 &&
	  Field_op1_Slot_inst_get (insn) == 10)
	return OPCODE_AE_L16X2M_X;
      if (Field_op2_Slot_inst_get (insn) == 11 &&
	  Field_op1_Slot_inst_get (insn) == 11)
	return OPCODE_AE_L16X2M_XU;
      if (Field_op2_Slot_inst_get (insn) == 12 &&
	  Field_op1_Slot_inst_get (insn) == 8)
	return OPCODE_AE_L32M_I;
      if (Field_op2_Slot_inst_get (insn) == 12 &&
	  Field_op1_Slot_inst_get (insn) == 9)
	return OPCODE_AE_L32M_IU;
      if (Field_op2_Slot_inst_get (insn) == 12 &&
	  Field_op1_Slot_inst_get (insn) == 10)
	return OPCODE_AE_L32M_X;
      if (Field_op2_Slot_inst_get (insn) == 12 &&
	  Field_op1_Slot_inst_get (insn) == 11)
	return OPCODE_AE_L32M_XU;
      if (Field_op2_Slot_inst_get (insn) == 12 &&
	  Field_op1_Slot_inst_get (insn) == 4)
	return OPCODE_AE_L32X2F24_XC;
      if (Field_op2_Slot_inst_get (insn) == 12 &&
	  Field_op1_Slot_inst_get (insn) == 5)
	return OPCODE_AE_L32X2F24_I;
      if (Field_op2_Slot_inst_get (insn) == 12 &&
	  Field_op1_Slot_inst_get (insn) == 6)
	return OPCODE_AE_L32X2F24_X;
      if (Field_op2_Slot_inst_get (insn) == 12 &&
	  Field_op1_Slot_inst_get (insn) == 7)
	return OPCODE_AE_L32X2F24_XP;
      if (Field_op2_Slot_inst_get (insn) == 12 &&
	  Field_op1_Slot_inst_get (insn) == 0)
	return OPCODE_AE_L32X2_XC;
      if (Field_op2_Slot_inst_get (insn) == 12 &&
	  Field_op1_Slot_inst_get (insn) == 1)
	return OPCODE_AE_L32X2_I;
      if (Field_op2_Slot_inst_get (insn) == 12 &&
	  Field_op1_Slot_inst_get (insn) == 2)
	return OPCODE_AE_L32X2_X;
      if (Field_op2_Slot_inst_get (insn) == 12 &&
	  Field_op1_Slot_inst_get (insn) == 3)
	return OPCODE_AE_L32X2_XP;
      if (Field_op2_Slot_inst_get (insn) == 12 &&
	  Field_op1_Slot_inst_get (insn) == 12)
	return OPCODE_AE_L16X4_I;
      if (Field_op2_Slot_inst_get (insn) == 12 &&
	  Field_op1_Slot_inst_get (insn) == 13)
	return OPCODE_AE_L16X4_XP;
      if (Field_op2_Slot_inst_get (insn) == 12 &&
	  Field_op1_Slot_inst_get (insn) == 15)
	return OPCODE_AE_L64_I;
      if (Field_op2_Slot_inst_get (insn) == 12 &&
	  Field_op1_Slot_inst_get (insn) == 14)
	return OPCODE_AE_LBKI;
      if (Field_op2_Slot_inst_get (insn) == 13 &&
	  Field_op1_Slot_inst_get (insn) == 8)
	return OPCODE_AE_S16X2M_I;
      if (Field_op2_Slot_inst_get (insn) == 13 &&
	  Field_op1_Slot_inst_get (insn) == 9)
	return OPCODE_AE_S16X2M_IU;
      if (Field_op2_Slot_inst_get (insn) == 13 &&
	  Field_op1_Slot_inst_get (insn) == 10)
	return OPCODE_AE_S16X2M_X;
      if (Field_op2_Slot_inst_get (insn) == 13 &&
	  Field_op1_Slot_inst_get (insn) == 11)
	return OPCODE_AE_S16X2M_XU;
      if (Field_op2_Slot_inst_get (insn) == 13 &&
	  Field_op1_Slot_inst_get (insn) == 12)
	return OPCODE_AE_S16X4_I;
      if (Field_op2_Slot_inst_get (insn) == 13 &&
	  Field_op1_Slot_inst_get (insn) == 5)
	return OPCODE_AE_S16M_L_I;
      if (Field_op2_Slot_inst_get (insn) == 13 &&
	  Field_op1_Slot_inst_get (insn) == 6)
	return OPCODE_AE_S16M_L_IU;
      if (Field_op2_Slot_inst_get (insn) == 13 &&
	  Field_op1_Slot_inst_get (insn) == 7)
	return OPCODE_AE_S16M_L_X;
      if (Field_op2_Slot_inst_get (insn) == 13 &&
	  Field_op1_Slot_inst_get (insn) == 14)
	return OPCODE_AE_S32F24_L_I;
      if (Field_op2_Slot_inst_get (insn) == 13 &&
	  Field_op1_Slot_inst_get (insn) == 15)
	return OPCODE_AE_S32F24_L_IP;
      if (Field_op2_Slot_inst_get (insn) == 13 &&
	  Field_op1_Slot_inst_get (insn) == 2)
	return OPCODE_AE_S16_0_I;
      if (Field_op2_Slot_inst_get (insn) == 13 &&
	  Field_op1_Slot_inst_get (insn) == 3)
	return OPCODE_AE_S16_0_IP;
      if (Field_op2_Slot_inst_get (insn) == 13 &&
	  Field_op1_Slot_inst_get (insn) == 4)
	return OPCODE_AE_S16_0_XP;
      if (Field_op2_Slot_inst_get (insn) == 13 &&
	  Field_op1_Slot_inst_get (insn) == 13)
	return OPCODE_AE_S24RA64S_XP;
      if (Field_op2_Slot_inst_get (insn) == 13 &&
	  Field_op1_Slot_inst_get (insn) == 0)
	return OPCODE_AE_VLEL32T;
      if (Field_op2_Slot_inst_get (insn) == 13 &&
	  Field_op1_Slot_inst_get (insn) == 1)
	return OPCODE_AE_VLEL16T;
      if (Field_op2_Slot_inst_get (insn) == 14 &&
	  Field_op1_Slot_inst_get (insn) == 12)
	return OPCODE_AE_S32X2F24_XC;
      if (Field_op2_Slot_inst_get (insn) == 14 &&
	  Field_op1_Slot_inst_get (insn) == 13)
	return OPCODE_AE_S32X2F24_I;
      if (Field_op2_Slot_inst_get (insn) == 14 &&
	  Field_op1_Slot_inst_get (insn) == 14)
	return OPCODE_AE_S32X2F24_X;
      if (Field_op2_Slot_inst_get (insn) == 14 &&
	  Field_op1_Slot_inst_get (insn) == 15)
	return OPCODE_AE_S32X2F24_XP;
      if (Field_op2_Slot_inst_get (insn) == 14 &&
	  Field_op1_Slot_inst_get (insn) == 8)
	return OPCODE_AE_S32X2_XC;
      if (Field_op2_Slot_inst_get (insn) == 14 &&
	  Field_op1_Slot_inst_get (insn) == 9)
	return OPCODE_AE_S32X2_I;
      if (Field_op2_Slot_inst_get (insn) == 14 &&
	  Field_op1_Slot_inst_get (insn) == 10)
	return OPCODE_AE_S32X2_X;
      if (Field_op2_Slot_inst_get (insn) == 14 &&
	  Field_op1_Slot_inst_get (insn) == 11)
	return OPCODE_AE_S32X2_XP;
      if (Field_op2_Slot_inst_get (insn) == 14 &&
	  Field_op1_Slot_inst_get (insn) == 0)
	return OPCODE_AE_S32_L_I;
      if (Field_op2_Slot_inst_get (insn) == 14 &&
	  Field_op1_Slot_inst_get (insn) == 1)
	return OPCODE_AE_S32_L_IP;
      if (Field_op2_Slot_inst_get (insn) == 14 &&
	  Field_op1_Slot_inst_get (insn) == 2)
	return OPCODE_AE_S32_L_X;
      if (Field_op2_Slot_inst_get (insn) == 14 &&
	  Field_op1_Slot_inst_get (insn) == 3)
	return OPCODE_AE_S32_L_XP;
      if (Field_op2_Slot_inst_get (insn) == 14 &&
	  Field_op1_Slot_inst_get (insn) == 4)
	return OPCODE_AE_S32M_I;
      if (Field_op2_Slot_inst_get (insn) == 14 &&
	  Field_op1_Slot_inst_get (insn) == 5)
	return OPCODE_AE_S32M_IU;
      if (Field_op2_Slot_inst_get (insn) == 14 &&
	  Field_op1_Slot_inst_get (insn) == 6)
	return OPCODE_AE_S32M_X;
      if (Field_op2_Slot_inst_get (insn) == 14 &&
	  Field_op1_Slot_inst_get (insn) == 7)
	return OPCODE_AE_S32M_XU;
      if (Field_op2_Slot_inst_get (insn) == 15)
	return OPCODE_AE_TRUNCA32X2F64S;
    }
  if (Field_op0_Slot_inst_get (insn) == 5)
    {
      if (Field_n_Slot_inst_get (insn) == 0)
	return OPCODE_CALL0;
      if (Field_n_Slot_inst_get (insn) == 1)
	return OPCODE_CALL4;
      if (Field_n_Slot_inst_get (insn) == 2)
	return OPCODE_CALL8;
      if (Field_n_Slot_inst_get (insn) == 3)
	return OPCODE_CALL12;
    }
  if (Field_op0_Slot_inst_get (insn) == 6)
    {
      if (Field_n_Slot_inst_get (insn) == 0)
	return OPCODE_J;
      if (Field_n_Slot_inst_get (insn) == 1)
	{
	  if (Field_m_Slot_inst_get (insn) == 0)
	    return OPCODE_BEQZ;
	  if (Field_m_Slot_inst_get (insn) == 1)
	    return OPCODE_BNEZ;
	  if (Field_m_Slot_inst_get (insn) == 2)
	    return OPCODE_BLTZ;
	  if (Field_m_Slot_inst_get (insn) == 3)
	    return OPCODE_BGEZ;
	}
      if (Field_n_Slot_inst_get (insn) == 2)
	{
	  if (Field_m_Slot_inst_get (insn) == 0)
	    return OPCODE_BEQI;
	  if (Field_m_Slot_inst_get (insn) == 1)
	    return OPCODE_BNEI;
	  if (Field_m_Slot_inst_get (insn) == 2)
	    return OPCODE_BLTI;
	  if (Field_m_Slot_inst_get (insn) == 3)
	    return OPCODE_BGEI;
	}
      if (Field_n_Slot_inst_get (insn) == 3)
	{
	  if (Field_m_Slot_inst_get (insn) == 0)
	    return OPCODE_ENTRY;
	  if (Field_m_Slot_inst_get (insn) == 1)
	    {
	      if (Field_r_Slot_inst_get (insn) == 0)
		return OPCODE_BF;
	      if (Field_r_Slot_inst_get (insn) == 1)
		return OPCODE_BT;
	      if (Field_r_Slot_inst_get (insn) == 8)
		return OPCODE_LOOP;
	      if (Field_r_Slot_inst_get (insn) == 9)
		return OPCODE_LOOPNEZ;
	      if (Field_r_Slot_inst_get (insn) == 10)
		return OPCODE_LOOPGTZ;
	    }
	  if (Field_m_Slot_inst_get (insn) == 2)
	    return OPCODE_BLTUI;
	  if (Field_m_Slot_inst_get (insn) == 3)
	    return OPCODE_BGEUI;
	}
    }
  if (Field_op0_Slot_inst_get (insn) == 7)
    {
      if (Field_r_Slot_inst_get (insn) == 0)
	return OPCODE_BNONE;
      if (Field_r_Slot_inst_get (insn) == 1)
	return OPCODE_BEQ;
      if (Field_r_Slot_inst_get (insn) == 2)
	return OPCODE_BLT;
      if (Field_r_Slot_inst_get (insn) == 3)
	return OPCODE_BLTU;
      if (Field_r_Slot_inst_get (insn) == 4)
	return OPCODE_BALL;
      if (Field_r_Slot_inst_get (insn) == 5)
	return OPCODE_BBC;
      if ((Field_r_Slot_inst_get (insn) == 6 ||
	   Field_r_Slot_inst_get (insn) == 7))
	return OPCODE_BBCI;
      if (Field_r_Slot_inst_get (insn) == 8)
	return OPCODE_BANY;
      if (Field_r_Slot_inst_get (insn) == 9)
	return OPCODE_BNE;
      if (Field_r_Slot_inst_get (insn) == 10)
	return OPCODE_BGE;
      if (Field_r_Slot_inst_get (insn) == 11)
	return OPCODE_BGEU;
      if (Field_r_Slot_inst_get (insn) == 12)
	return OPCODE_BNALL;
      if (Field_r_Slot_inst_get (insn) == 13)
	return OPCODE_BBS;
      if ((Field_r_Slot_inst_get (insn) == 14 ||
	   Field_r_Slot_inst_get (insn) == 15))
	return OPCODE_BBSI;
    }
  return XTENSA_UNDEFINED;
}

static int
Slot_inst16b_decode (const xtensa_insnbuf insn)
{
  if (Field_op0_Slot_inst16b_get (insn) == 12)
    {
      if (Field_i_Slot_inst16b_get (insn) == 0)
	return OPCODE_MOVI_N;
      if (Field_i_Slot_inst16b_get (insn) == 1)
	{
	  if (Field_z_Slot_inst16b_get (insn) == 0)
	    return OPCODE_BEQZ_N;
	  if (Field_z_Slot_inst16b_get (insn) == 1)
	    return OPCODE_BNEZ_N;
	}
    }
  if (Field_op0_Slot_inst16b_get (insn) == 13)
    {
      if (Field_r_Slot_inst16b_get (insn) == 0)
	return OPCODE_MOV_N;
      if (Field_r_Slot_inst16b_get (insn) == 15)
	{
	  if (Field_t_Slot_inst16b_get (insn) == 0)
	    return OPCODE_RET_N;
	  if (Field_t_Slot_inst16b_get (insn) == 1)
	    return OPCODE_RETW_N;
	  if (Field_t_Slot_inst16b_get (insn) == 2)
	    return OPCODE_BREAK_N;
	  if (Field_t_Slot_inst16b_get (insn) == 3 &&
	      Field_s_Slot_inst16b_get (insn) == 0)
	    return OPCODE_NOP_N;
	  if (Field_t_Slot_inst16b_get (insn) == 6 &&
	      Field_s_Slot_inst16b_get (insn) == 0)
	    return OPCODE_ILL_N;
	}
    }
  return XTENSA_UNDEFINED;
}

static int
Slot_inst16a_decode (const xtensa_insnbuf insn)
{
  if (Field_op0_Slot_inst16a_get (insn) == 8)
    return OPCODE_L32I_N;
  if (Field_op0_Slot_inst16a_get (insn) == 9)
    return OPCODE_S32I_N;
  if (Field_op0_Slot_inst16a_get (insn) == 10)
    return OPCODE_ADD_N;
  if (Field_op0_Slot_inst16a_get (insn) == 11)
    return OPCODE_ADDI_N;
  return XTENSA_UNDEFINED;
}

static int
Slot_xt_flix64_slot2_decode (const xtensa_insnbuf insn)
{
  if (Field_fld_xt_flix64_slot2_15_0_Slot_xt_flix64_slot2_get (insn) == 57600)
    return OPCODE_NOP;
  if (Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get (insn) == 2)
    return OPCODE_ADD;
  if (Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get (insn) == 3)
    return OPCODE_ADDI_N;
  if (Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get (insn) == 4)
    return OPCODE_ADDX2;
  if (Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get (insn) == 5)
    return OPCODE_ADDX4;
  if (Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get (insn) == 6)
    return OPCODE_AND;
  if (Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get (insn) == 7)
    return OPCODE_OR;
  if (Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get (insn) == 8)
    return OPCODE_SEXT;
  if (Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get (insn) == 9)
    return OPCODE_SUB;
  if (Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get (insn) == 10)
    return OPCODE_XOR;
  if (Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get (insn) == 11)
    return OPCODE_SRLI;
  if (Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get (insn) == 12 &&
      Field_fld_xt_flix64_slot2_3_3_Slot_xt_flix64_slot2_get (insn) == 0)
    return OPCODE_MOVI_N;
  if (Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get (insn) == 13 &&
      Field_fld_xt_flix64_slot2_7_4_Slot_xt_flix64_slot2_get (insn) == 0)
    return OPCODE_ABS;
  if (Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get (insn) == 13 &&
      Field_fld_xt_flix64_slot2_7_4_Slot_xt_flix64_slot2_get (insn) == 1)
    return OPCODE_NEG;
  if (Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get (insn) == 13 &&
      Field_fld_xt_flix64_slot2_7_4_Slot_xt_flix64_slot2_get (insn) == 2)
    return OPCODE_SRA;
  if (Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get (insn) == 13 &&
      Field_fld_xt_flix64_slot2_7_4_Slot_xt_flix64_slot2_get (insn) == 3)
    return OPCODE_SRL;
  if (Field_fld_xt_flix64_slot2_15_13_Slot_xt_flix64_slot2_get (insn) == 0)
    return OPCODE_SRAI;
  if (Field_fld_xt_flix64_slot2_15_8_Slot_xt_flix64_slot2_get (insn) == 224)
    return OPCODE_MOV_N;
  return XTENSA_UNDEFINED;
}

static int
Slot_xt_flix64_slot0_decode (const xtensa_insnbuf insn)
{
  if (Field_fld_xt_flix64_slot0_20_0_Slot_xt_flix64_slot0_get (insn) == 1962784)
    return OPCODE_NOP;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 452)
    return OPCODE_ADD;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 453)
    return OPCODE_ADDX2;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 454)
    return OPCODE_ADDX4;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 455)
    return OPCODE_ADDX8;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 456)
    return OPCODE_AND;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 457)
    return OPCODE_MAX;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 458)
    return OPCODE_MAXU;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 459)
    return OPCODE_MIN;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 460)
    return OPCODE_MINU;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 461)
    return OPCODE_MOVEQZ;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 462)
    return OPCODE_MOVGEZ;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 463)
    return OPCODE_MOVLTZ;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 464)
    return OPCODE_MOVNEZ;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 465)
    return OPCODE_MUL16S;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 466)
    return OPCODE_MUL16U;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 467)
    return OPCODE_MULL;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 468)
    return OPCODE_OR;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 469)
    return OPCODE_SRC;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 470)
    return OPCODE_SUB;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 471)
    return OPCODE_SUBX2;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 472)
    return OPCODE_SUBX4;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 473)
    return OPCODE_SUBX8;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 474)
    return OPCODE_XOR;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 475)
    return OPCODE_CLAMPS;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 476)
    return OPCODE_SEXT;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 477)
    return OPCODE_SRLI;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 478 &&
      Field_fld_xt_flix64_slot0_7_4_Slot_xt_flix64_slot0_get (insn) == 0)
    return OPCODE_ABS;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 478 &&
      Field_fld_xt_flix64_slot0_7_4_Slot_xt_flix64_slot0_get (insn) == 1)
    return OPCODE_NEG;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 478 &&
      Field_fld_xt_flix64_slot0_7_4_Slot_xt_flix64_slot0_get (insn) == 2)
    return OPCODE_SRA;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 478 &&
      Field_fld_xt_flix64_slot0_7_4_Slot_xt_flix64_slot0_get (insn) == 3)
    return OPCODE_SRL;
  if (Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get (insn) == 480 &&
      Field_fld_xt_flix64_slot0_3_0_Slot_xt_flix64_slot0_get (insn) == 0)
    return OPCODE_SLL;
  if (Field_fld_xt_flix64_slot0_20_13_Slot_xt_flix64_slot0_get (insn) == 224)
    return OPCODE_SLLI;
  if (Field_fld_xt_flix64_slot0_20_13_Slot_xt_flix64_slot0_get (insn) == 225)
    return OPCODE_SRAI;
  if (Field_fld_xt_flix64_slot0_20_16_Slot_xt_flix64_slot0_get (insn) == 18)
    return OPCODE_ADDI;
  if (Field_fld_xt_flix64_slot0_20_16_Slot_xt_flix64_slot0_get (insn) == 19)
    return OPCODE_ADDMI;
  if (Field_fld_xt_flix64_slot0_20_16_Slot_xt_flix64_slot0_get (insn) == 20)
    return OPCODE_L16SI;
  if (Field_fld_xt_flix64_slot0_20_16_Slot_xt_flix64_slot0_get (insn) == 21)
    return OPCODE_L16UI;
  if (Field_fld_xt_flix64_slot0_20_16_Slot_xt_flix64_slot0_get (insn) == 22)
    return OPCODE_L32I;
  if (Field_fld_xt_flix64_slot0_20_16_Slot_xt_flix64_slot0_get (insn) == 23)
    return OPCODE_L8UI;
  if (Field_fld_xt_flix64_slot0_20_16_Slot_xt_flix64_slot0_get (insn) == 24)
    return OPCODE_S16I;
  if (Field_fld_xt_flix64_slot0_20_16_Slot_xt_flix64_slot0_get (insn) == 25)
    return OPCODE_S32I;
  if (Field_fld_xt_flix64_slot0_20_16_Slot_xt_flix64_slot0_get (insn) == 26)
    return OPCODE_S8I;
  if (Field_fld_xt_flix64_slot0_20_16_Slot_xt_flix64_slot0_get (insn) == 27)
    return OPCODE_MOVI;
  if (Field_fld_xt_flix64_slot0_20_17_Slot_xt_flix64_slot0_get (insn) == 8)
    return OPCODE_EXTUI;
  if (Field_fld_xt_flix64_slot0_20_20_Slot_xt_flix64_slot0_get (insn) == 0)
    return OPCODE_L32R;
  if (Field_fld_xt_flix64_slot0_20_5_Slot_xt_flix64_slot0_get (insn) == 61336)
    return OPCODE_SSAI;
  if (Field_fld_xt_flix64_slot0_20_8_Slot_xt_flix64_slot0_get (insn) == 7664)
    return OPCODE_MOV_N;
  if (Field_fld_xt_flix64_slot0_20_8_Slot_xt_flix64_slot0_get (insn) == 7665)
    return OPCODE_NSA;
  if (Field_fld_xt_flix64_slot0_20_8_Slot_xt_flix64_slot0_get (insn) == 7666)
    return OPCODE_NSAU;
  if (Field_fld_xt_flix64_slot0_20_8_Slot_xt_flix64_slot0_get (insn) == 7680 &&
      Field_fld_xt_flix64_slot0_3_0_Slot_xt_flix64_slot0_get (insn) == 1)
    return OPCODE_SSA8B;
  if (Field_fld_xt_flix64_slot0_20_8_Slot_xt_flix64_slot0_get (insn) == 7681 &&
      Field_fld_xt_flix64_slot0_3_0_Slot_xt_flix64_slot0_get (insn) == 1)
    return OPCODE_SSA8L;
  if (Field_fld_xt_flix64_slot0_20_8_Slot_xt_flix64_slot0_get (insn) == 7682 &&
      Field_fld_xt_flix64_slot0_3_0_Slot_xt_flix64_slot0_get (insn) == 1)
    return OPCODE_SSL;
  if (Field_fld_xt_flix64_slot0_20_8_Slot_xt_flix64_slot0_get (insn) == 7683 &&
      Field_fld_xt_flix64_slot0_3_0_Slot_xt_flix64_slot0_get (insn) == 1)
    return OPCODE_SSR;
  return XTENSA_UNDEFINED;
}

static int
Slot_xt_flix64_slot1_decode (const xtensa_insnbuf insn)
{
  if (Field_fld_xt_flix64_slot1_19_0_Slot_xt_flix64_slot1_get (insn) == 688641)
    return OPCODE_NOP;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 148)
    return OPCODE_ADD;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 149)
    return OPCODE_ADDX2;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 150)
    return OPCODE_ADDX4;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 151)
    return OPCODE_ADDX8;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 152)
    return OPCODE_AND;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 153)
    return OPCODE_MOVEQZ;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 154)
    return OPCODE_MOVGEZ;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 155)
    return OPCODE_MOVLTZ;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 156)
    return OPCODE_MOVNEZ;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 157)
    return OPCODE_MUL16S;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 158)
    return OPCODE_MUL16U;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 159)
    return OPCODE_MULL;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 160)
    return OPCODE_OR;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 161)
    return OPCODE_SRC;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 162)
    return OPCODE_SUB;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 163)
    return OPCODE_XOR;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 164)
    return OPCODE_SEXT;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 165)
    return OPCODE_SRLI;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 166 &&
      Field_fld_xt_flix64_slot1_7_4_Slot_xt_flix64_slot1_get (insn) == 0)
    return OPCODE_NEG;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 166 &&
      Field_fld_xt_flix64_slot1_7_4_Slot_xt_flix64_slot1_get (insn) == 1)
    return OPCODE_SRA;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 166 &&
      Field_fld_xt_flix64_slot1_7_4_Slot_xt_flix64_slot1_get (insn) == 2)
    return OPCODE_SRL;
  if (Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get (insn) == 168 &&
      Field_fld_xt_flix64_slot1_3_0_Slot_xt_flix64_slot1_get (insn) == 0)
    return OPCODE_SLL;
  if (Field_fld_xt_flix64_slot1_19_13_Slot_xt_flix64_slot1_get (insn) == 72)
    return OPCODE_SLLI;
  if (Field_fld_xt_flix64_slot1_19_13_Slot_xt_flix64_slot1_get (insn) == 73)
    return OPCODE_SRAI;
  if (Field_fld_xt_flix64_slot1_19_16_Slot_xt_flix64_slot1_get (insn) == 6)
    return OPCODE_ADDI;
  if (Field_fld_xt_flix64_slot1_19_16_Slot_xt_flix64_slot1_get (insn) == 7)
    return OPCODE_ADDMI;
  if (Field_fld_xt_flix64_slot1_19_16_Slot_xt_flix64_slot1_get (insn) == 8)
    return OPCODE_MOVI;
  if (Field_fld_xt_flix64_slot1_19_17_Slot_xt_flix64_slot1_get (insn) == 2)
    return OPCODE_EXTUI;
  if (Field_fld_xt_flix64_slot1_19_18_Slot_xt_flix64_slot1_get (insn) == 0)
    return OPCODE_J;
  if (Field_fld_xt_flix64_slot1_19_8_Slot_xt_flix64_slot1_get (insn) == 2672)
    return OPCODE_MOV_N;
  if (Field_fld_xt_flix64_slot1_19_8_Slot_xt_flix64_slot1_get (insn) == 2688 &&
      Field_fld_xt_flix64_slot1_3_0_Slot_xt_flix64_slot1_get (insn) == 1)
    return OPCODE_JX;
  if (Field_fld_xt_flix64_slot1_19_8_Slot_xt_flix64_slot1_get (insn) == 2689 &&
      Field_fld_xt_flix64_slot1_3_0_Slot_xt_flix64_slot1_get (insn) == 1)
    return OPCODE_SSL;
  return XTENSA_UNDEFINED;
}

static int
Slot_ae2_slot0_decode (const xtensa_insnbuf insn)
{
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524496)
    return OPCODE_ADD;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524497)
    return OPCODE_ADDX2;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524498)
    return OPCODE_ADDX4;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524499)
    return OPCODE_ADDX8;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524500)
    return OPCODE_AE_ADDBRBA32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524501)
    return OPCODE_MOVEQZ;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524502)
    return OPCODE_MOVGEZ;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524503)
    return OPCODE_MOVLTZ;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524504)
    return OPCODE_MOVNEZ;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524505)
    return OPCODE_OR;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524506)
    return OPCODE_SUB;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524507)
    return OPCODE_SUBX2;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524508)
    return OPCODE_SUBX4;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524509)
    return OPCODE_SUBX8;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524510)
    return OPCODE_CLAMPS;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524511)
    return OPCODE_SEXT;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524512)
    return OPCODE_AE_CVTP24A16X2_HH;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524513)
    return OPCODE_AE_CVTP24A16X2_HL;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524514)
    return OPCODE_AE_CVTP24A16X2_LH;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524515)
    return OPCODE_AE_CVTP24A16X2_LL;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524516)
    return OPCODE_AE_MOVDA16X2;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524517)
    return OPCODE_AE_MOVDA32X2;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524518)
    return OPCODE_AE_TRUNCP24A32X2;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524519)
    return OPCODE_AE_L16M_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524520)
    return OPCODE_AE_L16M_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524521)
    return OPCODE_AE_L16M_XU;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524522)
    return OPCODE_AE_L16X2M_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524523)
    return OPCODE_AE_L16X2M_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524524)
    return OPCODE_AE_L16X2M_XU;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524525)
    return OPCODE_AE_L16X4_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524526)
    return OPCODE_AE_L16X4_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524527)
    return OPCODE_AE_L16X4_XP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524528)
    return OPCODE_AE_L16_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524529)
    return OPCODE_AE_L16_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524530)
    return OPCODE_AE_L16_XP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524531)
    return OPCODE_AE_L32F24_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524532)
    return OPCODE_AE_L32F24_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524533)
    return OPCODE_AE_L32F24_XP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524534)
    return OPCODE_AE_L32M_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524535)
    return OPCODE_AE_L32M_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524536)
    return OPCODE_AE_L32M_XU;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524537)
    return OPCODE_AE_L32X2F24_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524538)
    return OPCODE_AE_L32X2F24_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524539)
    return OPCODE_AE_L32X2F24_XP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524540)
    return OPCODE_AE_L32X2_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524541)
    return OPCODE_AE_L32X2_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524542)
    return OPCODE_AE_L32X2_XP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524543)
    return OPCODE_AE_L32_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524544)
    return OPCODE_AE_L32_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524545)
    return OPCODE_AE_L32_XP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524546)
    return OPCODE_AE_L64_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524547)
    return OPCODE_AE_L64_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524548)
    return OPCODE_AE_L64_XP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524549)
    return OPCODE_AE_S16M_L_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524550)
    return OPCODE_AE_S16M_L_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524551)
    return OPCODE_AE_S16M_L_XU;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524552)
    return OPCODE_AE_S16X2M_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524553)
    return OPCODE_AE_S16X2M_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524554)
    return OPCODE_AE_S16X2M_XU;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524555)
    return OPCODE_AE_S16X4_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524556)
    return OPCODE_AE_S16X4_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524557)
    return OPCODE_AE_S16X4_XP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524558)
    return OPCODE_AE_S16_0_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524559)
    return OPCODE_AE_S16_0_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524560)
    return OPCODE_AE_S16_0_XP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524561)
    return OPCODE_AE_S24RA64S_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524562)
    return OPCODE_AE_S24RA64S_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524563)
    return OPCODE_AE_S24RA64S_XP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524564)
    return OPCODE_AE_S32F24_L_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524565)
    return OPCODE_AE_S32F24_L_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524566)
    return OPCODE_AE_S32F24_L_XP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524567)
    return OPCODE_AE_S32M_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524568)
    return OPCODE_AE_S32M_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524569)
    return OPCODE_AE_S32M_XU;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524570)
    return OPCODE_AE_S32RA64S_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524571)
    return OPCODE_AE_S32RA64S_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524572)
    return OPCODE_AE_S32RA64S_XP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524573)
    return OPCODE_AE_S32X2F24_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524574)
    return OPCODE_AE_S32X2F24_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524575)
    return OPCODE_AE_S32X2F24_XP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524576)
    return OPCODE_AE_S32X2_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524577)
    return OPCODE_AE_S32X2_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524578)
    return OPCODE_AE_S32X2_XP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524579)
    return OPCODE_AE_S32_L_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524580)
    return OPCODE_AE_S32_L_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524581)
    return OPCODE_AE_S32_L_XP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524582)
    return OPCODE_AE_S64_X;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524583)
    return OPCODE_AE_S64_XC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524584)
    return OPCODE_AE_S64_XP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524585)
    return OPCODE_AE_S24X2RA64S_IP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524586)
    return OPCODE_AE_S32X2RA64S_IP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524587)
    return OPCODE_AE_ADD16;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524588)
    return OPCODE_AE_ADD16S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524589)
    return OPCODE_AE_ADD24S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524590)
    return OPCODE_AE_ADD32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524591)
    return OPCODE_AE_ADD32S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524592)
    return OPCODE_AE_ADD32_HL_LH;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524593)
    return OPCODE_AE_ADD64;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524594)
    return OPCODE_AE_ADD64S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524595)
    return OPCODE_AE_ADDSQ56S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524596)
    return OPCODE_AE_ADDSUB32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524597)
    return OPCODE_AE_ADDSUB32S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524598)
    return OPCODE_AE_ROUND16X4F32SASYM;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524599)
    return OPCODE_AE_ROUND16X4F32SSYM;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524600)
    return OPCODE_AE_ROUND24X2F48SASYM;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524601)
    return OPCODE_AE_ROUND24X2F48SSYM;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524602)
    return OPCODE_AE_ROUND32X2F48SASYM;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524603)
    return OPCODE_AE_ROUND32X2F48SSYM;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524604)
    return OPCODE_AE_ROUND32X2F64SASYM;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524605)
    return OPCODE_AE_ROUND32X2F64SSYM;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524606)
    return OPCODE_AE_ROUNDSP16Q48X2ASYM;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524607)
    return OPCODE_AE_ROUNDSP16Q48X2SYM;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524608)
    return OPCODE_AE_SAT16X4;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524609)
    return OPCODE_AE_SUB16;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524610)
    return OPCODE_AE_SUB16S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524611)
    return OPCODE_AE_SUB24S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524612)
    return OPCODE_AE_SUB32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524613)
    return OPCODE_AE_SUB32S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524614)
    return OPCODE_AE_SUB64;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524615)
    return OPCODE_AE_SUB64S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524616)
    return OPCODE_AE_SUBADD32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524617)
    return OPCODE_AE_SUBADD32S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524618)
    return OPCODE_AE_SUBSQ56S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524619)
    return OPCODE_AE_EQ64;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524620)
    return OPCODE_AE_LE64;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524621)
    return OPCODE_AE_LT64;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524622)
    return OPCODE_AE_MAX32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524623)
    return OPCODE_AE_MAX64;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524624)
    return OPCODE_AE_MAXABS32S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524625)
    return OPCODE_AE_MAXABS64S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524626)
    return OPCODE_AE_MIN32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524627)
    return OPCODE_AE_MIN64;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524628)
    return OPCODE_AE_MINABS32S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524629)
    return OPCODE_AE_MINABS64S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524630)
    return OPCODE_AE_AND;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524631)
    return OPCODE_AE_NAND;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524632)
    return OPCODE_AE_OR;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524633)
    return OPCODE_AE_SEXT32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524634)
    return OPCODE_AE_TRUNCP24Q48X2;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524635)
    return OPCODE_AE_XOR;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524636)
    return OPCODE_AE_MOVF64;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524637)
    return OPCODE_AE_MOVT64;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524638 &&
      Field_fld_ae2_slot0_8_8_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_LE32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524638 &&
      Field_fld_ae2_slot0_8_8_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_EQ32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524639 &&
      Field_fld_ae2_slot0_9_8_Slot_ae2_slot0_get (insn) == 3)
    return OPCODE_AE_LE16;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524639 &&
      Field_fld_ae2_slot0_9_8_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_EQ16;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524639 &&
      Field_fld_ae2_slot0_8_8_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LT32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524680 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_L16X4_RIC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524680 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA24X2_IC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524680 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA16X4_IC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524680 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA16X4_IP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524680 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_MOVDA32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524681 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_L32X2F24_RIC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524681 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_L16X4_RIP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524681 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA24X2_IP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524681 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA16X4_RIP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524681 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA16X4_RIC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524682 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_L32X2F24_RIP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524682 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_L32X2_RIC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524682 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA24X2_RIC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524682 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA24X2_IC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524682 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA24X2_IP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524683 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_L32X2_RIP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524683 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_S16X4_RIC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524683 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA24X2_RIP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524683 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA24X2_RIP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524683 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA24X2_RIC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524684 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_S32X2F24_RIC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524684 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_S16X4_RIP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524684 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA24_IC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524684 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA24_L_IC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524684 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA24_L_IP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524685 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_S32X2F24_RIP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524685 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_S32X2_RIC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524685 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA24_IP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524685 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA24_L_RIP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524685 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA24_L_RIC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524686 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_S32X2_RIP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524686 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA24_RIC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524686 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA32X2F24_IC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524686 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA32X2F24_IP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524686 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_ROUNDSP16F24ASYM;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524687 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA24_RIP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524687 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA32X2F24_RIP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524687 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA32X2F24_RIC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524687 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_CVTA32F24S_H;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524687 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_ROUNDSP16F24SYM;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524704 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_LA16X4_IC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524704 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_LA16X4_IP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524705 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA32X2F24_IC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524705 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA32X2F24_IP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524705 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_LA32X2F24_RIP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524705 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_LA32X2F24_RIC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524706 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_SA32X2_IC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524706 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_SA32X2_IP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524706 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA32X2_RIP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524706 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA32X2_RIC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524707 &&
      Field_fld_ae2_slot0_9_8_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LT16;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524708 &&
      Field_fld_ae2_slot0_5_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_MOVI;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524708 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_CVTA32F24S_L;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524708 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 13)
    return OPCODE_AE_MOVAD32_L;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524708 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 11)
    return OPCODE_AE_MOVAD32_H;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524708 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 9)
    return OPCODE_AE_MOVAD16_3;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524708 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 7)
    return OPCODE_AE_MOVAD16_2;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524708 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 5)
    return OPCODE_AE_MOVAD16_1;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524708 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 3)
    return OPCODE_AE_MOVAD16_0;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524708 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 15)
    return OPCODE_AE_NSA64;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524709 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_SATQ56S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524709 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SAT24S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524709 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_ROUNDSQ32F48ASYM;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524712 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_LA16X4_RIP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524712 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_LA16X4_RIC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524713 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA32X2_IC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524713 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA32X2_IP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524713 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_LA32X2_RIP;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524713 &&
      Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_LA32X2_RIC;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524714 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_CVT32X2F16_32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524714 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 4)
    return OPCODE_AE_CVT32X2F16_10;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524714 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 5)
    return OPCODE_AE_SEXT32X2D16_32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524714 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 3)
    return OPCODE_AE_SEXT32X2D16_10;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524714 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_TRUNCP16;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524714 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_MOV;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524714 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_TRUNCQ32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524715 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 11)
    return OPCODE_AE_NEG32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524715 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_ABS32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524715 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 10)
    return OPCODE_AE_NEG24S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524715 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_ABS24S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524715 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 12)
    return OPCODE_AE_NEG32S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524715 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 3)
    return OPCODE_AE_ABS32S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524715 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 9)
    return OPCODE_AE_NEG16S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524715 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_ABS16S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524715 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 13)
    return OPCODE_AE_NEG64;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524715 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 4)
    return OPCODE_AE_ABS64;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524715 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 15)
    return OPCODE_AE_NEGSQ56S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524715 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_ABSSQ56S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524715 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 14)
    return OPCODE_AE_NEG64S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524715 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 5)
    return OPCODE_AE_ABS64S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524715 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 7)
    return OPCODE_AE_DIV64D32_H;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524715 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 8)
    return OPCODE_AE_DIV64D32_L;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524716 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 14)
    return OPCODE_AE_MOVDA16;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524716 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 10)
    return OPCODE_AE_CVTQ56A32S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524716 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_CVT48A32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524716 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_CVT64A32;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524716 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 15)
    return OPCODE_AE_CVTQ56P32S_L;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524716 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 13)
    return OPCODE_AE_CVTQ56P32S_H;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524716 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 11)
    return OPCODE_AE_CVT64F32_H;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524716 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 9)
    return OPCODE_AE_TRUNCA32Q48;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524716 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 7)
    return OPCODE_AE_TRUNCA16P24S_L;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524716 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 5)
    return OPCODE_AE_TRUNCA16P24S_H;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524716 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_NSAZ16_0;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524716 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 3)
    return OPCODE_AE_NSAZ32_L;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524717 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SAT48S;
  if (Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get (insn) == 524717 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_ROUNDSQ32F48SYM;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65580 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_L16M_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65580 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 4)
    return OPCODE_AE_L16M_IU;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65580 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 5)
    return OPCODE_AE_L16_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65580 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 3)
    return OPCODE_AE_L16_IP;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65580 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 7)
    return OPCODE_AE_L32F24_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65580 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_L16X2M_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65580 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_L16X2M_IU;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65580 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_L16X4_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65581 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_L32F24_IP;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65581 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 5)
    return OPCODE_AE_L32_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65581 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 3)
    return OPCODE_AE_L32_IP;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65581 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 4)
    return OPCODE_AE_L32M_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65581 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_L32M_IU;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65581 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_L32X2F24_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65581 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_L32X2_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65581 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 7)
    return OPCODE_AE_L64_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65582 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_L64_IP;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65582 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_S16X2M_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65582 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_S16X2M_IU;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65582 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 5)
    return OPCODE_AE_S16X4_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65582 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 4)
    return OPCODE_AE_S16M_L_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65582 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_S16M_L_IU;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65582 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 3)
    return OPCODE_AE_S16_0_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65582 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 7)
    return OPCODE_AE_S16_0_IP;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65583 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_S32F24_L_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65583 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_S32F24_L_IP;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65583 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_S32M_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65583 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 5)
    return OPCODE_AE_S32M_IU;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65583 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 3)
    return OPCODE_AE_S32RA64S_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65583 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 7)
    return OPCODE_AE_S32RA64S_IP;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65583 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_S24RA64S_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65583 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 4)
    return OPCODE_AE_S24RA64S_IP;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65584 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 7)
    return OPCODE_AE_L32X2F24_IP;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65584 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 11)
    return OPCODE_AE_L32X2_IP;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65584 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 3)
    return OPCODE_AE_L16X4_IP;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65584 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_S32X2F24_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65584 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 4)
    return OPCODE_AE_S32X2_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65584 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 15)
    return OPCODE_AE_S16X4_IP;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65584 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_S32_L_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65584 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_S32_L_IP;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65584 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_S64_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65584 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 5)
    return OPCODE_AE_S64_IP;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65585 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_S32X2F24_IP;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65585 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 4)
    return OPCODE_AE_S32X2_IP;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65586 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 7 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LALIGN64_I;
  if (Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get (insn) == 65586 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 7 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SALIGN64_I;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32770)
    return OPCODE_AE_TRUNCA32F64S_L;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32771)
    return OPCODE_AE_TRUNCA32X2F64S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32772)
    return OPCODE_ADDI;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32773)
    return OPCODE_ADDMI;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32774)
    return OPCODE_MOVI;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32775)
    return OPCODE_AE_TRUNCI32F64S_L;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32776)
    return OPCODE_AE_TRUNCI32X2F64S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32777)
    return OPCODE_AE_SEL16I;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32778 &&
      Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_0_0_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_SLAI64;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32778 &&
      Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_0_0_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SRAI64;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32778 &&
      Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_0_0_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_SLAISQ56S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32778 &&
      Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_0_0_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SLAI64S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32779 &&
      Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_1_0_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SLAI24;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32779 &&
      Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_1_0_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_SRAI24;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32779 &&
      Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_1_0_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_SLAI32;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32779 &&
      Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_1_0_Slot_ae2_slot0_get (insn) == 3)
    return OPCODE_AE_SRAI32;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32779 &&
      Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_1_0_Slot_ae2_slot0_get (insn) == 3)
    return OPCODE_AE_SLAI24S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32779 &&
      Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_1_0_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SLAI32S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32779 &&
      Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_0_0_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_SRLI64;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32780 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 15)
    return OPCODE_AE_SRA64_32;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32780 &&
      Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_1_0_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SRLI24;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32780 &&
      Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_1_0_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_SRLI32;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32780 &&
      Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_1_0_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_SRAI32R;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32780 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 12)
    return OPCODE_AE_SLAA32;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32780 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 8)
    return OPCODE_AE_SLAA16S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32780 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 10)
    return OPCODE_AE_SLAA32S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32780 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 13)
    return OPCODE_AE_SLAAQ56;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32780 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 14)
    return OPCODE_AE_SLAA64;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32780 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11)
    return OPCODE_AE_SLAASQ56S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32780 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 9)
    return OPCODE_AE_SLAA64S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_SLAS24;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 12)
    return OPCODE_AE_SRLS24;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 8)
    return OPCODE_AE_SRAS24;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 13)
    return OPCODE_AE_SRAI16;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 3)
    return OPCODE_AE_SRAI16R;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_SLAS32;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 13)
    return OPCODE_AE_SRLS32;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 9)
    return OPCODE_AE_SRAS32;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 14)
    return OPCODE_AE_SRLA32;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 8)
    return OPCODE_AE_SRAA32;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 9)
    return OPCODE_AE_SLAI16S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 4)
    return OPCODE_AE_SRAA16S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_SRAA16RS;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SLAS24S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 3)
    return OPCODE_AE_SLAS32S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_SRAA32S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 12)
    return OPCODE_AE_SRAA32RS;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_SLASQ56;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 15)
    return OPCODE_AE_SRLSQ56;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 11)
    return OPCODE_AE_SRASQ56;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 5)
    return OPCODE_AE_SRLAQ56;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 10)
    return OPCODE_AE_SRAAQ56;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 4)
    return OPCODE_AE_SLAS64;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 14)
    return OPCODE_AE_SRLS64;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 10)
    return OPCODE_AE_SRAS64;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SRLA64;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_AE_SRAA64;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 7)
    return OPCODE_AE_SLASSQ56S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32793 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11 &&
      Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get (insn) == 5)
    return OPCODE_AE_SLAS64S;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32794 &&
      Field_fld_ae2_slot0_14_12_Slot_ae2_slot0_get (insn) == 4 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 4)
    return OPCODE_AE_MOVT16X4;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32794 &&
      Field_fld_ae2_slot0_14_12_Slot_ae2_slot0_get (insn) == 4 &&
      Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_MOVF16X4;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32794 &&
      Field_fld_ae2_slot0_14_12_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_5_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_AE_MOVT32X2;
  if (Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get (insn) == 32794 &&
      Field_fld_ae2_slot0_14_12_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_5_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_MOVF32X2;
  if (Field_fld_ae2_slot0_31_17_Slot_ae2_slot0_get (insn) == 16384)
    return OPCODE_EXTUI;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_9_8_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_BBCI_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_9_8_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_BBSI_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_BALL_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 5)
    return OPCODE_BANY_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 3)
    return OPCODE_BBC_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 7)
    return OPCODE_BBS_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 8)
    return OPCODE_BEQ_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 12)
    return OPCODE_BGEU_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 10)
    return OPCODE_BGE_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 14)
    return OPCODE_BLTU_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 9)
    return OPCODE_BLT_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 13)
    return OPCODE_BNALL_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 11)
    return OPCODE_BNE_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 0 &&
      Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get (insn) == 15)
    return OPCODE_BNONE_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_11_4_Slot_ae2_slot0_get (insn) == 10)
    return OPCODE_BEQZ_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_11_4_Slot_ae2_slot0_get (insn) == 74)
    return OPCODE_BGEZ_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_11_4_Slot_ae2_slot0_get (insn) == 42)
    return OPCODE_BLTZ_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_11_4_Slot_ae2_slot0_get (insn) == 106)
    return OPCODE_BNEZ_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_BEQI_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 4)
    return OPCODE_BGEI_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 6)
    return OPCODE_BLTI_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 12)
    return OPCODE_BNEI_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 2)
    return OPCODE_BGEUI_W18;
  if (Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get (insn) == 1 &&
      Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get (insn) == 8)
    return OPCODE_BLTUI_W18;
  if (Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_get (insn) == 16790626 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_LA16X4POS_PC;
  if (Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_get (insn) == 16790626 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA16X4NEG_PC;
  if (Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_get (insn) == 16790627 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_LA24POS_PC;
  if (Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_get (insn) == 16790627 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA24NEG_PC;
  if (Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_get (insn) == 16790634 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_LA24X2POS_PC;
  if (Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_get (insn) == 16790634 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA24X2NEG_PC;
  if (Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_get (insn) == 16790635 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_LA32X2POS_PC;
  if (Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_get (insn) == 16790635 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA32X2NEG_PC;
  if (Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_get (insn) == 16790642 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_LA64_PP;
  if (Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_get (insn) == 16790642 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 1)
    return OPCODE_AE_SA64NEG_FP;
  if (Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_get (insn) == 16790643 &&
      Field_fld_ae2_slot0_6_0_Slot_ae2_slot0_get (insn) == 21)
    return OPCODE_NOP;
  if (Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_get (insn) == 16790643 &&
      Field_fld_ae2_slot0_4_0_Slot_ae2_slot0_get (insn) == 20)
    return OPCODE_AE_ZALIGN64;
  if (Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_get (insn) == 16790643 &&
      Field_fld_ae2_slot0_4_2_Slot_ae2_slot0_get (insn) == 4)
    return OPCODE_AE_MOVALIGN;
  if (Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_get (insn) == 16790643 &&
      Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get (insn) == 0)
    return OPCODE_AE_SA64POS_FP;
  return XTENSA_UNDEFINED;
}

static int
Slot_ae_minislot2_decode (const xtensa_insnbuf insn)
{
  if (Field_fld_ae_minislot2_18_0_Slot_ae_minislot2_get (insn) == 330576)
    return OPCODE_NOP;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 0)
    return OPCODE_ADDI;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 1)
    return OPCODE_ADDMI;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 2)
    return OPCODE_AE_TRUNCA32F64S_L;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 3)
    return OPCODE_AE_TRUNCA32X2F64S;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 4)
    return OPCODE_MOVI;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_4_Slot_ae_minislot2_get (insn) == 180)
    return OPCODE_AE_MOVDA32;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_4_Slot_ae_minislot2_get (insn) == 179)
    return OPCODE_AE_MOVDA16;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_4_Slot_ae_minislot2_get (insn) == 178)
    return OPCODE_AE_CVTQ56A32S;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_4_Slot_ae_minislot2_get (insn) == 176)
    return OPCODE_AE_CVT48A32;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_4_Slot_ae_minislot2_get (insn) == 177)
    return OPCODE_AE_CVT64A32;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_get (insn) == 4)
    return OPCODE_AE_SLAA32;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_get (insn) == 2)
    return OPCODE_AE_SRAA32;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_get (insn) == 0)
    return OPCODE_AE_SLAA16S;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_get (insn) == 13)
    return OPCODE_AE_SRAA16S;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_get (insn) == 9)
    return OPCODE_AE_SRAA16RS;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_get (insn) == 8)
    return OPCODE_AE_SLAA32S;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_get (insn) == 10)
    return OPCODE_AE_SRAA32S;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_get (insn) == 6)
    return OPCODE_AE_SRAA32RS;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_get (insn) == 5)
    return OPCODE_AE_SLAAQ56;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_get (insn) == 3)
    return OPCODE_AE_SRAAQ56;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_get (insn) == 12)
    return OPCODE_AE_SLAA64;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_get (insn) == 14)
    return OPCODE_AE_SRAA64;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 5 &&
      Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_get (insn) == 1)
    return OPCODE_AE_SLAA64S;
  if (Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get (insn) == 6 &&
      Field_fld_ae_minislot2_9_8_Slot_ae_minislot2_get (insn) == 0 &&
      Field_fld_ae_minislot2_3_0_Slot_ae_minislot2_get (insn) == 0)
    return OPCODE_AE_MOVI;
  if (Field_fld_ae_minislot2_18_8_Slot_ae_minislot2_get (insn) == 1287)
    return OPCODE_AE_MOVAD16_0;
  if (Field_fld_ae_minislot2_18_8_Slot_ae_minislot2_get (insn) == 1303)
    return OPCODE_AE_MOVAD16_1;
  if (Field_fld_ae_minislot2_18_8_Slot_ae_minislot2_get (insn) == 1319)
    return OPCODE_AE_MOVAD16_2;
  if (Field_fld_ae_minislot2_18_8_Slot_ae_minislot2_get (insn) == 1335)
    return OPCODE_AE_MOVAD16_3;
  if (Field_fld_ae_minislot2_18_8_Slot_ae_minislot2_get (insn) == 1351)
    return OPCODE_AE_MOVAD32_H;
  if (Field_fld_ae_minislot2_18_8_Slot_ae_minislot2_get (insn) == 1367)
    return OPCODE_AE_MOVAD32_L;
  return XTENSA_UNDEFINED;
}

static int
Slot_ae_slot0_decode (const xtensa_insnbuf insn)
{
  if (Field_fld_ae_slot0_19_0_Slot_ae_slot0_get (insn) == 905877)
    return OPCODE_NOP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 80)
    return OPCODE_ADD;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 81)
    return OPCODE_ADDX2;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 82)
    return OPCODE_ADDX4;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 83)
    return OPCODE_ADDX8;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 84)
    return OPCODE_AE_ADDBRBA32;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 85)
    return OPCODE_MOVEQZ;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 86)
    return OPCODE_MOVGEZ;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 87)
    return OPCODE_MOVLTZ;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 88)
    return OPCODE_MOVNEZ;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 89)
    return OPCODE_OR;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 90)
    return OPCODE_SUB;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 91)
    return OPCODE_SUBX2;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 92)
    return OPCODE_SUBX4;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 93)
    return OPCODE_SUBX8;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 94)
    return OPCODE_CLAMPS;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 95)
    return OPCODE_SEXT;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 96)
    return OPCODE_AE_MOVDA32X2;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 97)
    return OPCODE_AE_TRUNCP24A32X2;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 98)
    return OPCODE_AE_L16M_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 99)
    return OPCODE_AE_L16M_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 100)
    return OPCODE_AE_L16M_XU;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 101)
    return OPCODE_AE_L16X2M_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 102)
    return OPCODE_AE_L16X2M_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 103)
    return OPCODE_AE_L16X2M_XU;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 104)
    return OPCODE_AE_L16X4_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 105)
    return OPCODE_AE_L16X4_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 106)
    return OPCODE_AE_L16X4_XP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 107)
    return OPCODE_AE_L16_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 108)
    return OPCODE_AE_L16_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 109)
    return OPCODE_AE_L16_XP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 110)
    return OPCODE_AE_L32F24_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 111)
    return OPCODE_AE_L32F24_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 112)
    return OPCODE_AE_L32F24_XP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 113)
    return OPCODE_AE_L32M_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 114)
    return OPCODE_AE_L32M_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 115)
    return OPCODE_AE_L32M_XU;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 116)
    return OPCODE_AE_L32X2F24_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 117)
    return OPCODE_AE_L32X2F24_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 118)
    return OPCODE_AE_L32X2F24_XP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 119)
    return OPCODE_AE_L32X2_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 120)
    return OPCODE_AE_L32X2_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 121)
    return OPCODE_AE_L32X2_XP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 122)
    return OPCODE_AE_L32_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 123)
    return OPCODE_AE_L32_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 124)
    return OPCODE_AE_L32_XP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 125)
    return OPCODE_AE_L64_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 126)
    return OPCODE_AE_L64_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 127)
    return OPCODE_AE_L64_XP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 128)
    return OPCODE_AE_S16M_L_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 129)
    return OPCODE_AE_S16M_L_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 130)
    return OPCODE_AE_S16M_L_XU;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 131)
    return OPCODE_AE_S16X2M_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 132)
    return OPCODE_AE_S16X2M_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 133)
    return OPCODE_AE_S16X2M_XU;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 134)
    return OPCODE_AE_S16X4_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 135)
    return OPCODE_AE_S16X4_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 136)
    return OPCODE_AE_S16X4_XP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 137)
    return OPCODE_AE_S16_0_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 138)
    return OPCODE_AE_S16_0_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 139)
    return OPCODE_AE_S16_0_XP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 140)
    return OPCODE_AE_S24RA64S_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 141)
    return OPCODE_AE_S24RA64S_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 142)
    return OPCODE_AE_S24RA64S_XP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 143)
    return OPCODE_AE_S32F24_L_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 144)
    return OPCODE_AE_S32F24_L_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 145)
    return OPCODE_AE_S32F24_L_XP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 146)
    return OPCODE_AE_S32M_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 147)
    return OPCODE_AE_S32M_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 148)
    return OPCODE_AE_S32M_XU;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 149)
    return OPCODE_AE_S32RA64S_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 150)
    return OPCODE_AE_S32RA64S_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 151)
    return OPCODE_AE_S32RA64S_XP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 152)
    return OPCODE_AE_S32X2F24_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 153)
    return OPCODE_AE_S32X2F24_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 154)
    return OPCODE_AE_S32X2F24_XP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 155)
    return OPCODE_AE_S32X2_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 156)
    return OPCODE_AE_S32X2_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 157)
    return OPCODE_AE_S32X2_XP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 158)
    return OPCODE_AE_S32_L_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 159)
    return OPCODE_AE_S32_L_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 160)
    return OPCODE_AE_S32_L_XP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 161)
    return OPCODE_AE_S64_X;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 162)
    return OPCODE_AE_S64_XC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 163)
    return OPCODE_AE_S64_XP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 164)
    return OPCODE_AE_L16M_I;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 165)
    return OPCODE_AE_L16M_IU;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 166)
    return OPCODE_AE_L16X2M_I;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 167)
    return OPCODE_AE_L16X2M_IU;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 168)
    return OPCODE_AE_L16_I;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 169)
    return OPCODE_AE_L16_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 170)
    return OPCODE_AE_L32F24_I;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 171)
    return OPCODE_AE_L32F24_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 172)
    return OPCODE_AE_L32M_I;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 173)
    return OPCODE_AE_L32M_IU;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 174)
    return OPCODE_AE_L32_I;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 175)
    return OPCODE_AE_L32_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 176)
    return OPCODE_AE_S16M_L_I;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 177)
    return OPCODE_AE_S16M_L_IU;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 178)
    return OPCODE_AE_S16X2M_I;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 179)
    return OPCODE_AE_S16X2M_IU;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 180)
    return OPCODE_AE_S16_0_I;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 181)
    return OPCODE_AE_S16_0_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 182)
    return OPCODE_AE_S24RA64S_I;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 183)
    return OPCODE_AE_S24RA64S_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 184)
    return OPCODE_AE_S32F24_L_I;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 185)
    return OPCODE_AE_S32F24_L_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 186)
    return OPCODE_AE_S32M_I;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 187)
    return OPCODE_AE_S32M_IU;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 188)
    return OPCODE_AE_S32RA64S_I;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 189)
    return OPCODE_AE_S32RA64S_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 190)
    return OPCODE_AE_S32_L_I;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 191)
    return OPCODE_AE_S32_L_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 200 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 6)
    return OPCODE_AE_CVTA32F24S_L;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 200 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 2)
    return OPCODE_AE_CVTA32F24S_H;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 200 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 7)
    return OPCODE_AE_MOVAD32_L;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 200 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 3)
    return OPCODE_AE_MOVAD32_H;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 200 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 15)
    return OPCODE_AE_TRUNCA16P24S_H;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 200 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 10)
    return OPCODE_AE_NSA64;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 200 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 14)
    return OPCODE_AE_NSAZ16_0;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 200 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 11)
    return OPCODE_AE_NSAZ32_L;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 201 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 7)
    return OPCODE_AE_CVT32X2F16_32;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 201 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 3)
    return OPCODE_AE_CVT32X2F16_10;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 201 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 11)
    return OPCODE_AE_SEXT32X2D16_32;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 201 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 14)
    return OPCODE_AE_SEXT32X2D16_10;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 201 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 10)
    return OPCODE_AE_MOV;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 201 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 6)
    return OPCODE_AE_TRUNCA32Q48;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 201 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 2)
    return OPCODE_AE_TRUNCA16P24S_L;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 204 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_L32X2F24_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 204 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_L16X4_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 205 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_L32X2_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 205 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_S16X4_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 206 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_S32X2F24_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 206 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_S32X2_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 207 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_LA16X4_IC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 207 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_LA16X4_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 207 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_LA16X4_RIP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 207 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_LA16X4_RIC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 208 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_LA24X2_IC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 208 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_LA24X2_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 208 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_LA24X2_RIP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 208 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_LA24X2_RIC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 209 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_LA24_IC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 209 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_LA24_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 209 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_LA24_RIP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 209 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_LA24_RIC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 210 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_LA32X2F24_IC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 210 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_LA32X2F24_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 210 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_LA32X2F24_RIP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 210 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_LA32X2F24_RIC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 211 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_LA32X2_IC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 211 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_LA32X2_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 211 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_LA32X2_RIP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 211 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_LA32X2_RIC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 212 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_SA16X4_IC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 212 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_SA16X4_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 212 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_SA16X4_RIP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 212 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_SA16X4_RIC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 213 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_SA24X2_IC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 213 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_SA24X2_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 213 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_SA24X2_RIP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 213 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_SA24X2_RIC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 214 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_SA24_L_IC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 214 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_SA24_L_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 214 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_SA24_L_RIP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 214 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_SA24_L_RIC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 215 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_SA32X2F24_IC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 215 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_SA32X2F24_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 215 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_SA32X2F24_RIP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 215 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_SA32X2F24_RIC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 216 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_SA32X2_IC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 216 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_SA32X2_IP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 216 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 1 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_SA32X2_RIP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 216 &&
      Field_fld_ae_slot0_7_7_Slot_ae_slot0_get (insn) == 0 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_SA32X2_RIC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 217 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 14)
    return OPCODE_AE_L32X2F24_RIP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 217 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 10)
    return OPCODE_AE_L32X2F24_RIC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 217 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 3)
    return OPCODE_AE_L32X2_RIP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 217 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_L32X2_RIC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 217 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 6)
    return OPCODE_AE_L16X4_RIP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 217 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 2)
    return OPCODE_AE_L16X4_RIC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 217 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 11)
    return OPCODE_AE_S32X2F24_RIP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 217 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 9)
    return OPCODE_AE_S32X2F24_RIC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 217 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 15)
    return OPCODE_AE_S32X2_RIP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 217 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 13)
    return OPCODE_AE_S32X2_RIC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 217 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 7)
    return OPCODE_AE_S16X4_RIP;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 217 &&
      Field_fld_ae_slot0_7_4_Slot_ae_slot0_get (insn) == 5)
    return OPCODE_AE_S16X4_RIC;
  if (Field_fld_ae_slot0_19_12_Slot_ae_slot0_get (insn) == 217 &&
      Field_fld_ae_slot0_5_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_MOVI;
  if (Field_fld_ae_slot0_19_14_Slot_ae_slot0_get (insn) == 48 &&
      Field_fld_ae_slot0_6_5_Slot_ae_slot0_get (insn) == 2)
    return OPCODE_AE_L32X2F24_I;
  if (Field_fld_ae_slot0_19_14_Slot_ae_slot0_get (insn) == 48 &&
      Field_fld_ae_slot0_6_5_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_L32X2_I;
  if (Field_fld_ae_slot0_19_14_Slot_ae_slot0_get (insn) == 48 &&
      Field_fld_ae_slot0_6_5_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_L16X4_I;
  if (Field_fld_ae_slot0_19_14_Slot_ae_slot0_get (insn) == 48 &&
      Field_fld_ae_slot0_6_5_Slot_ae_slot0_get (insn) == 3)
    return OPCODE_AE_L64_I;
  if (Field_fld_ae_slot0_19_14_Slot_ae_slot0_get (insn) == 49 &&
      Field_fld_ae_slot0_6_5_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_L64_IP;
  if (Field_fld_ae_slot0_19_14_Slot_ae_slot0_get (insn) == 49 &&
      Field_fld_ae_slot0_6_5_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_S32X2F24_I;
  if (Field_fld_ae_slot0_19_14_Slot_ae_slot0_get (insn) == 49 &&
      Field_fld_ae_slot0_6_5_Slot_ae_slot0_get (insn) == 3)
    return OPCODE_AE_S32X2_I;
  if (Field_fld_ae_slot0_19_14_Slot_ae_slot0_get (insn) == 49 &&
      Field_fld_ae_slot0_6_5_Slot_ae_slot0_get (insn) == 2)
    return OPCODE_AE_S16X4_I;
  if (Field_fld_ae_slot0_19_14_Slot_ae_slot0_get (insn) == 50 &&
      Field_fld_ae_slot0_6_5_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_S64_I;
  if (Field_fld_ae_slot0_19_14_Slot_ae_slot0_get (insn) == 50 &&
      Field_fld_ae_slot0_6_5_Slot_ae_slot0_get (insn) == 2)
    return OPCODE_AE_S64_IP;
  if (Field_fld_ae_slot0_19_14_Slot_ae_slot0_get (insn) == 55 &&
      Field_fld_ae_slot0_11_8_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_LALIGN64_I;
  if (Field_fld_ae_slot0_19_14_Slot_ae_slot0_get (insn) == 55 &&
      Field_fld_ae_slot0_11_8_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_SALIGN64_I;
  if (Field_fld_ae_slot0_19_16_Slot_ae_slot0_get (insn) == 2)
    return OPCODE_ADDI;
  if (Field_fld_ae_slot0_19_16_Slot_ae_slot0_get (insn) == 3)
    return OPCODE_ADDMI;
  if (Field_fld_ae_slot0_19_16_Slot_ae_slot0_get (insn) == 4)
    return OPCODE_MOVI;
  if (Field_fld_ae_slot0_19_17_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_EXTUI;
  if (Field_fld_ae_slot0_19_7_Slot_ae_slot0_get (insn) == 7044 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_LA16X4POS_PC;
  if (Field_fld_ae_slot0_19_7_Slot_ae_slot0_get (insn) == 7044 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_LA16X4NEG_PC;
  if (Field_fld_ae_slot0_19_7_Slot_ae_slot0_get (insn) == 7045 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_LA24POS_PC;
  if (Field_fld_ae_slot0_19_7_Slot_ae_slot0_get (insn) == 7045 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_LA24NEG_PC;
  if (Field_fld_ae_slot0_19_7_Slot_ae_slot0_get (insn) == 7046 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_LA24X2POS_PC;
  if (Field_fld_ae_slot0_19_7_Slot_ae_slot0_get (insn) == 7046 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_LA24X2NEG_PC;
  if (Field_fld_ae_slot0_19_7_Slot_ae_slot0_get (insn) == 7047 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_LA32X2POS_PC;
  if (Field_fld_ae_slot0_19_7_Slot_ae_slot0_get (insn) == 7047 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_LA32X2NEG_PC;
  if (Field_fld_ae_slot0_19_7_Slot_ae_slot0_get (insn) == 7076 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_LA64_PP;
  if (Field_fld_ae_slot0_19_7_Slot_ae_slot0_get (insn) == 7076 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 1)
    return OPCODE_AE_SA64NEG_FP;
  if (Field_fld_ae_slot0_19_7_Slot_ae_slot0_get (insn) == 7077 &&
      Field_fld_ae_slot0_4_0_Slot_ae_slot0_get (insn) == 20)
    return OPCODE_AE_ZALIGN64;
  if (Field_fld_ae_slot0_19_7_Slot_ae_slot0_get (insn) == 7077 &&
      Field_fld_ae_slot0_4_2_Slot_ae_slot0_get (insn) == 4)
    return OPCODE_AE_MOVALIGN;
  if (Field_fld_ae_slot0_19_7_Slot_ae_slot0_get (insn) == 7077 &&
      Field_fld_ae_slot0_4_4_Slot_ae_slot0_get (insn) == 0)
    return OPCODE_AE_SA64POS_FP;
  return XTENSA_UNDEFINED;
}

static int
Slot_ae2_slot1_decode (const xtensa_insnbuf insn)
{
  if (Field_fld_ae2_slot1_23_0_Slot_ae2_slot1_get (insn) == 13897904)
    return OPCODE_NOP;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 192)
    return OPCODE_AE_MUL16X4;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 193)
    return OPCODE_AE_MULAF16X4SS;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 194)
    return OPCODE_AE_MULS16X4;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 195 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MUL32_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 195 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MUL32U_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 195 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULA32U_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 195 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MUL32X16_L1;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 195 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MUL32X16_L3;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 195 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MUL32X16_H1;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 195 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MUL32X16_H3;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 195 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULA32X16_H1;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 196 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULA32_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 196 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULAF16SS_21;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 196 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULAF16SS_11;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 196 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MULAF16SS_00;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 196 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULAAFD16SS_33_22;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 196 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULAAFD16SS_11_00;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 196 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULAAD24_HH_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 196 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULAAFD24_HL_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 196 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULA32X16_L1;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 196 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULA32X16_L3;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 196 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULA32X16_H3;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 196 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULAAFD32X16_H3_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 196 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULAAFD32X16_H1_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 196 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULAAD32X16_H2_L3;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 196 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULAAD32X16_H0_L1;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 196 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MULAC32X16_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 197 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULAF32R_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 197 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULAF32S_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 197 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULAF32R_HH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 197 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULAF16SS_32;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 197 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULAF16SS_30;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 197 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULAF48Q32SP16S_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 197 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MULAFP24X2RA;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 197 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULAF32X16_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 197 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULAF32X16_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 197 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULAF32X16_H0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 197 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULAF32X16_H2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 197 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULAFP32X16X2RS_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 197 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MULAFP32X16X2RAS_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 197 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULAFP32X2RS;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 197 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULAFC24RA;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 197 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULAFC32X16RAS_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 198 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULAS32F48P16S_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 198 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULF16SS_22;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 198 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULF16SS_31;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 198 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MULF16SS_10;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 198 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MULF16SS_20;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 198 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULAQ32SP16U_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 198 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULASFD24_HH_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 198 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULASD24_HH_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 198 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULARFQ32SP24S_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 198 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULAFQ32SP24S_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 198 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULASFD32X16_H1_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 198 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULASD32X16_H1_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 198 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULAP32X16X2_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 198 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULAP32X2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 198 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULC24;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 198 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULC32X16_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 199 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULF32S_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 199 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULF32R_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 199 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULF32S_HH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 199 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULF16SS_33;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 199 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULF48Q32SP16U_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 199 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULFP24X2R;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 199 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULFQ32SP24S_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 199 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULF32X16_L1;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 199 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULF32X16_L3;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 199 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULF32X16_H1;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 199 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULF32X16_H3;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 199 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MULFP32X16X2RS_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 199 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MULFP32X16X2RAS_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 199 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULFP32X2RAS;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 199 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULFP16X4RAS;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 199 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULFC32X16RAS_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 200)
    return OPCODE_AE_MULA16X4;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 201)
    return OPCODE_AE_MULF16X4SS;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 202)
    return OPCODE_AE_MULSF16X4SS;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 203 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MUL32_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 203 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MUL32_HH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 203 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MUL32X16_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 203 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MUL32X16_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 203 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MUL32X16_H0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 203 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MUL32X16_H2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 203 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULA32X16_H0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 203 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULA32X16_H2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 204 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULA32_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 204 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULA32_HH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 204 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULAF16SS_22;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 204 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MULAF16SS_10;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 204 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULAF16SS_20;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 204 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULAAFD16SS_13_02;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 204 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULAAFD24_HH_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 204 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULAAD24_HL_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 204 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULA32X16_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 204 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULA32X16_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 204 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULAAD32X16_H3_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 204 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULAAD32X16_H1_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 204 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULAAFD32X16_H2_L3;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 204 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULAAFD32X16_H0_L1;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 204 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULAC24;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 204 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MULAC32X16_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 205 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULAF32S_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 205 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULAF32R_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 205 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULAF32S_HH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 205 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULAF16SS_33;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 205 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULAF16SS_31;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 205 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULAF48Q32SP16U_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 205 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULAFP24X2R;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 205 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULAFQ32SP24S_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 205 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULAF32X16_L1;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 205 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULAF32X16_L3;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 205 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULAF32X16_H1;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 205 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULAF32X16_H3;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 205 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MULAFP32X16X2RS_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 205 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MULAFP32X16X2RAS_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 205 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULAFP32X2RAS;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 205 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULAFC32X16RAS_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 206 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULAS32F48P16S_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 206 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULAS32F48P16S_HH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 206 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULF16SS_32;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 206 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MULF16SS_21;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 206 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULF16SS_30;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 206 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MULF16SS_11;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 206 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULF16SS_00;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 206 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULAQ32SP16S_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 206 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULAP24X2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 206 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULASFD24_HL_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 206 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULASD24_HL_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 206 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULARFQ32SP24S_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 206 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULASFD32X16_H3_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 206 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULASD32X16_H3_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 206 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULAP32X16X2_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 206 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULC32X16_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 207 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULF32R_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 207 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULF32S_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 207 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULF32R_HH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 207 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULF48Q32SP16S_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 207 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULFP24X2RA;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 207 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULFQ32SP24S_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 207 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULF32X16_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 207 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULF32X16_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 207 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULF32X16_H0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 207 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULF32X16_H2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 207 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MULFP32X16X2RS_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 207 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MULFP32X16X2RAS_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 207 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULFP32X2RS;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 207 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULFP16X4S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 207 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULFC24RA;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 207 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULFC32X16RAS_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 208 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULS32F48P16S_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 208 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULS32F48P16S_HH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 208 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULS32_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 208 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULS32_HH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 208 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULSF16SS_10;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 208 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULQ32SP16S_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 208 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULP24X2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 208 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MULSAFD24_HH_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 208 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULRFQ32SP24S_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 208 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULS32X16_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 208 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULS32X16_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 208 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULS32X16_H0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 208 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULS32X16_H2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 208 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULSAFD32X16_H3_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 208 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MULSAD32X16_H1_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 208 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULP32X16X2_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 209 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULSF32S_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 209 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULSF32R_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 209 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULSF32S_HH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 209 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULSF16SS_33;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 209 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULSF16SS_22;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 209 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULSF16SS_31;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 209 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULSF16SS_20;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 209 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULSF48Q32SP16U_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 209 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MULSFP24X2RA;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 209 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULSF32X16_L1;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 209 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULSF32X16_L3;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 209 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULSF32X16_H1;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 209 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULSF32X16_H3;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 209 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULSFP32X16X2RS_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 209 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MULSFP32X16X2RAS_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 209 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULSFP32X2RS;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 210 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULSS32F48P16S_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 210 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULSSFD16SS_33_22;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 210 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULSSFD16SS_11_00;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 210 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULZAAFD16SS_13_02;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 210 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULSQ32SP16U_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 210 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MULZAAD24_HL_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 210 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULSSD24_HH_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 210 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULSSFD24_HL_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 210 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULSRFQ32SP24S_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 210 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULSFQ32SP24S_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 210 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULSSFD32X16_H3_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 210 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULSSD32X16_H1_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 210 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULZAAD32X16_H3_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 210 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MULZAAD32X16_H1_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 210 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULSP32X16X2_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 210 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULSP32X2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 211 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MULZSSFD16SS_33_22;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 211 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MULZSSFD16SS_11_00;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 211 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULZAAFD24_HH_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 211 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULZASFD24_HH_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 211 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULZASD24_HH_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 211 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULZSAD24_HH_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 211 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULZSSD24_HH_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 211 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULZSSFD24_HL_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 211 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULZASFD32X16_H1_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 211 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULZASD32X16_H1_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 211 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULZSAD32X16_H3_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 211 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULZSAFD32X16_H1_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 211 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULZSSFD32X16_H3_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 211 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULZSSD32X16_H1_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 211 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULZAAFD32X16_H2_L3;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 211 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULZAAFD32X16_H0_L1;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_ADD32;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_ADDSUB32;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_SUB16;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_ADD32_HL_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (insn) == 171)
    return OPCODE_AE_ABS32;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_SUB24S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_SUB32S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_SUBADD32S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_ADD16S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (insn) == 155)
    return OPCODE_AE_ABS24S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (insn) == 187)
    return OPCODE_AE_ABS32S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (insn) == 251)
    return OPCODE_AE_NEG16S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (insn) == 139)
    return OPCODE_AE_ABS16S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (insn) == 203)
    return OPCODE_AE_ABS64;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_ADD64S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_SUB64S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (insn) == 235)
    return OPCODE_AE_ABSSQ56S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 212 &&
      Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (insn) == 219)
    return OPCODE_AE_ABS64S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 216 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULS32F48P16S_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 216 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULS32_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 216 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULS32U_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 216 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULSF16SS_11;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 216 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULSF16SS_00;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 216 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULQ32SP16U_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 216 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULSAD24_HH_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 216 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULRFQ32SP24S_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 216 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULS32X16_L1;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 216 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULS32X16_L3;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 216 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULS32X16_H1;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 216 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULS32X16_H3;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 216 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MULSAD32X16_H3_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 216 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MULSAFD32X16_H1_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 216 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULP32X16X2_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 216 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULP32X2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 217 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULSF32R_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 217 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULSF32S_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 217 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULSF32R_HH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 217 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULSF16SS_32;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 217 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULSF16SS_21;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 217 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULSF16SS_30;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 217 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULSF48Q32SP16S_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 217 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULSFP24X2R;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 217 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULSFQ32SP24S_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 217 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULSF32X16_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 217 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULSF32X16_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 217 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULSF32X16_H0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 217 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULSF32X16_H2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 217 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MULSFP32X16X2RS_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 217 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MULSFP32X16X2RAS_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 217 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULSFP32X2RAS;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 218 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULSS32F48P16S_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 218 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULSS32F48P16S_HH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 218 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULSSFD16SS_13_02;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 218 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_MULZAAFD16SS_33_22;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 218 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULZAAFD16SS_11_00;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 218 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULSQ32SP16S_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 218 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULSP24X2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 218 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULZAAD24_HH_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 218 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULSSFD24_HH_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 218 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULSSD24_HL_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 218 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULSRFQ32SP24S_H;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 218 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULSSD32X16_H3_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 218 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULSSFD32X16_H1_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 218 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MULZAAD32X16_H2_L3;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 218 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MULZAAD32X16_H0_L1;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 218 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULSP32X16X2_L;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 219 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 15)
    return OPCODE_AE_ADD16;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 219 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 12)
    return OPCODE_AE_MULZSSFD16SS_13_02;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 219 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULZAAFD24_HL_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 219 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULZASFD24_HL_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 219 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULZASD24_HL_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 219 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULZSAFD24_HH_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 219 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 13)
    return OPCODE_AE_MULZSSFD24_HH_LL;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 219 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULZSSD24_HL_LH;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 219 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULZAAFD32X16_H3_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 219 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULZAAFD32X16_H1_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 219 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULZASFD32X16_H3_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 219 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULZASD32X16_H3_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 219 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULZSAFD32X16_H3_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 219 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULZSAD32X16_H1_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 219 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULZSSD32X16_H3_L2;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 219 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 14)
    return OPCODE_AE_MULZSSFD32X16_H1_L0;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (insn) == 251)
    return OPCODE_AE_SHORTSWAP;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (insn) == 235)
    return OPCODE_AE_MOV;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_SUB32;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_SUBADD32;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (insn) == 155)
    return OPCODE_AE_NEG32;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_ADD24S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_ADD32S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_ADDSUB32S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_SUB16S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (insn) == 139)
    return OPCODE_AE_NEG24S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (insn) == 171)
    return OPCODE_AE_NEG32S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_ADD64;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_SUB64;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (insn) == 187)
    return OPCODE_AE_NEG64;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_ADDSQ56S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_SUBSQ56S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (insn) == 219)
    return OPCODE_AE_NEGSQ56S;
  if (Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get (insn) == 220 &&
      Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get (insn) == 203)
    return OPCODE_AE_NEG64S;
  if (Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_MULAFD24X2_FIR_H;
  if (Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_MULAFD24X2_FIR_L;
  if (Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (insn) == 2)
    return OPCODE_AE_MULAFD32X16X2_FIR_HH;
  if (Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (insn) == 3)
    return OPCODE_AE_MULAFD32X16X2_FIR_HL;
  if (Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (insn) == 4)
    return OPCODE_AE_MULAFD32X16X2_FIR_LH;
  if (Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (insn) == 5)
    return OPCODE_AE_MULAFD32X16X2_FIR_LL;
  if (Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (insn) == 6)
    return OPCODE_AE_MULFD24X2_FIR_H;
  if (Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (insn) == 7)
    return OPCODE_AE_MULFD24X2_FIR_L;
  if (Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (insn) == 8)
    return OPCODE_AE_MULFD32X16X2_FIR_HH;
  if (Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (insn) == 9)
    return OPCODE_AE_MULFD32X16X2_FIR_HL;
  if (Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (insn) == 10)
    return OPCODE_AE_MULFD32X16X2_FIR_LH;
  if (Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MULFD32X16X2_FIR_LL;
  if (Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (insn) == 12 &&
      Field_fld_ae2_slot1_18_16_Slot_ae2_slot1_get (insn) == 3 &&
      Field_fld_ae2_slot1_7_7_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_SEL16I;
  if (Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (insn) == 13 &&
      Field_fld_ae2_slot1_18_16_Slot_ae2_slot1_get (insn) == 4 &&
      Field_fld_ae2_slot1_13_11_Slot_ae2_slot1_get (insn) == 0 &&
      Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get (insn) == 11)
    return OPCODE_AE_MOVI;
  if (Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (insn) == 13 &&
      Field_fld_ae2_slot1_18_16_Slot_ae2_slot1_get (insn) == 4 &&
      Field_fld_ae2_slot1_7_3_Slot_ae2_slot1_get (insn) == 20 &&
      Field_fld_ae2_slot1_1_0_Slot_ae2_slot1_get (insn) == 1)
    return OPCODE_AE_PKSR32;
  if (Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get (insn) == 13 &&
      Field_fld_ae2_slot1_18_16_Slot_ae2_slot1_get (insn) == 4 &&
      Field_fld_ae2_slot1_7_3_Slot_ae2_slot1_get (insn) == 20 &&
      Field_fld_ae2_slot1_1_0_Slot_ae2_slot1_get (insn) == 0)
    return OPCODE_AE_PKSR24;
  return XTENSA_UNDEFINED;
}

static int
Slot_ae_minislot0_decode (const xtensa_insnbuf insn)
{
  if (Field_fld_ae_minislot0_16_0_Slot_ae_minislot0_get (insn) == 83456)
    return OPCODE_NOP;
  if (Field_fld_ae_minislot0_16_10_Slot_ae_minislot0_get (insn) == 80)
    return OPCODE_AE_MOVI;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 0)
    return OPCODE_AE_L16M_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 1)
    return OPCODE_AE_L16X2M_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 2)
    return OPCODE_AE_L16_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 3)
    return OPCODE_AE_L32F24_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 4)
    return OPCODE_AE_L32M_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 5)
    return OPCODE_AE_L32X2F24_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 6)
    return OPCODE_AE_L32X2_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 7)
    return OPCODE_AE_L32_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 8)
    return OPCODE_AE_L64_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 9)
    return OPCODE_AE_S16M_L_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 10)
    return OPCODE_AE_S16X2M_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 11)
    return OPCODE_AE_S16_0_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 12)
    return OPCODE_AE_S24RA64S_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 13)
    return OPCODE_AE_S32F24_L_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 14)
    return OPCODE_AE_S32M_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 15)
    return OPCODE_AE_S32RA64S_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 16)
    return OPCODE_AE_S32X2F24_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 17)
    return OPCODE_AE_S32X2_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 18)
    return OPCODE_AE_S32_L_I;
  if (Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get (insn) == 19)
    return OPCODE_AE_S64_I;
  if (Field_fld_ae_minislot0_16_8_Slot_ae_minislot0_get (insn) == 324)
    return OPCODE_AE_MOVDA16;
  if (Field_fld_ae_minislot0_16_8_Slot_ae_minislot0_get (insn) == 325)
    return OPCODE_AE_MOVDA32;
  return XTENSA_UNDEFINED;
}

static int
Slot_ae_minislot1_decode (const xtensa_insnbuf insn)
{
  if (Field_fld_ae_minislot1_0_0_Slot_ae_minislot1_get (insn) == 0)
    return OPCODE_NOP;
  return XTENSA_UNDEFINED;
}

static int
Slot_ae_slot1_decode (const xtensa_insnbuf insn)
{
  if (Field_fld_ae_slot1_19_0_Slot_ae_slot1_get (insn) == 1028336)
    return OPCODE_NOP;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 4)
    return OPCODE_AE_MUL32U_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 5)
    return OPCODE_AE_MUL32X16_H0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 6)
    return OPCODE_AE_MUL32X16_H1;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 7)
    return OPCODE_AE_MUL32X16_H2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 8)
    return OPCODE_AE_MUL32X16_H3;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 9)
    return OPCODE_AE_MUL32X16_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 10)
    return OPCODE_AE_MUL32X16_L1;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 11)
    return OPCODE_AE_MUL32X16_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 12)
    return OPCODE_AE_MUL32X16_L3;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 13)
    return OPCODE_AE_MUL32_HH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 14)
    return OPCODE_AE_MUL32_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 15)
    return OPCODE_AE_MUL32_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 16)
    return OPCODE_AE_MULA32U_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 17)
    return OPCODE_AE_MULA32X16_H0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 18)
    return OPCODE_AE_MULA32X16_H1;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 19)
    return OPCODE_AE_MULA32X16_H2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 20)
    return OPCODE_AE_MULA32X16_H3;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 21)
    return OPCODE_AE_MULA32X16_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 22)
    return OPCODE_AE_MULA32X16_L1;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 23)
    return OPCODE_AE_MULA32X16_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 24)
    return OPCODE_AE_MULA32X16_L3;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 25)
    return OPCODE_AE_MULA32_HH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 26)
    return OPCODE_AE_MULA32_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 27)
    return OPCODE_AE_MULA32_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 28)
    return OPCODE_AE_MULAAD24_HH_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 29)
    return OPCODE_AE_MULAAD24_HL_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 30)
    return OPCODE_AE_MULAAD32X16_H0_L1;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 31)
    return OPCODE_AE_MULAAD32X16_H1_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 32)
    return OPCODE_AE_MULAAD32X16_H2_L3;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 33)
    return OPCODE_AE_MULAAD32X16_H3_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 34)
    return OPCODE_AE_MULAAFD16SS_11_00;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 35)
    return OPCODE_AE_MULAAFD16SS_13_02;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 36)
    return OPCODE_AE_MULAAFD16SS_33_22;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 37)
    return OPCODE_AE_MULAAFD24_HH_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 38)
    return OPCODE_AE_MULAAFD24_HL_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 39)
    return OPCODE_AE_MULAAFD32X16_H0_L1;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 40)
    return OPCODE_AE_MULAAFD32X16_H1_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 41)
    return OPCODE_AE_MULAAFD32X16_H2_L3;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 42)
    return OPCODE_AE_MULAAFD32X16_H3_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 43)
    return OPCODE_AE_MULAC24;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 44)
    return OPCODE_AE_MULAC32X16_H;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 45)
    return OPCODE_AE_MULAC32X16_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 46)
    return OPCODE_AE_MULAF16SS_00;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 47)
    return OPCODE_AE_MULAF32R_HH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 48)
    return OPCODE_AE_MULAF32R_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 49)
    return OPCODE_AE_MULAF32R_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 50)
    return OPCODE_AE_MULAF32S_HH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 51)
    return OPCODE_AE_MULAF32S_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 52)
    return OPCODE_AE_MULAF32S_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 53)
    return OPCODE_AE_MULAF32X16_H0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 54)
    return OPCODE_AE_MULAF32X16_H1;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 55)
    return OPCODE_AE_MULAF32X16_H2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 56)
    return OPCODE_AE_MULAF32X16_H3;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 57)
    return OPCODE_AE_MULAF32X16_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 58)
    return OPCODE_AE_MULAF32X16_L1;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 59)
    return OPCODE_AE_MULAF32X16_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 60)
    return OPCODE_AE_MULAF32X16_L3;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 61)
    return OPCODE_AE_MULAF48Q32SP16S_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 62)
    return OPCODE_AE_MULAF48Q32SP16U_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 63)
    return OPCODE_AE_MULAFC24RA;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 64)
    return OPCODE_AE_MULAFC32X16RAS_H;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 65)
    return OPCODE_AE_MULAFC32X16RAS_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 66)
    return OPCODE_AE_MULAFP24X2R;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 67)
    return OPCODE_AE_MULAFP24X2RA;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 68)
    return OPCODE_AE_MULAFP32X16X2RAS_H;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 69)
    return OPCODE_AE_MULAFP32X16X2RAS_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 70)
    return OPCODE_AE_MULAFP32X16X2RS_H;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 71)
    return OPCODE_AE_MULAFP32X16X2RS_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 72)
    return OPCODE_AE_MULAFP32X2RAS;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 73)
    return OPCODE_AE_MULAFP32X2RS;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 74)
    return OPCODE_AE_MULAP24X2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 75)
    return OPCODE_AE_MULAP32X2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 76)
    return OPCODE_AE_MULAQ32SP16S_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 77)
    return OPCODE_AE_MULAQ32SP16U_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 78)
    return OPCODE_AE_MULAS32F48P16S_HH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 79)
    return OPCODE_AE_MULAS32F48P16S_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 80)
    return OPCODE_AE_MULAS32F48P16S_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 81)
    return OPCODE_AE_MULASD24_HH_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 82)
    return OPCODE_AE_MULASD24_HL_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 83)
    return OPCODE_AE_MULASD32X16_H1_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 84)
    return OPCODE_AE_MULASD32X16_H3_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 85)
    return OPCODE_AE_MULASFD24_HH_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 86)
    return OPCODE_AE_MULASFD24_HL_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 87)
    return OPCODE_AE_MULASFD32X16_H1_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 88)
    return OPCODE_AE_MULASFD32X16_H3_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 89)
    return OPCODE_AE_MULC24;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 90)
    return OPCODE_AE_MULC32X16_H;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 91)
    return OPCODE_AE_MULC32X16_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 92)
    return OPCODE_AE_MULF16SS_00;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 93)
    return OPCODE_AE_MULF32R_HH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 94)
    return OPCODE_AE_MULF32R_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 95)
    return OPCODE_AE_MULF32R_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 96)
    return OPCODE_AE_MULF32S_HH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 97)
    return OPCODE_AE_MULF32S_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 98)
    return OPCODE_AE_MULF32S_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 99)
    return OPCODE_AE_MULF32X16_H0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 100)
    return OPCODE_AE_MULF32X16_H1;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 101)
    return OPCODE_AE_MULF32X16_H2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 102)
    return OPCODE_AE_MULF32X16_H3;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 103)
    return OPCODE_AE_MULF32X16_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 104)
    return OPCODE_AE_MULF32X16_L1;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 105)
    return OPCODE_AE_MULF32X16_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 106)
    return OPCODE_AE_MULF32X16_L3;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 107)
    return OPCODE_AE_MULF48Q32SP16S_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 108)
    return OPCODE_AE_MULF48Q32SP16U_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 109)
    return OPCODE_AE_MULFC24RA;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 110)
    return OPCODE_AE_MULFC32X16RAS_H;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 111)
    return OPCODE_AE_MULFC32X16RAS_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 112)
    return OPCODE_AE_MULFP24X2R;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 113)
    return OPCODE_AE_MULFP24X2RA;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 114)
    return OPCODE_AE_MULFP32X16X2RAS_H;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 115)
    return OPCODE_AE_MULFP32X16X2RAS_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 116)
    return OPCODE_AE_MULFP32X16X2RS_H;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 117)
    return OPCODE_AE_MULFP32X16X2RS_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 118)
    return OPCODE_AE_MULFP32X2RAS;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 119)
    return OPCODE_AE_MULFP32X2RS;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 120)
    return OPCODE_AE_MULFQ32SP24S_H;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 121)
    return OPCODE_AE_MULFQ32SP24S_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 122)
    return OPCODE_AE_MULP24X2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 123)
    return OPCODE_AE_MULP32X2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 124)
    return OPCODE_AE_MULQ32SP16S_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 125)
    return OPCODE_AE_MULQ32SP16U_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 126)
    return OPCODE_AE_MULS32F48P16S_HH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 127)
    return OPCODE_AE_MULS32F48P16S_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 128)
    return OPCODE_AE_MULS32F48P16S_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 129)
    return OPCODE_AE_MULS32U_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 130)
    return OPCODE_AE_MULS32X16_H0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 131)
    return OPCODE_AE_MULS32X16_H1;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 132)
    return OPCODE_AE_MULS32X16_H2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 133)
    return OPCODE_AE_MULS32X16_H3;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 134)
    return OPCODE_AE_MULS32X16_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 135)
    return OPCODE_AE_MULS32X16_L1;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 136)
    return OPCODE_AE_MULS32X16_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 137)
    return OPCODE_AE_MULS32X16_L3;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 138)
    return OPCODE_AE_MULS32_HH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 139)
    return OPCODE_AE_MULS32_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 140)
    return OPCODE_AE_MULS32_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 141)
    return OPCODE_AE_MULSAD24_HH_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 142)
    return OPCODE_AE_MULSAFD24_HH_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 143)
    return OPCODE_AE_MULSAFD32X16_H1_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 144)
    return OPCODE_AE_MULSAFD32X16_H3_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 145)
    return OPCODE_AE_MULSF16SS_00;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 146)
    return OPCODE_AE_MULSF32R_HH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 147)
    return OPCODE_AE_MULSF32R_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 148)
    return OPCODE_AE_MULSF32R_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 149)
    return OPCODE_AE_MULSF32S_HH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 150)
    return OPCODE_AE_MULSF32S_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 151)
    return OPCODE_AE_MULSF32S_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 152)
    return OPCODE_AE_MULSF32X16_H0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 153)
    return OPCODE_AE_MULSF32X16_H1;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 154)
    return OPCODE_AE_MULSF32X16_H2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 155)
    return OPCODE_AE_MULSF32X16_H3;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 156)
    return OPCODE_AE_MULSF32X16_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 157)
    return OPCODE_AE_MULSF32X16_L1;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 158)
    return OPCODE_AE_MULSF32X16_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 159)
    return OPCODE_AE_MULSF32X16_L3;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 160)
    return OPCODE_AE_MULSF48Q32SP16S_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 161)
    return OPCODE_AE_MULSF48Q32SP16U_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 162)
    return OPCODE_AE_MULSFP24X2R;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 163)
    return OPCODE_AE_MULSFP24X2RA;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 164)
    return OPCODE_AE_MULSFP32X16X2RAS_H;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 165)
    return OPCODE_AE_MULSFP32X16X2RAS_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 166)
    return OPCODE_AE_MULSFP32X16X2RS_H;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 167)
    return OPCODE_AE_MULSFP32X16X2RS_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 168)
    return OPCODE_AE_MULSFP32X2RAS;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 169)
    return OPCODE_AE_MULSFP32X2RS;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 170)
    return OPCODE_AE_MULSP24X2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 171)
    return OPCODE_AE_MULSP32X2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 172)
    return OPCODE_AE_MULSQ32SP16S_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 173)
    return OPCODE_AE_MULSQ32SP16U_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 174)
    return OPCODE_AE_MULSRFQ32SP24S_H;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 175)
    return OPCODE_AE_MULSRFQ32SP24S_L;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 176)
    return OPCODE_AE_MULSS32F48P16S_HH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 177)
    return OPCODE_AE_MULSS32F48P16S_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 178)
    return OPCODE_AE_MULSS32F48P16S_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 179)
    return OPCODE_AE_MULSSD24_HH_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 180)
    return OPCODE_AE_MULSSD24_HL_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 181)
    return OPCODE_AE_MULSSD32X16_H1_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 182)
    return OPCODE_AE_MULSSD32X16_H3_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 183)
    return OPCODE_AE_MULSSFD16SS_11_00;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 184)
    return OPCODE_AE_MULSSFD16SS_13_02;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 185)
    return OPCODE_AE_MULSSFD16SS_33_22;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 186)
    return OPCODE_AE_MULSSFD24_HH_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 187)
    return OPCODE_AE_MULSSFD24_HL_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 188)
    return OPCODE_AE_MULSSFD32X16_H1_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 189)
    return OPCODE_AE_MULSSFD32X16_H3_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 190)
    return OPCODE_AE_MULZAAD24_HH_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 191)
    return OPCODE_AE_MULZAAD24_HL_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 192)
    return OPCODE_AE_MULZAAD32X16_H0_L1;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 193)
    return OPCODE_AE_MULZAAD32X16_H1_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 194)
    return OPCODE_AE_MULZAAD32X16_H2_L3;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 195)
    return OPCODE_AE_MULZAAD32X16_H3_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 196)
    return OPCODE_AE_MULZAAFD16SS_11_00;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 197)
    return OPCODE_AE_MULZAAFD16SS_13_02;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 198)
    return OPCODE_AE_MULZAAFD16SS_33_22;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 199)
    return OPCODE_AE_MULZAAFD24_HH_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 200)
    return OPCODE_AE_MULZAAFD24_HL_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 201)
    return OPCODE_AE_MULZAAFD32X16_H0_L1;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 202)
    return OPCODE_AE_MULZAAFD32X16_H1_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 203)
    return OPCODE_AE_MULZAAFD32X16_H2_L3;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 204)
    return OPCODE_AE_MULZAAFD32X16_H3_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 205)
    return OPCODE_AE_MULZASD24_HH_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 206)
    return OPCODE_AE_MULZASD24_HL_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 207)
    return OPCODE_AE_MULZASD32X16_H1_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 208)
    return OPCODE_AE_MULZASD32X16_H3_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 209)
    return OPCODE_AE_MULZASFD24_HH_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 210)
    return OPCODE_AE_MULZASFD24_HL_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 211)
    return OPCODE_AE_MULZASFD32X16_H1_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 212)
    return OPCODE_AE_MULZASFD32X16_H3_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 213)
    return OPCODE_AE_MULZSAD24_HH_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 214)
    return OPCODE_AE_MULZSAFD24_HH_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 215)
    return OPCODE_AE_MULZSAFD32X16_H1_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 216)
    return OPCODE_AE_MULZSAFD32X16_H3_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 217)
    return OPCODE_AE_MULZSSD24_HH_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 218)
    return OPCODE_AE_MULZSSD24_HL_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 219)
    return OPCODE_AE_MULZSSD32X16_H1_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 220)
    return OPCODE_AE_MULZSSD32X16_H3_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 221)
    return OPCODE_AE_MULZSSFD16SS_11_00;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 222)
    return OPCODE_AE_MULZSSFD16SS_13_02;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 223)
    return OPCODE_AE_MULZSSFD16SS_33_22;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 224)
    return OPCODE_AE_MULZSSFD24_HH_LL;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 225)
    return OPCODE_AE_MULZSSFD24_HL_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 226)
    return OPCODE_AE_MULZSSFD32X16_H1_L0;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 227)
    return OPCODE_AE_MULZSSFD32X16_H3_L2;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 228)
    return OPCODE_AE_ADD16;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 229)
    return OPCODE_AE_ADD16S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 230)
    return OPCODE_AE_ADD24S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 231)
    return OPCODE_AE_ADD32;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 232)
    return OPCODE_AE_ADD32S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 233)
    return OPCODE_AE_ADD32_HL_LH;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 234)
    return OPCODE_AE_ADD64;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 235)
    return OPCODE_AE_ADD64S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 236)
    return OPCODE_AE_ADDSQ56S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 237)
    return OPCODE_AE_ADDSUB32;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 238)
    return OPCODE_AE_ADDSUB32S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 239)
    return OPCODE_AE_SUB16;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 240)
    return OPCODE_AE_SUB16S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 241)
    return OPCODE_AE_SUB24S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 242)
    return OPCODE_AE_SUB32;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 243)
    return OPCODE_AE_SUB32S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 244)
    return OPCODE_AE_SUB64;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 245)
    return OPCODE_AE_SUB64S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 246)
    return OPCODE_AE_SUBADD32;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 247)
    return OPCODE_AE_SUBADD32S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 248)
    return OPCODE_AE_SUBSQ56S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 249 &&
      Field_fld_ae_slot1_3_3_Slot_ae_slot1_get (insn) == 0 &&
      Field_fld_ae_slot1_0_0_Slot_ae_slot1_get (insn) == 1)
    return OPCODE_AE_PKSR32;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 249 &&
      Field_fld_ae_slot1_3_3_Slot_ae_slot1_get (insn) == 0 &&
      Field_fld_ae_slot1_0_0_Slot_ae_slot1_get (insn) == 0)
    return OPCODE_AE_PKSR24;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 250 &&
      Field_fld_ae_slot1_9_8_Slot_ae_slot1_get (insn) == 0)
    return OPCODE_AE_MOVI;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 251 &&
      Field_fld_ae_slot1_7_4_Slot_ae_slot1_get (insn) == 14)
    return OPCODE_AE_MOV;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 251 &&
      Field_fld_ae_slot1_7_4_Slot_ae_slot1_get (insn) == 9)
    return OPCODE_AE_NEG32;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 251 &&
      Field_fld_ae_slot1_7_4_Slot_ae_slot1_get (insn) == 2)
    return OPCODE_AE_ABS32;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 251 &&
      Field_fld_ae_slot1_7_4_Slot_ae_slot1_get (insn) == 8)
    return OPCODE_AE_NEG24S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 251 &&
      Field_fld_ae_slot1_7_4_Slot_ae_slot1_get (insn) == 1)
    return OPCODE_AE_ABS24S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 251 &&
      Field_fld_ae_slot1_7_4_Slot_ae_slot1_get (insn) == 10)
    return OPCODE_AE_NEG32S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 251 &&
      Field_fld_ae_slot1_7_4_Slot_ae_slot1_get (insn) == 3)
    return OPCODE_AE_ABS32S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 251 &&
      Field_fld_ae_slot1_7_4_Slot_ae_slot1_get (insn) == 7)
    return OPCODE_AE_NEG16S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 251 &&
      Field_fld_ae_slot1_7_4_Slot_ae_slot1_get (insn) == 0)
    return OPCODE_AE_ABS16S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 251 &&
      Field_fld_ae_slot1_7_4_Slot_ae_slot1_get (insn) == 11)
    return OPCODE_AE_NEG64;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 251 &&
      Field_fld_ae_slot1_7_4_Slot_ae_slot1_get (insn) == 4)
    return OPCODE_AE_ABS64;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 251 &&
      Field_fld_ae_slot1_7_4_Slot_ae_slot1_get (insn) == 13)
    return OPCODE_AE_NEGSQ56S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 251 &&
      Field_fld_ae_slot1_7_4_Slot_ae_slot1_get (insn) == 6)
    return OPCODE_AE_ABSSQ56S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 251 &&
      Field_fld_ae_slot1_7_4_Slot_ae_slot1_get (insn) == 12)
    return OPCODE_AE_NEG64S;
  if (Field_fld_ae_slot1_19_12_Slot_ae_slot1_get (insn) == 251 &&
      Field_fld_ae_slot1_7_4_Slot_ae_slot1_get (insn) == 5)
    return OPCODE_AE_ABS64S;
  if (Field_fld_ae_slot1_19_14_Slot_ae_slot1_get (insn) == 0)
    return OPCODE_AE_SEL16I_N;
  return XTENSA_UNDEFINED;
}

static int
Slot_ae_slot2_0_decode (const xtensa_insnbuf insn)
{
  if (Field_fld_ae_slot2_0_19_0_Slot_ae_slot2_0_get (insn) == 962560)
    return OPCODE_NOP;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 38)
    return OPCODE_AE_MUL32X16_H0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 39)
    return OPCODE_AE_MUL32X16_H1_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 40)
    return OPCODE_AE_MUL32X16_H2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 41)
    return OPCODE_AE_MUL32X16_H3_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 42)
    return OPCODE_AE_MUL32X16_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 43)
    return OPCODE_AE_MUL32X16_L1_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 44)
    return OPCODE_AE_MUL32X16_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 45)
    return OPCODE_AE_MUL32X16_L3_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 46)
    return OPCODE_AE_MUL32_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 47)
    return OPCODE_AE_MULA32X16_H0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 48)
    return OPCODE_AE_MULA32X16_H1_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 49)
    return OPCODE_AE_MULA32X16_H2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 50)
    return OPCODE_AE_MULA32X16_H3_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 51)
    return OPCODE_AE_MULA32X16_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 52)
    return OPCODE_AE_MULA32X16_L1_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 53)
    return OPCODE_AE_MULA32X16_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 54)
    return OPCODE_AE_MULA32X16_L3_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 55)
    return OPCODE_AE_MULA32_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 56)
    return OPCODE_AE_MULAAD24_HH_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 57)
    return OPCODE_AE_MULAAD24_HL_LH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 58)
    return OPCODE_AE_MULAAD32X16_H0_L1_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 59)
    return OPCODE_AE_MULAAD32X16_H1_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 60)
    return OPCODE_AE_MULAAD32X16_H2_L3_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 61)
    return OPCODE_AE_MULAAD32X16_H3_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 62)
    return OPCODE_AE_MULAAFD16SS_11_00_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 63)
    return OPCODE_AE_MULAAFD16SS_13_02_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 64)
    return OPCODE_AE_MULAAFD16SS_33_22_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 65)
    return OPCODE_AE_MULAAFD24_HH_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 66)
    return OPCODE_AE_MULAAFD24_HL_LH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 67)
    return OPCODE_AE_MULAAFD32X16_H0_L1_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 68)
    return OPCODE_AE_MULAAFD32X16_H1_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 69)
    return OPCODE_AE_MULAAFD32X16_H2_L3_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 70)
    return OPCODE_AE_MULAAFD32X16_H3_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 71)
    return OPCODE_AE_MULAF16SS_00_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 72)
    return OPCODE_AE_MULAF32R_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 73)
    return OPCODE_AE_MULAF32S_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 74)
    return OPCODE_AE_MULAF32X16_H0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 75)
    return OPCODE_AE_MULAF32X16_H1_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 76)
    return OPCODE_AE_MULAF32X16_H2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 77)
    return OPCODE_AE_MULAF32X16_H3_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 78)
    return OPCODE_AE_MULAF32X16_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 79)
    return OPCODE_AE_MULAF32X16_L1_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 80)
    return OPCODE_AE_MULAF32X16_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 81)
    return OPCODE_AE_MULAF32X16_L3_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 82)
    return OPCODE_AE_MULAF48Q32SP16S_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 83)
    return OPCODE_AE_MULAF48Q32SP16U_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 84)
    return OPCODE_AE_MULAFP24X2RA_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 85)
    return OPCODE_AE_MULAFP24X2R_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 86)
    return OPCODE_AE_MULAFP32X16X2RAS_H_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 87)
    return OPCODE_AE_MULAFP32X16X2RAS_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 88)
    return OPCODE_AE_MULAFP32X16X2RS_H_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 89)
    return OPCODE_AE_MULAFP32X16X2RS_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 90)
    return OPCODE_AE_MULAFQ32SP24S_H_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 91)
    return OPCODE_AE_MULAFQ32SP24S_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 92)
    return OPCODE_AE_MULAP24X2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 93)
    return OPCODE_AE_MULAQ32SP16S_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 94)
    return OPCODE_AE_MULAQ32SP16U_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 95)
    return OPCODE_AE_MULARFQ32SP24S_H_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 96)
    return OPCODE_AE_MULARFQ32SP24S_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 97)
    return OPCODE_AE_MULAS32F48P16S_HH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 98)
    return OPCODE_AE_MULAS32F48P16S_LH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 99)
    return OPCODE_AE_MULAS32F48P16S_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 100)
    return OPCODE_AE_MULASD24_HH_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 101)
    return OPCODE_AE_MULASD24_HL_LH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 102)
    return OPCODE_AE_MULASD32X16_H1_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 103)
    return OPCODE_AE_MULASD32X16_H3_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 104)
    return OPCODE_AE_MULASFD24_HH_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 105)
    return OPCODE_AE_MULASFD24_HL_LH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 106)
    return OPCODE_AE_MULASFD32X16_H1_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 107)
    return OPCODE_AE_MULASFD32X16_H3_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 108)
    return OPCODE_AE_MULF16SS_00_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 109)
    return OPCODE_AE_MULF32R_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 110)
    return OPCODE_AE_MULF32S_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 111)
    return OPCODE_AE_MULF32X16_H0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 112)
    return OPCODE_AE_MULF32X16_H1_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 113)
    return OPCODE_AE_MULF32X16_H2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 114)
    return OPCODE_AE_MULF32X16_H3_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 115)
    return OPCODE_AE_MULF32X16_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 116)
    return OPCODE_AE_MULF32X16_L1_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 117)
    return OPCODE_AE_MULF32X16_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 118)
    return OPCODE_AE_MULF32X16_L3_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 119)
    return OPCODE_AE_MULF48Q32SP16S_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 120)
    return OPCODE_AE_MULF48Q32SP16U_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 121)
    return OPCODE_AE_MULFP24X2RA_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 122)
    return OPCODE_AE_MULFP24X2R_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 123)
    return OPCODE_AE_MULFP32X16X2RAS_H_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 124)
    return OPCODE_AE_MULFP32X16X2RAS_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 125)
    return OPCODE_AE_MULFP32X16X2RS_H_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 126)
    return OPCODE_AE_MULFP32X16X2RS_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 127)
    return OPCODE_AE_MULFQ32SP24S_H_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 128)
    return OPCODE_AE_MULFQ32SP24S_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 129)
    return OPCODE_AE_MULP24X2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 130)
    return OPCODE_AE_MULQ32SP16S_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 131)
    return OPCODE_AE_MULQ32SP16U_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 132)
    return OPCODE_AE_MULRFQ32SP24S_H_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 133)
    return OPCODE_AE_MULRFQ32SP24S_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 134)
    return OPCODE_AE_MULS32F48P16S_HH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 135)
    return OPCODE_AE_MULS32F48P16S_LH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 136)
    return OPCODE_AE_MULS32F48P16S_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 137)
    return OPCODE_AE_MULS32X16_H0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 138)
    return OPCODE_AE_MULS32X16_H1_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 139)
    return OPCODE_AE_MULS32X16_H2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 140)
    return OPCODE_AE_MULS32X16_H3_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 141)
    return OPCODE_AE_MULS32X16_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 142)
    return OPCODE_AE_MULS32X16_L1_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 143)
    return OPCODE_AE_MULS32X16_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 144)
    return OPCODE_AE_MULS32X16_L3_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 145)
    return OPCODE_AE_MULSAD24_HH_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 146)
    return OPCODE_AE_MULSAD32X16_H1_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 147)
    return OPCODE_AE_MULSAD32X16_H3_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 148)
    return OPCODE_AE_MULSAFD24_HH_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 149)
    return OPCODE_AE_MULSAFD32X16_H1_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 150)
    return OPCODE_AE_MULSAFD32X16_H3_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 151)
    return OPCODE_AE_MULSF16SS_00_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 152)
    return OPCODE_AE_MULSF32R_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 153)
    return OPCODE_AE_MULSF32X16_H0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 154)
    return OPCODE_AE_MULSF32X16_H1_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 155)
    return OPCODE_AE_MULSF32X16_H2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 156)
    return OPCODE_AE_MULSF32X16_H3_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 157)
    return OPCODE_AE_MULSF32X16_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 158)
    return OPCODE_AE_MULSF32X16_L1_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 159)
    return OPCODE_AE_MULSF32X16_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 160)
    return OPCODE_AE_MULSF32X16_L3_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 161)
    return OPCODE_AE_MULSF48Q32SP16S_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 162)
    return OPCODE_AE_MULSF48Q32SP16U_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 163)
    return OPCODE_AE_MULSFP24X2RA_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 164)
    return OPCODE_AE_MULSFP24X2R_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 165)
    return OPCODE_AE_MULSFP32X16X2RAS_H_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 166)
    return OPCODE_AE_MULSFP32X16X2RAS_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 167)
    return OPCODE_AE_MULSFP32X16X2RS_H_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 168)
    return OPCODE_AE_MULSFP32X16X2RS_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 169)
    return OPCODE_AE_MULSFQ32SP24S_H_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 170)
    return OPCODE_AE_MULSFQ32SP24S_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 171)
    return OPCODE_AE_MULSP24X2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 172)
    return OPCODE_AE_MULSQ32SP16S_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 173)
    return OPCODE_AE_MULSQ32SP16U_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 174)
    return OPCODE_AE_MULSRFQ32SP24S_H_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 175)
    return OPCODE_AE_MULSRFQ32SP24S_L_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 176)
    return OPCODE_AE_MULSS32F48P16S_HH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 177)
    return OPCODE_AE_MULSS32F48P16S_LH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 178)
    return OPCODE_AE_MULSS32F48P16S_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 179)
    return OPCODE_AE_MULSSD24_HH_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 180)
    return OPCODE_AE_MULSSD24_HL_LH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 181)
    return OPCODE_AE_MULSSD32X16_H1_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 182)
    return OPCODE_AE_MULSSD32X16_H3_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 183)
    return OPCODE_AE_MULSSFD16SS_11_00_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 184)
    return OPCODE_AE_MULSSFD16SS_13_02_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 185)
    return OPCODE_AE_MULSSFD16SS_33_22_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 186)
    return OPCODE_AE_MULSSFD24_HH_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 187)
    return OPCODE_AE_MULSSFD24_HL_LH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 188)
    return OPCODE_AE_MULSSFD32X16_H1_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 189)
    return OPCODE_AE_MULSSFD32X16_H3_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 190)
    return OPCODE_AE_MULZAAD24_HH_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 191)
    return OPCODE_AE_MULZAAD24_HL_LH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 192)
    return OPCODE_AE_MULZAAD32X16_H0_L1_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 193)
    return OPCODE_AE_MULZAAD32X16_H1_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 194)
    return OPCODE_AE_MULZAAD32X16_H2_L3_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 195)
    return OPCODE_AE_MULZAAD32X16_H3_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 196)
    return OPCODE_AE_MULZAAFD16SS_11_00_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 197)
    return OPCODE_AE_MULZAAFD16SS_13_02_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 198)
    return OPCODE_AE_MULZAAFD16SS_33_22_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 199)
    return OPCODE_AE_MULZAAFD24_HH_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 200)
    return OPCODE_AE_MULZAAFD24_HL_LH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 201)
    return OPCODE_AE_MULZAAFD32X16_H0_L1_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 202)
    return OPCODE_AE_MULZAAFD32X16_H1_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 203)
    return OPCODE_AE_MULZAAFD32X16_H2_L3_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 204)
    return OPCODE_AE_MULZAAFD32X16_H3_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 205)
    return OPCODE_AE_MULZASD24_HH_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 206)
    return OPCODE_AE_MULZASD24_HL_LH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 207)
    return OPCODE_AE_MULZASD32X16_H1_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 208)
    return OPCODE_AE_MULZASD32X16_H3_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 209)
    return OPCODE_AE_MULZASFD24_HH_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 210)
    return OPCODE_AE_MULZASFD24_HL_LH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 211)
    return OPCODE_AE_MULZASFD32X16_H1_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 212)
    return OPCODE_AE_MULZASFD32X16_H3_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 213)
    return OPCODE_AE_MULZSAD24_HH_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 214)
    return OPCODE_AE_MULZSAD32X16_H1_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 215)
    return OPCODE_AE_MULZSAD32X16_H3_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 216)
    return OPCODE_AE_MULZSAFD24_HH_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 217)
    return OPCODE_AE_MULZSAFD32X16_H1_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 218)
    return OPCODE_AE_MULZSAFD32X16_H3_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 219)
    return OPCODE_AE_MULZSSD24_HH_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 220)
    return OPCODE_AE_MULZSSD24_HL_LH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 221)
    return OPCODE_AE_MULZSSD32X16_H1_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 222)
    return OPCODE_AE_MULZSSD32X16_H3_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 223)
    return OPCODE_AE_MULZSSFD16SS_11_00_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 224)
    return OPCODE_AE_MULZSSFD16SS_13_02_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 225)
    return OPCODE_AE_MULZSSFD16SS_33_22_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 226)
    return OPCODE_AE_MULZSSFD24_HH_LL_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 227)
    return OPCODE_AE_MULZSSFD24_HL_LH_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 228)
    return OPCODE_AE_MULZSSFD32X16_H1_L0_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 229)
    return OPCODE_AE_MULZSSFD32X16_H3_L2_S2;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 230)
    return OPCODE_AE_SLAI16S;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 231)
    return OPCODE_AE_SRAI16;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 232)
    return OPCODE_AE_SRAI16R;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 233)
    return OPCODE_AE_SEXT32;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 234 &&
      Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (insn) == 0)
    return OPCODE_AE_SLAS24;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 234 &&
      Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (insn) == 12)
    return OPCODE_AE_SRLS24;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 234 &&
      Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (insn) == 8)
    return OPCODE_AE_SRAS24;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 234 &&
      Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (insn) == 2)
    return OPCODE_AE_SLAS32;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 234 &&
      Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (insn) == 13)
    return OPCODE_AE_SRLS32;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 234 &&
      Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (insn) == 9)
    return OPCODE_AE_SRAS32;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 234 &&
      Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (insn) == 1)
    return OPCODE_AE_SLAS24S;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 234 &&
      Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (insn) == 3)
    return OPCODE_AE_SLAS32S;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 234 &&
      Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (insn) == 6)
    return OPCODE_AE_SLASQ56;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 234 &&
      Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (insn) == 15)
    return OPCODE_AE_SRLSQ56;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 234 &&
      Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (insn) == 11)
    return OPCODE_AE_SRASQ56;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 234 &&
      Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (insn) == 4)
    return OPCODE_AE_SLAS64;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 234 &&
      Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (insn) == 14)
    return OPCODE_AE_SRLS64;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 234 &&
      Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (insn) == 10)
    return OPCODE_AE_SRAS64;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 234 &&
      Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (insn) == 7)
    return OPCODE_AE_SLASSQ56S;
  if (Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get (insn) == 234 &&
      Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get (insn) == 5)
    return OPCODE_AE_SLAS64S;
  if (Field_fld_ae_slot2_0_19_13_Slot_ae_slot2_0_get (insn) == 10)
    return OPCODE_AE_SLAI24;
  if (Field_fld_ae_slot2_0_19_13_Slot_ae_slot2_0_get (insn) == 11)
    return OPCODE_AE_SLAI24S;
  if (Field_fld_ae_slot2_0_19_13_Slot_ae_slot2_0_get (insn) == 12)
    return OPCODE_AE_SLAI32;
  if (Field_fld_ae_slot2_0_19_13_Slot_ae_slot2_0_get (insn) == 13)
    return OPCODE_AE_SLAI32S;
  if (Field_fld_ae_slot2_0_19_13_Slot_ae_slot2_0_get (insn) == 14)
    return OPCODE_AE_SRAI24;
  if (Field_fld_ae_slot2_0_19_13_Slot_ae_slot2_0_get (insn) == 15)
    return OPCODE_AE_SRAI32;
  if (Field_fld_ae_slot2_0_19_13_Slot_ae_slot2_0_get (insn) == 16)
    return OPCODE_AE_SRAI32R;
  if (Field_fld_ae_slot2_0_19_13_Slot_ae_slot2_0_get (insn) == 17)
    return OPCODE_AE_SRLI24;
  if (Field_fld_ae_slot2_0_19_13_Slot_ae_slot2_0_get (insn) == 18)
    return OPCODE_AE_SRLI32;
  if (Field_fld_ae_slot2_0_19_14_Slot_ae_slot2_0_get (insn) == 0)
    return OPCODE_AE_SLAI64;
  if (Field_fld_ae_slot2_0_19_14_Slot_ae_slot2_0_get (insn) == 1)
    return OPCODE_AE_SLAI64S;
  if (Field_fld_ae_slot2_0_19_14_Slot_ae_slot2_0_get (insn) == 2)
    return OPCODE_AE_SLAISQ56S;
  if (Field_fld_ae_slot2_0_19_14_Slot_ae_slot2_0_get (insn) == 3)
    return OPCODE_AE_SRAI64;
  if (Field_fld_ae_slot2_0_19_14_Slot_ae_slot2_0_get (insn) == 4)
    return OPCODE_AE_SRLI64;
  return XTENSA_UNDEFINED;
}

static int
Slot_ae_slot2_1_decode (const xtensa_insnbuf insn)
{
  if (Field_fld_ae_slot2_1_18_0_Slot_ae_slot2_1_get (insn) == 296448)
    return OPCODE_NOP;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 16)
    return OPCODE_AE_ADD16;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 17)
    return OPCODE_AE_ADD16S;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 18)
    return OPCODE_AE_ADD24S;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 19)
    return OPCODE_AE_ADD32;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 20)
    return OPCODE_AE_ADD32S;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 21)
    return OPCODE_AE_ADD32_HL_LH;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 22)
    return OPCODE_AE_ADD64;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 23)
    return OPCODE_AE_ADD64S;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 24)
    return OPCODE_AE_ADDSQ56S;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 25)
    return OPCODE_AE_ADDSUB32;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 26)
    return OPCODE_AE_ADDSUB32S;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 27)
    return OPCODE_AE_ROUND16X4F32SASYM;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 28)
    return OPCODE_AE_ROUND16X4F32SSYM;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 29)
    return OPCODE_AE_ROUND24X2F48SASYM;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 30)
    return OPCODE_AE_ROUND24X2F48SSYM;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 31)
    return OPCODE_AE_ROUND32X2F48SASYM;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 32)
    return OPCODE_AE_ROUND32X2F48SSYM;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 33)
    return OPCODE_AE_ROUND32X2F64SASYM;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 34)
    return OPCODE_AE_ROUND32X2F64SSYM;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 35)
    return OPCODE_AE_ROUNDSP16Q48X2ASYM;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 36)
    return OPCODE_AE_ROUNDSP16Q48X2SYM;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 37)
    return OPCODE_AE_SAT16X4;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 38)
    return OPCODE_AE_SUB16;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 39)
    return OPCODE_AE_SUB16S;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 40)
    return OPCODE_AE_SUB24S;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 41)
    return OPCODE_AE_SUB32;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 42)
    return OPCODE_AE_SUB32S;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 43)
    return OPCODE_AE_SUB64;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 44)
    return OPCODE_AE_SUB64S;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 45)
    return OPCODE_AE_SUBADD32;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 46)
    return OPCODE_AE_SUBADD32S;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 47)
    return OPCODE_AE_SUBSQ56S;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 48)
    return OPCODE_AE_EQ64;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 49)
    return OPCODE_AE_LE64;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 50)
    return OPCODE_AE_LT64;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 51)
    return OPCODE_AE_MAX32;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 52)
    return OPCODE_AE_MAX64;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 53)
    return OPCODE_AE_MAXABS32S;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 54)
    return OPCODE_AE_MAXABS64S;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 55)
    return OPCODE_AE_MIN32;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 56)
    return OPCODE_AE_MIN64;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 57)
    return OPCODE_AE_MINABS32S;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 58)
    return OPCODE_AE_MINABS64S;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 59)
    return OPCODE_AE_AND;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 60)
    return OPCODE_AE_NAND;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 61)
    return OPCODE_AE_OR;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 62)
    return OPCODE_AE_TRUNCP24Q48X2;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 63)
    return OPCODE_AE_XOR;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 64)
    return OPCODE_AE_MOVF64;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 65)
    return OPCODE_AE_MOVT64;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 66 &&
      Field_fld_ae_slot2_1_0_0_Slot_ae_slot2_1_get (insn) == 1)
    return OPCODE_AE_LE32;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 66 &&
      Field_fld_ae_slot2_1_0_0_Slot_ae_slot2_1_get (insn) == 0)
    return OPCODE_AE_EQ32;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 67 &&
      Field_fld_ae_slot2_1_1_0_Slot_ae_slot2_1_get (insn) == 3)
    return OPCODE_AE_LE16;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 67 &&
      Field_fld_ae_slot2_1_1_0_Slot_ae_slot2_1_get (insn) == 1)
    return OPCODE_AE_EQ16;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 67 &&
      Field_fld_ae_slot2_1_0_0_Slot_ae_slot2_1_get (insn) == 0)
    return OPCODE_AE_LT32;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 68 &&
      Field_fld_ae_slot2_1_8_8_Slot_ae_slot2_1_get (insn) == 1)
    return OPCODE_AE_MOVT32X2;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 68 &&
      Field_fld_ae_slot2_1_8_8_Slot_ae_slot2_1_get (insn) == 0)
    return OPCODE_AE_MOVF32X2;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 69 &&
      Field_fld_ae_slot2_1_9_8_Slot_ae_slot2_1_get (insn) == 1)
    return OPCODE_AE_MOVT16X4;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 69 &&
      Field_fld_ae_slot2_1_9_8_Slot_ae_slot2_1_get (insn) == 0)
    return OPCODE_AE_MOVF16X4;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 69 &&
      Field_fld_ae_slot2_1_9_8_Slot_ae_slot2_1_get (insn) == 2)
    return OPCODE_AE_MOVI;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 70 &&
      Field_fld_ae_slot2_1_1_0_Slot_ae_slot2_1_get (insn) == 0)
    return OPCODE_AE_LT16;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 73 &&
      Field_fld_ae_slot2_1_7_4_Slot_ae_slot2_1_get (insn) == 7)
    return OPCODE_AE_SHORTSWAP;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 73 &&
      Field_fld_ae_slot2_1_7_4_Slot_ae_slot2_1_get (insn) == 3)
    return OPCODE_AE_CVT32X2F16_32;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 73 &&
      Field_fld_ae_slot2_1_7_4_Slot_ae_slot2_1_get (insn) == 2)
    return OPCODE_AE_CVT32X2F16_10;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 73 &&
      Field_fld_ae_slot2_1_7_4_Slot_ae_slot2_1_get (insn) == 6)
    return OPCODE_AE_SEXT32X2D16_32;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 73 &&
      Field_fld_ae_slot2_1_7_4_Slot_ae_slot2_1_get (insn) == 5)
    return OPCODE_AE_SEXT32X2D16_10;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 73 &&
      Field_fld_ae_slot2_1_7_4_Slot_ae_slot2_1_get (insn) == 1)
    return OPCODE_AE_ROUNDSP16F24SYM;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 73 &&
      Field_fld_ae_slot2_1_7_4_Slot_ae_slot2_1_get (insn) == 0)
    return OPCODE_AE_ROUNDSP16F24ASYM;
  if (Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get (insn) == 73 &&
      Field_fld_ae_slot2_1_7_4_Slot_ae_slot2_1_get (insn) == 4)
    return OPCODE_AE_MOV;
  if (Field_fld_ae_slot2_1_18_16_Slot_ae_slot2_1_get (insn) == 0)
    return OPCODE_AE_SEL16I;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1107)
    return OPCODE_AE_ABS16S;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1111)
    return OPCODE_AE_ABS24S;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1115)
    return OPCODE_AE_ABS32;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1119)
    return OPCODE_AE_ABS32S;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1136)
    return OPCODE_AE_ABS64;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1137)
    return OPCODE_AE_ABS64S;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1138)
    return OPCODE_AE_ABSSQ56S;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1139)
    return OPCODE_AE_DIV64D32_H;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1140)
    return OPCODE_AE_DIV64D32_L;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1141)
    return OPCODE_AE_NEG16S;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1142)
    return OPCODE_AE_NEG24S;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1143)
    return OPCODE_AE_NEG32;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1144)
    return OPCODE_AE_NEG32S;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1145)
    return OPCODE_AE_NEG64;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1146)
    return OPCODE_AE_NEG64S;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1147)
    return OPCODE_AE_NEGSQ56S;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1148)
    return OPCODE_AE_ROUNDSQ32F48ASYM;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1149)
    return OPCODE_AE_ROUNDSQ32F48SYM;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1150)
    return OPCODE_AE_SAT24S;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1151)
    return OPCODE_AE_SAT48S;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1152)
    return OPCODE_AE_SATQ56S;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1153)
    return OPCODE_AE_CVT64F32_H;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1154)
    return OPCODE_AE_CVTQ56P32S_H;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1155)
    return OPCODE_AE_CVTQ56P32S_L;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1156)
    return OPCODE_AE_TRUNCP16;
  if (Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get (insn) == 1157)
    return OPCODE_AE_TRUNCQ32;
  return XTENSA_UNDEFINED;
}

static int
Slot_xt_dummy_decode (const xtensa_insnbuf insn)
{
  if (Field_fld_xt_dummy_0_0_Slot_xt_dummy_get (insn) == 0)
    return OPCODE_NOP;
  return XTENSA_UNDEFINED;
}

static int
Slot_xt_flix64_slot3_decode (const xtensa_insnbuf insn)
{
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 4)
    return OPCODE_BALL_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 5)
    return OPCODE_BANY_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 6)
    return OPCODE_BBC_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 7)
    return OPCODE_BBS_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 8)
    return OPCODE_BEQI_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 9)
    return OPCODE_BEQ_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 10)
    return OPCODE_BGEI_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 11)
    return OPCODE_BGEUI_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 12)
    return OPCODE_BGEU_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 13)
    return OPCODE_BGE_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 14)
    return OPCODE_BLTI_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 15)
    return OPCODE_BLTUI_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 16)
    return OPCODE_BLTU_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 17)
    return OPCODE_BLT_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 18)
    return OPCODE_BNALL_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 19)
    return OPCODE_BNEI_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 20)
    return OPCODE_BNE_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 21)
    return OPCODE_BNONE_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 22 &&
      Field_fld_xt_flix64_slot3_7_4_Slot_xt_flix64_slot3_get (insn) == 0)
    return OPCODE_BEQZ_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 22 &&
      Field_fld_xt_flix64_slot3_7_4_Slot_xt_flix64_slot3_get (insn) == 1)
    return OPCODE_BGEZ_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 22 &&
      Field_fld_xt_flix64_slot3_7_4_Slot_xt_flix64_slot3_get (insn) == 2)
    return OPCODE_BLTZ_W18;
  if (Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get (insn) == 22 &&
      Field_fld_xt_flix64_slot3_7_4_Slot_xt_flix64_slot3_get (insn) == 3)
    return OPCODE_BNEZ_W18;
  if (Field_fld_xt_flix64_slot3_30_27_Slot_xt_flix64_slot3_get (insn) == 0)
    return OPCODE_BBCI_W18;
  if (Field_fld_xt_flix64_slot3_30_27_Slot_xt_flix64_slot3_get (insn) == 1)
    return OPCODE_BBSI_W18;
  if (Field_fld_xt_flix64_slot3_30_6_Slot_xt_flix64_slot3_get (insn) == 23068673 &&
      Field_fld_xt_flix64_slot3_5_0_Slot_xt_flix64_slot3_get (insn) == 0)
    return OPCODE_NOP;
  return XTENSA_UNDEFINED;
}


/* Instruction slots.  */

static void
Slot_x24_Format_inst_0_get (const xtensa_insnbuf insn,
			    xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = (insn[0] & 0xffffff);
}

static void
Slot_x24_Format_inst_0_set (xtensa_insnbuf insn,
			    const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xffffff) | (slotbuf[0] & 0xffffff);
}

static void
Slot_x16a_Format_inst16a_0_get (const xtensa_insnbuf insn,
				xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = (insn[0] & 0xffff);
}

static void
Slot_x16a_Format_inst16a_0_set (xtensa_insnbuf insn,
				const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xffff) | (slotbuf[0] & 0xffff);
}

static void
Slot_x16b_Format_inst16b_0_get (const xtensa_insnbuf insn,
				xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = (insn[0] & 0xffff);
}

static void
Slot_x16b_Format_inst16b_0_set (xtensa_insnbuf insn,
				const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xffff) | (slotbuf[0] & 0xffff);
}

static void
Slot_ae_format_Format_ae_slot2_0_20_get (const xtensa_insnbuf insn,
					xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[0] & 0xf00000) >> 20);
  slotbuf[0] = (slotbuf[0] & ~0xf0) | (((insn[1] & 0xf0) >> 4) << 4);
  slotbuf[0] = (slotbuf[0] & ~0xf00) | (((insn[0] & 0xf0000000) >> 28) << 8);
  slotbuf[0] = (slotbuf[0] & ~0xff000) | (((insn[1] & 0xff000000) >> 24) << 12);
}

static void
Slot_ae_format_Format_ae_slot2_0_20_set (xtensa_insnbuf insn,
					const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xf00000) | ((slotbuf[0] & 0xf) << 20);
  insn[1] = (insn[1] & ~0xf0) | (((slotbuf[0] & 0xf0) >> 4) << 4);
  insn[0] = (insn[0] & ~0xf0000000) | (((slotbuf[0] & 0xf00) >> 8) << 28);
  insn[1] = (insn[1] & ~0xff000000) | (((slotbuf[0] & 0xff000) >> 12) << 24);
}

static void
Slot_ae_format_Format_ae_slot1_16_get (const xtensa_insnbuf insn,
				      xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[0] & 0xf0000) >> 16);
  slotbuf[0] = (slotbuf[0] & ~0xf0) | (((insn[0] & 0xf000000) >> 24) << 4);
  slotbuf[0] = (slotbuf[0] & ~0xf00) | ((insn[1] & 0xf) << 8);
  slotbuf[0] = (slotbuf[0] & ~0xff000) | (((insn[1] & 0xff0000) >> 16) << 12);
}

static void
Slot_ae_format_Format_ae_slot1_16_set (xtensa_insnbuf insn,
				      const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xf0000) | ((slotbuf[0] & 0xf) << 16);
  insn[0] = (insn[0] & ~0xf000000) | (((slotbuf[0] & 0xf0) >> 4) << 24);
  insn[1] = (insn[1] & ~0xf) | ((slotbuf[0] & 0xf00) >> 8);
  insn[1] = (insn[1] & ~0xff0000) | (((slotbuf[0] & 0xff000) >> 12) << 16);
}

static void
Slot_ae_format1_Format_ae_slot1_16_get (const xtensa_insnbuf insn,
				       xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[0] & 0xf0000) >> 16);
  slotbuf[0] = (slotbuf[0] & ~0xf0) | (((insn[0] & 0xf000000) >> 24) << 4);
  slotbuf[0] = (slotbuf[0] & ~0xf00) | ((insn[1] & 0xf) << 8);
  slotbuf[0] = (slotbuf[0] & ~0xff000) | (((insn[1] & 0xff0000) >> 16) << 12);
}

static void
Slot_ae_format1_Format_ae_slot1_16_set (xtensa_insnbuf insn,
				       const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xf0000) | ((slotbuf[0] & 0xf) << 16);
  insn[0] = (insn[0] & ~0xf000000) | (((slotbuf[0] & 0xf0) >> 4) << 24);
  insn[1] = (insn[1] & ~0xf) | ((slotbuf[0] & 0xf00) >> 8);
  insn[1] = (insn[1] & ~0xff0000) | (((slotbuf[0] & 0xff000) >> 12) << 16);
}

static void
Slot_ae_format_Format_ae_slot0_4_get (const xtensa_insnbuf insn,
				      xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[0] & 0xf00) >> 8);
  slotbuf[0] = (slotbuf[0] & ~0xf0) | (((insn[0] & 0xf0) >> 4) << 4);
  slotbuf[0] = (slotbuf[0] & ~0xf00) | (((insn[0] & 0xf000) >> 12) << 8);
  slotbuf[0] = (slotbuf[0] & ~0xff000) | (((insn[1] & 0xff00) >> 8) << 12);
}

static void
Slot_ae_format_Format_ae_slot0_4_set (xtensa_insnbuf insn,
				      const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xf00) | ((slotbuf[0] & 0xf) << 8);
  insn[0] = (insn[0] & ~0xf0) | (((slotbuf[0] & 0xf0) >> 4) << 4);
  insn[0] = (insn[0] & ~0xf000) | (((slotbuf[0] & 0xf00) >> 8) << 12);
  insn[1] = (insn[1] & ~0xff00) | (((slotbuf[0] & 0xff000) >> 12) << 8);
}

static void
Slot_ae_format1_Format_ae_slot0_4_get (const xtensa_insnbuf insn,
				       xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[0] & 0xf00) >> 8);
  slotbuf[0] = (slotbuf[0] & ~0xf0) | (((insn[0] & 0xf0) >> 4) << 4);
  slotbuf[0] = (slotbuf[0] & ~0xf00) | (((insn[0] & 0xf000) >> 12) << 8);
  slotbuf[0] = (slotbuf[0] & ~0xff000) | (((insn[1] & 0xff00) >> 8) << 12);
}

static void
Slot_ae_format1_Format_ae_slot0_4_set (xtensa_insnbuf insn,
				       const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xf00) | ((slotbuf[0] & 0xf) << 8);
  insn[0] = (insn[0] & ~0xf0) | (((slotbuf[0] & 0xf0) >> 4) << 4);
  insn[0] = (insn[0] & ~0xf000) | (((slotbuf[0] & 0xf00) >> 8) << 12);
  insn[1] = (insn[1] & ~0xff00) | (((slotbuf[0] & 0xff000) >> 12) << 8);
}

static void
Slot_ae_format1_Format_ae_slot2_1_20_get (const xtensa_insnbuf insn,
					 xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[0] & 0xf00000) >> 20);
  slotbuf[0] = (slotbuf[0] & ~0xf0) | (((insn[1] & 0xf0) >> 4) << 4);
  slotbuf[0] = (slotbuf[0] & ~0xf00) | (((insn[0] & 0xf0000000) >> 28) << 8);
  slotbuf[0] = (slotbuf[0] & ~0x7f000) | (((insn[1] & 0x7f000000) >> 24) << 12);
}

static void
Slot_ae_format1_Format_ae_slot2_1_20_set (xtensa_insnbuf insn,
					 const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xf00000) | ((slotbuf[0] & 0xf) << 20);
  insn[1] = (insn[1] & ~0xf0) | (((slotbuf[0] & 0xf0) >> 4) << 4);
  insn[0] = (insn[0] & ~0xf0000000) | (((slotbuf[0] & 0xf00) >> 8) << 28);
  insn[1] = (insn[1] & ~0x7f000000) | (((slotbuf[0] & 0x7f000) >> 12) << 24);
}

static void
Slot_ae_format2_Format_ae2_slot1_16_get (const xtensa_insnbuf insn,
					xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[0] & 0xfff0000) >> 16);
  slotbuf[0] = (slotbuf[0] & ~0xff000) | ((insn[1] & 0xff) << 12);
  slotbuf[0] = (slotbuf[0] & ~0xf00000) | (((insn[1] & 0xf000000) >> 24) << 20);
}

static void
Slot_ae_format2_Format_ae2_slot1_16_set (xtensa_insnbuf insn,
					const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xfff0000) | ((slotbuf[0] & 0xfff) << 16);
  insn[1] = (insn[1] & ~0xff) | ((slotbuf[0] & 0xff000) >> 12);
  insn[1] = (insn[1] & ~0xf000000) | (((slotbuf[0] & 0xf00000) >> 20) << 24);
}

static void
Slot_ae_format2_Format_ae2_slot0_4_get (const xtensa_insnbuf insn,
					xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[0] & 0xf00) >> 8);
  slotbuf[0] = (slotbuf[0] & ~0xf0) | (((insn[0] & 0xf0) >> 4) << 4);
  slotbuf[0] = (slotbuf[0] & ~0xf00) | (((insn[0] & 0xf000) >> 12) << 8);
  slotbuf[0] = (slotbuf[0] & ~0xf000) | (((insn[0] & 0xf0000000) >> 28) << 12);
  slotbuf[0] = (slotbuf[0] & ~0xffff0000) | (((insn[1] & 0xffff00) >> 8) << 16);
}

static void
Slot_ae_format2_Format_ae2_slot0_4_set (xtensa_insnbuf insn,
					const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xf00) | ((slotbuf[0] & 0xf) << 8);
  insn[0] = (insn[0] & ~0xf0) | (((slotbuf[0] & 0xf0) >> 4) << 4);
  insn[0] = (insn[0] & ~0xf000) | (((slotbuf[0] & 0xf00) >> 8) << 12);
  insn[0] = (insn[0] & ~0xf0000000) | (((slotbuf[0] & 0xf000) >> 12) << 28);
  insn[1] = (insn[1] & ~0xffff00) | (((slotbuf[0] & 0xffff0000) >> 16) << 8);
}

static void
Slot_ae_mini0_Format_ae_minislot2_4_get (const xtensa_insnbuf insn,
					 xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[0] & 0xf0) >> 4);
  slotbuf[0] = (slotbuf[0] & ~0xf0) | (((insn[0] & 0xf000) >> 12) << 4);
  slotbuf[0] = (slotbuf[0] & ~0xf00) | (((insn[1] & 0xf0) >> 4) << 8);
  slotbuf[0] = (slotbuf[0] & ~0xf000) | (((insn[0] & 0xf00000) >> 20) << 12);
  slotbuf[0] = (slotbuf[0] & ~0x30000) | (((insn[1] & 0xc) >> 2) << 16);
  slotbuf[0] = (slotbuf[0] & ~0x40000) | (((insn[1] & 0x100) >> 8) << 18);
}

static void
Slot_ae_mini0_Format_ae_minislot2_4_set (xtensa_insnbuf insn,
					 const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xf0) | ((slotbuf[0] & 0xf) << 4);
  insn[0] = (insn[0] & ~0xf000) | (((slotbuf[0] & 0xf0) >> 4) << 12);
  insn[1] = (insn[1] & ~0xf0) | (((slotbuf[0] & 0xf00) >> 8) << 4);
  insn[0] = (insn[0] & ~0xf00000) | (((slotbuf[0] & 0xf000) >> 12) << 20);
  insn[1] = (insn[1] & ~0xc) | (((slotbuf[0] & 0x30000) >> 16) << 2);
  insn[1] = (insn[1] & ~0x100) | (((slotbuf[0] & 0x40000) >> 18) << 8);
}

static void
Slot_ae_mini0_Format_ae_minislot1_33_get (const xtensa_insnbuf insn,
					 xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[1] & 0x2) >> 1);
}

static void
Slot_ae_mini0_Format_ae_minislot1_33_set (xtensa_insnbuf insn,
					 const xtensa_insnbuf slotbuf)
{
  insn[1] = (insn[1] & ~0x2) | ((slotbuf[0] & 0x1) << 1);
}

static void
Slot_ae_mini0_Format_ae_minislot0_8_get (const xtensa_insnbuf insn,
					 xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[0] & 0xf00) >> 8);
  slotbuf[0] = (slotbuf[0] & ~0xf0) | (((insn[0] & 0xf0000) >> 16) << 4);
  slotbuf[0] = (slotbuf[0] & ~0xff00) | (((insn[0] & 0xff000000) >> 24) << 8);
  slotbuf[0] = (slotbuf[0] & ~0x10000) | ((insn[1] & 0x1) << 16);
}

static void
Slot_ae_mini0_Format_ae_minislot0_8_set (xtensa_insnbuf insn,
					 const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xf00) | ((slotbuf[0] & 0xf) << 8);
  insn[0] = (insn[0] & ~0xf0000) | (((slotbuf[0] & 0xf0) >> 4) << 16);
  insn[0] = (insn[0] & ~0xff000000) | (((slotbuf[0] & 0xff00) >> 8) << 24);
  insn[1] = (insn[1] & ~0x1) | ((slotbuf[0] & 0x10000) >> 16);
}

static void
Slot_xt_format1_Format_xt_flix64_slot2_20_get (const xtensa_insnbuf insn,
					      xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[0] & 0xff00000) >> 20);
  slotbuf[0] = (slotbuf[0] & ~0xf00) | (((insn[1] & 0xf0) >> 4) << 8);
  slotbuf[0] = (slotbuf[0] & ~0x7000) | (((insn[1] & 0x1c000000) >> 26) << 12);
  slotbuf[0] = (slotbuf[0] & ~0x8000) | (((insn[1] & 0x40000000) >> 30) << 15);
}

static void
Slot_xt_format1_Format_xt_flix64_slot2_20_set (xtensa_insnbuf insn,
					      const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xff00000) | ((slotbuf[0] & 0xff) << 20);
  insn[1] = (insn[1] & ~0xf0) | (((slotbuf[0] & 0xf00) >> 8) << 4);
  insn[1] = (insn[1] & ~0x1c000000) | (((slotbuf[0] & 0x7000) >> 12) << 26);
  insn[1] = (insn[1] & ~0x40000000) | (((slotbuf[0] & 0x8000) >> 15) << 30);
}

static void
Slot_xt_format1_Format_xt_dummy_57_get (const xtensa_insnbuf insn,
				       xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[1] & 0x2000000) >> 25);
}

static void
Slot_xt_format1_Format_xt_dummy_57_set (xtensa_insnbuf insn,
				       const xtensa_insnbuf slotbuf)
{
  insn[1] = (insn[1] & ~0x2000000) | ((slotbuf[0] & 0x1) << 25);
}

static void
Slot_xt_format1_Format_xt_flix64_slot1_16_get (const xtensa_insnbuf insn,
					      xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[0] & 0xf0000) >> 16);
  slotbuf[0] = (slotbuf[0] & ~0xf0) | (((insn[0] & 0xf0000000) >> 28) << 4);
  slotbuf[0] = (slotbuf[0] & ~0xf00) | ((insn[1] & 0xf) << 8);
  slotbuf[0] = (slotbuf[0] & ~0xff000) | (((insn[1] & 0x1fe0000) >> 17) << 12);
}

static void
Slot_xt_format1_Format_xt_flix64_slot1_16_set (xtensa_insnbuf insn,
					      const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xf0000) | ((slotbuf[0] & 0xf) << 16);
  insn[0] = (insn[0] & ~0xf0000000) | (((slotbuf[0] & 0xf0) >> 4) << 28);
  insn[1] = (insn[1] & ~0xf) | ((slotbuf[0] & 0xf00) >> 8);
  insn[1] = (insn[1] & ~0x1fe0000) | (((slotbuf[0] & 0xff000) >> 12) << 17);
}

static void
Slot_xt_format1_Format_xt_flix64_slot0_4_get (const xtensa_insnbuf insn,
					      xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[0] & 0xfff0) >> 4);
  slotbuf[0] = (slotbuf[0] & ~0x1ff000) | (((insn[1] & 0x1ff00) >> 8) << 12);
}

static void
Slot_xt_format1_Format_xt_flix64_slot0_4_set (xtensa_insnbuf insn,
					      const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xfff0) | ((slotbuf[0] & 0xfff) << 4);
  insn[1] = (insn[1] & ~0x1ff00) | (((slotbuf[0] & 0x1ff000) >> 12) << 8);
}

static void
Slot_xt_format2_Format_xt_flix64_slot0_4_get (const xtensa_insnbuf insn,
					      xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[0] & 0xfff0) >> 4);
  slotbuf[0] = (slotbuf[0] & ~0xff000) | (((insn[0] & 0xff00000) >> 20) << 12);
  slotbuf[0] = (slotbuf[0] & ~0x100000) | ((insn[1] & 0x1) << 20);
}

static void
Slot_xt_format2_Format_xt_flix64_slot0_4_set (xtensa_insnbuf insn,
					      const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xfff0) | ((slotbuf[0] & 0xfff) << 4);
  insn[0] = (insn[0] & ~0xff00000) | (((slotbuf[0] & 0xff000) >> 12) << 20);
  insn[1] = (insn[1] & ~0x1) | ((slotbuf[0] & 0x100000) >> 20);
}

static void
Slot_xt_format2_Format_xt_flix64_slot3_16_get (const xtensa_insnbuf insn,
					      xtensa_insnbuf slotbuf)
{
  slotbuf[1] = 0;
  slotbuf[0] = ((insn[0] & 0xf0000000) >> 28);
  slotbuf[0] = (slotbuf[0] & ~0xf0) | (((insn[0] & 0xf0000) >> 16) << 4);
  slotbuf[0] = (slotbuf[0] & ~0x7fffff00) | (((insn[1] & 0xfffffe) >> 1) << 8);
}

static void
Slot_xt_format2_Format_xt_flix64_slot3_16_set (xtensa_insnbuf insn,
					      const xtensa_insnbuf slotbuf)
{
  insn[0] = (insn[0] & ~0xf0000000) | ((slotbuf[0] & 0xf) << 28);
  insn[0] = (insn[0] & ~0xf0000) | (((slotbuf[0] & 0xf0) >> 4) << 16);
  insn[1] = (insn[1] & ~0xfffffe) | (((slotbuf[0] & 0x7fffff00) >> 8) << 1);
}

static xtensa_get_field_fn
Slot_inst_get_field_fns[] = {
  Field_t_Slot_inst_get,
  Field_bbi4_Slot_inst_get,
  Field_bbi_Slot_inst_get,
  Field_imm12_Slot_inst_get,
  Field_imm8_Slot_inst_get,
  Field_s_Slot_inst_get,
  Field_imm12b_Slot_inst_get,
  Field_imm16_Slot_inst_get,
  Field_m_Slot_inst_get,
  Field_n_Slot_inst_get,
  Field_offset_Slot_inst_get,
  Field_op0_Slot_inst_get,
  Field_op1_Slot_inst_get,
  Field_op2_Slot_inst_get,
  Field_r_Slot_inst_get,
  Field_r_disp_Slot_inst_get,
  Field_r_3_Slot_inst_get,
  Field_sa4_Slot_inst_get,
  Field_sae4_Slot_inst_get,
  Field_sae_Slot_inst_get,
  Field_sal_Slot_inst_get,
  Field_sargt_Slot_inst_get,
  Field_sas4_Slot_inst_get,
  Field_sas_Slot_inst_get,
  Field_sr_Slot_inst_get,
  Field_st_Slot_inst_get,
  Field_thi3_Slot_inst_get,
  Field_imm4_Slot_inst_get,
  Field_mn_Slot_inst_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_t2_Slot_inst_get,
  Field_s2_Slot_inst_get,
  Field_r2_Slot_inst_get,
  Field_t4_Slot_inst_get,
  Field_s4_Slot_inst_get,
  Field_r4_Slot_inst_get,
  Field_t8_Slot_inst_get,
  Field_s8_Slot_inst_get,
  Field_r8_Slot_inst_get,
  Field_xt_wbr15_imm_Slot_inst_get,
  Field_xt_wbr18_imm_Slot_inst_get,
  Field_ae_fld_fhba4_Slot_inst_get,
  Field_ae_fld_fhba4_2_Slot_inst_get,
  Field_ae_fld_tp7_Slot_inst_get,
  Field_ae_fld_osa32_Slot_inst_get,
  Field_ae_fld_osa64_Slot_inst_get,
  Field_ae_fld_imm2_Slot_inst_get,
  Field_ae_fld_immls64_Slot_inst_get,
  Field_ae_fld_immls64pos_Slot_inst_get,
  Field_ae_fld_immls32_Slot_inst_get,
  Field_ae_fld_immls16_Slot_inst_get,
  0,
  Field_inst_15_12_Slot_inst_get,
  Field_inst_11_8_Slot_inst_get,
  Field_inst_7_4_Slot_inst_get,
  Field_inst_12_Slot_inst_get,
  Field_inst_7_Slot_inst_get,
  Field_inst_5_4_Slot_inst_get,
  Field_inst_7_6_Slot_inst_get,
  Field_inst_19_17_Slot_inst_get,
  Field_inst_19_18_Slot_inst_get,
  Field_inst_9_8_Slot_inst_get,
  Field_inst_4_Slot_inst_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_ls_v_Slot_inst_get,
  Field_ae_fld_ls_uu_Slot_inst_get,
  Field_ae_fld_ls_su_Slot_inst_get,
  Field_ae_fld_ls_av_Slot_inst_get,
  Field_ae_fld_ls_v1_Slot_inst_get,
  Field_ae_fld_ls_v2_Slot_inst_get,
  Field_ae_fld_cmpp_v0_Slot_inst_get,
  Field_ae_fld_cmpp_v1_Slot_inst_get,
  Field_ae_fld_cmpp_v_Slot_inst_get,
  Field_ae_fld_uu_v_Slot_inst_get,
  Field_ae_fld_uu_uu_Slot_inst_get,
  Field_ae_fld_dr_to_ar_v0_Slot_inst_get,
  Field_ae_fld_cmov_v_Slot_inst_get,
  Field_ae_fld_cmov_v0_Slot_inst_get,
  Field_ae_fld_pks_d_Slot_inst_get,
  Field_ae_fld_pks_s_Slot_inst_get,
  Field_ae_fld_shift_d_Slot_inst_get,
  Field_ae_fld_shift_d0_Slot_inst_get,
  Field_ae_fld_shift_sd_Slot_inst_get,
  Field_ae_fld_dr_to_dr_v_Slot_inst_get,
  Field_ae_fld_dr_to_dr_v0_Slot_inst_get,
  Field_ae_fld_dr_to_dr_v1_Slot_inst_get,
  Field_ae_fld_to_dr_v_Slot_inst_get,
  Field_ae_fld_to_dr_v0_Slot_inst_get,
  Field_ae_fld_selimm_Slot_inst_get,
  0,
  Field_fld_ar_to_dr_imm_Slot_inst_get,
  Field_ae_fld_arth_v_Slot_inst_get,
  Field_ae_fld_arth_v0_Slot_inst_get,
  Field_ae_fld_arth_v1_Slot_inst_get,
  Field_ae_fld_ar_to_dr_v_Slot_inst_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_inst_set_field_fns[] = {
  Field_t_Slot_inst_set,
  Field_bbi4_Slot_inst_set,
  Field_bbi_Slot_inst_set,
  Field_imm12_Slot_inst_set,
  Field_imm8_Slot_inst_set,
  Field_s_Slot_inst_set,
  Field_imm12b_Slot_inst_set,
  Field_imm16_Slot_inst_set,
  Field_m_Slot_inst_set,
  Field_n_Slot_inst_set,
  Field_offset_Slot_inst_set,
  Field_op0_Slot_inst_set,
  Field_op1_Slot_inst_set,
  Field_op2_Slot_inst_set,
  Field_r_Slot_inst_set,
  Field_r_disp_Slot_inst_set,
  Field_r_3_Slot_inst_set,
  Field_sa4_Slot_inst_set,
  Field_sae4_Slot_inst_set,
  Field_sae_Slot_inst_set,
  Field_sal_Slot_inst_set,
  Field_sargt_Slot_inst_set,
  Field_sas4_Slot_inst_set,
  Field_sas_Slot_inst_set,
  Field_sr_Slot_inst_set,
  Field_st_Slot_inst_set,
  Field_thi3_Slot_inst_set,
  Field_imm4_Slot_inst_set,
  Field_mn_Slot_inst_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_t2_Slot_inst_set,
  Field_s2_Slot_inst_set,
  Field_r2_Slot_inst_set,
  Field_t4_Slot_inst_set,
  Field_s4_Slot_inst_set,
  Field_r4_Slot_inst_set,
  Field_t8_Slot_inst_set,
  Field_s8_Slot_inst_set,
  Field_r8_Slot_inst_set,
  Field_xt_wbr15_imm_Slot_inst_set,
  Field_xt_wbr18_imm_Slot_inst_set,
  Field_ae_fld_fhba4_Slot_inst_set,
  Field_ae_fld_fhba4_2_Slot_inst_set,
  Field_ae_fld_tp7_Slot_inst_set,
  Field_ae_fld_osa32_Slot_inst_set,
  Field_ae_fld_osa64_Slot_inst_set,
  Field_ae_fld_imm2_Slot_inst_set,
  Field_ae_fld_immls64_Slot_inst_set,
  Field_ae_fld_immls64pos_Slot_inst_set,
  Field_ae_fld_immls32_Slot_inst_set,
  Field_ae_fld_immls16_Slot_inst_set,
  0,
  Field_inst_15_12_Slot_inst_set,
  Field_inst_11_8_Slot_inst_set,
  Field_inst_7_4_Slot_inst_set,
  Field_inst_12_Slot_inst_set,
  Field_inst_7_Slot_inst_set,
  Field_inst_5_4_Slot_inst_set,
  Field_inst_7_6_Slot_inst_set,
  Field_inst_19_17_Slot_inst_set,
  Field_inst_19_18_Slot_inst_set,
  Field_inst_9_8_Slot_inst_set,
  Field_inst_4_Slot_inst_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_ls_v_Slot_inst_set,
  Field_ae_fld_ls_uu_Slot_inst_set,
  Field_ae_fld_ls_su_Slot_inst_set,
  Field_ae_fld_ls_av_Slot_inst_set,
  Field_ae_fld_ls_v1_Slot_inst_set,
  Field_ae_fld_ls_v2_Slot_inst_set,
  Field_ae_fld_cmpp_v0_Slot_inst_set,
  Field_ae_fld_cmpp_v1_Slot_inst_set,
  Field_ae_fld_cmpp_v_Slot_inst_set,
  Field_ae_fld_uu_v_Slot_inst_set,
  Field_ae_fld_uu_uu_Slot_inst_set,
  Field_ae_fld_dr_to_ar_v0_Slot_inst_set,
  Field_ae_fld_cmov_v_Slot_inst_set,
  Field_ae_fld_cmov_v0_Slot_inst_set,
  Field_ae_fld_pks_d_Slot_inst_set,
  Field_ae_fld_pks_s_Slot_inst_set,
  Field_ae_fld_shift_d_Slot_inst_set,
  Field_ae_fld_shift_d0_Slot_inst_set,
  Field_ae_fld_shift_sd_Slot_inst_set,
  Field_ae_fld_dr_to_dr_v_Slot_inst_set,
  Field_ae_fld_dr_to_dr_v0_Slot_inst_set,
  Field_ae_fld_dr_to_dr_v1_Slot_inst_set,
  Field_ae_fld_to_dr_v_Slot_inst_set,
  Field_ae_fld_to_dr_v0_Slot_inst_set,
  Field_ae_fld_selimm_Slot_inst_set,
  0,
  Field_fld_ar_to_dr_imm_Slot_inst_set,
  Field_ae_fld_arth_v_Slot_inst_set,
  Field_ae_fld_arth_v0_Slot_inst_set,
  Field_ae_fld_arth_v1_Slot_inst_set,
  Field_ae_fld_ar_to_dr_v_Slot_inst_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_get_field_fn
Slot_inst16a_get_field_fns[] = {
  Field_t_Slot_inst16a_get,
  0,
  0,
  0,
  0,
  Field_s_Slot_inst16a_get,
  0,
  0,
  0,
  0,
  0,
  Field_op0_Slot_inst16a_get,
  0,
  0,
  Field_r_Slot_inst16a_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_i_Slot_inst16a_get,
  Field_imm6lo_Slot_inst16a_get,
  Field_imm6hi_Slot_inst16a_get,
  Field_imm7lo_Slot_inst16a_get,
  Field_imm7hi_Slot_inst16a_get,
  Field_z_Slot_inst16a_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_inst16a_set_field_fns[] = {
  Field_t_Slot_inst16a_set,
  0,
  0,
  0,
  0,
  Field_s_Slot_inst16a_set,
  0,
  0,
  0,
  0,
  0,
  Field_op0_Slot_inst16a_set,
  0,
  0,
  Field_r_Slot_inst16a_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_i_Slot_inst16a_set,
  Field_imm6lo_Slot_inst16a_set,
  Field_imm6hi_Slot_inst16a_set,
  Field_imm7lo_Slot_inst16a_set,
  Field_imm7hi_Slot_inst16a_set,
  Field_z_Slot_inst16a_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_get_field_fn
Slot_inst16b_get_field_fns[] = {
  Field_t_Slot_inst16b_get,
  0,
  0,
  0,
  0,
  Field_s_Slot_inst16b_get,
  0,
  0,
  0,
  0,
  0,
  Field_op0_Slot_inst16b_get,
  0,
  0,
  Field_r_Slot_inst16b_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_i_Slot_inst16b_get,
  Field_imm6lo_Slot_inst16b_get,
  Field_imm6hi_Slot_inst16b_get,
  Field_imm7lo_Slot_inst16b_get,
  Field_imm7hi_Slot_inst16b_get,
  Field_z_Slot_inst16b_get,
  Field_imm6_Slot_inst16b_get,
  Field_imm7_Slot_inst16b_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_inst16b_set_field_fns[] = {
  Field_t_Slot_inst16b_set,
  0,
  0,
  0,
  0,
  Field_s_Slot_inst16b_set,
  0,
  0,
  0,
  0,
  0,
  Field_op0_Slot_inst16b_set,
  0,
  0,
  Field_r_Slot_inst16b_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_i_Slot_inst16b_set,
  Field_imm6lo_Slot_inst16b_set,
  Field_imm6hi_Slot_inst16b_set,
  Field_imm7lo_Slot_inst16b_set,
  Field_imm7hi_Slot_inst16b_set,
  Field_z_Slot_inst16b_set,
  Field_imm6_Slot_inst16b_set,
  Field_imm7_Slot_inst16b_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_get_field_fn
Slot_ae_slot2_0_get_field_fns[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_tp7_Slot_ae_slot2_0_get,
  Field_ae_fld_osa32_Slot_ae_slot2_0_get,
  Field_ae_fld_osa64_Slot_ae_slot2_0_get,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_osa16_Slot_ae_slot2_0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_mul_x2_s2_d1_Slot_ae_slot2_0_get,
  Field_ae_fld_mul_x2_s2_d0_Slot_ae_slot2_0_get,
  Field_ae_fld_mul_x2_s2_q0_Slot_ae_slot2_0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_shift_d_Slot_ae_slot2_0_get,
  Field_ae_fld_shift_d0_Slot_ae_slot2_0_get,
  0,
  Field_ae_fld_dr_to_dr_v_Slot_ae_slot2_0_get,
  Field_ae_fld_dr_to_dr_v0_Slot_ae_slot2_0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot2_0_19_0_Slot_ae_slot2_0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_get,
  0,
  Field_fld_ae_slot2_0_19_13_Slot_ae_slot2_0_get,
  0,
  Field_fld_ae_slot2_0_19_14_Slot_ae_slot2_0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_ae_slot2_0_set_field_fns[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_tp7_Slot_ae_slot2_0_set,
  Field_ae_fld_osa32_Slot_ae_slot2_0_set,
  Field_ae_fld_osa64_Slot_ae_slot2_0_set,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_osa16_Slot_ae_slot2_0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_mul_x2_s2_d1_Slot_ae_slot2_0_set,
  Field_ae_fld_mul_x2_s2_d0_Slot_ae_slot2_0_set,
  Field_ae_fld_mul_x2_s2_q0_Slot_ae_slot2_0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_shift_d_Slot_ae_slot2_0_set,
  Field_ae_fld_shift_d0_Slot_ae_slot2_0_set,
  0,
  Field_ae_fld_dr_to_dr_v_Slot_ae_slot2_0_set,
  Field_ae_fld_dr_to_dr_v0_Slot_ae_slot2_0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot2_0_19_0_Slot_ae_slot2_0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot2_0_19_12_Slot_ae_slot2_0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot2_0_7_4_Slot_ae_slot2_0_set,
  0,
  Field_fld_ae_slot2_0_19_13_Slot_ae_slot2_0_set,
  0,
  Field_fld_ae_slot2_0_19_14_Slot_ae_slot2_0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_get_field_fn
Slot_ae_slot1_get_field_fns[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_imm2_Slot_ae_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_mul_d0_Slot_ae_slot1_get,
  Field_ae_fld_mul_d1_Slot_ae_slot1_get,
  Field_ae_fld_mul_q0_Slot_ae_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_pks_d_Slot_ae_slot1_get,
  Field_ae_fld_pks_s_Slot_ae_slot1_get,
  0,
  0,
  0,
  Field_ae_fld_dr_to_dr_v_Slot_ae_slot1_get,
  Field_ae_fld_dr_to_dr_v0_Slot_ae_slot1_get,
  Field_ae_fld_dr_to_dr_v1_Slot_ae_slot1_get,
  Field_ae_fld_to_dr_v_Slot_ae_slot1_get,
  Field_ae_fld_to_dr_v0_Slot_ae_slot1_get,
  0,
  Field_ae_fld_selimm_n_Slot_ae_slot1_get,
  Field_fld_ar_to_dr_imm_Slot_ae_slot1_get,
  Field_ae_fld_arth_v_Slot_ae_slot1_get,
  Field_ae_fld_arth_v0_Slot_ae_slot1_get,
  Field_ae_fld_arth_v1_Slot_ae_slot1_get,
  Field_ae_fld_ar_to_dr_v_Slot_ae_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot1_19_0_Slot_ae_slot1_get,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot1_19_14_Slot_ae_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot1_19_12_Slot_ae_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot1_7_4_Slot_ae_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot1_9_8_Slot_ae_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot1_0_0_Slot_ae_slot1_get,
  Field_fld_ae_slot1_3_3_Slot_ae_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_ae_slot1_set_field_fns[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_imm2_Slot_ae_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_mul_d0_Slot_ae_slot1_set,
  Field_ae_fld_mul_d1_Slot_ae_slot1_set,
  Field_ae_fld_mul_q0_Slot_ae_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_pks_d_Slot_ae_slot1_set,
  Field_ae_fld_pks_s_Slot_ae_slot1_set,
  0,
  0,
  0,
  Field_ae_fld_dr_to_dr_v_Slot_ae_slot1_set,
  Field_ae_fld_dr_to_dr_v0_Slot_ae_slot1_set,
  Field_ae_fld_dr_to_dr_v1_Slot_ae_slot1_set,
  Field_ae_fld_to_dr_v_Slot_ae_slot1_set,
  Field_ae_fld_to_dr_v0_Slot_ae_slot1_set,
  0,
  Field_ae_fld_selimm_n_Slot_ae_slot1_set,
  Field_fld_ar_to_dr_imm_Slot_ae_slot1_set,
  Field_ae_fld_arth_v_Slot_ae_slot1_set,
  Field_ae_fld_arth_v0_Slot_ae_slot1_set,
  Field_ae_fld_arth_v1_Slot_ae_slot1_set,
  Field_ae_fld_ar_to_dr_v_Slot_ae_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot1_19_0_Slot_ae_slot1_set,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot1_19_14_Slot_ae_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot1_19_12_Slot_ae_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot1_7_4_Slot_ae_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot1_9_8_Slot_ae_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot1_0_0_Slot_ae_slot1_set,
  Field_fld_ae_slot1_3_3_Slot_ae_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_get_field_fn
Slot_ae_slot0_get_field_fns[] = {
  Field_t_Slot_ae_slot0_get,
  0,
  0,
  0,
  Field_imm8_Slot_ae_slot0_get,
  Field_s_Slot_ae_slot0_get,
  Field_imm12b_Slot_ae_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_op2_Slot_ae_slot0_get,
  Field_r_Slot_ae_slot0_get,
  0,
  0,
  0,
  0,
  Field_sae_Slot_ae_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_immls64_Slot_ae_slot0_get,
  Field_ae_fld_immls64pos_Slot_ae_slot0_get,
  Field_ae_fld_immls32_Slot_ae_slot0_get,
  Field_ae_fld_immls16_Slot_ae_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_ls_v_Slot_ae_slot0_get,
  Field_ae_fld_ls_uu_Slot_ae_slot0_get,
  Field_ae_fld_ls_su_Slot_ae_slot0_get,
  Field_ae_fld_ls_av_Slot_ae_slot0_get,
  Field_ae_fld_ls_v1_Slot_ae_slot0_get,
  0,
  0,
  0,
  0,
  Field_ae_fld_uu_v_Slot_ae_slot0_get,
  Field_ae_fld_uu_uu_Slot_ae_slot0_get,
  Field_ae_fld_dr_to_ar_v0_Slot_ae_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_to_dr_v_Slot_ae_slot0_get,
  Field_ae_fld_to_dr_v0_Slot_ae_slot0_get,
  0,
  0,
  Field_fld_ar_to_dr_imm_Slot_ae_slot0_get,
  0,
  0,
  0,
  Field_ae_fld_ar_to_dr_v_Slot_ae_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot0_19_12_Slot_ae_slot0_get,
  0,
  Field_fld_ae_slot0_19_16_Slot_ae_slot0_get,
  0,
  Field_fld_ae_slot0_19_17_Slot_ae_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot0_19_0_Slot_ae_slot0_get,
  0,
  0,
  Field_fld_ae_slot0_7_4_Slot_ae_slot0_get,
  Field_fld_ae_slot0_11_8_Slot_ae_slot0_get,
  0,
  Field_fld_ae_slot0_19_7_Slot_ae_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot0_5_4_Slot_ae_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot0_6_5_Slot_ae_slot0_get,
  Field_fld_ae_slot0_19_14_Slot_ae_slot0_get,
  Field_fld_ae_slot0_7_7_Slot_ae_slot0_get,
  0,
  0,
  Field_fld_ae_slot0_4_4_Slot_ae_slot0_get,
  0,
  Field_fld_ae_slot0_4_2_Slot_ae_slot0_get,
  0,
  Field_fld_ae_slot0_4_0_Slot_ae_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_ae_slot0_set_field_fns[] = {
  Field_t_Slot_ae_slot0_set,
  0,
  0,
  0,
  Field_imm8_Slot_ae_slot0_set,
  Field_s_Slot_ae_slot0_set,
  Field_imm12b_Slot_ae_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_op2_Slot_ae_slot0_set,
  Field_r_Slot_ae_slot0_set,
  0,
  0,
  0,
  0,
  Field_sae_Slot_ae_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_immls64_Slot_ae_slot0_set,
  Field_ae_fld_immls64pos_Slot_ae_slot0_set,
  Field_ae_fld_immls32_Slot_ae_slot0_set,
  Field_ae_fld_immls16_Slot_ae_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_ls_v_Slot_ae_slot0_set,
  Field_ae_fld_ls_uu_Slot_ae_slot0_set,
  Field_ae_fld_ls_su_Slot_ae_slot0_set,
  Field_ae_fld_ls_av_Slot_ae_slot0_set,
  Field_ae_fld_ls_v1_Slot_ae_slot0_set,
  0,
  0,
  0,
  0,
  Field_ae_fld_uu_v_Slot_ae_slot0_set,
  Field_ae_fld_uu_uu_Slot_ae_slot0_set,
  Field_ae_fld_dr_to_ar_v0_Slot_ae_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_to_dr_v_Slot_ae_slot0_set,
  Field_ae_fld_to_dr_v0_Slot_ae_slot0_set,
  0,
  0,
  Field_fld_ar_to_dr_imm_Slot_ae_slot0_set,
  0,
  0,
  0,
  Field_ae_fld_ar_to_dr_v_Slot_ae_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot0_19_12_Slot_ae_slot0_set,
  0,
  Field_fld_ae_slot0_19_16_Slot_ae_slot0_set,
  0,
  Field_fld_ae_slot0_19_17_Slot_ae_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot0_19_0_Slot_ae_slot0_set,
  0,
  0,
  Field_fld_ae_slot0_7_4_Slot_ae_slot0_set,
  Field_fld_ae_slot0_11_8_Slot_ae_slot0_set,
  0,
  Field_fld_ae_slot0_19_7_Slot_ae_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot0_5_4_Slot_ae_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot0_6_5_Slot_ae_slot0_set,
  Field_fld_ae_slot0_19_14_Slot_ae_slot0_set,
  Field_fld_ae_slot0_7_7_Slot_ae_slot0_set,
  0,
  0,
  Field_fld_ae_slot0_4_4_Slot_ae_slot0_set,
  0,
  Field_fld_ae_slot0_4_2_Slot_ae_slot0_set,
  0,
  Field_fld_ae_slot0_4_0_Slot_ae_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_get_field_fn
Slot_ae_slot2_1_get_field_fns[] = {
  Field_t_Slot_ae_slot2_1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_r_Slot_ae_slot2_1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_t2_Slot_ae_slot2_1_get,
  0,
  Field_r2_Slot_ae_slot2_1_get,
  Field_t4_Slot_ae_slot2_1_get,
  0,
  Field_r4_Slot_ae_slot2_1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_cmpp_v0_Slot_ae_slot2_1_get,
  Field_ae_fld_cmpp_v1_Slot_ae_slot2_1_get,
  Field_ae_fld_cmpp_v_Slot_ae_slot2_1_get,
  0,
  0,
  0,
  Field_ae_fld_cmov_v_Slot_ae_slot2_1_get,
  Field_ae_fld_cmov_v0_Slot_ae_slot2_1_get,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_dr_to_dr_v_Slot_ae_slot2_1_get,
  Field_ae_fld_dr_to_dr_v0_Slot_ae_slot2_1_get,
  Field_ae_fld_dr_to_dr_v1_Slot_ae_slot2_1_get,
  Field_ae_fld_to_dr_v_Slot_ae_slot2_1_get,
  Field_ae_fld_to_dr_v0_Slot_ae_slot2_1_get,
  Field_ae_fld_selimm_Slot_ae_slot2_1_get,
  0,
  Field_fld_ar_to_dr_imm_Slot_ae_slot2_1_get,
  Field_ae_fld_arth_v_Slot_ae_slot2_1_get,
  Field_ae_fld_arth_v0_Slot_ae_slot2_1_get,
  Field_ae_fld_arth_v1_Slot_ae_slot2_1_get,
  Field_ae_fld_ar_to_dr_v_Slot_ae_slot2_1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot2_1_18_0_Slot_ae_slot2_1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot2_1_9_8_Slot_ae_slot2_1_get,
  0,
  Field_fld_ae_slot2_1_7_4_Slot_ae_slot2_1_get,
  Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_get,
  Field_fld_ae_slot2_1_1_0_Slot_ae_slot2_1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot2_1_18_16_Slot_ae_slot2_1_get,
  0,
  Field_fld_ae_slot2_1_0_0_Slot_ae_slot2_1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot2_1_8_8_Slot_ae_slot2_1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_ae_slot2_1_set_field_fns[] = {
  Field_t_Slot_ae_slot2_1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_r_Slot_ae_slot2_1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_t2_Slot_ae_slot2_1_set,
  0,
  Field_r2_Slot_ae_slot2_1_set,
  Field_t4_Slot_ae_slot2_1_set,
  0,
  Field_r4_Slot_ae_slot2_1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_cmpp_v0_Slot_ae_slot2_1_set,
  Field_ae_fld_cmpp_v1_Slot_ae_slot2_1_set,
  Field_ae_fld_cmpp_v_Slot_ae_slot2_1_set,
  0,
  0,
  0,
  Field_ae_fld_cmov_v_Slot_ae_slot2_1_set,
  Field_ae_fld_cmov_v0_Slot_ae_slot2_1_set,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_dr_to_dr_v_Slot_ae_slot2_1_set,
  Field_ae_fld_dr_to_dr_v0_Slot_ae_slot2_1_set,
  Field_ae_fld_dr_to_dr_v1_Slot_ae_slot2_1_set,
  Field_ae_fld_to_dr_v_Slot_ae_slot2_1_set,
  Field_ae_fld_to_dr_v0_Slot_ae_slot2_1_set,
  Field_ae_fld_selimm_Slot_ae_slot2_1_set,
  0,
  Field_fld_ar_to_dr_imm_Slot_ae_slot2_1_set,
  Field_ae_fld_arth_v_Slot_ae_slot2_1_set,
  Field_ae_fld_arth_v0_Slot_ae_slot2_1_set,
  Field_ae_fld_arth_v1_Slot_ae_slot2_1_set,
  Field_ae_fld_ar_to_dr_v_Slot_ae_slot2_1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot2_1_18_0_Slot_ae_slot2_1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot2_1_9_8_Slot_ae_slot2_1_set,
  0,
  Field_fld_ae_slot2_1_7_4_Slot_ae_slot2_1_set,
  Field_fld_ae_slot2_1_18_12_Slot_ae_slot2_1_set,
  Field_fld_ae_slot2_1_1_0_Slot_ae_slot2_1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot2_1_18_8_Slot_ae_slot2_1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot2_1_18_16_Slot_ae_slot2_1_set,
  0,
  Field_fld_ae_slot2_1_0_0_Slot_ae_slot2_1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_slot2_1_8_8_Slot_ae_slot2_1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_get_field_fn
Slot_ae2_slot1_get_field_fns[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_imm2_Slot_ae2_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_mul_d0_Slot_ae2_slot1_get,
  Field_ae_fld_mul_d1_Slot_ae2_slot1_get,
  Field_ae_fld_mul_q0_Slot_ae2_slot1_get,
  0,
  0,
  0,
  Field_ae_fld_mul_x4_d2_Slot_ae2_slot1_get,
  Field_ae_fld_mul_x4_q1_Slot_ae2_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_pks_d_Slot_ae2_slot1_get,
  Field_ae_fld_pks_s_Slot_ae2_slot1_get,
  0,
  0,
  0,
  Field_ae_fld_dr_to_dr_v_Slot_ae2_slot1_get,
  Field_ae_fld_dr_to_dr_v0_Slot_ae2_slot1_get,
  Field_ae_fld_dr_to_dr_v1_Slot_ae2_slot1_get,
  Field_ae_fld_to_dr_v_Slot_ae2_slot1_get,
  Field_ae_fld_to_dr_v0_Slot_ae2_slot1_get,
  Field_ae_fld_selimm_Slot_ae2_slot1_get,
  0,
  Field_fld_ar_to_dr_imm_Slot_ae2_slot1_get,
  Field_ae_fld_arth_v_Slot_ae2_slot1_get,
  Field_ae_fld_arth_v0_Slot_ae2_slot1_get,
  Field_ae_fld_arth_v1_Slot_ae2_slot1_get,
  Field_ae_fld_ar_to_dr_v_Slot_ae2_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot1_23_0_Slot_ae2_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_get,
  0,
  0,
  Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_get,
  Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_get,
  0,
  Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot1_13_11_Slot_ae2_slot1_get,
  0,
  0,
  0,
  Field_fld_ae2_slot1_7_7_Slot_ae2_slot1_get,
  Field_fld_ae2_slot1_18_16_Slot_ae2_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot1_1_0_Slot_ae2_slot1_get,
  Field_fld_ae2_slot1_7_3_Slot_ae2_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot1_7_6_Slot_ae2_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_ae2_slot1_set_field_fns[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_imm2_Slot_ae2_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_mul_d0_Slot_ae2_slot1_set,
  Field_ae_fld_mul_d1_Slot_ae2_slot1_set,
  Field_ae_fld_mul_q0_Slot_ae2_slot1_set,
  0,
  0,
  0,
  Field_ae_fld_mul_x4_d2_Slot_ae2_slot1_set,
  Field_ae_fld_mul_x4_q1_Slot_ae2_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_pks_d_Slot_ae2_slot1_set,
  Field_ae_fld_pks_s_Slot_ae2_slot1_set,
  0,
  0,
  0,
  Field_ae_fld_dr_to_dr_v_Slot_ae2_slot1_set,
  Field_ae_fld_dr_to_dr_v0_Slot_ae2_slot1_set,
  Field_ae_fld_dr_to_dr_v1_Slot_ae2_slot1_set,
  Field_ae_fld_to_dr_v_Slot_ae2_slot1_set,
  Field_ae_fld_to_dr_v0_Slot_ae2_slot1_set,
  Field_ae_fld_selimm_Slot_ae2_slot1_set,
  0,
  Field_fld_ar_to_dr_imm_Slot_ae2_slot1_set,
  Field_ae_fld_arth_v_Slot_ae2_slot1_set,
  Field_ae_fld_arth_v0_Slot_ae2_slot1_set,
  Field_ae_fld_arth_v1_Slot_ae2_slot1_set,
  Field_ae_fld_ar_to_dr_v_Slot_ae2_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot1_23_0_Slot_ae2_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot1_7_4_Slot_ae2_slot1_set,
  0,
  0,
  Field_fld_ae2_slot1_23_16_Slot_ae2_slot1_set,
  Field_fld_ae2_slot1_23_20_Slot_ae2_slot1_set,
  0,
  Field_fld_ae2_slot1_11_4_Slot_ae2_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot1_13_11_Slot_ae2_slot1_set,
  0,
  0,
  0,
  Field_fld_ae2_slot1_7_7_Slot_ae2_slot1_set,
  Field_fld_ae2_slot1_18_16_Slot_ae2_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot1_1_0_Slot_ae2_slot1_set,
  Field_fld_ae2_slot1_7_3_Slot_ae2_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot1_7_6_Slot_ae2_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_get_field_fn
Slot_ae2_slot0_get_field_fns[] = {
  Field_t_Slot_ae2_slot0_get,
  0,
  Field_bbi_Slot_ae2_slot0_get,
  0,
  Field_imm8_Slot_ae2_slot0_get,
  Field_s_Slot_ae2_slot0_get,
  Field_imm12b_Slot_ae2_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_op2_Slot_ae2_slot0_get,
  Field_r_Slot_ae2_slot0_get,
  0,
  0,
  0,
  0,
  Field_sae_Slot_ae2_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_t2_Slot_ae2_slot0_get,
  0,
  Field_r2_Slot_ae2_slot0_get,
  Field_t4_Slot_ae2_slot0_get,
  0,
  Field_r4_Slot_ae2_slot0_get,
  0,
  0,
  0,
  0,
  Field_xt_wbr18_imm_Slot_ae2_slot0_get,
  0,
  0,
  Field_ae_fld_tp7_Slot_ae2_slot0_get,
  Field_ae_fld_osa32_Slot_ae2_slot0_get,
  Field_ae_fld_osa64_Slot_ae2_slot0_get,
  0,
  Field_ae_fld_immls64_Slot_ae2_slot0_get,
  Field_ae_fld_immls64pos_Slot_ae2_slot0_get,
  Field_ae_fld_immls32_Slot_ae2_slot0_get,
  Field_ae_fld_immls16_Slot_ae2_slot0_get,
  Field_ae_fld_osa16_Slot_ae2_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_ls_v_Slot_ae2_slot0_get,
  Field_ae_fld_ls_uu_Slot_ae2_slot0_get,
  Field_ae_fld_ls_su_Slot_ae2_slot0_get,
  Field_ae_fld_ls_av_Slot_ae2_slot0_get,
  Field_ae_fld_ls_v1_Slot_ae2_slot0_get,
  Field_ae_fld_ls_v2_Slot_ae2_slot0_get,
  Field_ae_fld_cmpp_v0_Slot_ae2_slot0_get,
  Field_ae_fld_cmpp_v1_Slot_ae2_slot0_get,
  Field_ae_fld_cmpp_v_Slot_ae2_slot0_get,
  Field_ae_fld_uu_v_Slot_ae2_slot0_get,
  Field_ae_fld_uu_uu_Slot_ae2_slot0_get,
  Field_ae_fld_dr_to_ar_v0_Slot_ae2_slot0_get,
  Field_ae_fld_cmov_v_Slot_ae2_slot0_get,
  Field_ae_fld_cmov_v0_Slot_ae2_slot0_get,
  0,
  0,
  Field_ae_fld_shift_d_Slot_ae2_slot0_get,
  Field_ae_fld_shift_d0_Slot_ae2_slot0_get,
  Field_ae_fld_shift_sd_Slot_ae2_slot0_get,
  Field_ae_fld_dr_to_dr_v_Slot_ae2_slot0_get,
  Field_ae_fld_dr_to_dr_v0_Slot_ae2_slot0_get,
  Field_ae_fld_dr_to_dr_v1_Slot_ae2_slot0_get,
  Field_ae_fld_to_dr_v_Slot_ae2_slot0_get,
  Field_ae_fld_to_dr_v0_Slot_ae2_slot0_get,
  Field_ae_fld_selimm_Slot_ae2_slot0_get,
  0,
  Field_fld_ar_to_dr_imm_Slot_ae2_slot0_get,
  Field_ae_fld_arth_v_Slot_ae2_slot0_get,
  Field_ae_fld_arth_v0_Slot_ae2_slot0_get,
  Field_ae_fld_arth_v1_Slot_ae2_slot0_get,
  Field_ae_fld_ar_to_dr_v_Slot_ae2_slot0_get,
  Field_fld_ae2_slot0_11_4_Slot_ae2_slot0_get,
  Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_get,
  Field_fld_ae2_slot0_9_8_Slot_ae2_slot0_get,
  Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_get,
  Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_get,
  Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_get,
  Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_get,
  0,
  0,
  0,
  Field_fld_ae2_slot0_31_17_Slot_ae2_slot0_get,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot0_6_0_Slot_ae2_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_get,
  0,
  0,
  0,
  Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot0_8_8_Slot_ae2_slot0_get,
  0,
  0,
  Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_get,
  Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_get,
  0,
  0,
  0,
  Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_get,
  Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_get,
  0,
  Field_fld_ae2_slot0_4_2_Slot_ae2_slot0_get,
  0,
  Field_fld_ae2_slot0_4_0_Slot_ae2_slot0_get,
  0,
  0,
  Field_fld_ae2_slot0_5_4_Slot_ae2_slot0_get,
  Field_fld_ae2_slot0_14_12_Slot_ae2_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot0_1_0_Slot_ae2_slot0_get,
  0,
  Field_fld_ae2_slot0_0_0_Slot_ae2_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_ae2_slot0_set_field_fns[] = {
  Field_t_Slot_ae2_slot0_set,
  0,
  Field_bbi_Slot_ae2_slot0_set,
  0,
  Field_imm8_Slot_ae2_slot0_set,
  Field_s_Slot_ae2_slot0_set,
  Field_imm12b_Slot_ae2_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_op2_Slot_ae2_slot0_set,
  Field_r_Slot_ae2_slot0_set,
  0,
  0,
  0,
  0,
  Field_sae_Slot_ae2_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_t2_Slot_ae2_slot0_set,
  0,
  Field_r2_Slot_ae2_slot0_set,
  Field_t4_Slot_ae2_slot0_set,
  0,
  Field_r4_Slot_ae2_slot0_set,
  0,
  0,
  0,
  0,
  Field_xt_wbr18_imm_Slot_ae2_slot0_set,
  0,
  0,
  Field_ae_fld_tp7_Slot_ae2_slot0_set,
  Field_ae_fld_osa32_Slot_ae2_slot0_set,
  Field_ae_fld_osa64_Slot_ae2_slot0_set,
  0,
  Field_ae_fld_immls64_Slot_ae2_slot0_set,
  Field_ae_fld_immls64pos_Slot_ae2_slot0_set,
  Field_ae_fld_immls32_Slot_ae2_slot0_set,
  Field_ae_fld_immls16_Slot_ae2_slot0_set,
  Field_ae_fld_osa16_Slot_ae2_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_ls_v_Slot_ae2_slot0_set,
  Field_ae_fld_ls_uu_Slot_ae2_slot0_set,
  Field_ae_fld_ls_su_Slot_ae2_slot0_set,
  Field_ae_fld_ls_av_Slot_ae2_slot0_set,
  Field_ae_fld_ls_v1_Slot_ae2_slot0_set,
  Field_ae_fld_ls_v2_Slot_ae2_slot0_set,
  Field_ae_fld_cmpp_v0_Slot_ae2_slot0_set,
  Field_ae_fld_cmpp_v1_Slot_ae2_slot0_set,
  Field_ae_fld_cmpp_v_Slot_ae2_slot0_set,
  Field_ae_fld_uu_v_Slot_ae2_slot0_set,
  Field_ae_fld_uu_uu_Slot_ae2_slot0_set,
  Field_ae_fld_dr_to_ar_v0_Slot_ae2_slot0_set,
  Field_ae_fld_cmov_v_Slot_ae2_slot0_set,
  Field_ae_fld_cmov_v0_Slot_ae2_slot0_set,
  0,
  0,
  Field_ae_fld_shift_d_Slot_ae2_slot0_set,
  Field_ae_fld_shift_d0_Slot_ae2_slot0_set,
  Field_ae_fld_shift_sd_Slot_ae2_slot0_set,
  Field_ae_fld_dr_to_dr_v_Slot_ae2_slot0_set,
  Field_ae_fld_dr_to_dr_v0_Slot_ae2_slot0_set,
  Field_ae_fld_dr_to_dr_v1_Slot_ae2_slot0_set,
  Field_ae_fld_to_dr_v_Slot_ae2_slot0_set,
  Field_ae_fld_to_dr_v0_Slot_ae2_slot0_set,
  Field_ae_fld_selimm_Slot_ae2_slot0_set,
  0,
  Field_fld_ar_to_dr_imm_Slot_ae2_slot0_set,
  Field_ae_fld_arth_v_Slot_ae2_slot0_set,
  Field_ae_fld_arth_v0_Slot_ae2_slot0_set,
  Field_ae_fld_arth_v1_Slot_ae2_slot0_set,
  Field_ae_fld_ar_to_dr_v_Slot_ae2_slot0_set,
  Field_fld_ae2_slot0_11_4_Slot_ae2_slot0_set,
  Field_fld_ae2_slot0_7_4_Slot_ae2_slot0_set,
  Field_fld_ae2_slot0_9_8_Slot_ae2_slot0_set,
  Field_fld_ae2_slot0_11_11_Slot_ae2_slot0_set,
  Field_fld_ae2_slot0_31_30_Slot_ae2_slot0_set,
  Field_fld_ae2_slot0_11_8_Slot_ae2_slot0_set,
  Field_fld_ae2_slot0_31_12_Slot_ae2_slot0_set,
  0,
  0,
  0,
  Field_fld_ae2_slot0_31_17_Slot_ae2_slot0_set,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot0_6_0_Slot_ae2_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot0_31_7_Slot_ae2_slot0_set,
  0,
  0,
  0,
  Field_fld_ae2_slot0_31_16_Slot_ae2_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot0_3_0_Slot_ae2_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot0_8_8_Slot_ae2_slot0_set,
  0,
  0,
  Field_fld_ae2_slot0_6_4_Slot_ae2_slot0_set,
  Field_fld_ae2_slot0_31_15_Slot_ae2_slot0_set,
  0,
  0,
  0,
  Field_fld_ae2_slot0_4_4_Slot_ae2_slot0_set,
  Field_fld_ae2_slot0_7_7_Slot_ae2_slot0_set,
  0,
  Field_fld_ae2_slot0_4_2_Slot_ae2_slot0_set,
  0,
  Field_fld_ae2_slot0_4_0_Slot_ae2_slot0_set,
  0,
  0,
  Field_fld_ae2_slot0_5_4_Slot_ae2_slot0_set,
  Field_fld_ae2_slot0_14_12_Slot_ae2_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae2_slot0_1_0_Slot_ae2_slot0_set,
  0,
  Field_fld_ae2_slot0_0_0_Slot_ae2_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_get_field_fn
Slot_ae_minislot2_get_field_fns[] = {
  Field_t_Slot_ae_minislot2_get,
  0,
  0,
  0,
  Field_imm8_Slot_ae_minislot2_get,
  Field_s_Slot_ae_minislot2_get,
  Field_imm12b_Slot_ae_minislot2_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_r_Slot_ae_minislot2_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_dr_to_ar_v0_Slot_ae_minislot2_get,
  0,
  0,
  0,
  0,
  Field_ae_fld_shift_d_Slot_ae_minislot2_get,
  Field_ae_fld_shift_d0_Slot_ae_minislot2_get,
  Field_ae_fld_shift_sd_Slot_ae_minislot2_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ar_to_dr_imm_Slot_ae_minislot2_get,
  0,
  0,
  0,
  Field_ae_fld_ar_to_dr_v_Slot_ae_minislot2_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_get,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot2_18_0_Slot_ae_minislot2_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot2_11_4_Slot_ae_minislot2_get,
  0,
  Field_fld_ae_minislot2_3_0_Slot_ae_minislot2_get,
  Field_fld_ae_minislot2_9_8_Slot_ae_minislot2_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot2_18_8_Slot_ae_minislot2_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_ae_minislot2_set_field_fns[] = {
  Field_t_Slot_ae_minislot2_set,
  0,
  0,
  0,
  Field_imm8_Slot_ae_minislot2_set,
  Field_s_Slot_ae_minislot2_set,
  Field_imm12b_Slot_ae_minislot2_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_r_Slot_ae_minislot2_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_dr_to_ar_v0_Slot_ae_minislot2_set,
  0,
  0,
  0,
  0,
  Field_ae_fld_shift_d_Slot_ae_minislot2_set,
  Field_ae_fld_shift_d0_Slot_ae_minislot2_set,
  Field_ae_fld_shift_sd_Slot_ae_minislot2_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ar_to_dr_imm_Slot_ae_minislot2_set,
  0,
  0,
  0,
  Field_ae_fld_ar_to_dr_v_Slot_ae_minislot2_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot2_18_16_Slot_ae_minislot2_set,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot2_18_0_Slot_ae_minislot2_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot2_11_4_Slot_ae_minislot2_set,
  0,
  Field_fld_ae_minislot2_3_0_Slot_ae_minislot2_set,
  Field_fld_ae_minislot2_9_8_Slot_ae_minislot2_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot2_18_8_Slot_ae_minislot2_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot2_11_8_Slot_ae_minislot2_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_get_field_fn
Slot_ae_minislot1_get_field_fns[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot1_0_0_Slot_ae_minislot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_ae_minislot1_set_field_fns[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot1_0_0_Slot_ae_minislot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_get_field_fn
Slot_ae_minislot0_get_field_fns[] = {
  0,
  0,
  0,
  0,
  0,
  Field_s_Slot_ae_minislot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_immls64_Slot_ae_minislot0_get,
  0,
  Field_ae_fld_immls32_Slot_ae_minislot0_get,
  Field_ae_fld_immls16_Slot_ae_minislot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_ls_v_Slot_ae_minislot0_get,
  0,
  0,
  0,
  Field_ae_fld_ls_v1_Slot_ae_minislot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ar_to_dr_imm_Slot_ae_minislot0_get,
  0,
  0,
  0,
  Field_ae_fld_ar_to_dr_v_Slot_ae_minislot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot0_16_0_Slot_ae_minislot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot0_16_10_Slot_ae_minislot0_get,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot0_16_8_Slot_ae_minislot0_get,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_ae_minislot0_set_field_fns[] = {
  0,
  0,
  0,
  0,
  0,
  Field_s_Slot_ae_minislot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_immls64_Slot_ae_minislot0_set,
  0,
  Field_ae_fld_immls32_Slot_ae_minislot0_set,
  Field_ae_fld_immls16_Slot_ae_minislot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_ae_fld_ls_v_Slot_ae_minislot0_set,
  0,
  0,
  0,
  Field_ae_fld_ls_v1_Slot_ae_minislot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ar_to_dr_imm_Slot_ae_minislot0_set,
  0,
  0,
  0,
  Field_ae_fld_ar_to_dr_v_Slot_ae_minislot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot0_16_0_Slot_ae_minislot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot0_16_10_Slot_ae_minislot0_set,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot0_16_8_Slot_ae_minislot0_set,
  0,
  0,
  0,
  0,
  0,
  Field_fld_ae_minislot0_16_12_Slot_ae_minislot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_get_field_fn
Slot_xt_flix64_slot2_get_field_fns[] = {
  Field_t_Slot_xt_flix64_slot2_get,
  0,
  0,
  0,
  0,
  Field_s_Slot_xt_flix64_slot2_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_r_Slot_xt_flix64_slot2_get,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_sargt_Slot_xt_flix64_slot2_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_imm7_Slot_xt_flix64_slot2_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot2_15_8_Slot_xt_flix64_slot2_get,
  Field_fld_xt_flix64_slot2_3_3_Slot_xt_flix64_slot2_get,
  0,
  Field_fld_xt_flix64_slot2_7_4_Slot_xt_flix64_slot2_get,
  0,
  0,
  Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot2_15_0_Slot_xt_flix64_slot2_get,
  0,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot2_15_13_Slot_xt_flix64_slot2_get,
  0,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_xt_flix64_slot2_set_field_fns[] = {
  Field_t_Slot_xt_flix64_slot2_set,
  0,
  0,
  0,
  0,
  Field_s_Slot_xt_flix64_slot2_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_r_Slot_xt_flix64_slot2_set,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_sargt_Slot_xt_flix64_slot2_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_imm7_Slot_xt_flix64_slot2_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot2_15_8_Slot_xt_flix64_slot2_set,
  Field_fld_xt_flix64_slot2_3_3_Slot_xt_flix64_slot2_set,
  0,
  Field_fld_xt_flix64_slot2_7_4_Slot_xt_flix64_slot2_set,
  0,
  0,
  Field_fld_xt_flix64_slot2_15_12_Slot_xt_flix64_slot2_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot2_15_0_Slot_xt_flix64_slot2_set,
  0,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot2_15_13_Slot_xt_flix64_slot2_set,
  0,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_get_field_fn
Slot_xt_dummy_get_field_fns[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_xt_dummy_0_0_Slot_xt_dummy_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_xt_dummy_set_field_fns[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_xt_dummy_0_0_Slot_xt_dummy_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_get_field_fn
Slot_xt_flix64_slot1_get_field_fns[] = {
  Field_t_Slot_xt_flix64_slot1_get,
  0,
  0,
  0,
  Field_imm8_Slot_xt_flix64_slot1_get,
  Field_s_Slot_xt_flix64_slot1_get,
  Field_imm12b_Slot_xt_flix64_slot1_get,
  0,
  0,
  0,
  Field_offset_Slot_xt_flix64_slot1_get,
  0,
  0,
  Field_op2_Slot_xt_flix64_slot1_get,
  Field_r_Slot_xt_flix64_slot1_get,
  0,
  0,
  0,
  0,
  Field_sae_Slot_xt_flix64_slot1_get,
  Field_sal_Slot_xt_flix64_slot1_get,
  Field_sargt_Slot_xt_flix64_slot1_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot1_19_8_Slot_xt_flix64_slot1_get,
  0,
  0,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_get,
  0,
  0,
  Field_fld_xt_flix64_slot1_19_16_Slot_xt_flix64_slot1_get,
  0,
  Field_fld_xt_flix64_slot1_19_17_Slot_xt_flix64_slot1_get,
  Field_fld_xt_flix64_slot1_19_18_Slot_xt_flix64_slot1_get,
  0,
  Field_fld_xt_flix64_slot1_7_4_Slot_xt_flix64_slot1_get,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot1_19_0_Slot_xt_flix64_slot1_get,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot1_3_0_Slot_xt_flix64_slot1_get,
  0,
  Field_fld_xt_flix64_slot1_19_13_Slot_xt_flix64_slot1_get,
  0,
  0,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_xt_flix64_slot1_set_field_fns[] = {
  Field_t_Slot_xt_flix64_slot1_set,
  0,
  0,
  0,
  Field_imm8_Slot_xt_flix64_slot1_set,
  Field_s_Slot_xt_flix64_slot1_set,
  Field_imm12b_Slot_xt_flix64_slot1_set,
  0,
  0,
  0,
  Field_offset_Slot_xt_flix64_slot1_set,
  0,
  0,
  Field_op2_Slot_xt_flix64_slot1_set,
  Field_r_Slot_xt_flix64_slot1_set,
  0,
  0,
  0,
  0,
  Field_sae_Slot_xt_flix64_slot1_set,
  Field_sal_Slot_xt_flix64_slot1_set,
  Field_sargt_Slot_xt_flix64_slot1_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot1_19_8_Slot_xt_flix64_slot1_set,
  0,
  0,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot1_19_12_Slot_xt_flix64_slot1_set,
  0,
  0,
  Field_fld_xt_flix64_slot1_19_16_Slot_xt_flix64_slot1_set,
  0,
  Field_fld_xt_flix64_slot1_19_17_Slot_xt_flix64_slot1_set,
  Field_fld_xt_flix64_slot1_19_18_Slot_xt_flix64_slot1_set,
  0,
  Field_fld_xt_flix64_slot1_7_4_Slot_xt_flix64_slot1_set,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot1_19_0_Slot_xt_flix64_slot1_set,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot1_3_0_Slot_xt_flix64_slot1_set,
  0,
  Field_fld_xt_flix64_slot1_19_13_Slot_xt_flix64_slot1_set,
  0,
  0,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_get_field_fn
Slot_xt_flix64_slot0_get_field_fns[] = {
  Field_t_Slot_xt_flix64_slot0_get,
  0,
  0,
  0,
  Field_imm8_Slot_xt_flix64_slot0_get,
  Field_s_Slot_xt_flix64_slot0_get,
  Field_imm12b_Slot_xt_flix64_slot0_get,
  Field_imm16_Slot_xt_flix64_slot0_get,
  0,
  0,
  0,
  0,
  0,
  Field_op2_Slot_xt_flix64_slot0_get,
  Field_r_Slot_xt_flix64_slot0_get,
  0,
  0,
  0,
  0,
  Field_sae_Slot_xt_flix64_slot0_get,
  Field_sal_Slot_xt_flix64_slot0_get,
  Field_sargt_Slot_xt_flix64_slot0_get,
  0,
  Field_sas_Slot_xt_flix64_slot0_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot0_20_8_Slot_xt_flix64_slot0_get,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot0_7_4_Slot_xt_flix64_slot0_get,
  0,
  Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_get,
  0,
  0,
  Field_fld_xt_flix64_slot0_20_16_Slot_xt_flix64_slot0_get,
  0,
  Field_fld_xt_flix64_slot0_20_17_Slot_xt_flix64_slot0_get,
  0,
  0,
  Field_fld_xt_flix64_slot0_20_20_Slot_xt_flix64_slot0_get,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot0_20_0_Slot_xt_flix64_slot0_get,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot0_3_0_Slot_xt_flix64_slot0_get,
  0,
  Field_fld_xt_flix64_slot0_20_13_Slot_xt_flix64_slot0_get,
  0,
  0,
  Field_fld_xt_flix64_slot0_20_5_Slot_xt_flix64_slot0_get,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_xt_flix64_slot0_set_field_fns[] = {
  Field_t_Slot_xt_flix64_slot0_set,
  0,
  0,
  0,
  Field_imm8_Slot_xt_flix64_slot0_set,
  Field_s_Slot_xt_flix64_slot0_set,
  Field_imm12b_Slot_xt_flix64_slot0_set,
  Field_imm16_Slot_xt_flix64_slot0_set,
  0,
  0,
  0,
  0,
  0,
  Field_op2_Slot_xt_flix64_slot0_set,
  Field_r_Slot_xt_flix64_slot0_set,
  0,
  0,
  0,
  0,
  Field_sae_Slot_xt_flix64_slot0_set,
  Field_sal_Slot_xt_flix64_slot0_set,
  Field_sargt_Slot_xt_flix64_slot0_set,
  0,
  Field_sas_Slot_xt_flix64_slot0_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot0_20_8_Slot_xt_flix64_slot0_set,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot0_7_4_Slot_xt_flix64_slot0_set,
  0,
  Field_fld_xt_flix64_slot0_20_12_Slot_xt_flix64_slot0_set,
  0,
  0,
  Field_fld_xt_flix64_slot0_20_16_Slot_xt_flix64_slot0_set,
  0,
  Field_fld_xt_flix64_slot0_20_17_Slot_xt_flix64_slot0_set,
  0,
  0,
  Field_fld_xt_flix64_slot0_20_20_Slot_xt_flix64_slot0_set,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot0_20_0_Slot_xt_flix64_slot0_set,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot0_3_0_Slot_xt_flix64_slot0_set,
  0,
  Field_fld_xt_flix64_slot0_20_13_Slot_xt_flix64_slot0_set,
  0,
  0,
  Field_fld_xt_flix64_slot0_20_5_Slot_xt_flix64_slot0_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_get_field_fn
Slot_xt_flix64_slot3_get_field_fns[] = {
  Field_t_Slot_xt_flix64_slot3_get,
  0,
  Field_bbi_Slot_xt_flix64_slot3_get,
  0,
  0,
  Field_s_Slot_xt_flix64_slot3_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_r_Slot_xt_flix64_slot3_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_xt_wbr18_imm_Slot_xt_flix64_slot3_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot3_7_4_Slot_xt_flix64_slot3_get,
  Field_fld_xt_flix64_slot3_30_27_Slot_xt_flix64_slot3_get,
  Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot3_5_0_Slot_xt_flix64_slot3_get,
  Field_fld_xt_flix64_slot3_30_6_Slot_xt_flix64_slot3_get,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_ar0_get,
  Implicit_Field_ar4_get,
  Implicit_Field_ar8_get,
  Implicit_Field_ar12_get,
  Implicit_Field_bt16_get,
  Implicit_Field_bs16_get,
  Implicit_Field_br16_get,
  Implicit_Field_brall_get
};

static xtensa_set_field_fn
Slot_xt_flix64_slot3_set_field_fns[] = {
  Field_t_Slot_xt_flix64_slot3_set,
  0,
  Field_bbi_Slot_xt_flix64_slot3_set,
  0,
  0,
  Field_s_Slot_xt_flix64_slot3_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_r_Slot_xt_flix64_slot3_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_xt_wbr18_imm_Slot_xt_flix64_slot3_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot3_7_4_Slot_xt_flix64_slot3_set,
  Field_fld_xt_flix64_slot3_30_27_Slot_xt_flix64_slot3_set,
  Field_fld_xt_flix64_slot3_30_26_Slot_xt_flix64_slot3_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Field_fld_xt_flix64_slot3_5_0_Slot_xt_flix64_slot3_set,
  Field_fld_xt_flix64_slot3_30_6_Slot_xt_flix64_slot3_set,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set,
  Implicit_Field_set
};

static xtensa_slot_internal slots[] = {
  { "Inst", "x24", 0,
    Slot_x24_Format_inst_0_get, Slot_x24_Format_inst_0_set,
    Slot_inst_get_field_fns, Slot_inst_set_field_fns,
    Slot_inst_decode, "nop" },
  { "Inst16a", "x16a", 0,
    Slot_x16a_Format_inst16a_0_get, Slot_x16a_Format_inst16a_0_set,
    Slot_inst16a_get_field_fns, Slot_inst16a_set_field_fns,
    Slot_inst16a_decode, "" },
  { "Inst16b", "x16b", 0,
    Slot_x16b_Format_inst16b_0_get, Slot_x16b_Format_inst16b_0_set,
    Slot_inst16b_get_field_fns, Slot_inst16b_set_field_fns,
    Slot_inst16b_decode, "nop.n" },
  { "ae_slot2_0", "ae_format", 2,
    Slot_ae_format_Format_ae_slot2_0_20_get, Slot_ae_format_Format_ae_slot2_0_20_set,
    Slot_ae_slot2_0_get_field_fns, Slot_ae_slot2_0_set_field_fns,
    Slot_ae_slot2_0_decode, "nop" },
  { "ae_slot1", "ae_format", 1,
    Slot_ae_format_Format_ae_slot1_16_get, Slot_ae_format_Format_ae_slot1_16_set,
    Slot_ae_slot1_get_field_fns, Slot_ae_slot1_set_field_fns,
    Slot_ae_slot1_decode, "nop" },
  { "ae_slot1", "ae_format1", 1,
    Slot_ae_format1_Format_ae_slot1_16_get, Slot_ae_format1_Format_ae_slot1_16_set,
    Slot_ae_slot1_get_field_fns, Slot_ae_slot1_set_field_fns,
    Slot_ae_slot1_decode, "nop" },
  { "ae_slot0", "ae_format", 0,
    Slot_ae_format_Format_ae_slot0_4_get, Slot_ae_format_Format_ae_slot0_4_set,
    Slot_ae_slot0_get_field_fns, Slot_ae_slot0_set_field_fns,
    Slot_ae_slot0_decode, "nop" },
  { "ae_slot0", "ae_format1", 0,
    Slot_ae_format1_Format_ae_slot0_4_get, Slot_ae_format1_Format_ae_slot0_4_set,
    Slot_ae_slot0_get_field_fns, Slot_ae_slot0_set_field_fns,
    Slot_ae_slot0_decode, "nop" },
  { "ae_slot2_1", "ae_format1", 2,
    Slot_ae_format1_Format_ae_slot2_1_20_get, Slot_ae_format1_Format_ae_slot2_1_20_set,
    Slot_ae_slot2_1_get_field_fns, Slot_ae_slot2_1_set_field_fns,
    Slot_ae_slot2_1_decode, "nop" },
  { "ae2_slot1", "ae_format2", 1,
    Slot_ae_format2_Format_ae2_slot1_16_get, Slot_ae_format2_Format_ae2_slot1_16_set,
    Slot_ae2_slot1_get_field_fns, Slot_ae2_slot1_set_field_fns,
    Slot_ae2_slot1_decode, "nop" },
  { "ae2_slot0", "ae_format2", 0,
    Slot_ae_format2_Format_ae2_slot0_4_get, Slot_ae_format2_Format_ae2_slot0_4_set,
    Slot_ae2_slot0_get_field_fns, Slot_ae2_slot0_set_field_fns,
    Slot_ae2_slot0_decode, "nop" },
  { "ae_minislot2", "ae_mini0", 2,
    Slot_ae_mini0_Format_ae_minislot2_4_get, Slot_ae_mini0_Format_ae_minislot2_4_set,
    Slot_ae_minislot2_get_field_fns, Slot_ae_minislot2_set_field_fns,
    Slot_ae_minislot2_decode, "nop" },
  { "ae_minislot1", "ae_mini0", 1,
    Slot_ae_mini0_Format_ae_minislot1_33_get, Slot_ae_mini0_Format_ae_minislot1_33_set,
    Slot_ae_minislot1_get_field_fns, Slot_ae_minislot1_set_field_fns,
    Slot_ae_minislot1_decode, "nop" },
  { "ae_minislot0", "ae_mini0", 0,
    Slot_ae_mini0_Format_ae_minislot0_8_get, Slot_ae_mini0_Format_ae_minislot0_8_set,
    Slot_ae_minislot0_get_field_fns, Slot_ae_minislot0_set_field_fns,
    Slot_ae_minislot0_decode, "nop" },
  { "xt_flix64_slot2", "xt_format1", 3,
    Slot_xt_format1_Format_xt_flix64_slot2_20_get, Slot_xt_format1_Format_xt_flix64_slot2_20_set,
    Slot_xt_flix64_slot2_get_field_fns, Slot_xt_flix64_slot2_set_field_fns,
    Slot_xt_flix64_slot2_decode, "nop" },
  { "xt_dummy", "xt_format1", 2,
    Slot_xt_format1_Format_xt_dummy_57_get, Slot_xt_format1_Format_xt_dummy_57_set,
    Slot_xt_dummy_get_field_fns, Slot_xt_dummy_set_field_fns,
    Slot_xt_dummy_decode, "nop" },
  { "xt_flix64_slot1", "xt_format1", 1,
    Slot_xt_format1_Format_xt_flix64_slot1_16_get, Slot_xt_format1_Format_xt_flix64_slot1_16_set,
    Slot_xt_flix64_slot1_get_field_fns, Slot_xt_flix64_slot1_set_field_fns,
    Slot_xt_flix64_slot1_decode, "nop" },
  { "xt_flix64_slot0", "xt_format1", 0,
    Slot_xt_format1_Format_xt_flix64_slot0_4_get, Slot_xt_format1_Format_xt_flix64_slot0_4_set,
    Slot_xt_flix64_slot0_get_field_fns, Slot_xt_flix64_slot0_set_field_fns,
    Slot_xt_flix64_slot0_decode, "nop" },
  { "xt_flix64_slot0", "xt_format2", 0,
    Slot_xt_format2_Format_xt_flix64_slot0_4_get, Slot_xt_format2_Format_xt_flix64_slot0_4_set,
    Slot_xt_flix64_slot0_get_field_fns, Slot_xt_flix64_slot0_set_field_fns,
    Slot_xt_flix64_slot0_decode, "nop" },
  { "xt_flix64_slot3", "xt_format2", 1,
    Slot_xt_format2_Format_xt_flix64_slot3_16_get, Slot_xt_format2_Format_xt_flix64_slot3_16_set,
    Slot_xt_flix64_slot3_get_field_fns, Slot_xt_flix64_slot3_set_field_fns,
    Slot_xt_flix64_slot3_decode, "nop" }
};


/* Instruction formats.  */

static void
Format_x24_encode (xtensa_insnbuf insn)
{
  insn[0] = 0;
  insn[1] = 0;
}

static void
Format_x16a_encode (xtensa_insnbuf insn)
{
  insn[0] = 0x8;
  insn[1] = 0;
}

static void
Format_x16b_encode (xtensa_insnbuf insn)
{
  insn[0] = 0xc;
  insn[1] = 0;
}

static void
Format_ae_format_encode (xtensa_insnbuf insn)
{
  insn[0] = 0xf;
  insn[1] = 0;
}

static void
Format_ae_format1_encode (xtensa_insnbuf insn)
{
  insn[0] = 0xe;
  insn[1] = 0x80000000;
}

static void
Format_ae_format2_encode (xtensa_insnbuf insn)
{
  insn[0] = 0xe;
  insn[1] = 0;
}

static void
Format_ae_mini0_encode (xtensa_insnbuf insn)
{
  insn[0] = 0xe;
  insn[1] = 0x40000000;
}

static void
Format_xt_format1_encode (xtensa_insnbuf insn)
{
  insn[0] = 0xe;
  insn[1] = 0x20000000;
}

static void
Format_xt_format2_encode (xtensa_insnbuf insn)
{
  insn[0] = 0xe;
  insn[1] = 0x10000000;
}

static int Format_x24_slots[] = { 0 };

static int Format_x16a_slots[] = { 1 };

static int Format_x16b_slots[] = { 2 };

static int Format_ae_format_slots[] = { 6, 4, 3 };

static int Format_ae_format1_slots[] = { 7, 5, 8 };

static int Format_ae_format2_slots[] = { 10, 9 };

static int Format_ae_mini0_slots[] = { 11, 13, 12 };

static int Format_xt_format1_slots[] = { 17, 16, 14, 15 };

static int Format_xt_format2_slots[] = { 18, 19 };

static xtensa_format_internal formats[] = {
  { "x24", 3, Format_x24_encode, 1, Format_x24_slots },
  { "x16a", 2, Format_x16a_encode, 1, Format_x16a_slots },
  { "x16b", 2, Format_x16b_encode, 1, Format_x16b_slots },
  { "ae_format", 8, Format_ae_format_encode, 3, Format_ae_format_slots },
  { "ae_format1", 8, Format_ae_format1_encode, 3, Format_ae_format1_slots },
  { "ae_format2", 8, Format_ae_format2_encode, 2, Format_ae_format2_slots },
  { "ae_mini0", 8, Format_ae_mini0_encode, 3, Format_ae_mini0_slots },
  { "xt_format1", 8, Format_xt_format1_encode, 4, Format_xt_format1_slots },
  { "xt_format2", 8, Format_xt_format2_encode, 2, Format_xt_format2_slots }
};


static int
format_decoder (const xtensa_insnbuf insn)
{
  if ((insn[0] & 0x8) == 0 && (insn[1] & 0) == 0)
    return 0; /* x24 */
  if ((insn[0] & 0xc) == 0x8 && (insn[1] & 0) == 0)
    return 1; /* x16a */
  if ((insn[0] & 0xe) == 0xc && (insn[1] & 0) == 0)
    return 2; /* x16b */
  if ((insn[0] & 0xf) == 0xf && (insn[1] & 0) == 0)
    return 3; /* ae_format */
  if ((insn[0] & 0xf) == 0xe && (insn[1] & 0x80000000) == 0x80000000)
    return 4; /* ae_format1 */
  if ((insn[0] & 0xf) == 0xe && (insn[1] & 0xf0000000) == 0)
    return 5; /* ae_format2 */
  if ((insn[0] & 0xf) == 0xe && (insn[1] & 0xfffffe00) == 0x40000000)
    return 6; /* ae_mini0 */
  if ((insn[0] & 0xf) == 0xe && (insn[1] & 0xa0000000) == 0x20000000)
    return 7; /* xt_format1 */
  if ((insn[0] & 0xf) == 0xe && (insn[1] & 0xff000000) == 0x10000000)
    return 8; /* xt_format2 */
  return -1;
}

static int length_table[256] = {
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  2,
  2,
  2,
  2,
  2,
  2,
  8,
  8,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  2,
  2,
  2,
  2,
  2,
  2,
  8,
  8,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  2,
  2,
  2,
  2,
  2,
  2,
  8,
  8,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  2,
  2,
  2,
  2,
  2,
  2,
  8,
  8,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  2,
  2,
  2,
  2,
  2,
  2,
  8,
  8,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  2,
  2,
  2,
  2,
  2,
  2,
  8,
  8,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  2,
  2,
  2,
  2,
  2,
  2,
  8,
  8,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  2,
  2,
  2,
  2,
  2,
  2,
  8,
  8,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  2,
  2,
  2,
  2,
  2,
  2,
  8,
  8,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  2,
  2,
  2,
  2,
  2,
  2,
  8,
  8,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  2,
  2,
  2,
  2,
  2,
  2,
  8,
  8,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  2,
  2,
  2,
  2,
  2,
  2,
  8,
  8,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  2,
  2,
  2,
  2,
  2,
  2,
  8,
  8,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  2,
  2,
  2,
  2,
  2,
  2,
  8,
  8,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  2,
  2,
  2,
  2,
  2,
  2,
  8,
  8,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  2,
  2,
  2,
  2,
  2,
  2,
  8,
  8
};

static int
length_decoder (const unsigned char *insn)
{
  int l = insn[0];
  return length_table[l];
}


/* Top-level ISA structure.  */

xtensa_isa_internal xtensa_modules = {
  0 /* little-endian */,
  8 /* insn_size */, 0,
  9, formats, format_decoder, length_decoder,
  20, slots,
  229 /* num_fields */,
  335, operands,
  1273, iclasses,
  1368, opcodes, 0,
  9, regfiles,
  NUM_STATES, states, 0,
  NUM_SYSREGS, sysregs, 0,
  { MAX_SPECIAL_REG, MAX_USER_REG }, { 0, 0 },
  0, interfaces, 0,
  9, funcUnits, 0
};
